---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:2015-12-28;208
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20151230&codiceRedaz=15G00222&dataVigenza=20251104
dataGU: 20151230
codiceRedaz: 15G00222
dataVigenza: 20251104
---

# Disposizioni per la formazione del bilancio annuale e pluriennale dello Stato (legge di stabilita' 2016). (15G00222)

La Camera dei deputati ed il Senato della Repubblica hanno approvato;

IL PRESIDENTE DELLA REPUBBLICA

Promulga la seguente legge:

## Art. 1.

1. I livelli massimi del saldo netto da finanziare e del ricorso al mercato finanziario, in termini di competenza, di cui all'articolo 11, comma 3, lettera a), della legge 31 dicembre 2009, n. 196, per gli anni 2016, 2017 e 2018, sono indicati nell'allegato n. 1 annesso alla presente legge. I livelli del ricorso al mercato si intendono al netto delle operazioni effettuate al fine di rimborsare prima della scadenza o di ristrutturare passivita' preesistenti con ammortamento a carico dello Stato.

2. Nell'allegato n. 2 annesso alla presente legge e' indicato l'adeguamento degli importi dei trasferimenti dovuti dallo Stato, ai sensi rispettivamente dell'articolo 37, comma 3, lettera c), della legge 9 marzo 1989, n. 88, e successive modificazioni, dell'articolo 59, comma 34, della legge 27 dicembre 1997, n. 449, e successive modificazioni, e dell'articolo 2, comma 4, della legge 12 novembre 2011, n. 183, per l'anno 2016. I predetti importi sono ripartiti tra le gestioni interessate con il procedimento di cui all'articolo 14 della legge 7 agosto 1990, n. 241, e successive modificazioni.

3. Nell'allegato n. 2 annesso alla presente legge sono, inoltre, indicati gli importi complessivi dovuti per l'anno 2016 ai sensi dell'articolo 2, comma 4, della legge 12 novembre 2011, n. 183, nonche' gli importi che, prima del riparto tra le gestioni interessate, sono attribuiti:

- a) alla gestione per i coltivatori diretti, mezzadri e coloni a completamento dell'integrale assunzione a carico dello Stato dell'onere relativo ai trattamenti pensionistici liquidati anteriormente al 1° gennaio 1989;
- b) alla gestione speciale minatori;
- c) alla gestione speciale di previdenza e assistenza per i lavoratori dello spettacolo gia' iscritti al soppresso ENPALS.

4. Gli esperti contabili iscritti nella Sezione B Esperti contabili dell'Albo dei dottori commercialisti e degli esperti contabili, istituito ai sensi della legge 24 febbraio 2005, n. 34, e del decreto legislativo 28 giugno 2005, n. 139, che esercitano la libera professione con carattere di continuita', sono iscritti alla Cassa nazionale di previdenza ed assistenza a favore dei ragionieri e periti commerciali.

5. Il comma 430 dell'articolo 1 della legge 27 dicembre 2013, n. 147, e' abrogato.

6. Al comma 718 dell'articolo 1 della legge 23 dicembre 2014, n. 190, sono apportate le seguenti modifiche:

- a) alla lettera a), le parole: «di due punti percentuali a decorrere dal 1° gennaio 2016 e di un ulteriore punto percentuale dal 1° gennaio 2017» sono sostituite dalle seguenti: «di tre punti percentuali dal 1° gennaio 2017»;
- b) alla lettera b), le parole: «di due punti percentuali a decorrere dal 1° gennaio 2016, di un ulteriore punto percentuale dal 1° gennaio 2017 e di ulteriori 0,5 punti percentuali dal 1° gennaio 2018» sono sostituite dalle seguenti: «di due punti percentuali dal 1° gennaio 2017 e di un ulteriore punto percentuale dal 1° gennaio 2018»;
- c) alla lettera c), le parole: «700 milioni di euro per l'anno 2018» sono sostituite dalle seguenti: «350 milioni di euro per l'anno 2018».

7. Al comma 632 dell'articolo 1 della legge 23 dicembre 2014, n. 190, al terzo periodo, le parole da: «, con provvedimento del direttore dell'Agenzia delle dogane e dei monopoli» fino alla fine del periodo sono soppresse.

8. Il comma 4-bis dell'articolo 51 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e' abrogato.

9. Al fine di evitare un pregiudizio alla continuita' dell'azione amministrativa, ai dipendenti dell'Amministrazione economico-finanziaria, ivi incluse le Agenzie fiscali, cui sono state affidate le mansioni della terza area sulla base dei contratti individuali di lavoro a tempo indeterminato stipulati in esito al superamento di concorsi banditi in applicazione del contratto collettivo nazionale di comparto del quadriennio 1998-2001, o del quadriennio 2002-2005, continua ad essere corrisposto, a titolo individuale e in via provvisoria, sino all'adozione di una specifica disciplina contrattuale, il relativo trattamento economico e gli stessi continuano ad esplicare le relative funzioni, nei limiti delle facolta' assunzionali a tempo indeterminato e delle vacanze di organico previste per le strutture interessate.

10. All'articolo 13 del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, sono apportate le seguenti modificazioni:

- a) al comma 2, le parole da: «, nonche' l'unita' immobiliare» fino a: «non superiore a 15.000 euro annui» sono soppresse;
- b) al comma 3, prima della lettera a) e' inserita la seguente: «0a) per le unita' immobiliari, fatta eccezione per quelle classificate nelle categorie catastali A/1, A/8 e A/9, concesse in comodato dal soggetto passivo ai parenti in linea retta entro il primo grado che le utilizzano come abitazione principale, a condizione che il contratto sia registrato e che il comodante possieda un solo immobile in Italia e risieda anagraficamente nonche' dimori abitualmente nello stesso comune in cui e' situato l'immobile concesso in comodato; il beneficio si applica anche nel caso in cui il comodante oltre all'immobile concesso in comodato possieda nello stesso comune un altro immobile adibito a propria abitazione principale, ad eccezione delle unita' abitative classificate nelle categorie catastali A/1, A/8 e A/9; ai fini dell'applicazione delle disposizioni della presente lettera, il soggetto passivo attesta il possesso dei suddetti requisiti nel modello di dichiarazione di cui all'articolo 9, comma 6, del decreto legislativo 14 marzo 2011, n. 23»;
- c) al comma 5, il secondo periodo e' soppresso;
- d) il comma 8-bis e' abrogato;
- e) al comma 13-bis, le parole: «21 ottobre» sono sostituite dalle seguenti: «termine perentorio del 14 ottobre».

11. Al comma 8 dell'articolo 9 del decreto legislativo 14 marzo 2011, n. 23, l'ultimo periodo e' soppresso.

12. All'articolo 8, comma 1, del decreto legislativo 14 marzo 2011, n. 23, e' aggiunto il seguente periodo: «Le disposizioni di cui al presente comma si applicano, dal periodo d'imposta 2014, anche all'imposta municipale immobiliare della provincia autonoma di Bolzano, istituita dalla legge provinciale 19 aprile 2014, n. 3, ed all'imposta immobiliare semplice della provincia autonoma di Trento, istituita dalla legge provinciale 30 dicembre 2014, n. 14».

13. A decorrere dall'anno 2016, l'esenzione dall'imposta municipale propria (IMU) prevista dalla lettera h) del comma 1 dell'articolo 7 del decreto legislativo 30 dicembre 1992, n. 504, si applica sulla base dei criteri individuati dalla circolare del Ministero delle finanze n. 9 del 14 giugno 1993, pubblicata nel supplemento ordinario n. 53 alla Gazzetta Ufficiale n. 141 del 18 giugno 1993. Sono, altresi', esenti dall'IMU i terreni agricoli:

- a) posseduti e condotti dai coltivatori diretti e dagli imprenditori agricoli professionali di cui all'articolo 1 del decreto legislativo 29 marzo 2004, n. 99, iscritti nella previdenza agricola, indipendentemente dalla loro ubicazione;
- b) ubicati nei comuni delle isole minori di cui all'allegato A annesso alla legge 28 dicembre 2001, n. 448;
- c) a immutabile destinazione agrosilvo-pastorale a proprieta' collettiva indivisibile e inusucapibile. A decorrere dall'anno 2016, sono abrogati i commi da 1 a 9-bis dell'articolo 1 del decreto-legge 24 gennaio 2015, n. 4, convertito, con modificazioni, dalla legge 24 marzo 2015, n. 34.

14. All'articolo 1 della legge 27 dicembre 2013, n. 147:

- a) al comma 639, le parole: «a carico sia del possessore che dell'utilizzatore dell'immobile» sono sostituite dalle seguenti: «a carico sia del possessore che dell'utilizzatore dell'immobile, escluse le unita' immobiliari destinate ad abitazione principale dal possessore nonche' dall'utilizzatore e dal suo nucleo familiare, ad eccezione di quelle classificate nelle categorie catastali A/1, A/8 e A/9»;
- b) il comma 669 e' sostituito dal seguente: «669. Il presupposto impositivo della TASI e' il possesso o la detenzione, a qualsiasi titolo, di fabbricati e di aree edificabili, ad eccezione, in ogni caso, dei terreni agricoli e dell'abitazione principale, come definiti ai sensi dell'imposta municipale propria di cui all'articolo 13, comma 2, del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, escluse quelle classificate nelle categorie catastali A/1, A/8 e A/9»;
- c) al comma 678 sono aggiunti, in fine, i seguenti periodi: «Per i fabbricati costruiti e destinati dall'impresa costruttrice alla vendita, fintanto che permanga tale destinazione e non siano in ogni caso locati, l'aliquota e' ridotta allo 0,1 per cento. I comuni possono modificare la suddetta aliquota, in aumento, sino allo 0,25 per cento o, in diminuzione, fino all' azzeramento»;
- d) al comma 681 sono aggiunti, in fine, i seguenti periodi: «Nel caso in cui l'unita' immobiliare e' detenuta da un soggetto che la destina ad abitazione principale, escluse quelle classificate nelle categorie catastali A/1, A/8 e A/9, il possessore versa la TASI nella percentuale stabilita dal comune nel regolamento relativo all'anno 2015. Nel caso di mancato invio della delibera entro il termine del 10 settembre 2014 di cui al comma 688 ovvero nel caso di mancata determinazione della predetta percentuale stabilita dal comune nel regolamento relativo al 2015, la percentuale di versamento a carico del possessore e' pari al 90 per cento dell'ammontare complessivo del tributo»;
- e) al comma 688, le parole: «21 ottobre» sono sostituite dalle seguenti: «termine perentorio del 14 ottobre».

15. All'articolo 13, comma 2, lettera a), del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, sono aggiunte, in fine, le seguenti parole: «, ivi incluse le unita' immobiliari appartenenti alle cooperative edilizie a proprieta' indivisa destinate a studenti universitari soci assegnatari, anche in deroga al richiesto requisito della residenza anagrafica».

16. Il comma 15-bis dell'articolo 19 del citato decreto-legge n. 201 del 2011, convertito, con modificazioni, dalla legge n. 214 del 2011, e' sostituito dal seguente: «15-bis. L'imposta di cui al comma 13 non si applica al possesso dell'abitazione principale e delle pertinenze della stessa e alla casa coniugale assegnata al coniuge, a seguito di provvedimento di separazione legale, annullamento, scioglimento o cessazione degli effetti civili del matrimonio, ad eccezione delle unita' immobiliari che in Italia risultano classificate nelle categorie catastali A/1, A/8 e A/9, per le quali si applica l'aliquota nella misura ridotta dello 0,4 per cento e la detrazione, fino a concorrenza del suo ammontare, di euro 200 rapportati al periodo dell'anno durante il quale si protrae tale destinazione; se l'unita' immobiliare e' adibita ad abitazione principale da piu' soggetti passivi la detrazione spetta a ciascuno di essi proporzionalmente alla quota per la quale la destinazione medesima si verifica».

17. Al fine di tenere conto dell'esenzione di cui ai commi da 10 a 16, 53 e 54 del presente articolo prevista per l'IMU e la TASI, all'articolo 1 della legge 24 dicembre 2012, n. 228, sono apportate le seguenti modifiche:

- a) al comma 380-ter, lettera a), dopo il primo periodo e' inserito il seguente: «A decorrere dall'anno 2016 la dotazione del Fondo di solidarieta' comunale di cui al primo periodo e' incrementata di 3.767,45 milioni di euro» e il secondo e il terzo periodo sono sostituiti dai seguenti: «La dotazione del Fondo di cui al primo periodo e' assicurata attraverso una quota dell'imposta municipale propria, di spettanza dei comuni, di cui al citato articolo 13 del decreto-legge n. 201 del 2011, pari a 4.717,9 milioni di euro per ciascuno degli anni 2014 e 2015 e a 2.768,8 milioni di euro per ciascuno degli anni 2016 e seguenti. Corrispondentemente, nei predetti esercizi e' versata all'entrata del bilancio statale una quota di pari importo dell'imposta municipale propria, di spettanza dei comuni. A seguito della riduzione della quota di imposta municipale propria di spettanza comunale da versare al bilancio dello Stato per alimentare il Fondo di solidarieta' comunale, a decorrere dall'anno 2016, la dotazione del predetto Fondo e' corrispondentemente ridotta in misura pari a 1. 949,1 milioni di euro annui»;
- b) al comma 380-ter, lettera a), l'ultimo periodo e' sostituito dal seguente: «Al fine di incentivare il processo di riordino e semplificazione degli enti territoriali, una quota del Fondo di solidarieta' comunale, non inferiore a 30 milioni di euro a decorrere dall'anno 2014, e' destinata ad incrementare il contributo spettante alle unioni di comuni ai sensi dell'articolo 53, comma 10, della legge 23 dicembre 2000, n. 388, e successive modificazioni, e una quota non inferiore a 30 milioni di euro e' destinata, ai sensi dell'articolo 20 del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, e successive modificazioni, ai comuni istituiti a seguito di fusione»;
- c) al comma 380-ter, lettera b), le parole: «per gli anni 2015 e successivi» sono sostituite dalle seguenti: «per l'anno 2015, entro il 30 aprile per l'anno 2016 ed entro il 30 novembre dell'anno precedente a quello di riferimento per gli anni 2017 e successivi»;
- d) al comma 380-ter, la lettera d) e' sostituita dalla seguente: «d) con il decreto del Presidente del Consiglio dei ministri di cui alla lettera b) puo' essere variata la quota di gettito dell'imposta municipale propria di spettanza comunale di cui alla lettera a) da versare al bilancio dello Stato e, corrispondentemente, rideterminata la dotazione del Fondo di cui alla medesima lettera a). Le modalita' di versamento al bilancio dello Stato sono determinate con il medesimo decreto del Presidente del Consiglio dei ministri. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio»;
- e) al comma 380-quater: 1) dopo le parole: «20 per cento» sono inserite le seguenti: «per l'anno 2015, il 30 per cento per l'anno 2016, il 40 percento per l'anno 2017 e il 55 per cento per l'anno 2018»; 2) le parole: «approvati dalla Commissione tecnica paritetica per l'attuazione del federalismo fiscale di cui all'articolo 4 della legge 5 maggio 2009, n. 42, entro il 31 dicembre dell'anno precedente a quello di riferimento» sono sostituite dalle seguenti: «approvati dalla Commissione tecnica per i fabbisogni standard entro il 31 dicembre dell'anno precedente a quello di riferimento. Per l'anno 2016, sono assunti a riferimento i fabbisogni standard approvati dalla predetta Commissione entro il 31 marzo 2016»; 3) le parole: «l'anno 2015», ovunque ricorrono, sono sostituite dalle seguenti: «gli anni 2015 e 2016»;
- f) dopo il comma 380-quinquies sono inseriti i seguenti: «380-sexies. Con il medesimo decreto del Presidente del Consiglio dei ministri di cui alla lettera b) del comma 380-ter, l'incremento di 3.767,45 milioni di euro per gli anni 2016 e successivi della dotazione del Fondo di solidarieta' comunale, in deroga a quanto disposto dai commi 380-ter e 380-quater, e' ripartito tra i comuni interessati sulla base del gettito effettivo IMU e TASI derivante dagli immobili adibiti ad abitazione principale e dai terreni agricoli, relativo all'anno 2015. A decorrere dall'anno 2016, in deroga a quanto disposto dai commi 380-ter e 380-quater, una quota del Fondo di solidarieta' comunale, pari a 80 milioni di euro, e' accantonata per essere ripartita tra i comuni per i quali il riparto dell'importo di 3.767,45 milioni di euro, di cui al periodo precedente, non assicura il ristoro di un importo equivalente al gettito della TASI sull'abitazione principale stimato ad aliquota di base. La quota di 80 milioni di euro del Fondo di solidarieta' comunale e' ripartita in modo da garantire a ciascuno dei comuni di cui al precedente periodo l'equivalente del gettito della TASI sull'abitazione principale stimato ad aliquota di base. 380-septies. A decorrere dall'anno 2016 l'ammontare del Fondo di solidarieta' comunale di cui al comma 380-ter, al netto degli importi erogati ai sensi del comma 380-sexies, per ciascun comune: a) della Regione siciliana e della regione Sardegna e' determinato in modo tale da garantire la medesima dotazione netta del Fondo di solidarieta' comunale per l'anno 2015; b) delle regioni a statuto ordinario non ripartito secondo i criteri di cui al comma 380-quater e' determinato in modo tale da garantire proporzionalmente la dotazione netta del Fondo di solidarieta' comunale per l'anno 2015. 380-octies. Ai fini del comma 380-septies, per dotazione netta si intende la differenza tra le assegnazioni di risorse, al netto degli importi erogati ai sensi del comma 380-sexies per ciascun comune, e la quota di alimentazione del fondo a carico di ciascun comune».

18. All'articolo 20 del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, sono apportate le seguenti modificazioni:

- a) dopo il comma 1 e' inserito il seguente: «1-bis. A decorrere dall'anno 2016, il contributo straordinario a favore degli enti di cui al comma 1 e' commisurato al 40 per cento dei trasferimenti erariali attribuiti per l'anno 2010, nel limite degli stanziamenti finanziari previsti e comunque in misura non superiore a 2 milioni di euro per ciascun beneficiario. Con decreto di natura non regolamentare del Ministro dell'interno, sentita la Conferenza Stato-citta' ed autonomie locali, sono disciplinate le modalita' di riparto del contributo, prevedendo che in caso di fabbisogno eccedente le disponibilita' sia data priorita' alle fusioni o incorporazioni aventi maggiori anzianita' e che le eventuali disponibilita' eccedenti rispetto al fabbisogno determinato ai sensi del primo periodo siano ripartite a favore dei medesimi enti in base alla popolazione e al numero dei comuni originari»;
- b) al comma 3, le parole: «di cui al comma 1» sono sostituite dalle seguenti: «di cui ai commi 1 e 1-bis».

19. Per le medesime finalita' di cui al comma 17, per i comuni delle regioni Friuli Venezia Giulia e Valle d'Aosta a cui la legge attribuisce competenza in materia di finanza locale, la compensazione del minor gettito IMU e TASI avviene attraverso un minor accantonamento di 85,978 milioni di euro, a valere sulle quote di compartecipazione ai tributi erariali, ai sensi del comma 17 del citato articolo 13 del decreto-legge n. 201 del 2011, convertito, con modificazioni, dalla legge n. 214 del 2011, sulla base del gettito effettivo IMU e TASI derivante dagli immobili adibiti ad abitazione principale e dai terreni agricoli, relativo all'anno 2015.

20. Per l'anno 2016 e' attribuito ai comuni un contributo di complessivi 390 milioni di euro da ripartire, con decreto del Ministro dell'interno, di concerto con il Ministro dell'economia e delle finanze, da adottare entro il 28 febbraio 2016, in proporzione alle somme attribuite, ai sensi del decreto del Ministro dell'economia e delle finanze 6 novembre 2014, pubblicato nel supplemento ordinario alla Gazzetta Ufficiale n. 271 del 21 novembre 2014, adottato ai sensi dell'articolo 1, comma 731, della legge 27 dicembre 2013, n. 147. Le somme di cui al periodo precedente non sono considerate tra le entrate finali valide ai fini del vincolo del pareggio di bilancio di cui ai commi da 707 a 734 del presente articolo. Le disponibilita' in conto residui iscritte in bilancio per l'anno 2015, relative all'autorizzazione di spesa di cui all'articolo 1, comma 10, del decreto-legge 8 aprile 2013, n. 35, convertito, con modificazioni, dalla legge 6 giugno 2013, n. 64, e successive modificazioni, sono destinate, nel limite di 390 milioni di euro, al finanziamento del contributo di cui al presente comma, che entra in vigore il giorno stesso della pubblicazione della presente legge nella Gazzetta Ufficiale. A tal fine le predette somme sono versate all'entrata del bilancio dello Stato nell'anno 2016.

21. A decorrere dal 1° gennaio 2016, la determinazione della rendita catastale degli immobili a destinazione speciale e particolare, censibili nelle categorie catastali dei gruppi D ed E, e' effettuata, tramite stima diretta, tenendo conto del suolo e delle costruzioni, nonche' degli elementi ad essi strutturalmente connessi che ne accrescono la qualita' e l'utilita', nei limiti dell'ordinario apprezzamento. Sono esclusi dalla stessa stima diretta macchinari, congegni, attrezzature ed altri impianti, funzionali allo specifico processo produttivo.

22. A decorrere dal 1° gennaio 2016, gli intestatari catastali degli immobili di cui al comma 21 possono presentare atti di aggiornamento ai sensi del regolamento di cui al decreto del Ministro delle finanze 19 aprile 1994, n. 701, per la rideterminazione della rendita catastale degli immobili gia' censiti nel rispetto dei criteri di cui al medesimo comma 21.

23. Limitatamente all'anno di imposizione 2016, in deroga all'articolo 13, comma 4, del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, per gli atti di aggiornamento di cui al comma 22 presentati entro il 15 giugno 2016 le rendite catastali rideterminate hanno effetto dal 1° gennaio 2016.

24. Entro il 30 settembre 2016, l'Agenzia delle entrate comunica al Ministero dell'economia e delle finanze, con riferimento agli atti di aggiornamento di cui al comma 23, i dati relativi, per ciascuna unita' immobiliare, alle rendite proposte e a quelle gia' iscritte in catasto dal 1° gennaio 2016; il Ministro dell'economia e delle finanze, di concerto con il Ministro dell'interno, emana, secondo una metodologia adottata sentita la Conferenza Stato-citta' ed autonomie locali, entro il 31 ottobre 2016, il decreto per ripartire il contributo annuo di 155 milioni di euro attribuito ai comuni a titolo di compensazione del minor gettito per l'anno 2016. A decorrere dall'anno 2017, il contributo annuo di 155 milioni di euro e' ripartito con decreto del Ministro dell'economia e delle finanze, di concerto con il Ministro dell'interno e secondo una metodologia adottata sentita la Conferenza Stato-citta' ed autonomie locali, da emanare, entro il 30 giugno 2017, sulla base dei dati comunicati, entro il 31 marzo 2017, dall'Agenzia delle entrate al Ministero dell'economia e delle finanze e relativi, per ciascuna unita' immobiliare, alle rendite proposte nel corso del 2016 ai sensi del comma 22 e a quelle gia' iscritte in catasto al 1° gennaio 2016. (75)

25. L'articolo 11 del decreto legislativo 14 marzo 2011, n. 23, e' abrogato.

26. Al fine di contenere il livello complessivo della pressione tributaria, in coerenza con gli equilibri generali di finanza pubblica, per gli anni 2016 , 2017 e 2018 e' sospesa l'efficacia delle leggi regionali e delle deliberazioni degli enti locali nella parte in cui prevedono aumenti dei tributi e delle addizionali attribuiti alle regioni e agli enti locali con legge dello Stato rispetto ai livelli di aliquote o tariffe applicabili per l'anno 2015. Per l'anno 2018 la sospensione di cui al primo periodo non si applica ai comuni istituiti a seguito di fusione ai sensi degli articoli 15 e 16 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, al fine di consentire, a parita' di gettito, l'armonizzazione delle diverse aliquote. Sono fatte salve, per il settore sanitario, le disposizioni di cui all'articolo 1, comma 174, della legge 30 dicembre 2004, n. 311, e all'articolo 2, commi 79, 80, 83 e 86, della legge 23 dicembre 2009, n. 191, nonche' la possibilita' di effettuare manovre fiscali incrementative ai fini dell'accesso alle anticipazioni di liquidita' di cui agli articoli 2 e 3 del decreto-legge 8 aprile 2013, n. 35, convertito, con modificazioni, dalla legge 6 giugno 2013, n. 64, e successivi rifinanziamenti. La sospensione di cui al primo periodo non si applica alla tassa sui rifiuti (TARI) di cui all'articolo 1, comma 639, della legge 27 dicembre 2013, n. 147, e a decorrere dal 2017 al contributo di sbarco di cui all'articolo 4, comma 3-bis, del decreto legislativo 14 marzo 2011, n. 23, ne' per gli enti locali che deliberano il predissesto, ai sensi dell'articolo 243-bis del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, o il dissesto, ai sensi degli articoli 246 e seguenti del medesimo testo unico di cui al decreto legislativo n. 267 del 2000.(18)

27. All'articolo 1 della legge 27 dicembre 2013, n. 147, sono apportate le seguenti modificazioni:

- a) al comma 652, terzo periodo, le parole: «per gli anni 2014 e 2015» sono sostituite dalle seguenti: «per gli anni 2014, 2015, 2016 e 2017»;
- b) al comma 653, la parola: «2016» e' sostituita dalla seguente: «2018».

28. Per l'anno 2016, limitatamente agli immobili non esentati ai sensi dei commi da 10 a 26 del presente articolo, i comuni possono mantenere con espressa deliberazione del consiglio comunale la maggiorazione della TASI di cui al comma 677 dell'articolo 1 della legge 27 dicembre 2013, n. 147, nella stessa misura applicata per l'anno 2015. Per l'anno 2017, i comuni che hanno deliberato ai sensi del periodo precedente possono continuare a mantenere con espressa deliberazione del consiglio comunale la stessa maggiorazione confermata per l'anno 2016. Per l'anno 2018, i comuni che hanno deliberato ai sensi del periodo precedente possono continuare a mantenere con espressa deliberazione del consiglio comunale la stessa maggiorazione confermata per gli anni 2016 e 2017. Per l'anno 2019 i comuni che hanno deliberato ai sensi del periodo precedente possono continuare a mantenere con espressa deliberazione del consiglio comunale la stessa aliquota confermata per gli anni 2016, 2017 e 2018.

29. Con decreto del Presidente del Consiglio dei ministri, da adottare entro trenta giorni dalla data di entrata in vigore della presente legge, e' istituita, presso il Ministero dell'economia e delle finanze, la Commissione tecnica per i fabbisogni standard di cui al decreto legislativo 26 novembre 2010, n. 216. la Commissione e' formata da quattordici componenti, di cui uno, con funzioni di presidente, designato dal Presidente del Consiglio dei ministri, tre designati dal Ministro dell'economia e delle finanze, uno designato dal Ministro dell'interno, uno designato dal Ministro delegato per gli affari regionali e le autonomie, uno designato dall'Autorita' politica delegata in materia di coesione territoriale, uno designato dall'Istituto nazionale di statistica, tre designati dall'Associazione nazionale dei comuni italiani, di cui uno in rappresentanza delle aree vaste, e e tre designati dalla Conferenza delle regioni e delle province autonome.

29-bis. La Commissione di cui al comma 29, con cadenza biennale, a partire dall'anno 2018, presenta una relazione alla Commissione parlamentare per l'attuazione del federalismo fiscale in merito allo stato di attuazione delle disposizioni di cui ai capi II, III, IV e VI della legge 5 maggio 2009, n. 42, con particolare riferimento alle ipotesi tecniche inerenti la determinazione dei livelli essenziali delle prestazioni e al funzionamento dello schema perequativo.

30. La Commissione di cui al comma 29 e' istituita senza nuovi o maggiori oneri per la finanza pubblica e si avvale delle strutture e dell'organizzazione del Ministero dell'economia e delle finanze. Ai componenti della Commissione non e' corrisposto alcun compenso, ne' indennita', ne' rimborso di spese. La Commissione definisce, nella sua prima seduta, da convocare entro dieci giorni dalla sua istituzione, le modalita' di organizzazione e di funzionamento e stabilisce i tempi e la disciplina procedurale dei propri lavori.

31. All'articolo 5, comma 1, del decreto legislativo 26 novembre 2010, n. 216, la lettera e) e' sostituita dalla seguente: «e) le metodologie predisposte ai sensi della lettera a) e le elaborazioni relative alla determinazione dei fabbisogni standard di cui alla lettera b) sono sottoposte alla Commissione tecnica per i fabbisogni standard, anche separatamente, per l'approvazione; in assenza di osservazioni, le stesse si intendono approvate decorsi quindici giorni dal loro ricevimento. Le metodologie e i fabbisogni approvati dalla Commissione tecnica sono trasmessi dalla societa' Soluzioni per il sistema economico - Sose Spa al Dipartimento della Ragioneria generale dello Stato e al Dipartimento delle finanze del Ministero dell'economia e delle finanze».

32. Il comma 1 dell'articolo 6 del decreto legislativo 26 novembre 2010, n. 216, e' sostituito dal seguente: «1. Con uno o piu' decreti del Presidente del Consiglio dei ministri, previa deliberazione del Consiglio dei ministri, sono adottati, anche separatamente, la nota metodologica relativa alla procedura di calcolo di cui agli articoli precedenti e il fabbisogno standard per ciascun comune e provincia, previa verifica da parte del Dipartimento della Ragioneria generale dello Stato del Ministero dell'economia e delle finanze, ai fini del rispetto dell'articolo 1, comma 3. Lo schema di decreto e' corredato di una relazione tecnica redatta ai sensi dell'articolo 17, comma 3, della legge 31 dicembre 2009, n. 196, e successive modificazioni, che ne evidenzia gli effetti finanziari. Sullo schema di decreto e' sentita la Conferenza Stato-citta' ed autonomie locali. Nel caso di adozione dei soli fabbisogni standard, decorsi quindici giorni dalla sua trasmissione alla Conferenza, il decreto puo' essere comunque adottato, previa deliberazione definitiva da parte del Consiglio dei ministri; esso e' pubblicato nella Gazzetta Ufficiale. Nel caso di adozione della nota metodologica relativa alla procedura di calcolo, decorsi quindici giorni dalla trasmissione alla Conferenza, lo schema e' comunque trasmesso alle Camere ai fini dell'espressione del parere da parte della Commissione parlamentare per l'attuazione del federalismo fiscale e da parte delle Commissioni parlamentari competenti per le conseguenze di carattere finanziario. Decorsi quindici giorni dalla trasmissione alle Camere da parte del Governo, il decreto puo' essere comunque adottato, previa deliberazione definitiva da parte del Consiglio dei ministri; esso e' pubblicato nella Gazzetta Ufficiale. Il Governo, se non intende conformarsi ai pareri parlamentari, trasmette alle Camere una relazione con cui indica le ragioni per le quali non si e' conformato ai citati pareri. Ciascuno dei decreti del Presidente del Consiglio dei ministri recante determinazione dei fabbisogni standard per i comuni e le province indica in allegato gli elementi considerati ai fini di tale determinazione».

33. All'articolo 7, comma 2, del decreto legislativo 26 novembre 2010, n. 216, le parole da: «, che si avvale» fino a: «federalismo fiscale» sono soppresse.

34. La Commissione tecnica paritetica per l'attuazione del federalismo fiscale, di cui all'articolo 4 della legge 5 maggio 2009,n. 42, e' soppressa a decorrere dalla data di entrata in vigore della presente legge. Le funzioni di segreteria tecnica della Conferenza permanente per il coordinamento della finanza pubblica svolte dalla predetta Commissione ai sensi degli articoli 4, comma 4, e 5, comma 1, lettera g), della legge n. 42 del 2009 sono trasferite alla Commissione tecnica per i fabbisogni standard istituita ai sensi del comma 29 del presente articolo.

35. All'articolo 22 della tariffa delle tasse sulle concessioni governative, annessa al decreto del Presidente della Repubblica 26 ottobre 1972, n. 641, dopo il numero 8 e' aggiunto il seguente: «8-bis. Iscrizione all'albo di cui all'articolo 31, comma 4, del testo unico di cui al decreto legislativo 24 febbraio 1998, n. 58. La tassa e' dovuta per le iscrizioni successive alla data di entrata in vigore della presente legge».

36. Le funzioni di vigilanza sui promotori finanziari attribuite alla CONSOB dal testo unico delle disposizioni in materia di intermediazione finanziaria, di cui al decreto legislativo 24 febbraio 1998, n. 58, di seguito denominato «decreto legislativo n. 58 del 1998», sono trasferite all'organismo di cui all'articolo 31, comma 4, del predetto decreto legislativo, che assume anche le funzioni dell'organismo di cui agli articoli 18-bis, comma 6, e 18-ter, comma 3, del medesimo decreto legislativo nonche' la denominazione di «organismo di vigilanza e tenuta dell'albo unico dei consulenti finanziari». Tale organismo opera nel rispetto dei principi e dei criteri stabiliti dalla CONSOB con proprio regolamento e sotto la vigilanza della medesima. I riferimenti all'organismo di tenuta dell'albo dei consulenti finanziari nonche' alla CONSOB, contenuti negli articoli 18-bis, comma 6, 31, comma 7, 55 e 196, comma 2, del decreto legislativo n. 58 del 1998, si intendono sostituiti da riferimenti all'organismo di cui al primo periodo del presente comma. I commi 2, 3, 4 e 5 dell'articolo 18-bis del decreto legislativo n. 58 del 1998 sono abrogati. Resta ferma la vigente regolamentazione degli obblighi previdenziali degli iscritti all'albo di cui al citato articolo 31, comma 4, del decreto legislativo n. 58 del 1998.

37. L'albo unico dei promotori finanziari di cui all'articolo 31, comma 4, del decreto legislativo n. 58 del 1998 assume la denominazione di «albo unico dei consulenti finanziari». Nell'albo sono iscritti, in tre distinte sezioni, i consulenti finanziari abilitati all'offerta fuori sede, i consulenti finanziari autonomi e le societa' di consulenza finanziaria. I riferimenti all'albo dei consulenti finanziari, contenuti negli articoli 18-bis, comma 1, e 18-ter, comma 3, del decreto legislativo n. 58 del 1998 si intendono sostituiti da riferimenti all'albo unico di cui al primo periodo del presente comma.

38. Gli agenti di assicurazione persone fisiche iscritti nel Registro unico degli intermediari assicurativi e riassicurativi (RUI), Sezione A, su richiesta sono iscritti nell'albo di cui al comma 37 del presente articolo, nella sezione dei consulenti finanziari abilitati all'offerta fuori sede, purche' in possesso dei medesimi requisiti di onorabilita' e professionalita' previsti per questi ultimi. A tal fine l'organismo di cui all'articolo 31, comma 4, del decreto legislativo n. 58 del 1998, con propria delibera, definisce, in coerenza con il quadro normativo europeo e nazionale di riferimento, il contenuto di una prova valutativa semplificata che i soggetti di cui al primo periodo del presente comma devono sostenere in considerazione dei requisiti di professionalita' gia' posseduti. In tal caso si applica il regime di vigilanza di cui al comma 36 e gli agenti di assicurazione di cui al presente comma sono soggetti alle regole di condotta vigenti per i consulenti finanziari abilitati all'offerta fuori sede. PERIODO SOPPRESSO DAL D.L. 31 MAGGIO 2021, N. 77, CONVERTITO CON MODIFICAZIONI DALLA L. 29 LUGLIO 2021, N. 108.

39. I promotori finanziari di cui all'articolo 31 del decreto legislativo n. 58 del 1998 assumono la denominazione di «consulenti finanziari abilitati all'offerta fuori sede». I consulenti finanziari di cui all'articolo 18-bis del decreto legislativo n. 58 del 1998 assumono la denominazione di «consulenti finanziari autonomi». Agli articoli 30, 31, 55, 166, 187-quater, 191 e 196 del decreto legislativo n. 58 del 1998, le parole: «promotore finanziario» e «promotori finanziari», ovunque ricorrono, sono sostituite, rispettivamente, dalle seguenti: «consulente finanziario abilitato all'offerta fuori sede» e «consulenti finanziari abilitati all'offerta fuori sede» e all'articolo 18-bis del decreto legislativo n. 58 del 1998, le parole: «consulenti finanziari» e «consulente finanziario» sono sostituite, rispettivamente, dalle seguenti: «consulenti finanziari autonomi» e «consulente finanziario autonomo».

40. L'organismo di cui al comma 36 si avvale del proprio personale e di un contingente di personale anche con qualifica dirigenziale posto in posizione di distacco, comando o altro analogo istituto da amministrazioni pubbliche, incluse le autorita' amministrative indipendenti. L'organismo rimborsa alle amministrazioni di appartenenza gli oneri relativi al citato personale; resta a carico dell'organismo anche l'eventuale attribuzione di un compenso aggiuntivo. Al termine del periodo di distacco, comando o altro analogo istituto e degli eventuali rinnovi, il predetto personale rientra nell'amministrazione di appartenenza, salvo che, a richiesta del personale interessato, l'organismo non lo immetta nel proprio organico a tempo indeterminato. PERIODO SOPPRESSO DALLA L. 25 MARZO 2024, N. 21. Si applica l'articolo 17, comma 14, della legge 15 maggio 1997, n. 127.

41. Entro sei mesi dall'adozione del regolamento di cui al comma 36, la CONSOB e l'organismo per la tenuta dell'albo unico dei promotori finanziari stabiliscono con protocollo di intesa le modalita' operative e i tempi del trasferimento delle funzioni, gli adempimenti occorrenti per dare attuazione al nuovo assetto statutario e organizzativo, nonche' le attivita' propedeutiche connesse all'iscrizione con esonero dalla prova valutativa delle persone fisiche consulenti finanziari autonomi e delle societa' di consulenza finanziaria. I soggetti che risultano iscritti, alla data di cui alla lettera a) del presente comma, nell'albo unico dei promotori finanziari tenuto dall'organismo di cui all'articolo 31, comma 4, del decreto legislativo n. 58 del 1998 sono iscritti di diritto nell'albo unico dei consulenti finanziari. Con successive delibere da adottare, anche disgiuntamente, in conformita' al predetto regolamento di cui al comma 36 e al protocollo di intesa di cui al primo periodo del presente comma, la CONSOB stabilisce:

- a) la data di avvio dell'operativita' dell'albo unico dei consulenti finanziari;
- b) la data di avvio dell'operativita' dell'organismo di vigilanza e tenuta dell'albo unico dei consulenti finanziari.

42. Le entrate derivanti dalle disposizioni di cui al comma 35 affluiscono, a decorrere dall'anno 2016, all'entrata del bilancio dello Stato.

43. All'articolo 190-ter del decreto legislativo n. 58 del 1998 sono apportate le seguenti modificazioni:

- a) le lettere b) e c) del comma 1 sono abrogate;
- b) dopo il comma 2 e' aggiunto il seguente: «2-bis. Su proposta della CONSOB, il Ministro dell'economia e delle finanze puo' sciogliere gli organi di gestione e di controllo dell'organismo di cui all'articolo 31 qualora risultino gravi irregolarita' nell'amministrazione, ovvero gravi violazioni delle disposizioni legislative, amministrative o statutarie che regolano l'attivita' dello stesso. Il Ministero dell'economia e delle finanze provvede agli adempimenti necessari alla ricostituzione degli organi di gestione e controllo dell'organismo, assicurandone la continuita' operativa, se necessario anche attraverso la nomina di un commissario. La CONSOB puo' disporre la rimozione di uno o piu' componenti degli organi di gestione e controllo in caso di grave inosservanza dei doveri ad essi assegnati dalla legge, dallo statuto o dalle disposizioni di vigilanza, nonche' dei provvedimenti specifici e di altre istruzioni impartite dalla CONSOB, ovvero in caso di comprovata inadeguatezza, accertata dalla CONSOB, all'esercizio delle funzioni cui sono preposti».

44. L'articolo 8 del decreto legislativo 8 ottobre 2007, n. 179, e' sostituito dal seguente: «Art. 8. - (Fondo per la tutela stragiudiziale dei risparmiatori e degli investitori). -1. Al fine di agevolare l'accesso dei risparmiatori e degli investitori alla piu' ampia tutela nell'ambito delle procedure di risoluzione stragiudiziale delle controversie di cui all'articolo 2, commi 5-bis e 5-ter, la CONSOB istituisce presso il proprio bilancio il Fondo per la tutela stragiudiziale dei risparmiatori e degli investitori, di seguito denominato "Fondo". Il Fondo e' destinato a garantire ai risparmiatori e agli investitori, diversi dai clienti professionali di cui all'articolo 6, commi 2-quinquies e 2-sexies, del decreto legislativo 24 febbraio 1998, n. 58, nei limiti delle disponibilita' del Fondo medesimo, la gratuita' dell'accesso alla procedura di risoluzione stragiudiziale delle controversie di cui al citato articolo 2, commi 5-bis e 5-ter, del presente decreto, mediante esonero dal versamento della relativa quota concernente le spese amministrative per l'avvio della procedura, nonche', per l'eventuale parte residua, a consentire l'adozione di ulteriori misure a favore dei risparmiatori e degli investitori, da parte della CONSOB, anche con riguardo alla tematica dell'educazione finanziaria. 2. Il Fondo e' finanziato con il versamento della meta' degli importi delle sanzioni amministrative pecuniarie riscosse per la violazione delle norme che disciplinano le attivita' di cui alla parte II del decreto legislativo 24 febbraio 1998, n. 58, nonche', nel limite di 250.000 euro annui a decorrere dall'anno 2016, con le risorse iscritte in un apposito capitolo dello stato di previsione del Ministero dell'economia e delle finanze in relazione ai versamenti effettuati all'entrata del bilancio dello Stato per il pagamento della tassa sulle concessioni governative di cui al decreto del Presidente della Repubblica 26 ottobre 1972, n. 641, per l'iscrizione nell'albo di cui all'articolo 31, comma 4, del medesimo decreto legislativo n. 58 del 1998. L'impiego delle somme affluite al Fondo, con riguardo a quelle relative alla violazione delle norme che disciplinano le attivita' di cui alla parte II del citato decreto legislativo n. 58 del 1998, e' condizionato all'accertamento, con sentenza passata in giudicato o con lodo arbitrale non piu' impugnabile, della violazione sanzionata. Nel caso di incapienza del Fondo resta fermo quanto previsto dall'ultimo periodo del comma 5-ter dell'articolo 2 del presente decreto. La CONSOB adotta le occorrenti misure affinche' gli importi delle sanzioni amministrative pecuniarie di cui al primo periodo affluiscano, nella misura spettante, contestualmente al versamento da parte del soggetto obbligato, direttamente al bilancio della CONSOB, per essere destinate al Fondo».

45. Al decreto legislativo 8 ottobre 2007, n. 179, sono apportate le seguenti modificazioni:

- a) nel titolo, le parole: «fondo di garanzia per i risparmiatori e gli investitori» sono sostituite dalle seguenti: «Fondo per la tutela stragiudiziale dei risparmiatori e degli investitori»;
- b) la rubrica del capo II e' sostituita dalla seguente: «Fondo per la tutela stragiudiziale dei risparmiatori e degli investitori».

46. Nelle more del coordinamento da effettuare ai sensi dell'articolo 9, comma 1, lettera u), della legge 9 luglio 2015, n. 114, e allo scopo di assicurare tempestivamente ai risparmiatori e agli investitori una procedura di effettiva tutela stragiudiziale delle controversie, la CONSOB, rispetto agli oneri attualmente sostenuti per il funzionamento della Camera di conciliazione e arbitrato di cui all'articolo 2, commi da 1 a 5, del decreto legislativo 8 ottobre 2007, n. 179, provvede alle maggiori spese di funzionamento occorrenti per rendere operativo l'organo di cui all'articolo 2, comma 5-ter, del citato decreto legislativo n. 179 del 2007 mediante il ricorso, senza nuovi o maggiori oneri per la finanza pubblica e fatto salvo quanto previsto dalle disposizioni di cui al comma 44 del presente articolo, alle risorse di cui all'articolo 40, comma 3, della legge 23 dicembre 1994, n. 724, e successive modificazioni, nonche' agli importi posti a carico degli utenti delle procedure medesime.

47. Gli articoli 2, commi da 1 a 5, 3, 4, 5 e 6 del decreto legislativo 8 ottobre 2007, n. 179, sono abrogati dalla data in cui diviene operativo l'organo decidente di cui al comma 5-ter dell'articolo 2 del citato decreto legislativo n. 179 del 2007. Il regolamento della CONSOB indicato al citato comma 5-ter dell'articolo 2 del decreto legislativo n. 179 del 2007 prevede, altresi', le disposizioni transitorie per la definizione delle procedure di conciliazione che risultano avviate e non ancora concluse alla data in cui diviene operativo l'organo decidente di cui al primo periodo.

48. Dall'attuazione delle disposizioni di cui ai commi da 35 a 47 non devono derivare nuovi o maggiori oneri a carico della finanza pubblica.

49. Il termine di cui all'articolo unico del decreto del Ministro dell'interno 13 maggio 2015, pubblicato nella Gazzetta Ufficiale n. 115 del 20 maggio 2015, deve intendersi riferito al 31 luglio 2015, in quanto ultimo giorno del mese di luglio.

50. Per l'intera durata del programma «Erasmus +», alle borse di studio per la mobilita' internazionale erogate a favore degli studenti delle universita' e delle istituzioni di alta formazione artistica, musicale e coreutica (AFAM), ai sensi dell'articolo 6, paragrafo 1, e dell'articolo 7, paragrafo 1, lettera a), del regolamento (UE) n. 1288/2013 del Parlamento europeo e del Consiglio, dell'11 dicembre 2013, si applicano le esenzioni previste all'articolo 1, comma 3, del decreto-legge 9 maggio 2003, n. 105, convertito, con modificazioni, dalla legge 11 luglio 2003, n. 170.

51. All'articolo 6 della legge 30 novembre 1989, n. 398, dopo il comma 6 e' inserito il seguente: «6-bis. Le somme corrisposte a titolo di borsa di studio per la frequenza dei corsi di perfezionamento e delle scuole di specializzazione, per i corsi di dottorato di ricerca, per lo svolgimento di attivita' di ricerca dopo il dottorato e per i corsi di perfezionamento all'estero, erogate dalla provincia autonoma di Bolzano, sono esenti dall'imposta sul reddito delle persone fisiche nei confronti dei percipienti».

52. Le disposizioni di cui al comma 51 si applicano per i periodi d'imposta per i quali non siano ancora scaduti i termini di accertamento e di riscossione ai sensi della normativa vigente.

53. All'articolo 13 del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, dopo il comma 6 e' inserito il seguente: «6-bis. Per gli immobili locati a canone concordato di cui alla legge 9 dicembre 1998, n. 431, l'imposta, determinata applicando l'aliquota stabilita dal comune ai sensi del comma 6, e' ridotta al 75 per cento».

54. Al comma 678 dell'articolo 1 della legge 27 dicembre 2013, n. 147, e' aggiunto, in fine, il seguente periodo: «Per gli immobili locati a canone concordato di cui alla legge 9 dicembre 1998, n. 431, l'imposta, determinata applicando l'aliquota stabilita dal comune ai sensi del comma 683, e' ridotta al 75 per cento».

55. All'articolo 1, nota II-bis), della tariffa, parte prima, allegata al testo unico delle disposizioni concernenti l'imposta di registro, di cui al decreto del Presidente della Repubblica 26 aprile 1986, n. 131, e' aggiunto, in fine, il seguente comma: «4-bis. L'aliquota del 2 per cento si applica anche agli atti di acquisto per i quali l'acquirente non soddisfa il requisito di cui alla lettera c) del comma 1 e per i quali i requisiti di cui alle lettere a) e b) del medesimo comma si verificano senza tener conto dell'immobile acquistato con le agevolazioni elencate nella lettera c), a condizione che quest'ultimo immobile sia alienato entro un anno dalla data dell'atto. In mancanza di detta alienazione, all'atto di cui al periodo precedente si applica quanto previsto dal comma 4».

56. Ai fini dell'imposta sul reddito delle persone fisiche, si detrae dall'imposta lorda, fino alla concorrenza del suo ammontare, il 50 per cento dell'importo corrisposto per il pagamento dell'imposta sul valore aggiunto in relazione all'acquisto, effettuato entro il 31 dicembre 2017, di unita' immobiliari a destinazione residenziale, di classe energetica A o B ai sensi della normativa vigente, cedute dalle imprese costruttrici delle stesse. La detrazione di cui al precedente periodo e' pari al 50 per cento dell'imposta dovuta sul corrispettivo d'acquisto ed e' ripartita in dieci quote costanti nell'anno in cui sono state sostenute le spese e nei nove periodi d'imposta successivi.

57. Tutti gli atti e i provvedimenti emanati in esecuzione dei piani di ricomposizione fondiaria e di riordino fondiario promossi dalle regioni, dalle province, dai comuni e dalle comunita' montane sono esenti da imposta di registro, ipotecaria, catastale e di bollo.

58. Ai sensi dell'articolo 1, comma 2, della legge 27 luglio 2000, n. 212, l'articolo 32, secondo comma, del decreto del Presidente della Repubblica 29 settembre 1973, n. 601, si interpreta nel senso che l'imposta di registro in misura fissa e l'esenzione dalle imposte ipotecarie e catastali si applicano agli atti di trasferimento della proprieta' delle aree previste al titolo III della legge 22 ottobre 1971, n. 865, indipendentemente dal titolo di acquisizione della proprieta' da parte degli enti locali.

59. L'articolo 13 della legge 9 dicembre 1998, n. 431, e' sostituito dal seguente: «Art. 13 - (Patti contrari alla legge) - 1. E' nulla ogni pattuizione volta a determinare un importo del canone di locazione superiore a quello risultante dal contratto scritto e registrato. E' fatto carico al locatore di provvedere alla registrazione nel termine perentorio di trenta giorni, dandone documentata comunicazione, nei successivi sessanta giorni, al conduttore ed all'amministratore del condominio, anche ai fini dell'ottemperanza agli obblighi di tenuta dell'anagrafe condominiale di cui all'articolo 1130, numero 6), del codice civile. 2. Nei casi di nullita' di cui al comma 1 il conduttore, con azione proponibile nel termine di sei mesi dalla riconsegna dell'immobile locato, puo' chiedere la restituzione delle somme corrisposte in misura superiore al canone risultante dal contratto scritto e registrato. 3. E' nulla ogni pattuizione volta a derogare ai limiti di durata del contratto stabiliti dalla presente legge. 4. Per i contratti di cui al comma 3 dell'articolo 2 e' nulla ogni pattuizione volta ad attribuire al locatore un canone superiore a quello massimo definito dagli accordi conclusi in sede locale per immobili aventi le medesime caratteristiche e appartenenti alle medesime tipologie. Per i contratti stipulati in base al comma 1 dell'articolo 2, e' nulla, ove in contrasto con le disposizioni della presente legge, qualsiasi pattuizione diretta ad attribuire al locatore un canone superiore a quello contrattualmente stabilito. 5. Per i conduttori che, per gli effetti della disciplina di cui all'articolo 3, commi 8 e 9, del decreto legislativo 14 marzo 2011, n. 23, prorogati dall'articolo 5, comma 1-ter, del decreto-legge 28 marzo 2014, n. 47, convertito, con modificazioni, dalla legge 23 maggio 2014, n. 80, hanno versato, nel periodo intercorso dalla data di entrata in vigore del decreto legislativo n. 23 del 2011 al giorno 16 luglio 2015, il canone annuo di locazione nella misura stabilita dalla disposizione di cui al citato articolo 3, comma 8, del decreto legislativo n. 23 del 2011, l'importo del canone di locazione dovuto ovvero dell'indennita' di occupazione maturata, su base annua, e' pari al triplo della rendita catastale dell'immobile, nel periodo considerato. 6. Nei casi di nullita' di cui al comma 4 il conduttore, con azione proponibile nel termine di sei mesi dalla riconsegna dell'immobile locato, puo' richiedere la restituzione delle somme indebitamente versate. Nei medesimi casi il conduttore puo' altresi' richiedere, con azione proponibile dinanzi all'autorita' giudiziaria, che la locazione venga ricondotta a condizioni conformi a quanto previsto dal comma 1 dell'articolo 2 ovvero dal comma 3 dell'articolo 2. Tale azione e', altresi', consentita nei casi in cui il locatore non abbia provveduto alla prescritta registrazione del contratto nel termine di cui al comma 1 del presente articolo. Nel giudizio che accerta l'esistenza del contratto di locazione il giudice determina il canone dovuto, che non puo' eccedere quello del valore minimo definito ai sensi dell'articolo 2 ovvero quello definito ai sensi dell'articolo 5, commi 2 e 3, nel caso di conduttore che abiti stabilmente l'alloggio per i motivi ivi regolati. L'autorita' giudiziaria stabilisce la restituzione delle somme eventualmente eccedenti. 7. Le disposizioni di cui al comma 6 devono ritenersi applicabili a tutte le ipotesi ivi previste insorte sin dall'entrata in vigore della presente legge. 8. I riferimenti alla registrazione del contratto di cui alla presente legge non producono effetti se non vi e' obbligo di registrazione del contratto stesso».

60. All'articolo 11, comma 1, del regolamento di cui al decreto del Presidente della Repubblica 13 settembre 2005, n. 296, dopo la lettera g) e' aggiunta la seguente: «g-bis) le associazioni sportive dilettantistiche, le quali: 1) non hanno fini di lucro; 2) sono affiliate alle federazioni sportive nazionali o agli enti nazionali di promozione sportiva riconosciuti ai sensi delle leggi vigenti; 3) svolgono attivita' sportiva dilettantistica, come definita dalla normativa regolamentare degli organismi affilianti».

61. All'articolo 77, comma 1, del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, a decorrere dal 1° gennaio 2017, con effetto per i periodi d'imposta successivi a quello in corso al 31 dicembre 2016, le parole: «27,5 per cento» sono sostituite dalle seguenti: «24 per cento».

62. All'articolo 27, comma 3-ter, del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, a decorrere dal 1° gennaio 2017, con effetto per i periodi d'imposta successivi a quello in corso al 31 dicembre 2016, le parole: «dell'1,375 per cento» sono sostituite dalle seguenti: «dell'1,20 per cento».

63. Il Fondo di cui all'articolo 1, comma 200, della legge 23 dicembre 2014, n. 190, e' rifinanziato nella misura di 632,5 milioni di euro per l'anno 2016 e di 854,53 milioni di euro per l'anno 2017 ed e' ridotto nella misura di 1,37 milioni di euro a decorrere dall'anno 2018. Le dotazioni finanziarie di parte corrente delle missioni di spesa di ciascun Ministero, di cui all'articolo 21, comma 5, lettera b), della legge 31 dicembre 2009, n. 196, sono ridotte nella misura di 171,7 milioni di euro per l'anno 2018.

64. In relazione ai commi 61 e 62, con decreto del Ministro dell'economia e delle finanze sono proporzionalmente rideterminate le percentuali di cui agli articoli 47, comma 1, 58, comma 2, 59 e 68, comma 3, del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, nonche' la percentuale di cui all'articolo 4, comma 1, lettera q), del decreto legislativo 12 dicembre 2003, n. 344. La rideterminazione delle percentuali di cui agli articoli 58, comma 2, e 68, comma 3, del citato testo unico di cui al decreto del Presidente della Repubblica n. 917 del 1986 non si applica ai soggetti di cui all'articolo 5 del medesimo testo unico. Con il medesimo decreto sono altresi' determinate la normativa transitoria e le relative decorrenze.

65. Per gli intermediari finanziari, escluse le societa' di gestione dei fondi comuni d'investimento e le societa' di intermediazione mobiliare di cui al testo unico delle disposizioni in materia di intermediazione finanziaria, di cui al decreto legislativo 24 febbraio 1998, n. 58, e per la Banca d'Italia, l'aliquota di cui all'articolo 77 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e' applicata con una addizionale di 3,5 punti percentuali. (31) (37)

66. I soggetti che hanno esercitato l'opzione per la tassazione di gruppo di cui all'articolo 117 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e i soggetti che hanno esercitato, in qualita' di partecipati, l'opzione per la trasparenza fiscale di cui all'articolo 115 del citato testo unico assoggettano autonomamente il proprio reddito imponibile all'addizionale prevista dal comma 65 del presente articolo e provvedono al relativo versamento; i soggetti che hanno esercitato, in qualita' di partecipanti, l'opzione per la trasparenza fiscale di cui al citato articolo 115 del medesimo testo unico assoggettano il proprio reddito imponibile all'addizionale prevista dal comma 65 del presente articolo senza tener conto del reddito imputato dalla societa' partecipata.

67. All'articolo 96, comma 5-bis, del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, il primo periodo e' sostituito dal seguente: "Gli interessi passivi sostenuti dalle imprese di assicurazione e dalle societa' capogruppo di gruppi assicurativi, nonche' dalle societa' di gestione dei fondi comuni d'investimento e dalle societa' di intermediazione mobiliare di cui al testo unico delle disposizioni in materia di intermediazione finanziaria, di cui al decreto legislativo 24 febbraio 1998, n. 58, sono deducibili nei limiti del 96 per cento del loro ammontare". (31)

68. All'articolo 6, comma 8, del decreto legislativo 15 dicembre 1997, n. 446, il secondo periodo e' soppresso.

69. Le disposizioni di cui ai commi da 65 a 68 si applicano a decorrere dal periodo d'imposta successivo a quello in corso al 31 dicembre 2016.

70. Al decreto legislativo 15 dicembre 1997, n. 446, sono apportate le seguenti modificazioni:

- a) all'articolo 3: 1) al comma 1, la lettera d) e' abrogata; 2) al comma 2, dopo la lettera c) e' aggiunta la seguente: «c-bis) i soggetti che esercitano una attivita' agricola ai sensi dell'articolo 32 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, i soggetti di cui all'articolo 8 del decreto legislativo 18 maggio 2001, n. 227, nonche' le cooperative e loro consorzi di cui all'articolo 10 del decreto del Presidente della Repubblica 29 settembre 1973, n. 601»;
- b) all'articolo 4, comma 2, primo periodo, le parole: «e le imprese agricole» e le parole: «e all'estensione dei terreni» sono soppresse;
- c) all'articolo 9: 1) la rubrica e' sostituita dalla seguente: «Determinazione del valore della produzione netta per alcuni soggetti del settore agricolo»; 2) al comma 1, le parole: «i soggetti di cui all'articolo 3, comma 1, lettera d), e per» sono soppresse;
- d) all'articolo 12, comma 2, primo periodo, le parole: «, ovvero derivante da imprese agricole esercitate nel territorio stesso» sono soppresse;
- e) all'articolo 45, il comma 1 e' abrogato.

71. All'articolo 1 della legge 24 dicembre 2007, n. 244, il comma 238 e' abrogato.

72. Le disposizioni del comma 70 si applicano a decorrere dal periodo d'imposta successivo a quello in corso al 31 dicembre 2015.

73. All'articolo 11, comma 4-octies, del decreto legislativo 15 dicembre 1997, n. 446, e' aggiunto, in fine, il seguente periodo: «La deduzione di cui al periodo precedente e' ammessa altresi', nei limiti del 70 per cento della differenza ivi prevista, calcolata per ogni lavoratore stagionale impiegato per almeno centoventi giorni per due periodi d'imposta, a decorrere dal secondo contratto stipulato con lo stesso datore di lavoro nell'arco temporale di due anni a partire dalla data di cessazione del precedente contratto».

74. Al decreto-legge 4 giugno 2013, n. 63, convertito, con modificazioni, dalla legge 3 agosto 2013, n. 90, sono apportate le seguenti modificazioni:

- a) all'articolo 14, le parole: «31 dicembre 2015», ovunque ricorrono, sono sostituite dalle seguenti: «31 dicembre 2016» e dopo il comma 2-bis e' inserito il seguente: «2-ter. Per le spese sostenute dal 1° gennaio 2016 al 31 dicembre 2016 per interventi di riqualificazione energetica di parti comuni degli edifici condominiali, i soggetti di cui all'articolo 11, comma 2, e all'articolo 13, comma 1, lettera a), e comma 5, lettera a), del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e successive modificazioni, in luogo della detrazione di cui al comma 1 del presente articolo possono optare per la cessione del corrispondente credito ai fornitori che hanno effettuato i predetti interventi, con modalita' da definire con provvedimento del direttore dell'Agenzia delle entrate, da emanare entro sessanta giorni dalla data di entrata in vigore della presente disposizione»;
- b) all'articolo 15, comma 1, le parole: «31 dicembre 2015» sono sostituite dalle seguenti: «31 dicembre 2016»;
- c) all'articolo 16, le parole: «31 dicembre 2015», ovunque ricorrono, sono sostituite dalle seguenti: «31 dicembre 2016».

75. Le giovani coppie costituenti un nucleo familiare composto da coniugi o da conviventi more uxorio che abbiano costituito nucleo da almeno tre anni, in cui almeno uno dei due componenti non abbia superato i trentacinque anni, acquirenti di unita' immobiliare da adibire ad abitazione principale, beneficiano di una detrazione dall'imposta lorda, fino a concorrenza del suo ammontare, per le spese documentate sostenute per l'acquisto di mobili ad arredo della medesima unita' abitativa. La detrazione di cui al presente comma, da ripartire tra gli aventi diritto in dieci quote annuali di pari importo, spetta nella misura del 50 per cento delle spese sostenute dal 1° gennaio 2016 al 31 dicembre 2016 ed e' calcolata su un ammontare complessivo non superiore a 16.000 euro. Il beneficio di cui al presente comma non e' cumulabile con quello di cui alla lettera c) del comma 74.

76. Con il contratto di locazione finanziaria di immobile da adibire ad abitazione principale, la banca o l'intermediario finanziario iscritto nell'albo di cui all'articolo 106 del testo unico delle leggi in materia bancaria e creditizia, di cui al decreto legislativo 1° settembre 1993, n. 385, si obbliga ad acquistare o a far costruire l'immobile su scelta e secondo le indicazioni dell'utilizzatore, che se ne assume tutti i rischi, anche di perimento, e lo mette a disposizione per un dato tempo verso un determinato corrispettivo che tenga conto del prezzo di acquisto o di costruzione e della durata del contratto. Alla scadenza del contratto l'utilizzatore ha la facolta' di acquistare la proprieta' del bene a un prezzo prestabilito.

77. All'acquisto dell'immobile oggetto del contratto di locazione finanziaria si applica l'articolo 67, terzo comma, lettera a), del regio decreto 16 marzo 1942, n. 267.

78. In caso di risoluzione del contratto di locazione finanziaria per inadempimento dell'utilizzatore, il concedente ha diritto alla restituzione del bene ed e' tenuto a corrispondere all'utilizzatore quanto ricavato dalla vendita o da altra collocazione del bene avvenute a valori di mercato, dedotta la somma dei canoni scaduti e non pagati fino alla data della risoluzione, dei canoni a scadere attualizzati e del prezzo pattuito per l'esercizio dell'opzione finale di acquisto. L'eventuale differenza negativa e' corrisposta dall'utilizzatore al concedente. Nelle attivita' di vendita e ricollocazione del bene, di cui al periodo precedente, la banca o l'intermediario finanziario deve attenersi a criteri di trasparenza e pubblicita' nei confronti dell'utilizzatore.

79. Per il contratto di cui al comma 76 l'utilizzatore puo' chiedere, previa presentazione di apposita richiesta al concedente, la sospensione del pagamento dei corrispettivi periodici per non piu' di una volta e per un periodo massimo complessivo non superiore a dodici mesi nel corso dell'esecuzione del contratto medesimo. In tal caso, la durata del contratto e' prorogata di un periodo eguale alla durata della sospensione. L'ammissione al beneficio della sospensione e' subordinata esclusivamente all'accadimento di almeno uno dei seguenti eventi, intervenuti successivamente alla stipula del contratto di cui al comma 76:

- a) cessazione del rapporto di lavoro subordinato, ad eccezione delle ipotesi di risoluzione consensuale, di risoluzione per limiti di eta' con diritto a pensione di vecchiaia o di anzianita', di licenziamento per giusta causa o giustificato motivo soggettivo, di dimissioni del lavoratore non per giusta causa;
- b) cessazione dei rapporti di lavoro di cui all'articolo 409, numero 3), del codice di procedura civile, ad eccezione delle ipotesi di risoluzione consensuale, di recesso datoriale per giusta causa, di recesso del lavoratore non per giusta causa.

80. Al termine della sospensione, il pagamento dei corrispettivi periodici riprende secondo gli importi e con la periodicita' originariamente previsti dal contratto, salvo diverso patto eventualmente intervenuto fra le parti per la rinegoziazione delle condizioni del contratto medesimo. Decorso il periodo di sospensione, in caso di mancata ripresa dei pagamenti si applicano le disposizioni del comma 78. La sospensione non comporta l'applicazione di alcuna commissione o spesa di istruttoria e avviene senza richiesta di garanzie aggiuntive.

81. Per il rilascio dell'immobile il concedente puo' agire con il procedimento per convalida di sfratto di cui al libro IV, titolo I, capo II, del codice di procedura civile.

82. All'articolo 15, comma 1, del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, dopo la lettera i-sexies) sono inserite le seguenti: «i-sexies.1) i canoni, e i relativi oneri accessori, per un importo non superiore a 8.000 euro, e il costo di acquisto a fronte dell'esercizio dell'opzione finale, per un importo non superiore a 20.000 euro, derivanti da contratti di locazione finanziaria su unita' immobiliari, anche da costruire, da adibire ad abitazione principale entro un anno dalla consegna, sostenuti da giovani di eta' inferiore a 35 anni con un reddito complessivo non superiore a 55.000 euro all'atto della stipula del contratto di locazione finanziaria che non sono titolari di diritti di proprieta' su immobili a destinazione abitativa; la detrazione spetta alle condizioni di cui alla lettera b); i-sexies.2) le spese di cui alla lettera i-sexies.1), alle condizioni ivi indicate e per importi non superiori alla meta' di quelli ivi indicati, sostenute da soggetti di eta' non inferiore a 35 anni con un reddito complessivo non superiore a 55.000 euro all'atto della stipula del contratto di locazione finanziaria che non sono titolari di diritti di proprieta' su immobili a destinazione abitativa».

83. Al testo unico delle disposizioni concernenti l'imposta di registro, di cui al decreto del Presidente della Repubblica 26 aprile 1986, n. 131, sono apportate le seguenti modificazioni:

- a) all'articolo 40, comma 1-bis, le parole: «immobili strumentali, anche da costruire ed ancorche' assoggettati all'imposta sul valore aggiunto, di cui all'articolo 10, primo comma, numero 8-ter)» sono sostituite dalle seguenti: «immobili abitativi e strumentali, anche da costruire ed ancorche' assoggettati all'imposta sul valore aggiunto, di cui all'articolo 10, primo comma, numeri 8-bis) e 8-ter)»;
- b) all'articolo 1 della tariffa, parte prima: 1) dopo il terzo capoverso e' aggiunto il seguente: «Se il trasferimento e' effettuato nei confronti di banche e intermediari finanziari autorizzati all'esercizio dell'attivita' di leasing finanziario, e ha per oggetto case di abitazione, di categoria catastale diversa da Al, A8 e A9, acquisite in locazione finanziaria da utilizzatori per i quali ricorrono le condizioni di cui alle note II-bis) e II-sexies): 1,5 per cento»; 2) e' aggiunta, in fine, la seguente nota: «II-sexies) Nell'applicazione della nota II-bis) ai trasferimenti effettuati nei confronti di banche e intermediari finanziari autorizzati all'esercizio dell'attivita' di leasing finanziario, si considera, in luogo dell'acquirente, l'utilizzatore e, in luogo dell'atto di acquisto, il contratto di locazione finanziaria»;
- c) all'articolo 8-bis della tariffa, parte prima: 1) dopo il comma 1 sono aggiunti i seguenti: «1-bis. Atti relativi alle cessioni, da parte degli utilizzatori, di contratti di locazione finanziaria aventi ad oggetto immobili a destinazione abitativa, di categoria catastale diversa da Al, A8 e A9, effettuate nei confronti di soggetti per i quali ricorrono le condizioni di cui alle note II-bis) e II-sexies) dell'articolo 1, ancorche' assoggettati all'imposta sul valore aggiunto, di cui all'articolo 10, primo comma, numero 8-bis), del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633: 1,5 per cento. 1-ter. Atti, diversi da quelli di cui al comma 1-bis, relativi alle cessioni, da parte degli utilizzatori, di contratti di locazione finanziaria aventi ad oggetto immobili a destinazione abitativa, anche da costruire ed ancorche' assoggettati all'imposta sul valore aggiunto, di cui all'articolo 10, primo comma, numero 8-bis), del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633: 9 per cento»; 2) alla nota I), le parole: «di cui al comma 1» sono sostituite dalle seguenti: «di cui ai commi 1, 1-bis e 1-ter».

84. Le disposizioni di cui ai commi 82 e 83 si applicano dal 1° gennaio 2016 al 31 dicembre 2020.

85. In attuazione del principio di salvaguardia ambientale e al fine di incentivare la sostituzione, mediante demolizione, dei veicoli di cui all'articolo 54, comma 1, lettera m), del codice della strada, di cui al decreto legislativo 30 aprile 1992, n. 285, di categoria «euro 0», «euro 1» o «euro 2» con veicoli nuovi, aventi classi di emissione non inferiore ad «euro 5» della medesima tipologia, e' riconosciuto un contributo fino a un massimo di 8.000 euro per ciascun veicolo acquistato. A tale fine e' autorizzata la spesa massima di 5 milioni di euro per l'anno 2016. Il contributo e' anticipato all'acquirente dal rivenditore sotto forma di sconto sul prezzo di vendita ed e' a questo rimborsato sotto forma di credito d'imposta di pari importo, da utilizzare in compensazione ai sensi dell'articolo 17 del decreto legislativo 9 luglio 1997, n. 241. Con decreto del Ministro delle infrastrutture e dei trasporti, di concerto con il Ministro dell'economia e delle finanze, sono definite le modalita' di attuazione, comprese quelle per usufruire del credito d'imposta, le modalita' di comunicazione delle spese effettuate ai fini della verifica della capienza dei fondi disponibili, il regime dei controlli nonche' ogni altra disposizione necessaria per il monitoraggio dell'agevolazione.

86. Le disposizioni di cui al comma 85 si applicano per i veicoli nuovi acquistati con contratto stipulato tra il venditore e l'acquirente a decorrere dal 1° gennaio 2016 e fino al 31 dicembre 2016 e immatricolati entro il 31 marzo 2017.

87. Le detrazioni di cui all'articolo 14 del decreto-legge 4 giugno 2013, n. 63, convertito, con modificazioni, dalla legge 3 agosto 2013, n. 90, sono usufruibili anche dagli Istituti autonomi per le case popolari, comunque denominati, per le spese sostenute, dal 1° gennaio 2016 al 31 dicembre 2016, per interventi realizzati su immobili di loro proprieta' adibiti ad edilizia residenziale pubblica.

88. Le detrazioni fiscali di cui all'articolo 14 del decreto-legge 4 giugno 2013, n. 63, convertito, con modificazioni, dalla legge 3 agosto 2013, n. 90, si applicano anche alle spese sostenute per l'acquisto, l'installazione e la messa in opera di dispositivi multimediali per il controllo da remoto degli impianti di riscaldamento o produzione di acqua calda o di climatizzazione delle unita' abitative, volti ad aumentare la consapevolezza dei consumi energetici da parte degli utenti e a garantire un funzionamento efficiente degli impianti. Tali dispositivi devono:

- a) mostrare attraverso canali multimediali i consumi energetici, mediante la fornitura periodica dei dati;
- b) mostrare le condizioni di funzionamento correnti e la temperatura di regolazione degli impianti;
- c) consentire l'accensione, lo spegnimento e la programmazione settimanale degli impianti da remoto.

89. All'articolo 6 del decreto del Presidente della Repubblica 29 settembre 1973, n. 601, al comma 1, lettera c-bis), dopo le parole: «e loro consorzi» sono aggiunte le seguenti: «nonche' enti aventi le stesse finalita' sociali dei predetti Istituti, istituiti nella forma di societa' che rispondono ai requisiti della legislazione dell'Unione europea in materia di "in house providing" e che siano costituiti e operanti alla data del 31 dicembre 2013».

90. All'articolo 88 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, al comma 3, lettera b), dopo le parole: «comunque denominati,» sono inserite le seguenti: «e agli enti aventi le stesse finalita' sociali dei predetti Istituti, istituiti nella forma di societa' che rispondono ai requisiti della legislazione dell'Unione europea in materia di "in house providing" e che siano costituiti e operanti alla data del 31 dicembre 2013,».

91. Ai fini delle imposte sui redditi, per i soggetti titolari di reddito d'impresa e per gli esercenti arti e professioni che effettuano investimenti in beni materiali strumentali nuovi dal 15 ottobre 2015 al 31 dicembre 2016, con esclusivo riferimento alla determinazione delle quote di ammortamento e dei canoni di locazione finanziaria, il costo di acquisizione e' maggiorato del 40 per cento. (14)

92. Fermo restando quanto disposto al comma 91 e solo per gli investimenti effettuati nello stesso periodo ivi previsto, sono altresi' maggiorati del 40 per cento i limiti rilevanti per la deduzione delle quote di ammortamento e dei canoni di locazione finanziaria dei beni di cui all'articolo 164, comma 1, lettera b), del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917.

93. La disposizione di cui al comma 91 non si applica agli investimenti in beni materiali strumentali per i quali il decreto del Ministro delle finanze 31 dicembre 1988, pubblicato nel supplemento ordinario alla Gazzetta Ufficiale n. 27 del 2 febbraio 1989, stabilisce coefficienti di ammortamento inferiori al 6,5 per cento, agli investimenti in fabbricati e costruzioni, nonche' agli investimenti in beni di cui all'allegato n. 3 annesso alla presente legge.

94. Le disposizioni dei commi 91 e 92 non producono effetti sulla determinazione dell'acconto dovuto per il periodo di imposta in corso al 31 dicembre 2015. La determinazione dell'acconto dovuto per il periodo di imposta in corso al 31 dicembre 2016 e' effettuata considerando, quale imposta del periodo precedente, quella che si sarebbe determinata in assenza delle disposizioni dei citati commi 91 e 92.

95. Al comma 10 dell'articolo 15 del decreto-legge 29 novembre 2008, n. 185, convertito, con modificazioni, dalla legge 28 gennaio 2009, n. 2, le parole: «non superiore ad un decimo» sono sostituite dalle seguenti: «non superiore ad un quinto».

96. La disposizione di cui al comma 95 si applica alle operazioni di aggregazione aziendale poste in essere a decorrere dall'esercizio successivo a quello in corso al 31 dicembre 2015.

97. Le disposizioni di cui ai commi 91 e 92 non producono effetti sui valori attualmente stabiliti per l'elaborazione e il calcolo degli studi di settore previsti dall'articolo 62-bis del decreto-legge 30 agosto 1993, n. 331, convertito, con modificazioni, dalla legge 29 ottobre 1993, n. 427, e successive modificazioni.

98. Alle imprese che effettuano l'acquisizione dei beni strumentali nuovi indicati nel comma 99, destinati a strutture produttive ubicate nelle zone assistite delle regioni Campania, Puglia, Basilicata, Calabria, della Regione siciliana e delle regioni Sardegna e Molise, ammissibili alle deroghe previste dall'articolo 107, paragrafo 3, lettera a), del Trattato sul funzionamento dell'Unione europea, e nelle zone assistite della regione Abruzzo, ammissibili alle deroghe previste dall'articolo 107, paragrafo 3, lettera c), del Trattato sul funzionamento dell'Unione europea, come individuate dalla Carta degli aiuti a finalita' regionale 2022-2027, fino al 31 dicembre 2023, e' attribuito un credito d'imposta nella misura massima consentita dalla Carta degli aiuti a finalita' regionale 2014-2020 C(2014) 6424 final del 16 settembre 2014, come modificata dalla decisione C(2016) 5938 final del 23 settembre 2016. Alle imprese attive nel settore della produzione primaria di prodotti agricoli, nel settore della pesca e dell'acquacoltura, disciplinato dal regolamento (UE) n. 1379/2013 del Parlamento europeo e del Consiglio, dell'11 dicembre 2013, e nel settore della trasformazione e della commercializzazione di prodotti agricoli, della pesca e dell'acquacoltura, che effettuano l'acquisizione di beni strumentali nuovi, gli aiuti sono concessi nei limiti e alle condizioni previsti dalla normativa europea in materia di aiuti di Stato nei settori agricolo, forestale e delle zone rurali e ittico.

99. Per le finalita' di cui al comma 98, sono agevolabili gli investimenti, facenti parte di un progetto di investimento iniziale come definito all'articolo 2, punti 49, 50 e 51, del regolamento (UE) n. 651/2014 della Commissione, del 17 giugno 2014, relativi all'acquisto, anche mediante contratti di locazione finanziaria, di macchinari, impianti e attrezzature varie destinati a strutture produttive gia' esistenti o che vengono impiantate nel territorio.

100. L'agevolazione non si applica ai soggetti che operano nei settori dell'industria siderurgica, carbonifera, della costruzione navale, delle fibre sintetiche, dei trasporti e delle relative infrastrutture, della produzione e della distribuzione di energia e delle infrastrutture energetiche, nonche' ai settori creditizio, finanziario e assicurativo. L'agevolazione, altresi', non si applica alle imprese in difficolta' come definite dalla comunicazione della Commissione europea 2014/C 249/01, del 31 luglio 2014.

101. Il credito d'imposta e' commisurato alla quota del costo complessivo dei beni indicati nel comma 99, nel limite massimo, per ciascun progetto di investimento, di 3 milioni di euro per le piccole imprese, di 10 milioni di euro per le medie imprese e di 15 milioni di euro per le grandi imprese. Per gli investimenti effettuati mediante contratti di locazione finanziaria, si assume il costo sostenuto dal locatore per l'acquisto dei beni; tale costo non comprende le spese di manutenzione.

102. Il credito d'imposta e' cumulabile con aiuti de minimis e con altri aiuti di Stato che abbiano ad oggetto i medesimi costi ammessi al beneficio, a condizione che tale cumulo non porti al superamento dell'intensita' o dell'importo di aiuto piu' elevati consentiti dalle pertinenti discipline europee di riferimento.

103. I soggetti che intendono avvalersi del credito d'imposta devono presentare apposita comunicazione all'Agenzia delle entrate. Le modalita', i termini di presentazione e il contenuto della comunicazione sono stabiliti con provvedimento del direttore dell'Agenzia medesima, da emanare entro sessanta giorni dalla data di pubblicazione della presente legge nella Gazzetta Ufficiale. L'Agenzia delle entrate comunica alle imprese l'autorizzazione alla fruizione del credito d'imposta.

104. Il credito d'imposta e' utilizzabile esclusivamente in compensazione ai sensi dell'articolo 17 del decreto legislativo 9 luglio 1997, n. 241, e successive modificazioni, a decorrere dal periodo d'imposta in cui e' stato effettuato l'investimento e deve essere indicato nella dichiarazione dei redditi relativa al periodo d'imposta di maturazione del credito e nelle dichiarazioni dei redditi relative ai periodi d'imposta successivi fino a quello nel quale se ne conclude l'utilizzo. Al credito d'imposta non si applica il limite di cui all'articolo 1, comma 53, della legge 24 dicembre 2007, n. 244.

105. Se i beni oggetto dell'agevolazione non entrano in funzione entro il secondo periodo d'imposta successivo a quello della loro acquisizione o ultimazione, il credito d'imposta e' rideterminato escludendo dagli investimenti agevolati il costo dei beni non entrati in funzione. Se, entro il quinto periodo d'imposta successivo a quello nel quale sono entrati in funzione, i beni sono dismessi, ceduti a terzi, destinati a finalita' estranee all'esercizio dell'impresa ovvero destinati a strutture produttive diverse da quelle che hanno dato diritto all'agevolazione, il credito d'imposta e' rideterminato escludendo dagli investimenti agevolati il costo dei beni anzidetti. Per i beni acquisiti in locazione finanziaria, le disposizioni di cui al presente comma si applicano anche se non viene esercitato il riscatto. Il credito d'imposta indebitamente utilizzato rispetto all'importo rideterminato secondo le disposizioni del presente comma e' restituito mediante versamento da eseguire entro il termine stabilito per il versamento a saldo dell'imposta sui redditi dovuta per il periodo d'imposta in cui si verificano le ipotesi ivi indicate.

106. Qualora, a seguito dei controlli, sia accertata l'indebita fruizione, anche parziale, del credito d'imposta per il mancato rispetto delle condizioni richieste dalla norma ovvero a causa dell'inammissibilita' dei costi sulla base dei quali e' stato determinato l'importo fruito, l'Agenzia delle entrate provvede al recupero del relativo importo, maggiorato di interessi e sanzioni previsti dalla legge.

107. L'agevolazione di cui ai commi da 98 a 106 e' concessa nel rispetto dei limiti e delle condizioni previsti dal regolamento (UE) n. 651/2014 della Commissione, del 17 giugno 2014, che dichiara alcune categorie di aiuti compatibili con il mercato interno in applicazione degli articoli 107 e 108 del Trattato sul funzionamento dell'Unione europea, e in particolare dall'articolo 14 del medesimo regolamento, che disciplina gli aiuti a finalita' regionale agli investimenti.

108. Gli oneri derivanti dai commi da 98 a 107 sono valutati in 617 milioni di euro per ciascuno degli anni 2016, 2017, 2018, 2019 e 2020, in 1.053,9 milioni di euro per ciascuno degli anni 2021 e 2022 e in 1.467 milioni di euro per l'anno 2023; i predetti importi sono corrispondentemente iscritti in apposito capitolo di spesa dello stato di previsione del Ministero dell'economia e delle finanze. Ai predetti oneri si fa fronte per 250 milioni di euro annui, relativamente alle agevolazioni concesse alle piccole e medie imprese, a valere sulle risorse europee e di cofinanziamento nazionale previste nel programma operativo nazionale «Imprese e Competitivita' 2014/ 2020» e nei programmi operativi relativi al Fondo europeo di sviluppo regionale (FESR) 2014/2020 delle regioni in cui si applica l'incentivo. A tal fine le predette risorse sono annualmente versate all'entrata del bilancio dello Stato. Le amministrazioni titolari dei predetti programmi comunicano al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato gli importi, europei e nazionali, riconosciuti a titolo di credito d'imposta dall'Unione europea, da versare all'entrata del bilancio dello Stato. Nelle more della conclusione della procedura finalizzata all'individuazione delle risorse, alla regolazione contabile delle compensazioni esercitate ai sensi del presente comma si provvede mediante anticipazioni a carico delle disponibilita' del Fondo di rotazione di cui all'articolo 5 della legge 16 aprile 1987, n. 183. Le risorse cosi' anticipate vengono reintegrate al Fondo, per la parte relativa all'Unione europea, a valere sui successivi accrediti delle corrispondenti risorse dell'Unione europea in favore dei citati programmi operativi e, per la parte di cofinanziamento nazionale, a valere sulle corrispondenti quote di cofinanziamento nazionale riconosciute a seguito delle predette rendicontazioni di spesa. (18) (31)

109. Entro il 31 marzo 2016 si provvede, con le procedure di cui all'articolo 4, comma 3, del decreto-legge 28 giugno 2013, n. 76, convertito, con modificazioni, dalla legge 9 agosto 2013, n. 99, alla ricognizione delle risorse del Fondo di rotazione di cui all'articolo 5 della legge 16 aprile 1987, n. 183, gia' destinate agli interventi del Piano di Azione Coesione (PAC), non ancora oggetto di impegni giuridicamente vincolanti rispetto ai cronoprogrammi approvati. A tal fine, le amministrazioni titolari di interventi del PAC, approvati alla data di entrata in vigore della presente legge, inviano al sistema di monitoraggio nazionale, entro il 31 gennaio 2016, i dati relativi alle risorse impegnate e pagate per ciascuna linea di intervento.

110. Con decreto del Presidente del Consiglio dei ministri, adottato entro il 30 aprile 2016 di concerto con il Ministro dell'economia e delle finanze e con il Ministro del lavoro e delle politiche sociali, e' determinato l'ammontare delle risorse disponibili in esito alla ricognizione di cui al comma 109 ed e' disposto l'utilizzo delle stesse per l'estensione dell'esonero contributivo di cui ai commi 178 e 179 alle assunzioni a tempo indeterminato effettuate nell'anno 2017 in favore dei datori di lavoro privati, operanti nelle regioni Abruzzo, Molise, Campania, Basilicata, Sicilia, Puglia, Calabria e Sardegna, alle medesime condizioni previste dai predetti commi, eventualmente rimodulando la durata temporale e l'entita' dell'esonero e comunque assicurando una maggiorazione della percentuale di decontribuzione e del relativo importo massimo per l'assunzione di donne di qualsiasi eta', prive di un impiego regolarmente retribuito da almeno sei mesi, in ragione delle risorse che si renderanno disponibili ai sensi del comma 109, la cui efficacia e' subordinata all'autorizzazione della Commissione europea ai sensi dell'articolo 108, paragrafo 3, del Trattato sul funzionamento dell'Unione europea.

111. All'articolo 1 della legge 23 dicembre 2014, n. 190, sono apportate le seguenti modificazioni:

- a) la lettera d) del comma 54 e' abrogata;
- b) al comma 57, dopo la lettera d) e' aggiunta la seguente: «d-bis) i soggetti che nell'anno precedente hanno percepito redditi di lavoro dipendente e redditi assimilati a quelli di lavoro dipendente, di cui rispettivamente agli articoli 49 e 50 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, eccedenti l'importo di 30.000 euro; la verifica di tale soglia e' irrilevante se il rapporto di lavoro e' cessato»;
- c) al comma 65, alinea, le parole: «e per i due successivi, il reddito determinato ai sensi del comma 64 e' ridotto di un terzo» sono sostituite dalle seguenti: «e per i quattro successivi, l'aliquota di cui al comma 64 e' stabilita nella misura del 5 per cento»;
- d) il comma 77 e' sostituito dal seguente: «77. Il reddito forfettario determinato ai sensi dei precedenti commi costituisce base imponibile ai sensi dell'articolo 1 della legge 2 agosto 1990, n. 233. Su tale reddito si applica la contribuzione dovuta ai fini previdenziali, ridotta del 35 per cento. Si applica, per l'accredito della contribuzione, la disposizione di cui all'articolo 2, comma 29, della legge 8 agosto 1995, n. 335».

112. L'allegato n. 4 annesso alla legge 23 dicembre 2014, n. 190, e' sostituito dal seguente: «ALLEGATO 4 Articolo 1, comma 54, lettera a) (Regime fiscale per lavoratori autonomi) Pro- gres- sivo Gruppo di settore Codici attivita' ATECO 2007 Valore soglia dei ricavi/compensi Redditivita' 1 Industrie alimentari e delle bevande (10-11) 45.000 40% 2 Commercio all'ingrosso e al dettaglio 45- (da 46.2 a 46.9) - (da 47.1 a 47.7)-47.9 50.000 40% 3 Commercio ambulante di prodotti alimentari e bevande 47.81 40.000 40% 4 Commercio ambulante di altri prodotti 47.82 - 47.89 30.000 54% 5 Costruzioni e attivita' immobiliari (41 - 42 - 43) - (68) 25.000 86% 6 Intermediari del commercio 46.1 25.000 62% 7 Attivita' dei servizi di alloggio e di ristorazione (55-56) 50.000 40% 8 Attivita' professionali, scientifiche, tecniche, sanitarie, di istruzione, servizi finanziari ed assicurativi (64 - 65 - 66) - (69 - 70 - 71 - 72 - 73 - 74 - 75) - (85) - (86 - 87 - 88) 30.000 78% 9 Altre attivita' economiche (01 - 02 - 03)- (05 - 06 - 07 - 08 - 09) - (12 - 13 - 14 - 15 - 16 - 17 - 18 - 19 - 20 - 21 - 22 - 23 - 24 - 25 - 26 - 27 - 28 - 29 - 30 - 31 - 32 - 33) - (35) - (36 - 37 - 38 - 39) - (49 - 50 - 51 - 52 - 53) - (58 - 59 - 60 - 61 - 62 - 63) - (77 - 78 - 79 - 80 - 81 - 82) - (84) - (90 -91 - 92 - 93) - (94 - 95 - 96) -(97 - 98) - (99) 30.000 67% ».

113. Le disposizioni di cui alla lettera c) del comma 111 si applicano, per gli anni 2016, 2017, 2018 e 2019, anche ai soggetti che nel 2015 hanno iniziato una nuova attivita', avvalendosi delle disposizioni di cui all'articolo 1, comma 65, della citata legge n. 190 del 2014, vigente anteriormente alle modifiche di cui alla lettera c) del comma 111.

114. Fermo restando il trattamento previdenziale per i soci delle cooperative artigiane che stabiliscono un rapporto di lavoro in forma autonoma ai sensi dell'articolo 1, comma 3, della legge 3 aprile 2001, n. 142, ai fini dell'imposta sul reddito si applica l'articolo 50 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e successive modificazioni.

115. Le societa' in nome collettivo, in accomandita semplice, a responsabilita' limitata, per azioni e in accomandita per azioni che, entro il 30 settembre 2016, assegnano o cedono ai soci beni immobili, diversi da quelli indicati nell'articolo 43, comma 2, primo periodo, del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, o beni mobili iscritti in pubblici registri non utilizzati come beni strumentali nell'attivita' propria dell'impresa, possono applicare le disposizioni dei commi dal presente al comma 120 a condizione che tutti i soci risultino iscritti nel libro dei soci, ove prescritto, alla data del 30 settembre 2015, ovvero che vengano iscritti entro trenta giorni dalla data di entrata in vigore della presente legge, in forza di titolo di trasferimento avente data certa anteriore al 1° ottobre 2015. Le medesime disposizioni si applicano alle societa' che hanno per oggetto esclusivo o principale la gestione dei predetti beni e che entro il 30 settembre 2016 si trasformano in societa' semplici.(14)

116. Sulla differenza tra il valore normale dei beni assegnati o, in caso di trasformazione, quello dei beni posseduti all'atto della trasformazione, e il loro costo fiscalmente riconosciuto, si applica un'imposta sostitutiva delle imposte sui redditi e dell'imposta regionale sulle attivita' produttive nella misura dell'8 per cento ovvero del 10,5 per cento per le societa' considerate non operative in almeno due dei tre periodi di imposta precedenti a quello in corso al momento della assegnazione, cessione o trasformazione. Le riserve in sospensione d'imposta annullate per effetto dell'assegnazione dei beni ai soci e quelle delle societa' che si trasformano sono assoggettate ad imposta sostitutiva nella misura del 13 per cento. (14)

117. Per gli immobili, su richiesta della societa' e nel rispetto delle condizioni prescritte, il valore normale puo' essere determinato in misura pari a quello risultante dall'applicazione all'ammontare delle rendite risultanti in catasto dei moltiplicatori determinati con i criteri e le modalita' previsti dal primo periodo del comma 4 dell'articolo 52 del testo unico delle disposizioni concernenti l'imposta di registro, di cui al decreto del Presidente della Repubblica 26 aprile 1986, n. 131. In caso di cessione, ai fini della determinazione dell'imposta sostitutiva, il corrispettivo della cessione, se inferiore al valore normale del bene, determinato ai sensi dell'articolo 9 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e successive modificazioni, o in alternativa, ai sensi del primo periodo, e' computato in misura non inferiore ad uno dei due valori. (14)

118. Il costo fiscalmente riconosciuto delle azioni o quote possedute dai soci delle societa' trasformate va aumentato della differenza assoggettata ad imposta sostitutiva. Nei confronti dei soci assegnatari non si applicano le disposizioni di cui ai commi 1, secondo periodo, e da 5 a 8 dell'articolo 47 del citato testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica n. 917 del 1986. Tuttavia, il valore normale dei beni ricevuti, al netto dei debiti accollati, riduce il costo fiscalmente riconosciuto delle azioni o quote possedute. (14)

119. Per le assegnazioni e le cessioni ai soci di cui ai commi da 115 a 118, le aliquote dell'imposta proporzionale di registro eventualmente applicabili sono ridotte alla meta' e le imposte ipotecarie e catastali si applicano in misura fissa. (14)

120. Le societa' che si avvalgono delle disposizioni di cui ai commi da 115 a 118 devono versare il 60 per cento dell'imposta sostitutiva entro il 30 novembre 2016 e la restante parte entro il 16 giugno 2017, con i criteri di cui al decreto legislativo 9 luglio 1997, n. 241. Per la riscossione, i rimborsi ed il contenzioso si applicano le disposizioni previste per le imposte sui redditi. (14)

121. L'imprenditore individuale che alla data del 31 ottobre 2015 possiede beni immobili strumentali di cui all'articolo 43, comma 2, del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, puo', entro il 31 maggio 2016, optare per l'esclusione dei beni stessi dal patrimonio dell'impresa, con effetto dal periodo di imposta in corso alla data del 1° gennaio 2016, mediante il pagamento di una imposta sostitutiva dell'imposta sul reddito delle persone fisiche e dell'imposta regionale sulle attivita' produttive nella misura dell'8 per cento della differenza tra il valore normale di tali beni ed il relativo valore fiscalmente riconosciuto. Si applicano, in quanto compatibili, le disposizioni dei commi da 115 a 120. (14) (38) (47)

122. Gli oneri previsti dall'articolo 4, comma 14, della legge 12 novembre 2011, n. 183, e relativi agli accertamenti clinico-strumentali e di laboratorio indicati dall'amministrazione per il reclutamento del personale volontario per le esigenze dei distaccamenti volontari del Corpo nazionale dei vigili del fuoco di cui all'articolo 9, comma 2, lettera b), del decreto legislativo 8 marzo 2006, n. 139, sono a carico della medesima.

123. All'articolo 11, comma 4-bis, lettera d-bis), del decreto legislativo 15 dicembre 1997, n. 446, e successive modificazioni, le parole: «di euro 2.500, di euro 1.875, di euro 1.250 e di euro 625» sono sostituite dalle seguenti: «di euro 5.000, di euro 3.750, di euro 2.500 e di euro 1.250».

124. Le disposizioni di cui al comma 123 si applicano a decorrere dal periodo d'imposta successivo a quello in corso al 31 dicembre 2015.

125. All'articolo 2 del decreto legislativo 15 dicembre 1997, n. 446, concernente il presupposto dell'imposta regionale sulle attivita' produttive, dopo il comma 1 e' aggiunto il seguente: «1-bis. Non sussiste autonoma organizzazione ai fini dell'imposta nel caso di medici che abbiano sottoscritto specifiche convenzioni con le strutture ospedaliere per lo svolgimento della professione all'interno di tali strutture, laddove gli stessi percepiscano per l'attivita' svolta presso le medesime strutture piu' del 75 per cento del proprio reddito complessivo. Sono in ogni caso irrilevanti, ai fini della sussistenza dell'autonoma organizzazione, l'ammontare del reddito realizzato e le spese direttamente connesse all'attivita' svolta. L'esistenza dell'autonoma organizzazione e' comunque configurabile in presenza di elementi che superano lo standard e i parametri previsti dalla convenzione con il Servizio sanitario nazionale».

126. L'articolo 26 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, e' sostituito dal seguente: «Art. 26. - (Variazioni dell'imponibile o dell'imposta). - 1. Le disposizioni degli articoli 21 e seguenti devono essere osservate, in relazione al maggiore ammontare, tutte le volte che successivamente all' emissione della fattura o alla registrazione di cui agli articoli 23 e 24 l'ammontare imponibile di un'operazione o quello della relativa imposta viene ad aumentare per qualsiasi motivo, compresa la rettifica di inesattezze della fatturazione o della registrazione. 2. Se un'operazione per la quale sia stata emessa fattura, successivamente alla registrazione di cui agli articoli 23 e 24, viene meno in tutto o in parte, o se ne riduce l'ammontare imponibile, in conseguenza di dichiarazione di nullita', annullamento, revoca, risoluzione, rescissione e simili o in conseguenza dell'applicazione di abbuoni o sconti previsti contrattualmente, il cedente del bene o prestatore del servizio ha diritto di portare in detrazione ai sensi dell'articolo 19 l'imposta corrispondente alla variazione, registrandola a norma dell'articolo 25. 3. La disposizione di cui al comma 2 non puo' essere applicata dopo il decorso di un anno dall'effettuazione dell'operazione imponibile qualora gli eventi ivi indicati si verifichino in dipendenza di sopravvenuto accordo fra le parti e puo' essere applicata, entro lo stesso termine, anche in caso di rettifica di inesattezze della fatturazione che abbiano dato luogo all'applicazione dell'articolo 21, comma 7. 4. La disposizione di cui al comma 2 si applica anche in caso di mancato pagamento, in tutto o in parte, da parte del cessionario o committente: a) a partire dalla data in cui quest'ultimo e' assoggettato a una procedura concorsuale o dalla data del decreto che omologa un accordo di ristrutturazione dei debiti di cui all'articolo 182-bis del regio decreto 16 marzo 1942, n. 267, o dalla data di pubblicazione nel registro delle imprese di un piano attestato ai sensi dell'articolo 67, terzo comma, lettera d), del regio decreto 16 marzo 1942, n. 267; b) a causa di procedure esecutive individuali rimaste infruttuose. 5. Ove il cedente o prestatore si avvalga della facolta' di cui al comma 2, il cessionario o committente, che abbia gia' registrato l'operazione ai sensi dell'articolo 25, deve in tal caso registrare la variazione a norma dell'articolo 23 o dell'articolo 24, nei limiti della detrazione operata, salvo il suo diritto alla restituzione dell'importo pagato al cedente o prestatore a titolo di rivalsa. L'obbligo di cui al primo periodo non si applica nel caso di procedure concorsuali di cui al comma 4, lettera a). 6. Nel caso in cui, successivamente agli eventi di cui al comma 4, il corrispettivo sia pagato, in tutto o in parte, si applica la disposizione di cui al comma 1. In tal caso, il cessionario o committente che abbia assolto all'obbligo di cui al comma 5 ha diritto di portare in detrazione ai sensi dell'articolo 19 l'imposta corrispondente alla variazione in aumento. 7. La correzione di errori materiali o di calcolo nelle registrazioni di cui agli articoli 23, 25 e 39 e nelle liquidazioni periodiche di cui all'articolo 27, all'articolo 1 del regolamento di cui al decreto del Presidente della Repubblica 23 marzo 1998, n. 100, e successive modificazioni, e all'articolo 7 del regolamento di cui al decreto del Presidente della Repubblica 14 ottobre 1999, n. 542, e successive modificazioni, deve essere fatta, mediante annotazione delle variazioni dell'imposta in aumento nel registro di cui all'articolo 23 e delle variazioni dell'imposta in diminuzione nel registro di cui all'articolo 25. Con le stesse modalita' devono essere corretti, nel registro di cui all'articolo 24, gli errori materiali inerenti alla trascrizione di dati indicati nelle fatture o nei registri tenuti a norma di legge. 8. Le variazioni di cui ai commi 2, 3, 4 e 5 e quelle per errori di registrazione di cui al comma 7 possono essere effettuate dal cedente o prestatore del servizio e dal cessionario o committente anche mediante apposite annotazioni in rettifica rispettivamente sui registri di cui agli articoli 23 e 24 e sul registro di cui all'articolo 25. 9. Nel caso di risoluzione contrattuale, relativa a contratti a esecuzione continuata o periodica, conseguente a inadempimento, la facolta' di cui al comma 2 non si estende a quelle cessioni e a quelle prestazioni per cui sia il cedente o prestatore che il cessionario o committente abbiano correttamente adempiuto alle proprie obbligazioni. 10. La facolta' di cui al comma 2 puo' essere esercitata, ricorrendo i presupposti di cui a tale disposizione, anche dai cessionari e committenti debitori dell'imposta ai sensi dell'articolo 17 o dell'articolo 74 del presente decreto ovvero dell'articolo 44 del decreto-legge 30 agosto 1993, n. 331, convertito, con modificazioni, dalla legge 29 ottobre 1993, n. 427, e successive modificazioni. In tal caso, si applica ai cessionari o committenti la disposizione di cui al comma 5. 11. Ai fini del comma 4, lettera a), il debitore si considera assoggettato a procedura concorsuale dalla data della sentenza dichiarativa del fallimento o del provvedimento che ordina la liquidazione coatta amministrativa o del decreto di ammissione alla procedura di concordato preventivo o del decreto che dispone la procedura di amministrazione straordinaria delle grandi imprese in crisi. 12. Ai fini del comma 4, lettera b), una procedura esecutiva individuale si considera in ogni caso infruttuosa: a) nell'ipotesi di pignoramento presso terzi, quando dal verbale di pignoramento redatto dall'ufficiale giudiziario risulti che presso il terzo pignorato non vi sono beni o crediti da pignorare; b) nell'ipotesi di pignoramento di beni mobili, quando dal verbale di pignoramento redatto dall'ufficiale giudiziario risulti la mancanza di beni da pignorare ovvero l'impossibilita' di accesso al domicilio del debitore ovvero la sua irreperibilita'; c) nell'ipotesi in cui, dopo che per tre volte l'asta per la vendita del bene pignorato sia andata deserta, si decida di interrompere la procedura esecutiva per eccessiva onerosita'».

127. Le disposizioni di cui all'articolo 26, comma 4, lettera a), e comma 5, secondo periodo, del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, nel testo risultante dalle modifiche apportate dal comma 126, si applicano nei casi in cui il cessionario o committente sia assoggettato a una procedura concorsuale successivamente al 31 dicembre 2016. Le altre modifiche apportate dal comma 126 al predetto articolo 26, in quanto volte a chiarire l'applicazione delle disposizioni contenute in tale ultimo articolo e quindi di carattere interpretativo, si applicano anche alle operazioni effettuate anteriormente alla data di cui al periodo precedente.

128. Al sesto comma dell'articolo 17 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, e successive modificazioni, dopo la lettera a-ter) e' inserita la seguente: «a-quater) alle prestazioni di servizi rese dalle imprese consorziate nei confronti del consorzio di appartenenza che, ai sensi delle lettere b), c) ed e) del comma 1 dell'articolo 34 del codice di cui al decreto legislativo 12 aprile 2006, n. 163, e successive modificazioni, si e' reso aggiudicatario di una commessa nei confronti di un ente pubblico al quale il predetto consorzio e' tenuto ad emettere fattura ai sensi del comma 1 dell'articolo 17-ter del presente decreto. L'efficacia della disposizione di cui al periodo precedente e' subordinata al rilascio, da parte del Consiglio dell'Unione europea, dell'autorizzazione di una misura di deroga ai sensi dell'articolo 395 della direttiva 2006/112/CE del Consiglio, del 28 novembre 2006, e successive modificazioni».

129. Le disposizioni di cui all'articolo 12, comma 7-bis, del decreto-legge 23 dicembre 2013, n. 145, convertito, con modificazioni, dalla legge 21 febbraio 2014, n. 9, si applicano anche nell'anno 2016 con le modalita' previste nel medesimo comma. Per l'anno 2016 il decreto del Ministro dell'economia e delle finanze, di concerto con il Ministro dello sviluppo economico, previsto nel citato comma 7-bis, e' adottato entro novanta giorni dalla data di entrata in vigore della presente legge.

130. L'articolo 57 del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, e' sostituito dal seguente: «Art. 57. - (Termine per gli accertamenti). - 1. Gli avvisi relativi alle rettifiche e agli accertamenti previsti nell'articolo 54 e nel secondo comma dell'articolo 55 devono essere notificati, a pena di decadenza, entro il 31 dicembre del quinto anno successivo a quello in cui e' stata presentata la dichiarazione. 2. Nei casi di omessa presentazione della dichiarazione o di presentazione di dichiarazione nulla l'avviso di accertamento dell'imposta a norma del primo comma dell'articolo 55 puo' essere notificato entro il 31 dicembre del settimo anno successivo a quello in cui la dichiarazione avrebbe dovuto essere presentata. 3. Nel caso di richiesta di rimborso dell'eccedenza d'imposta detraibile risultante dalla dichiarazione annuale, se tra la data di notifica della richiesta di documenti da parte dell'ufficio e la data della loro consegna intercorre un periodo superiore a quindici giorni, il termine di decadenza, relativo agli anni in cui si e' formata l'eccedenza detraibile chiesta a rimborso, e' differito di un periodo di tempo pari a quello compreso tra il sedicesimo giorno e la data di consegna. 4. Fino alla scadenza del termine stabilito nei commi precedenti le rettifiche e gli accertamenti possono essere integrati o modificati, mediante la notificazione di nuovi avvisi, in base alla sopravvenuta conoscenza di nuovi elementi da parte dell'Agenzia delle entrate. Nell'avviso devono essere specificamente indicati, a pena di nullita', i nuovi elementi e gli atti o fatti attraverso i quali sono venuti a conoscenza dell'ufficio dell'imposta sul valore aggiunto».

131. L'articolo 43 del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, e' sostituito dal seguente: «Art. 43. - (Termine per l'accertamento). - 1. Gli avvisi di accertamento devono essere notificati, a pena di decadenza, entro il 31 dicembre del quinto anno successivo a quello in cui e' stata presentata la dichiarazione. 2. Nei casi di omessa presentazione della dichiarazione o di presentazione di dichiarazione nulla l'avviso di accertamento puo' essere notificato entro il 31 dicembre del settimo anno successivo a quello in cui la dichiarazione avrebbe dovuto essere presentata. 3. Fino alla scadenza del termine stabilito nei commi precedenti l'accertamento puo' essere integrato o modificato in aumento mediante la notificazione di nuovi avvisi, in base alla sopravvenuta conoscenza di nuovi elementi da parte dell'Agenzia delle entrate. Nell'avviso devono essere specificamente indicati, a pena di nullita', i nuovi elementi e gli atti o fatti attraverso i quali sono venuti a conoscenza dell'ufficio delle imposte».

132. Le disposizioni di cui all'articolo 57, commi 1 e 2, del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, e all'articolo 43, commi 1 e 2, del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, come sostituiti dai commi 130 e 131 del presente articolo, si applicano agli avvisi relativi al periodo d'imposta in corso alla data del 31 dicembre 2016 e ai periodi successivi. Per i periodi d'imposta precedenti, gli avvisi di accertamento devono essere notificati, a pena di decadenza, entro il 31 dicembre del quarto anno successivo a quello in cui e' stata presentata la dichiarazione ovvero, nei casi di omessa presentazione della dichiarazione o di dichiarazione nulla, entro il 31 dicembre del quinto anno successivo a quello in cui la dichiarazione avrebbe dovuto essere presentata. Tuttavia, in caso di violazione che comporta obbligo di denuncia ai sensi dell'articolo 331 del codice di procedura penale per alcuno dei reati previsti dal decreto legislativo 10 marzo 2000, n. 74, i termini di cui al periodo precedente sono raddoppiati relativamente al periodo d'imposta in cui e' stata commessa la violazione; il raddoppio non opera qualora la denuncia da parte dell'Amministrazione finanziaria, in cui e' ricompresa la Guardia di finanza, sia presentata o trasmessa oltre la scadenza ordinaria dei termini di cui al primo periodo. Resta fermo quanto disposto dall'ultimo periodo del comma 5 dell'articolo 5-quater del decreto-legge 28 giugno 1990, n. 167, convertito, con modificazioni, dalla legge 4 agosto 1990, n. 227, e successive modificazioni.

133. All'articolo 32, commi 1 e 2, del decreto legislativo 24 settembre 2015, n. 158, le parole: «1° gennaio 2017» sono sostituite dalle seguenti: «1° gennaio 2016». Restano comunque ferme le sanzioni nella misura dovuta in base alle norme relative alla procedura di collaborazione volontaria di cui alla legge 15 dicembre 2014, n. 186, vigenti alla data di presentazione della relativa istanza. Ai soli fini della procedura di collaborazione volontaria di cui al periodo precedente, tutti gli atti che per legge devono essere notificati al contribuente, di cui agli articoli 5-quater e 5-quinquies del decreto-legge 28 giugno 1990, n. 167, convertito, con modificazioni, dalla legge 4 agosto 1990, n. 227, e successive modificazioni, possono essere allo stesso notificati dal competente ufficio dell'Agenzia delle entrate, in deroga ad ogni altra disposizione di legge, mediante posta elettronica certificata, con le modalita' previste dal regolamento di cui al decreto del Presidente della Repubblica 11 febbraio 2005, n. 68, all'indirizzo di posta elettronica certificata del professionista che lo assiste nell'ambito della procedura di collaborazione volontaria. Per i fini di cui al periodo precedente il contribuente deve manifestare la propria volonta' di ricevere gli atti della procedura all'indirizzo di posta elettronica certificata del professionista che lo assiste. La notifica si intende comunque perfezionata nel momento in cui il gestore del servizio di posta elettronica certificata trasmette all'ufficio la ricevuta di accettazione con la relativa attestazione temporale che certifica l'avvenuta spedizione del messaggio; i termini che hanno inizio dalla notificazione decorrono dalla data di avvenuta consegna contenuta nella ricevuta che il gestore del servizio di posta elettronica certificata del professionista trasmette all'ufficio. Se la casella di posta elettronica del professionista risulta satura, ovvero nei casi in cui l'indirizzo di posta elettronica del professionista non risulta valido o attivo, si applicano le disposizioni in materia di notificazione degli avvisi e degli altri atti che per legge devono essere notificati al contribuente.

134. Nelle ipotesi di definizione degli accertamenti o di omessa impugnazione di cui al decreto legislativo 19 giugno 1997, n. 218, i contribuenti che, nei trentasei mesi antecedenti al 15 ottobre 2015, sono decaduti dal beneficio della rateazione, sono riammessi al piano di rateazione inizialmente concesso ai sensi dello stesso decreto legislativo n. 218 del 1997, limitatamente al versamento delle imposte dirette, a condizione che entro il 31 maggio 2016 riprendano il versamento della prima delle rate scadute.

135. Ai fini di cui al comma 134, il contribuente interessato, nei dieci giorni successivi al versamento, trasmette copia della relativa quietanza all'ufficio competente affinche' lo stesso proceda alla sospensione dei carichi eventualmente iscritti a ruolo ancorche' rateizzati ai sensi dell'articolo 19 del decreto del Presidente della Repubblica 29 settembre 1973, n. 602. Lo stesso ufficio:

- a) ricalcola le rate dovute tenendo conto di tutti i pagamenti effettuati anche a seguito di iscrizione a ruolo, imputandole alle analoghe voci dell'originario piano di rateazione;
- b) verificato il versamento delle rate residue, provvede allo sgravio degli stessi carichi iscritti a ruolo.

136. Non sono ripetibili le somme versate, ove superiori all'ammontare di quanto dovuto, ricalcolato ai sensi del comma 135.

137. Il debitore decade dal piano di rateazione a cui e' stato riammesso ai sensi del comma 134 in caso di mancato pagamento di due rate anche non consecutive, esclusa ogni ulteriore proroga.

138. A seguito della trasmissione della quietanza, non possono essere avviate nuove azioni esecutive. Se la rateazione e' richiesta dopo una segnalazione effettuata ai sensi dell'articolo 48-bis del decreto del Presidente della Repubblica 29 settembre 1973, n. 602, la stessa non puo' essere concessa limitatamente agli importi che ne costituiscono oggetto.

139. Al fine di garantire la stabilita' del gettito tributario derivante dagli atti registrati dai notai, alla legge 16 febbraio 1913, n. 89, e successive modificazioni, sono apportate le seguenti modificazioni:

- a) dopo il comma 3 dell'articolo 22 sono inseriti i seguenti: «3-bis. In caso di mancato versamento da parte del notaio dei tributi riscossi in relazione agli atti da lui rogati o autenticati, se il danno non e' coperto da polizza assicurativa, l'agente della riscossione puo' richiederne il pagamento direttamente al Fondo. L'erogazione e' subordinata: a) all'esercizio dell'azione penale nei confronti del notaio ed alla pronuncia del suo rinvio a giudizio; b) all'emissione, per il pagamento dei tributi di cui al primo periodo, di un atto esecutivo dell'Agenzia delle entrate, non sospeso dall'autorita' giudiziaria o dall'Amministrazione finanziaria, nei confronti del notaio. 3-ter. Il Fondo, quando provvede al pagamento dei tributi di cui al comma 3-bis, e' legalmente surrogato nei confronti del notaio in tutte le ragioni, azioni e privilegi spettanti all'Amministrazione finanziaria. Il Fondo puo', esibendo il documento attestante la somma pagata, richiedere all'autorita' giudiziaria l'ingiunzione di pagamento. L'ingiunzione e' provvisoriamente esecutiva a norma dell'articolo 642 del codice di procedura civile. Non e' ammissibile l'opposizione fondata sul motivo che le imposte pagate non erano dovute o erano dovute in misura minore. Il Fondo puo' agire esecutivamente sull'indennita' dovuta dalla Cassa nazionale del notariato al notaio alla sua cessazione, nel limite di cui al quarto comma dell'articolo 545 del codice di procedura civile, e, a tutela del proprio credito, puo' notificare alla Cassa un atto di opposizione al pagamento diretto al notaio dell'indennita' nello stesso limite. 3-quater. Con decreto non regolamentare del Ministro dell'economia e delle finanze, sentito il Consiglio nazionale del notariato, sono disciplinate le modalita' procedurali e l'erogazione delle somme da parte del Fondo all'Amministrazione finanziaria, e per la successiva surroga ad essa del Fondo medesimo. 3-quinquies. Se e' accertato con decisione passata in giudicato che il notaio non ha commesso il fatto ovvero che il fatto non costituisce reato, l'Agenzia delle entrate rimborsa senza indugio le somme pagate al Fondo o, se il Fondo ha recuperato le somme dal notaio, al notaio medesimo»;
- b) al comma 4 dell'articolo 22 sono aggiunte, in fine, le seguenti parole: «, fatto salvo il caso di cui al comma 3-bis, nel quale il danno e' dimostrato con l'esibizione dell'atto esecutivo ed e' quantificato sulla base delle risultanze dello stesso atto»;
- c) all'articolo 93-bis, comma 2, lettera a), sono aggiunte, in fine, le seguenti parole: «nonche' richiedere, anche periodicamente, informazioni e l'esibizione di documenti, estratti repertoriali, atti, registri e libri anche di natura fiscale»;
- d) dopo il comma 2 dell'articolo 93-bis e' inserito il seguente: «2-bis. L'Agenzia delle entrate trasmette al Consiglio nazionale del notariato, esclusivamente con modalita' telematiche entro il secondo mese successivo a quello di scadenza, le informazioni sugli omessi e ritardati versamenti richiesti ai notai con avviso di liquidazione»;
- e) all'articolo 19: 1) al comma 1, le parole: «con oneri a carico del proprio bilancio» sono sostituite dalle seguenti: «con separata contribuzione obbligatoria a carico di tutti gli iscritti al ruolo, da versare al Consiglio nazionale del notariato. Il contributo e' riscosso dal Consiglio nazionale del notariato con le modalita' di cui all'articolo 21 della legge 27 giugno 1991, n. 220, entro il 28 febbraio di ciascun anno»; 2) dopo il comma 1 e' inserito il seguente: «1-bis. La misura dei contributi e' determinata dal Consiglio nazionale del notariato entro il 31 ottobre di ciascun anno per l'anno successivo in misura corrispondente ai premi ed agli oneri da esso pagati ed e' ragguagliata ai parametri soggetti ad annotamento nei repertori di ciascun notaio secondo quanto stabilito dalla legge e tenuto conto del numero e dell'ammontare dei sinistri liquidati per ciascun notaio a partire dal 1° febbraio 1999»;
- f) al comma 1 dell'articolo 142-bis e' aggiunto, in fine, il seguente periodo: «Il notaio e' punito in ogni caso con la destituzione quando commette un reato omettendo o ritardando il versamento di tributi dovuti in relazione agli atti da lui rogati o autenticati»;
- g) dopo il comma 1 dell'articolo 144 e' inserito il seguente: «1-bis. Nell'ipotesi di cui all'ultimo periodo del comma 1 dell'articolo 142-bis, la sospensione per un anno e' sostituita alla destituzione solo se il notaio ha riparato interamente il danno e non e' recidivo nella stessa infrazione».

140. Le disposizioni di cui al comma 139 si applicano a decorrere dal 1° gennaio 2016.

141. All'articolo 14, comma 4, della legge 24 dicembre 1993, n. 537, e' aggiunto, in fine, il seguente periodo: «In caso di violazione che comporta obbligo di denuncia ai sensi dell'articolo 331 del codice di procedura penale per qualsiasi reato da cui possa derivare un provento o vantaggio illecito, anche indiretto, le competenti autorita' inquirenti ne danno immediatamente notizia all'Agenzia delle entrate, affinche' proceda al conseguente accertamento».

142. Al testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e successive modificazioni, sono apportate le seguenti modificazioni:

- a) i commi da 10 a 12-bis dell'articolo 110 sono abrogati;
- b) all'articolo 167: 1) al comma 1, le parole: «di cui al decreto o al provvedimento emanati ai sensi del comma 4» sono sostituite dalle seguenti: «di cui al comma 4, diversi da quelli appartenenti all'Unione europea ovvero da quelli aderenti allo Spazio economico europeo con i quali l'Italia abbia stipulato un accordo che assicuri un effettivo scambio di informazioni»; 2) il comma 4 e' sostituito dal seguente: «4. I regimi fiscali, anche speciali, di Stati o territori si considerano privilegiati laddove il livello nominale di tassazione risulti inferiore al 50 per cento di quello applicabile in Italia»; 3) al comma 6, le parole: «e, comunque, non inferiore al 27 per cento» sono sostituite dalle seguenti: «e, comunque, non inferiore all'aliquota ordinaria dell'imposta sul reddito delle societa'»; 4) al comma 8-bis, alinea, dopo le parole: «localizzati in Stati o territori diversi da quelli ivi richiamati» sono inserite le seguenti: «o in Stati appartenenti all'Unione europea ovvero a quelli aderenti allo Spazio economico europeo con i quali l'Italia abbia stipulato un accordo che assicuri un effettivo scambio di informazioni».

143. Quando leggi, regolamenti, decreti o altre norme o provvedimenti fanno riferimento agli Stati o territori di cui al decreto e al provvedimento emanati ai sensi dell'articolo 167, comma 4, del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, ovvero agli Stati o territori individuati in base ai criteri di cui al medesimo articolo 167, comma 4, il riferimento si intende agli Stati o territori a regime fiscale privilegiato individuati in base ai criteri di cui all'articolo 47-bis, comma 1, del citato testo unico. (37)

144. Le disposizioni di cui ai commi 142 e 143 si applicano a decorrere dal periodo d'imposta successivo a quello in corso al 31 dicembre 2015.

145. A fini di adeguamento alle direttive emanate dall'Organizzazione per la cooperazione e lo sviluppo economico in materia di obbligo delle imprese multinazionali di predisporre e presentare annualmente una rendicontazione Paese per Paese che riporti l'ammontare dei ricavi e gli utili lordi, le imposte pagate e maturate, insieme con altri elementi indicatori di un'attivita' economica effettiva, con decreto del Ministro dell'economia e delle finanze, da emanare entro novanta giorni dalla data di entrata in vigore della presente legge, sono stabiliti modalita', termini, elementi e condizioni, coerentemente con le citate direttive, per la trasmissione della predetta rendicontazione all'Agenzia delle entrate da parte delle societa' controllanti, residenti nel territorio dello Stato ai sensi dell'articolo 73 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e successive modificazioni, che hanno l'obbligo di redazione del bilancio consolidato, con un fatturato consolidato, conseguito dal gruppo di imprese multinazionali nel periodo d'imposta precedente a quello di rendicontazione, di almeno 750 milioni di euro e che non sono a loro volta controllate da soggetti diversi dalle persone fisiche. L'Agenzia delle entrate assicura la riservatezza delle informazioni contenute nella rendicontazione di cui al primo periodo almeno nella stessa misura richiesta per le informazioni fornite ai sensi delle disposizioni della Convenzione multilaterale sulla mutua assistenza amministrativa in materia fiscale. In caso di omessa presentazione della rendicontazione di cui al primo periodo o di invio dei dati incompleti o non veritieri si applica la sanzione amministrativa pecuniaria da euro 10.000 a euro 50.000.

146. Agli obblighi di cui al comma 145, alle condizioni ivi indicate, sono tenute anche le societa' controllate, residenti nel territorio dello Stato, nel caso in cui la societa' controllante che ha l'obbligo di redazione del bilancio consolidato sia residente in uno Stato che non ha introdotto l'obbligo di presentazione della rendicontazione Paese per Paese ovvero non ha in vigore con l'Italia un accordo che consenta lo scambio delle informazioni relative alla rendicontazione Paese per Paese ovvero e' inadempiente all'obbligo di scambio delle informazioni relative alla rendicontazione Paese per Paese.

147. COMMA ABROGATO DAL D.L. 30 DICEMBRE 2016, N. 244, CONVERTITO CON MODIFICAZIONI DALLA L. 27 FEBBRAIO 2017, N. 19.

148. All'articolo 1 della legge 23 dicembre 2014, n. 190, sono apportate le seguenti modificazioni:

- a) al comma 39, primo periodo, le parole: «opere dell'ingegno» sono sostituite dalle seguenti: «software protetto da copyright»;
- b) dopo il comma 42-bis e' inserito il seguente: «42-ter. Qualora piu' beni tra quelli di cui al comma 39, appartenenti a un medesimo soggetto, siano collegati da vincoli di complementarieta' e vengano utilizzati congiuntamente ai fini della realizzazione di un prodotto o di una famiglia di prodotti o di un processo o di un gruppo di processi, tali beni possono costituire un solo bene immateriale ai fini delle disposizioni dei commi da 37 a 42-bis».

149. COMMA ABROGATO DALLA L. 3 MAGGIO 2019, N. 37.

150. COMMA ABROGATO DALLA L. 3 MAGGIO 2019, N. 37.

151. COMMA ABROGATO DALLA L. 3 MAGGIO 2019, N. 37.

152. Per l'anno 2016, la misura del canone di abbonamento alla televisione per uso privato di cui al regio decreto-legge 21 febbraio 1938, n. 246, convertito dalla legge 4 giugno 1938, n. 880, e' pari, nel suo complesso, all'importo di euro 100.

153. Al regio decreto-legge 21 febbraio 1938, n. 246, convertito dalla legge 4 giugno 1938, n. 880, sono apportate le seguenti modificazioni:

- a) all'articolo 1, secondo comma, sono aggiunti, in fine, i seguenti periodi: «La detenzione di un apparecchio si presume altresi' nel caso in cui esista un'utenza per la fornitura di energia elettrica nel luogo in cui un soggetto ha la sua residenza anagrafica. Allo scopo di superare le presunzioni di cui ai precedenti periodi, a decorrere dall'anno 2016 e' ammessa esclusivamente una dichiarazione rilasciata ai sensi del testo unico di cui al decreto del Presidente della Repubblica 28 dicembre 2000, n. 445, la cui mendacia comporta gli effetti, anche penali, di cui all'articolo 76 del medesimo testo unico. Tale dichiarazione e' presentata all'Agenzia delle entrate - Direzione provinciale I di Torino - Ufficio territoriale di Torino I - Sportello S.A.T., con le modalita' definite con provvedimento del direttore dell'Agenzia delle entrate, e ha validita' per l'anno in cui e' stata presentata»;
- b) all'articolo 1, dopo il secondo comma e' aggiunto il seguente: «Il canone di abbonamento e', in ogni caso, dovuto una sola volta in relazione agli apparecchi di cui al primo comma detenuti, nei luoghi adibiti a propria residenza o dimora, dallo stesso soggetto e dai soggetti appartenenti alla stessa famiglia anagrafica, come individuata dall'articolo 4 del regolamento di cui al decreto del Presidente della Repubblica 30 maggio 1989, n. 223»;
- c) all'articolo 3 e' aggiunto, in fine, il seguente comma: «Per i titolari di utenza di fornitura di energia elettrica di cui all'articolo 1, secondo comma, secondo periodo, il pagamento del canone avviene in dieci rate mensili, addebitate sulle fatture emesse dall'impresa elettrica aventi scadenza del pagamento successiva alla scadenza delle rate. Le rate, ai fini dell'inserimento in fattura, s'intendono scadute il primo giorno di ciascuno dei mesi da gennaio ad ottobre. L'importo delle rate e' oggetto di distinta indicazione nel contesto della fattura emessa dall'impresa elettrica e non e' imponibile ai fini fiscali. Le somme riscosse sono riversate direttamente all'Erario mediante versamento unitario di cui all'articolo 17 del decreto legislativo 9 luglio 1997, n. 241, e successive modificazioni. Le imprese elettriche devono effettuare il predetto riversamento entro il giorno 20 del mese successivo a quello di incasso e, comunque, l'intero canone deve essere riscosso e riversato entro il 20 dicembre. Sono in ogni caso esclusi obblighi di anticipazione da parte delle imprese elettriche».

154. Con decreto del Ministro dello sviluppo economico, di concerto con il Ministro dell'economia e delle finanze, sentita l'Autorita' per l'energia elettrica, il gas e il sistema idrico, da adottare entro quarantacinque giorni dalla data di entrata in vigore della presente legge, sono definiti termini e modalita' per il riversamento all'Erario, e per le conseguenze di eventuali ritardi, anche in forma di interessi moratori, dei canoni incassati dalle aziende di vendita dell'energia elettrica, che a tal fine non sono considerate sostituti di imposta, eventualmente tramite un soggetto unico individuato dal medesimo decreto, per l'individuazione e comunicazione dei dati utili ai fini del controllo, per l'individuazione dei soggetti di cui al comma 156, nonche' le misure tecniche che si rendano eventualmente necessarie per l'attuazione della presente norma.

155. In caso di violazione degli obblighi di comunicazione e di versamento dei canoni di cui al comma 154, si applicano, rispettivamente, le sanzioni di cui agli articoli 5, comma 1, e 13, comma 1, del decreto legislativo 18 dicembre 1997, n. 471, e successive modificazioni.

156. Per l'attuazione di quanto previsto dai commi 153, 154 e 155 e limitatamente alle finalita' di cui ai commi da 152 a 160, l'Anagrafe tributaria, l'Autorita' per l'energia elettrica, il gas e il sistema idrico, l'Acquirente Unico Spa, il Ministero dell'interno, i comuni, nonche' gli altri soggetti pubblici o privati che ne hanno la disponibilita' sono autorizzati allo scambio e all'utilizzo di tutte le informazioni utili, e in particolare dei dati relativi alle famiglie anagrafiche, alle utenze per la fornitura di energia elettrica, ai soggetti tenuti al pagamento del canone di abbonamento alla televisione, ai soggetti beneficiari delle agevolazioni di cui all'articolo 38, comma 8, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, nonche' ai soggetti esenti dal pagamento del canone.

157. Al fine di semplificare le modalita' di pagamento del canone, le autorizzazioni all'addebito diretto sul conto corrente bancario o postale ovvero su altri mezzi di pagamento, rilasciate a intermediari finanziari dai titolari di utenza per la fornitura di energia elettrica per il pagamento delle relative fatture, si intendono in ogni caso estese al pagamento del canone di abbonamento televisivo. La disposizione di cui al presente comma si applica anche alle suddette autorizzazioni all'addebito gia' rilasciate alla data di entrata in vigore della presente legge, fatta salva la facolta' di revoca dell'autorizzazione nel suo complesso da parte dell' utente.

158. A decorrere dalla data di entrata in vigore della presente legge non e' piu' esercitabile la facolta' di presentare la denunzia di cessazione dell'abbonamento radiotelevisivo per suggellamento, di cui all'articolo 10, primo comma, del regio decreto-legge 21 febbraio 1938, n. 246, convertito dalla legge 4 giugno 1938, n. 880. Restano ferme la disciplina vigente in materia di accertamento e riscossione coattiva e le disposizioni in materia di canone di abbonamento speciale per la detenzione fuori dell'ambito familiare, salvo quanto disposto dal precedente periodo.

159. In sede di prima applicazione di quanto disposto dai commi da 152 a 158:

- a) avuto riguardo ai tempi tecnici necessari all'adeguamento dei sistemi di fatturazione, nella prima fattura successiva al 1° luglio 2016 sono cumulativamente addebitate tutte le rate scadute;
- b) l'Agenzia delle entrate mette a disposizione delle imprese elettriche, per il tramite del sistema informativo integrato istituito presso l'Acquirente Unico Spa dall'articolo 1-bis del decreto-legge 8 luglio 2010, n. 105, convertito, con modificazioni, dalla legge 13 agosto 2010, n. 129, l'elenco dei soggetti esenti ai sensi delle disposizioni vigenti o che abbiano presentato la dichiarazione di cui al comma 153, lettera a), e fornisce ogni dato utile a individuare i soggetti obbligati;
- c) le imprese elettriche all'atto della conclusione dei nuovi contratti di fornitura acquisiscono la dichiarazione del cliente in ordine alla residenza anagrafica nel luogo di fornitura. Il cliente e' tenuto a comunicare ogni successiva variazione.

160. COMMA ABROGATO DALLA L. 30 DICEMBRE 2020, N. 178.

161. COMMA ABROGATO DALLA L. 30 DICEMBRE 2020, N. 178.

162. COMMA ABROGATO DALLA L. 30 DICEMBRE 2020, N. 178.

163. Con regolamento da adottare ai sensi dell'articolo 17, comma 2, della legge 23 agosto 1988, n. 400, e succesive modificazioni, su proposta del Ministro dello sviluppo economico, di concerto con il Ministro dell'economia e delle finanze, sono stabiliti i criteri di riparto tra i soggetti beneficiari e le procedure di erogazione delle risorse del Fondo per il pluralismo e l'innovazione dell'informazione istituito nello stato di previsione del Ministero dell'economia e delle finanze, da assegnare in favore delle emittenti radiofoniche e televisive locali per la realizzazione di obiettivi di pubblico interesse, quali la promozione del pluralismo dell'informazione, il sostegno dell'occupazione nel settore, il miglioramento dei livelli qualitativi dei contenuti forniti e l'incentivazione dell'uso di tecnologie innovative.

164. Con effetto a decorrere dalla data di entrata in vigore del regolamento di cui al comma 163, sono abrogate le disposizioni vigenti relative alle provvidenze in favore delle emittenti radiofoniche e televisive operanti in ambito locale, e in particolare le seguenti:

- a) articolo 45, comma 3, della legge 23 dicembre 1998, n. 448;
- b) articolo 145, commi 18 e 19, della legge 23 dicembre 2000, n. 388;
- c) articolo 52, comma 18, della legge 28 dicembre 2001, n. 448;
- d) articolo 4, comma 190, della legge 24 dicembre 2003, n. 350;
- e) articolo 1, comma 1247, ultimo periodo, della legge 27 dicembre 2006, n. 296.

165. COMMA ABROGATO DALLA L. 27 DICEMBRE 2017, N. 205.

166. COMMA ABROGATO DALLA L. 27 DICEMBRE 2017, N. 205.

167. Al fine di dare attuazione all'Accordo tra l'Italia e la Santa Sede in materia di radiodiffusione televisiva e sonora del 14 e 15 giugno 2010, il Ministero dello sviluppo economico predispone entro trenta giorni dalla data di entrata in vigore della presente legge una procedura di gara con offerte economiche al ribasso a partire dalla tariffa annuale massima per ogni M/bits stabilita per abitante dall'articolo 27, comma 3, del regolamento di cui all'allegato A alla delibera dell'Autorita' per le garanzie nelle comunicazioni n. 353/11/Cons del 23 giugno 2011 per selezionare un operatore di rete gia' titolare di diritto d'uso che metta a disposizione senza oneri per la Citta' del Vaticano per un periodo pari alla durata dell'Accordo una capacita' trasmissiva pari a 4 M/bits su un multiplex televisivo preferibilmente isocanale con copertura del territorio nazionale che raggiunga almeno il 70 per cento della popolazione. Al fine di rimborsare gli importi di aggiudicazione corrisposti dall'operatore di rete che mette a disposizione senza oneri per la Citta' del Vaticano per un periodo pari alla durata dell'Accordo la capacita' trasmissiva pari a 4 M/bits ai sensi del primo periodo, e' autorizzata la spesa di 2,724 milioni di euro annui a decorrere dall'anno 2016. (31)

168. A seguito dell'aggiudicazione resta salva la facolta' delle parti di stipulare patti in deroga a quanto disposto dal comma 167.

169. Al fine di realizzare attivita' di studio, verifiche tecniche ed interventi in tema di attribuzione di frequenze aggiuntive a specifici servizi, propedeutiche alla razionalizzazione della banda 700 MHz, e per l'armonizzazione internazionale dell'uso dello spettro, e' costituito un apposito Fondo per il riassetto dello spettro radio presso il Ministero dello sviluppo economico con una dotazione di euro 276.000 annui a decorrere dal 2016. Con successivo decreto del Ministro dello sviluppo economico, da emanare entro sessanta giorni dalla data di entrata in vigore della presente legge, sono individuate le specifiche modalita' di utilizzazione del Fondo e di realizzazione delle attivita'.

170. I maggiori o minori valori che derivano dalla riduzione o conversione di strumenti di capitale nei casi di cui al titolo IV, capo II, del decreto legislativo 16 novembre 2015, n. 180, e all'articolo 52, comma 1, lettera a), numeri ii) e iii), del medesimo decreto legislativo n. 180 del 2015, non concorrono alla formazione del reddito complessivo ai fini delle imposte sul reddito e alla determinazione del valore della produzione netta del soggetto che ha emesso gli strumenti.

171. Fermo restando quanto stabilito dal comma 170, i maggiori o minori valori che derivano dall'attuazione di una misura di risoluzione di cui all'articolo 39, comma 1, lettera d), del decreto legislativo 16 novembre 2015, n. 180, i conferimenti del fondo di risoluzione, di cui all'articolo 49, comma 5, del decreto legislativo n. 180 del 2015, e le somme corrisposte dal sistema di garanzia dei depositanti, di cui all'articolo 86 del decreto legislativo n. 180 del 2015, non concorrono alla formazione del reddito complessivo ai fini delle imposte sul reddito, per la parte che eccede le perdite fiscali pregresse e di periodo, di cui all'articolo 84 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e alla determinazione del valore della produzione netta dell'ente sottoposto a risoluzione. Ai fini del presente comma non si considera il limite dell'80 per cento di cui al citato articolo 84 del testo unico di cui al decreto del Presidente della Repubblica n. 917 del 1986 e rilevano anche le perdite trasferite al consolidato nazionale di cui all'articolo 117 del medesimo testo unico e non ancora utilizzate.

172. L'importo dei contributi per i diritti d'uso delle frequenze televisive in tecnica digitale, dovuto dagli operatori di rete in ambito nazionale o locale, e' determinato, con decreto del Ministero dello sviluppo economico, da emanare entro sessanta giorni dalla data di pubblicazione della presente legge nella Gazzetta Ufficiale, in modo trasparente, proporzionato allo scopo, non discriminatorio e obiettivo sulla base dell'estensione geografica del titolo autorizzato, del valore di mercato delle frequenze, tenendo conto di meccanismi premianti finalizzati alla cessione di capacita' trasmissiva a fini concorrenziali nonche' all'uso di tecnologie innovative. L'articolo 3-quinquies, comma 4, del decreto-legge 2 marzo 2012, n. 16, convertito, con modificazioni, dalla legge 26 aprile 2012, n. 44, e' abrogato.

173. Il regime contributivo di cui al comma 172 si applica anche alle annualita' per le quali i contributi dovuti non sono stati determinati.

174. Dall'importo dei contributi di cui al comma 172 e dei diritti amministrativi per gli operatori nazionali e locali, titolari di autorizzazione generale per l'attivita' di operatore di rete televisiva in tecnologia digitale terrestre e per l'utilizzo di frequenze radioelettriche per i collegamenti in ponte radio, calcolati in base all'allegato n. 10 del codice delle comunicazioni elettroniche, di cui al decreto legislativo 1° agosto 2003, n. 259, e successive modificazioni, devono derivare entrate complessive annuali per il bilancio dello Stato in misura non inferiore a euro 32,8 milioni.

175. Agli oneri derivanti dall'attuazione dei commi 172, 173 e 174, pari a 11 milioni di euro annui a decorrere dall'anno 2015, si provvede, per l'anno 2015, mediante utilizzo delle somme gia' versate, entro il 9 dicembre 2015, all'entrata del bilancio dello Stato ai sensi dell'articolo 148, comma 1, della legge 23 dicembre 2000, n. 388, che restano acquisite all'erario per il corrispondente importo, e, a decorrere dall'anno 2016, mediante corrispondente riduzione del Fondo di cui all'articolo 1, comma 200, della legge 23 dicembre 2014, n. 190.

176. Le disposizioni dei commi da 172 a 175 entrano in vigore il giorno successivo alla data di pubblicazione della presente legge nella Gazzetta Ufficiale.

177. Per le finalita' di cui all'articolo 2, comma 3, del decreto-legge 30 dicembre 2009, n. 194, convertito, con modificazioni, dalla legge 26 febbraio 2010, n. 25, e' autorizzata la spesa di 10 milioni di euro per l'anno 2016. Agli oneri derivanti dal primo periodo si provvede mediante corrispondente riduzione del fondo di cui all'articolo 1, comma 200, della legge 23 dicembre 2014, n. 190.

178. Al fine di promuovere forme di occupazione stabile, ai datori di lavoro privati, con esclusione del settore agricolo, e con riferimento alle nuove assunzioni con contratto di lavoro a tempo indeterminato, con esclusione dei contratti di apprendistato e dei contratti di lavoro domestico, decorrenti dal 1° gennaio 2016 con riferimento a contratti stipulati non oltre il 31 dicembre 2016, e' riconosciuto, per un periodo massimo di ventiquattro mesi, ferma restando l'aliquota di computo delle prestazioni pensionistiche, l'esonero dal versamento del 40 per cento dei complessivi contributi previdenziali a carico dei datori di lavoro, con esclusione dei premi e contributi dovuti all'INAIL, nel limite massimo di un importo di esonero pari a 3.250 euro su base annua. L'esonero di cui al presente comma spetta ai datori di lavoro in presenza delle nuove assunzioni di cui al primo periodo, con esclusione di quelle relative a lavoratori che nei sei mesi precedenti siano risultati occupati a tempo indeterminato presso qualsiasi datore di lavoro, e non spetta con riferimento a lavoratori per i quali il beneficio di cui al presente comma ovvero di cui all'articolo 1, comma 118, della legge 23 dicembre 2014, n. 190, sia gia' stato usufruito in relazione a precedente assunzione a tempo indeterminato. L'esonero di cui al presente comma non e' cumulabile con altri esoneri o riduzioni delle aliquote di finanziamento previsti dalla normativa vigente. L'esonero di cui al presente comma non spetta ai datori di lavoro in presenza di assunzioni relative a lavoratori in riferimento ai quali i datori di lavoro, ivi considerando societa' controllate o collegate ai sensi dell'articolo 2359 del codice civile o facenti capo, anche per interposta persona, allo stesso soggetto, hanno comunque gia' in essere un contratto a tempo indeterminato nei tre mesi antecedenti la data di entrata in vigore della presente legge. L'INPS provvede, con le risorse umane, strumentali e finanziarie disponibili a legislazione vigente, al monitoraggio del numero di rapporti di lavoro attivati ai sensi del presente comma e delle conseguenti minori entrate contributive, inviando relazioni mensili al Ministero del lavoro e delle politiche sociali e al Ministero dell'economia e delle finanze.

179. Per i datori di lavoro del settore agricolo le disposizioni di cui al comma 178 si applicano:

- a) nel limite di 1,1 milioni di euro per l'anno 2016, 2,8 milioni di euro per l'anno 2017, 1,8 milioni di euro per l'anno 2018, 0,1 milioni di euro per l'anno 2019 per i lavoratori con qualifica di impiegati e dirigenti;
- b) nel limite di 1,6 milioni di euro per l'anno 2016, 8,8 milioni di euro per l'anno 2017, 7,2 milioni di euro per l'anno 2018, 0,8 milioni di euro per l'anno 2019, con riferimento alle nuove assunzioni con contratto di lavoro a tempo indeterminato, con esclusione dei contratti di apprendistato, decorrenti dal 1° gennaio 2016 con riferimento a contratti stipulati non oltre il 31 dicembre 2016, con esclusione dei lavoratori che nell'anno 2015 siano risultati occupati a tempo indeterminato e relativamente ai lavoratori occupati a tempo determinato che risultino iscritti negli elenchi nominativi per un numero di giornate di lavoro non inferiore a 250 giornate con riferimento all'anno 2015.

180. L'esonero contributivo di cui al comma 179 e' riconosciuto dall'ente previdenziale in base all'ordine cronologico di presentazione delle domande e, nel caso di insufficienza delle risorse indicate al comma 179, valutata anche su base pluriennale con riferimento alla durata dell'esonero, l'ente previdenziale non prende in considerazione ulteriori domande, fornendo immediata comunicazione anche attraverso il proprio sito internet. L'ente previdenziale provvede al monitoraggio delle minori entrate valutate con riferimento alla durata dell'incentivo, inviando relazioni mensili al Ministero del lavoro e delle politiche sociali, al Ministero delle politiche agricole alimentari e forestali ed al Ministero dell'economia e delle finanze.

181. Il datore di lavoro che subentra nella fornitura di servizi in appalto e che assume, ancorche' in attuazione di un obbligo preesistente, stabilito da norme di legge o della contrattazione collettiva, un lavoratore per il quale il datore di lavoro cessante fruisce dell'esonero contributivo di cui ai commi 178 o 179, preserva il diritto alla fruizione dell'esonero contributivo medesimo nei limiti della durata e della misura che residua computando, a tal fine, il rapporto di lavoro con il datore di lavoro cessante.

182. Salva espressa rinuncia scritta del prestatore di lavoro, sono soggetti a una imposta sostitutiva dell'imposta sul reddito delle persone fisiche e delle addizionali regionali e comunali pari al 10 per cento, entro il limite di importo complessivo di 3.000 euro lordi, i premi di risultato di ammontare variabile la cui corresponsione sia legata ad incrementi di produttivita', redditivita', qualita', efficienza ed innovazione, misurabili e verificabili sulla base di criteri definiti con il decreto di cui al comma 188, nonche' le somme erogate sotto forma di partecipazione agli utili dell'impresa. (71) (87)

183. Ai fini della determinazione dei premi di produttivita', e' computato il periodo obbligatorio di congedo di maternita'.

184. Le somme e i valori di cui al comma 2 e all'ultimo periodo del comma 3 dell'articolo 51 del testo unico di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, non concorrono, nel rispetto dei limiti ivi indicati, a formare il reddito di lavoro dipendente, ne' sono soggetti all'imposta sostitutiva disciplinata dai commi da 182 a 191, anche nell'eventualita' in cui gli stessi siano fruiti, per scelta del lavoratore, in sostituzione, in tutto o in parte, delle somme di cui al comma 182. Le somme e i valori di cui al comma 4 del medesimo articolo 51 concorrono a formare il reddito di lavoro dipendente secondo le regole ivi previste e non sono soggetti all'imposta sostitutiva disciplinata dai commi da 182 a 191 del presente articolo, anche nell'eventualita' in cui gli stessi siano fruiti, per scelta del lavoratore, in sostituzione, in tutto o in parte, delle somme di cui al comma 182.

184-bis. Ai fini dell'applicazione del comma 184, non concorrono a formare il reddito di lavoro dipendente, ne' sono soggetti all'imposta sostitutiva disciplinata dai commi da 182 a 191:

- a) i contributi alle forme pensionistiche complementari di cui al decreto legislativo 5 dicembre 2005, n. 252, e quelli ai sottoconti italiani di prodotti pensionistici individuali paneuropei (PEPP) di cui al regolamento (UE) 2019/1238, versati, per scelta del lavoratore, in sostituzione, in tutto o in parte, delle somme di cui al comma 182, anche se eccedenti i limiti indicati all'articolo 8, commi 4 e 6, del medesimo decreto legislativo n. 252 del 2005, o quelli indicati dalle disposizioni nazionali di attuazione del Regolamento (UE) 2019/1238. Tali contributi non concorrono a formare la parte imponibile delle prestazioni pensionistiche complementari ai fini dell'applicazione delle previsioni di cui all'articolo 11, comma 6, del medesimo decreto legislativo n. 252 del 2005, nonche' ai fini dell'applicazione delle disposizioni nazionali di attuazione del regolamento (UE) 2019/1238.;
- b) i contributi di assistenza sanitaria di cui all'articolo 51, comma 2, lettera a), del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, versati per scelta del lavoratore in sostituzione, in tutto o in parte, delle somme di cui al comma 182 del presente articolo, anche se eccedenti i limiti indicati nel medesimo articolo 51, comma 2, lettera a);
- c) il valore delle azioni di cui all'articolo 51, comma 2, lettera g), del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, ricevute, per scelta del lavoratore, in sostituzione, in tutto o in parte, delle somme di cui al comma 182 del presente articolo, anche se eccedente il limite indicato nel medesimo articolo 51, comma 2, lettera g), e indipendentemente dalle condizioni dallo stesso stabilite . Ai fini di quanto stabilito dall'articolo 68, comma 6, del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, il costo o il valore di acquisto e' pari al valore delle azioni ricevute, per scelta del lavoratore, in sostituzione, in tutto o in parte, delle somme di cui al medesimo comma 182.

185. Per l'accertamento, la riscossione, le sanzioni e il contenzioso, si applicano, in quanto compatibili, le ordinarie disposizioni in materia di imposte dirette.

186. Le disposizioni di cui ai commi da 182 a 185 trovano applicazione per il settore privato e con riferimento ai titolari di reddito di lavoro dipendente di importo non superiore, nell'anno precedente quello di percezione delle somme di cui al comma 182, a euro 80.000. Se il sostituto d'imposta tenuto ad applicare l'imposta sostitutiva non e' lo stesso che ha rilasciato la certificazione unica dei redditi per l'anno precedente, il beneficiario attesta per iscritto l'importo del reddito di lavoro dipendente conseguito nel medesimo anno.

187. Ai fini dell'applicazione delle disposizioni di cui ai commi da 182 a 191, le somme e i valori di cui ai commi 182 e 184 devono essere erogati in esecuzione dei contratti aziendali o territoriali di cui all'articolo 51 del decreto legislativo 15 giugno 2015, n. 81.

188. Con decreto del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, da emanare entro sessanta giorni dalla data di entrata in vigore della presente legge, sono stabiliti i criteri di misurazione degli incrementi di produttivita', redditivita', qualita', efficienza ed innovazione di cui al comma 182 nonche' le modalita' attuative delle previsioni contenute nei commi da 182 a 191, compresi gli strumenti e le modalita' di partecipazione all'organizzazione del lavoro, di cui al comma 189. Il decreto prevede altresi' le modalita' del monitoraggio dei contratti aziendali o territoriali di cui al comma 187.

189. Per le aziende che coinvolgono pariteticamente i lavoratori nell'organizzazione del lavoro, con le modalita' specificate nel decreto di cui al comma 188, e' ridotta di venti punti percentuali l'aliquota contributiva a carico del datore di lavoro per il regime relativo all'invalidita', la vecchiaia ed i superstiti su una quota delle erogazioni previste dal comma 182 non superiore a 800 euro. Sulla medesima quota, non e' dovuta alcuna contribuzione a carico del lavoratore. Con riferimento alla quota di erogazioni di cui al presente comma e' corrispondentemente ridotta l'aliquota contributiva di computo ai fini pensionistici. (18)

190. All'articolo 51 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, sono apportate le seguenti modifiche:

- a) al comma 2: 1) la lettera f) e' sostituita dalla seguente: «f) l'utilizzazione delle opere e dei servizi riconosciuti dal datore di lavoro volontariamente o in conformita' a disposizioni di contratto o di accordo o di regolamento aziendale, offerti alla generalita' dei dipendenti o a categorie di dipendenti e ai familiari indicati nell'articolo 12 per le finalita' di cui al comma 1 dell'articolo 100»; 2) la lettera f-bis) e' sostituita dalla seguente: «f-bis) le somme, i servizi e le prestazioni erogati dal datore di lavoro alla generalita' dei dipendenti o a categorie di dipendenti per la fruizione, da parte dei familiari indicati nell'articolo 12, dei servizi di educazione e istruzione anche in eta' prescolare, compresi i servizi integrativi e di mensa ad essi connessi, nonche' per la frequenza di ludoteche e di centri estivi e invernali e per borse di studio a favore dei medesimi familiari»; 3) dopo la lettera f-bis) e' inserita la seguente: «f-ter) le somme e le prestazioni erogate dal datore di lavoro alla generalita' dei dipendenti o a categorie di dipendenti per la fruizione dei servizi di assistenza ai familiari anziani o non autosufficienti indicati nell'articolo 12»;
- b) dopo il comma 3 e' inserito il seguente: «3-bis. Ai fini dell'applicazione dei commi 2 e 3, l'erogazione di beni, prestazioni, opere e servizi da parte del datore di lavoro puo' avvenire mediante documenti di legittimazione, in formato cartaceo o elettronico, riportanti un valore nominale».

191. All'articolo 25, comma 1, del decreto legislativo 15 giugno 2015, n. 80, le parole: «al 10 per cento» sono sostituite dalle seguenti: «a 38,3 milioni di euro per l'anno 2016, a 36,2 milioni di euro per l'anno 2017 e a 35,6 milioni di euro per l'anno 2018». Le risorse del Fondo di cui all'articolo 1, comma 68, ultimo periodo, della legge 24 dicembre 2007, n. 247, e successive modificazioni, sono ridotte di 344,7 milioni di euro per l'anno 2016, 325,8 milioni di euro per l'anno 2017, 320,4 milioni di euro per l'anno 2018, 344 milioni di euro per l'anno 2019, 329 milioni di euro per l'anno 2020, 310 milioni di euro per l'anno 2021 e 293 milioni di euro annui a decorrere dall'anno 2022.

192. Al fine di assicurare l'efficacia e la sostenibilita' della strategia nazionale per la valorizzazione dei beni e delle aziende confiscate alla criminalita' organizzata ed il corretto funzionamento del sistema di monitoraggio analitico sull'utilizzo di tali beni, in coerenza con quanto previsto dal Programma nazionale di riforma contenuto nel Documento di economia e finanza 2015, l'Agenzia nazionale per l'amministrazione e la destinazione dei beni sequestrati e confiscati alla criminalita' organizzata promuove specifiche azioni di rafforzamento e sviluppo delle competenze, anche interne, necessarie per l'efficace svolgimento delle funzioni istituzionali.

193. Alla realizzazione delle misure di cui al comma 192 concorrono, nel limite massimo di 5 milioni di euro per ciascuno degli anni 2016, 2017 e 2018, le risorse previste nell'ambito dei programmi operativi nazionali della Commissione europea 2014/2020 «Governance e capacita' istituzionale» e «Legalita'», nonche' dei programmi di azione e coesione di cui alla delibera CIPE n. 10/ 2015 del 28 gennaio 2015, previa verifica di coerenza da parte delle rispettive Autorita' di gestione con gli obiettivi dei predetti programmi.

194. Nell'ambito dei programmi cofinanziati dall'Unione europea per il periodo 2014/2020 e degli interventi complementari alla programmazione dell'Unione europea di cui alla citata delibera CIPE n. 10/2015, a titolarita' delle amministrazioni regionali, gli enti interessati possono pianificare, di concerto con l'Agenzia nazionale per l'amministrazione e la destinazione dei beni sequestrati e confiscati alla criminalita' organizzata, specifiche azioni rivolte all'efficace valorizzazione dei predetti beni.

195. Per ciascun anno del triennio 2016-2018 e' autorizzata la spesa di 10 milioni di euro al fine di assicurare alle aziende sequestrate e confiscate alla criminalita' organizzata nei procedimenti penali per i delitti di cui all'articolo 51, comma 3-bis, del codice di procedura penale e di cui agli articoli 240-bis, primo comma, del codice penale, 301, comma 5-bis, del decreto del Presidente della Repubblica 23 gennaio 1973, n. 43, e 85-bis del decreto del Presidente della Repubblica 9 ottobre 1990, n. 309 e nei procedimenti di applicazione di misure di prevenzione patrimoniali, limitatamente ai soggetti destinatari di cui all'articolo 4, comma 1, lettere a) e b), del codice di cui al decreto legislativo 6 settembre 2011, n. 159, la continuita' del credito bancario e l'accesso al medesimo, il sostegno agli investimenti e agli oneri necessari per gli interventi di ristrutturazione aziendale, la tutela dei livelli occupazionali, la promozione di misure di emersione del lavoro irregolare, la tutela della salute e della sicurezza del lavoro, il sostegno alle cooperative previste dall'articolo 48, comma 3, lettera c), e comma 8, lettera a) nonche' delle imprese affittuarie o cessionarie di cui all'articolo 48, comma 8, lettere a) e b), del citato codice di cui al decreto legislativo n. 159 del 2011. (14)

196. Le risorse di cui al comma 195 confluiscono:

- a) nella misura di 3 milioni di euro annui, in un'apposita sezione del Fondo di garanzia per le piccole e medie imprese, di cui all'articolo 2, comma 100, lettera a), della legge 23 dicembre 1996, n. 662, destinata alla concessione di garanzie per operazioni finanziarie erogate in favore di imprese, di qualunque dimensione, sequestrate o confiscate alla criminalita' organizzata, come individuate al comma 195 del presente articolo, ovvero di imprese che rilevano i complessi aziendali di quelle sequestrate o confiscate alla criminalita' organizzata, come individuate al medesimo comma 195;
- b) nella misura di 7 milioni di euro annui, in un'apposita sezione del Fondo per la crescita sostenibile, di cui all'articolo 23 del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134, per l'erogazione di finanziamenti agevolati di importo non superiore a due milioni di euro e di durata non superiore a quindici anni comprensivi di cinque anni di preammortamento in favore delle imprese di cui alla lettera a).

197. Con decreto del Ministro dello sviluppo economico, di concerto con il Ministro dell'economia e delle finanze, sentito il Ministro della giustizia, sono determinati, nel rispetto delle vigenti disposizioni in materia di aiuti di Stato, i limiti, i criteri e le modalita' per la concessione delle garanzie e dei finanziamenti di cui al comma 196, lettere a) e b). I predetti criteri sono formulati avuto particolare riguardo per le imprese che presentano gravi difficolta' di accesso al credito.

198. In caso di revoca del provvedimento di sequestro, in qualunque stato e grado del procedimento, l'avente diritto, quale condizione per la restituzione dell'azienda, e' tenuto a rimborsare gli importi liquidati dalla sezione di cui al comma 196, lettera a), a seguito dell'eventuale escussione della garanzia. Con il decreto di cui al comma 197 sono disciplinate le modalita' per la restituzione, con applicazione di interessi a tassi di mercato, della quota residua del finanziamento erogato, per il caso di revoca del provvedimento di sequestro.

199. Presso il Ministero dello sviluppo economico e' istituito il Fondo per il credito alle vittime di mancati pagamenti, con una dotazione di 10 milioni di euro annui per il triennio 2016-2018, avente come finalita' il sostegno alle piccole e medie imprese che entrano in crisi a causa della mancata corresponsione di denaro da parte di propri debitori nell'ambito dell'attivita' di impresa.

200. Possono accedere al Fondo di cui al comma 199, con le modalita' stabilite dal comma 201, le piccole e medie imprese, definite ai sensi dell'articolo 3 della direttiva 2013/34/UE del Parlamento europeo e del Consiglio, del 26 giugno 2013, anche se in concordato preventivo con continuita', e i professionisti parti offese in un procedimento penale, pendente alla data di presentazione delle domande di accesso al Fondo, a carico di debitori imputati dei delitti di cui agli articoli 629, 640 e 641 del codice penale, 2621 del codice civile, 216, 217, 218, 223, 224 e 225 del regio decreto 16 marzo 1942, n. 267. Possono altresi' accedere al Fondo le piccole e medie imprese di cui al primo periodo e i professionisti ammessi o iscritti al passivo di una procedura concorsuale per la quale il curatore, il commissario o il liquidatore giudiziale si sono costituiti parte civile nel processo penale per i reati di cui al presente comma, ovvero il cui credito e' riconosciuto da una sentenza definitiva di condanna per i reati medesimi.

201. Con decreto del Ministro dello sviluppo economico, di concerto con il Ministro dell'economia e delle finanze, sono determinati, nel rispetto delle vigenti disposizioni in materia di aiuti di Stato, i limiti, i criteri e le modalita' per la concessione dei finanziamenti agevolati da parte dello Stato nei confronti delle imprese di cui al comma 200.

201-bis. Il provvedimento di concessione e di erogazione del finanziamento agevolato di cui al comma 201 e' adottato anche in pendenza della verifica da parte del Ministero dello sviluppo economico della correttezza e della conformita' delle dichiarazioni rese dai soggetti che hanno formulato richiesta di accesso al Fondo di cui al comma 199; in tale caso, il finanziamento e' erogato, a titolo di acconto, per un importo pari al 50 per cento di quanto dovuto e il saldo e' corrisposto all'esito della verifica. Il provvedimento e' comunque revocato quando e' accertata la carenza dei suoi presupposti, con conseguente recupero delle somme anticipate a titolo di acconto, secondo le modalita' stabilite dal decreto di cui al comma 201.

202. In caso di assoluzione dei debitori imputati di cui al comma 200, i soggetti beneficiari dei finanziamenti agevolati sono tenuti al rimborso delle somme erogate secondo le modalita' stabilite dal decreto di cui al comma 201.

203. Per i lavoratori autonomi, titolari di posizione fiscale ai fini dell'imposta sul valore aggiunto, iscritti alla gestione separata di cui all'articolo 2, comma 26, della legge 8 agosto 1995, n. 335, che non risultino iscritti ad altre gestioni di previdenza obbligatoria ne' pensionati, l'aliquota contributiva di cui all'articolo 1, comma 79, della legge 24 dicembre 2007, n. 247, e successive modificazioni, e' confermata al 27 per cento anche per l'anno 2016.

204. Al fine di favorire la tutela del lavoro autonomo non imprenditoriale e l'articolazione flessibile nei tempi e nei luoghi del lavoro subordinato a tempo indeterminato, e' istituito nello stato di previsione del Ministero del lavoro e delle politiche sociali un fondo con una dotazione finanziaria di 10 milioni di euro per l'anno 2016 e di 50 milioni di euro annui a decorrere dall'anno 2017.(21)

205. Il congedo obbligatorio per il padre lavoratore dipendente, da fruire entro i cinque mesi dalla nascita del figlio, nonche' il congedo facoltativo da utilizzare nello stesso periodo, in alternativa alla madre che si trovi in astensione obbligatoria, previsti in via sperimentale per gli anni 2013, 2014 e 2015 dall'articolo 4, comma 24, lettera a), della legge 28 giugno 2012, n. 92, sono prorogati sperimentalmente per l'anno 2016 ed il congedo obbligatorio e' aumentato a due giorni, che possono essere goduti anche in via non continuativa. Ai medesimi congedi, obbligatorio e facoltativo, si applica la disciplina recata dal decreto del Ministro del lavoro e delle politiche sociali 22 dicembre 2012, pubblicato nella Gazzetta Ufficiale n. 37 del 13 febbraio 2013. Alla copertura dell'onere derivante dal presente comma, valutato in 24 milioni di euro per l'anno 2016, si provvede quanto a 14 milioni di euro mediante corrispondente riduzione del Fondo sociale per occupazione e formazione di cui all'articolo 18, comma 1, lettera a), del decreto-legge 29 novembre 2008, n. 185, convertito, con modificazioni, dalla legge 28 gennaio 2009, n. 2. (14) (38) (47)(56)

206. Il Fondo per il finanziamento ordinario delle universita' e' incrementato di 6 milioni di euro per l'anno 2016 e di 10 milioni di euro annui a decorrere dall'anno 2017. A valere sulle risorse di cui al primo periodo, con decreto del Ministro dell'istruzione, dell'universita' e della ricerca, di concerto con il Ministro dell'economia e delle finanze, da emanare entro il 31 gennaio 2016, e' approvato un piano straordinario per la chiamata di professori di prima fascia, inclusi coloro che hanno ottenuto l'idoneita' ai sensi della legge 3 luglio 1998, n. 210, tenuto conto che, ai sensi dell'articolo 18, comma 4, della legge 30 dicembre 2010, n. 240, almeno il 20 per cento delle risorse deve essere destinato a soggetti esterni all'ateneo chiamante. Le chiamate di cui al precedente periodo sono effettuate secondo le procedure di cui all'articolo 18, comma 1, ovvero di cui all'articolo 29, comma 4, della legge n. 240 del 2010.

207. COMMA ABROGATO DALLA L. 30 DICEMBRE 2018, N. 145.

208. COMMA ABROGATO DALLA L. 30 DICEMBRE 2018, N. 145.

209. COMMA ABROGATO DALLA L. 30 DICEMBRE 2018, N. 145.

210. COMMA ABROGATO DALLA L. 30 DICEMBRE 2018, N. 145.

211. COMMA ABROGATO DALLA L. 30 DICEMBRE 2018, N. 145.

212. COMMA ABROGATO DALLA L. 30 DICEMBRE 2018, N. 145.

213. Per tutelare la funzione e le infrastrutture di ricerca delle scienze religiose, per dare continuita' alla formazione di studiosi e strumenti di studio dell'ebraismo, per rivitalizzare la tradizione e il patrimonio di conoscenze sulla storia, le lingue e le culture dell'Africa e dell'Oriente attraverso il sostegno diretto ad istituzioni di riconosciuta competenza e adatte a promuovere la sicurezza del Paese attraverso la formazione e l'impegno di studiose e studiosi in un sistema di relazioni scientifiche internazionali, e' autorizzata la spesa di 3 milioni di euro annui a decorrere dal 2016, da iscrivere in apposito fondo istituito nello stato di previsione del Ministero dell'istruzione, dell'universita' e della ricerca.

214. Per il sostegno e l'attuazione degli interventi di cui al comma 213 il Ministero dell'istruzione, dell'universita' e della ricerca stipula appositi accordi di programma con amministrazioni pubbliche, enti pubblici, istituzioni scientifiche, infrastrutture e organismi di ricerca come definiti dall'articolo 2, punto 83, del regolamento (UE) n. 651/2014 della Commissione, del 17 giugno 2014.

215. Il termine del 31 dicembre 2015 di cui all'articolo 6, comma 6-bis, del decreto-legge 31 dicembre 2014, n. 192, convertito, con modificazioni, dalla legge 27 febbraio 2015, n. 11, e' differito al 31 dicembre 2016. All'articolo 4, comma 9-bis, del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, al quarto periodo, le parole: «per l'anno 2014» sono sostituite dalle seguenti: «per l'anno 2015» e le parole: «fino al 31 dicembre 2015» sono sostituite dalle seguenti: «fino al 31 dicembre 2016»; al quinto periodo, le parole: «Per l'anno 2015» sono sostituite dalle seguenti: «Per l'anno 2016»; dopo il quinto periodo sono aggiunti i seguenti: «Fermo restando il rispetto delle disposizioni di cui all'articolo 1, commi 557, 557-quater e 562, primo periodo, della legge 27 dicembre 2006, n. 296, la proroga puo' essere disposta in deroga ai limiti o divieti prescritti dalle vigenti disposizioni di legge. Per l'anno 2016, agli enti territoriali di cui al primo periodo del presente comma, che si trovino nelle condizioni di cui all'articolo 259 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, non si applicano le disposizioni di cui ai commi 6, 7 e 8 del medesimo articolo. Per gli stessi enti, la proroga dei rapporti di lavoro a tempo determinato e' subordinata all'assunzione integrale degli oneri a carico della regione ai sensi dall'articolo 259, comma 10, del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267». (15)

216. Nell'ottica di favorire il ricambio generazionale e l'immissione nella pubblica amministrazione di personale altamente qualificato, oltre al reclutamento di professori e ricercatori previsto dai commi da 207 a 212 e dai commi da 247 a 252 e dei dirigenti vincitori di procedure selettive gia' gestite dalla Scuola nazionale dell'amministrazione (SNA), le facolta' assunzionali nel triennio 2016-2018 delle amministrazioni dello Stato sono prioritariamente finalizzate all'assunzione di cinquanta dirigenti mediante apposita procedura selettiva gestita dalla SNA e di cinquanta unita' nei profili iniziali della carriera prefettizia, nonche' di dieci avvocati dello Stato e dieci procuratori dello Stato. Con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro per la semplificazione e la pubblica amministrazione, di concerto con il Ministro dell'economia e delle finanze, sono individuati i criteri della procedura selettiva e della ripartizione tra le amministrazioni interessate del personale dirigenziale.

217. Il comma 1 dell'articolo 29 del decreto legislativo 30 marzo 2001, n. 165, e' sostituito dal seguente: «1. Il reclutamento dei dirigenti scolastici si realizza mediante corso-concorso selettivo di formazione bandito dal Ministero dell'istruzione, dell'universita' e della ricerca, sentito il Ministero dell'economia e delle finanze, per tutti i posti vacanti nel triennio, fermo restando il regime autorizzatorio in materia di assunzioni di cui all'articolo 39, comma 3-bis, della legge 27 dicembre 1997, n. 449, e successive modificazioni. Al corso-concorso possono essere ammessi candidati in numero superiore a quello dei posti, secondo una percentuale massima del 20 per cento, determinata dal decreto di cui all'ultimo periodo del presente comma. Al concorso per l'accesso al corso-concorso puo' partecipare il personale docente ed educativo delle istituzioni scolastiche ed educative statali in possesso del relativo diploma di laurea magistrale ovvero di laurea conseguita in base al previgente ordinamento, che abbia maturato un'anzianita' complessiva nel ruolo di appartenenza di almeno cinque anni. E' previsto il pagamento di un contributo, da parte dei candidati, per le spese della procedura concorsuale. Il concorso puo' comprendere una prova preselettiva e comprende una o piu' prove scritte, cui sono ammessi tutti coloro che superano l'eventuale preselezione, e una prova orale, a cui segue la valutazione dei titoli. Il corso-concorso si svolge in giorni e orari e con metodi didattici compatibili con l'attivita' didattica svolta dai partecipanti, con eventuale riduzione del loro carico didattico. Le spese di viaggio e alloggio sono a carico dei partecipanti. Con decreto del Ministro dell'istruzione, dell'universita' e della ricerca sono definite le modalita' di svolgimento delle procedure concorsuali, la durata del corso e le forme di valutazione dei candidati ammessi al corso».

218. All'articolo 17 del decreto-legge 12 settembre 2013, n. 104, convertito, con modificazioni, dalla legge 8 novembre 2013, n. 128, sono apportate le seguenti modificazioni:

- a) il comma 2 e' abrogato;
- b) il comma 3 e' sostituito dal seguente: «3. Le risorse poste nella disponibilita' della Scuola nazionale dell'amministrazione per il reclutamento e la formazione iniziale dei dirigenti scolastici sono versate all'entrata del bilancio dello Stato per la successiva riassegnazione ai pertinenti capitoli dello stato di previsione del Ministero dell'istruzione, dell'universita' e della ricerca e costituiscono limite di spesa per l'organizzazione dei corsi-concorsi di cui all'articolo 29 del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio».

219. COMMA ABROGATO DAL D.LGS. 25 MAGGIO 2017, N. 75.(25)

220. COMMA ABROGATO DAL D.LGS. 25 MAGGIO 2017, N. 75.

221. Le regioni e gli enti locali provvedono alla ricognizione delle proprie dotazioni organiche dirigenziali secondo i rispettivi ordinamenti, nonche' al riordino delle competenze degli uffici dirigenziali, eliminando eventuali duplicazioni. Allo scopo di garantire la maggior flessibilita' della figura dirigenziale nonche' il corretto funzionamento degli uffici, il conferimento degli incarichi dirigenziali puo' essere attribuito senza alcun vincolo di esclusivita' anche ai dirigenti dell'avvocatura civica e della polizia municipale. Per la medesima finalita', non trovano applicazione le disposizioni adottate ai sensi dell'articolo 1, comma 5, della legge 6 novembre 2012, n. 190, ove la dimensione dell'ente risulti incompatibile con la rotazione dell'incarico dirigenziale.

222. COMMA ABROGATO DAL D.LGS. 25 MAGGIO 2017, N. 75.

223. All'articolo 1, comma 330, della legge 23 dicembre 2014, n. 190, le parole: «2016/2017» sono sostituite dalle seguenti: «2017/2018».

224. COMMA ABROGATO DAL D.LGS. 25 MAGGIO 2017, N. 75.

225. Entro un anno dalla data di entrata in vigore del decreto legislativo attuativo dell'articolo 8, comma 1, lettera e), della legge 7 agosto 2015, n. 124, ferme restando le riduzioni delle dotazioni organiche previste dall'articolo 2, comma 1, lettere a) e b), del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, e la conseguente rideterminazione degli organici adottata con decreto del Presidente del Consiglio dei ministri 22 maggio 2015, pubblicato nella Gazzetta Ufficiale n. 217 del 18 settembre 2015, il Ministero dell'interno provvede a predisporre il regolamento di organizzazione di cui all'articolo 2, comma 7, del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, intervenendo coerentemente con le disposizioni di cui al predetto decreto legislativo. Entro il predetto termine, il medesimo Ministero provvede a dare attuazione alle disposizioni di cui all'articolo 2, comma 11, lettera b), del citato decreto-legge n. 95 del 2012, con conseguente riassorbimento, entro il successivo anno, degli effetti derivanti dalle riduzioni di cui al citato articolo 2, comma 1, lettere a) e b). In caso di adozione del regolamento di cui al presente comma in data antecedente alla data di entrata in vigore del decreto legislativo attuativo dell'articolo 8, comma 1, lettera e), della legge 7 agosto 2015, n. 124, il Ministero dell'interno provvede esclusivamente agendo sugli uffici centrali.

226. Le regioni e gli enti locali che hanno conseguito gli obiettivi di finanza pubblica possono compensare le somme da recuperare di cui al primo periodo del comma 1 dell'articolo 4 del decreto-legge 6 marzo 2014, n. 16, convertito, con modificazioni, dalla legge 2 maggio 2014, n. 68, anche attraverso l'utilizzo dei risparmi effettivamente derivanti dalle misure di razionalizzazione organizzativa adottate ai sensi del comma 221, certificati dall'organo di revisione, comprensivi di quelli derivanti dall'applicazione del comma 228.

227. Le amministrazioni di cui all'articolo 3, commi 1 e 2, del decreto-legge 24 giugno 2014, n. 90, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 114, possono procedere, per gli anni 2016, 2017 e 2018, ad assunzioni di personale a tempo indeterminato di qualifica non dirigenziale nel limite di un contingente di personale corrispondente, per ciascuno dei predetti anni, ad una spesa pari al 25 per cento di quella relativa al medesimo personale cessato nell'anno precedente. Per i ricercatori e tecnologi restano ferme le percentuali di turn over previste dall'articolo 3, comma 2, del decreto-legge 24 giugno 2014, n. 90, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 114. Al fine di garantire la continuita' nell'attuazione delle attivita' di ricerca, tenuto conto di quanto disposto dall'articolo 2, comma 4, del decreto legislativo 15 giugno 2015, n. 81, e nelle more della emanazione dei decreti di riordino di cui all'articolo 17, comma 1, della legge 7 agosto 2015, n. 124, gli istituti e gli enti di ricerca possono continuare ad avvalersi del personale con contratto di collaborazione coordinata e continuativa in essere alla data del 31 dicembre 2015, mediante l'attivazione, previa verifica di idoneita', di contratti a tempo determinato a valere sulle risorse disponibili, ai sensi dell'articolo 1, comma 188, della legge 23 dicembre 2005, n. 266, e successive modificazioni, nonche', nel limite del 30 per cento, sulle risorse derivanti dalle facolta' assunzionali disponibili a legislazione vigente, senza nuovi o maggiori oneri a carico della finanza pubblica. PERIODO ABROGATO DAL D.LGS. 25 MAGGIO 2017, N. 75. Resta escluso dalle disposizioni di cui al presente comma il personale di cui all'articolo 3 del decreto legislativo 30 marzo 2001, n. 165. Sono conseguentemente ridotti gli stanziamenti di bilancio delle amministrazioni centrali.

228. Le amministrazioni di cui all'articolo 3, comma 5, del decreto-legge 24 giugno 2014, n. 90, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 114, e successive modificazioni, possono procedere, per gli anni 2016, 2017 e 2018, ad assunzioni di personale a tempo indeterminato di qualifica non dirigenziale nel limite di un contingente di personale corrispondente, per ciascuno dei predetti anni, ad una spesa pari al 25 per cento di quella relativa al medesimo personale cessato nell'anno precedente. Ferme restando le facolta' assunzionali previste dall'articolo 1, comma 562, della legge 27 dicembre 2006, n. 296, per gli enti che nell'anno 2015 non erano sottoposti alla disciplina del patto di stabilita' interno, qualora il rapporto dipendenti-popolazione dell'anno precedente sia inferiore al rapporto medio dipendenti-popolazione per classe demografica, come definito triennalmente con il decreto del Ministro dell'interno di cui all'articolo 263, comma 2, del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, la percentuale stabilita al periodo precedente e' innalzata al 75 per cento nei comuni con popolazione superiore a 1.000 abitanti, per gli anni 2017 e 2018. Per i comuni con popolazione compresa tra 1.000 e 5.000 abitanti che rilevano nell'anno precedente una spesa per il personale inferiore al 24 per cento della media delle entrate correnti registrate nei conti consuntivi dell'ultimo triennio, la predetta percentuale e' innalzata al 100 per cento. Fermi restando l'equilibrio di bilancio di cui ai commi 707 e seguenti del presente articolo e il parametro di spesa del personale di cui all'articolo 1, comma 557-quater, della legge 27 dicembre 2006, n. 296, per le regioni che rilevano nell'anno precedente una spesa per il personale inferiore al 12 per cento del titolo primo delle entrate correnti, considerate al netto di quelle a destinazione vincolata, la percentuale stabilita al primo periodo e' innalzata, per gli anni 2017 e 2018, al 75 per cento. In relazione a quanto previsto dal primo periodo del presente comma, al solo fine di definire il processo di mobilita' del personale degli enti di area vasta destinato a funzioni non fondamentali, come individuato dall'articolo 1, comma 421, della citata legge n. 190 del 2014, restano ferme le percentuali stabilite dall'articolo 3, comma 5, del decreto-legge 24 giugno 2014, n. 90, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 114. Il comma 5-quater dell'articolo 3 del decreto-legge 24 giugno 2014, n. 90, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 114, e' disapplicato con riferimento agli anni 2017 e 2018. (14) (18)

228-bis. Per garantire la continuita' e assicurare la qualita' del servizio educativo nelle scuole dell'infanzia e negli asili nido degli enti locali, in analogia con quanto disposto dalla legge 13 luglio 2015, n. 107, per il sistema nazionale di istruzione e formazione, i comuni possono procedere, negli anni 2016, 2017 e 2018, ad un piano triennale straordinario di assunzioni a tempo indeterminato di personale insegnante ed educativo necessario per consentire il mantenimento dei livelli di offerta formativa, nei limiti delle disponibilita' di organico e della spesa di personale sostenuta per assicurare i relativi servizi nell'anno educativo e scolastico 2015-2016, fermo restando il rispetto degli obiettivi del saldo non negativo, in termini di competenza, tra le entrate e le spese finali, e le norme di contenimento della spesa di personale.

228-ter. Al fine di ridurre il ricorso ai contratti a termine nell'ambito delle scuole dell'infanzia e degli asili nido e valorizzare la professionalita' acquisita dal personale educativo e scolastico impiegato nello svolgimento dei predetti servizi con rapporto di lavoro a tempo determinato, i comuni possono, nel triennio scolastico 2016-2019, assumere personale inserito in proprie graduatorie adottate in applicazione dell'articolo 4, comma 6, del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, e in applicazione dell'articolo 1, comma 558, della legge 27 dicembre 2006, n. 296, e all'articolo 3, comma 90, della legge 24 dicembre 2007, n. 244, nonche' personale inserito in altre proprie graduatorie definite a seguito di prove selettive per titoli ed esami. Fermo restando il rispetto degli obiettivi dei saldo non negativo, in termini di competenza, tra le entrate e le spese finali, e le norme di contenimento della spesa di personale, qualora le stesse amministrazioni possano sostenere a regime la spesa di personale di cui all'articolo 9, comma 28, del decreto-legge 31 maggio 2010, n. 78, convertito dalla legge 30 luglio 2010, n. 122, e successive modificazioni, riferita a contratti di lavoro subordinato a tempo determinato sottoscritti con il personale destinatario delle assunzioni di cui al primo periodo del presente comma, le corrispondenti risorse, in misura non superiore all'ammontare medio relativo al triennio anteriore al 2016, possono essere utilizzate per assunzioni a tempo indeterminato volte al superamento dei medesimi contratti a termine, con contestuale e definitiva riduzione di tale valore di spesa dal tetto di cui al predetto articolo 9, comma 28. Per le finalita' del comma 228-bis e del presente comma, i comuni possono, altresi', avviare nuove procedure selettive per titoli ed esami, per assunzioni con contratto di lavoro a tempo indeterminato, riservate al personale insegnante ed educativo, che abbia maturato, alla data di entrata in vigore del presente decreto, tre anni di servizio, anche non continuativi, con contratto di lavoro subordinato a tempo determinato alle dipendenze dell'amministrazione che indice le procedure di reclutamento, nel limite massimo del cinquanta per cento delle facolta' di assunzione definite nel piano triennale del comma 228-bis, al netto di quelle utilizzate per lo scorrimento delle graduatorie di cui al primo periodo in riduzione della spesa di cui all'articolo 9, comma 28, del decreto-legge n. 78 del 2010. Le graduatorie compilate in esito alle procedure selettive di cui al precedente periodo sono composte da un numero di' soggetti pari, al massimo, al numero dei posti per i quali queste sono bandite, maggiorato del 10 per cento. Nelle more del completamento delle procedure di cui al presente comma, continuano ad applicarsi le disposizioni previste dall'articolo 29, comma 2, lettera c), del decreto legislativo 15 giugno 2015, n. 81 e comunque non oltre il 31 dicembre 2019.

228-quater. Nei tempi stabiliti dal comma 228-ter e comunque non oltre il 31 dicembre 2019, gli enti locali e le istituzioni locali possono, nell'ambito della propria autonomia organizzativa, esperire procedure concorsuali finalizzate a valorizzare specifiche esperienze professionali maturate all'interno dei medesimi enti e istituzioni locali che gestiscono servizi per l'infanzia. Gli enti e le istituzioni di cui al periodo precedente possono valorizzare tali esperienze prevedendo, anche contestualmente, la proroga delle graduatorie vigenti per un massimo di tre anni a partire dal 1° settembre 2016 e il superamento della fase preselettiva per coloro che hanno maturato un'esperienza lavorativa di almeno centocinquanta giorni di lavoro nell'amministrazione che bandisce il concorso ai sensi dell'articolo 4, comma 6, del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, e in applicazione dell'articolo 1, comma 558, della legge 27 dicembre 2006, n. 296, e dell'articolo 3, comma 90, della legge 24 dicembre 2007, n. 244.

228-quinquies. Le disposizioni di cui ai commi 228-bis e 228-ter si applicano anche ai comuni che non hanno rispettato il patto di stabilita' interno nell'anno 2015.

229. A decorrere dall'anno 2016, fermi restando i vincoli generali sulla spesa di personale, i comuni istituiti a decorrere dall'anno 2011 a seguito di fusione nonche' le unioni di comuni possono procedere ad assunzioni di personale a tempo indeterminato nel limite del 100 per cento della spesa relativa al personale di ruolo cessato dal servizio nell'anno precedente.

230. Il Fondo per il funzionamento delle istituzioni scolastiche, di cui all'articolo 1, comma 601, della legge 27 dicembre 2006, n. 296, e successive modificazioni, e' incrementato di euro 23,5 milioni per l'anno 2016.

231. All'articolo 1 della legge 13 luglio 2015, n. 107, sono apportate le seguenti modificazioni:

- a) al comma 145, la parola: «2014» e' sostituita dalla seguente: «2015» e la parola: «2016» dalla seguente: «2017»;
- b) al comma 150, le parole: «2016», «2017», «2018», «2019» e «2020» sono sostituite rispettivamente dalle seguenti: «2017», «2018», «2019», «2020» e «2021».

232. Ai maggiori oneri derivanti dal comma 230, pari ad euro 23,5 milioni per l'anno 2016, si provvede, quanto a euro 7,5 milioni, mediante utilizzo dei risparmi di spesa derivanti dal comma 231 e, quanto a euro 16 milioni, mediante versamento all'entrata del bilancio dello Stato delle somme giacenti nel conto corrente n. 53823530 presso la societa' Poste italiane Spa. Gli ulteriori risparmi di spesa derivanti dal comma 231, pari a 7,5 milioni di euro per l'anno 2017 e a 5,8 milioni di euro per l'anno 2018, confluiscono nel Fondo di cui all'articolo 1, comma 202, della legge 13 luglio 2015, n. 107. Nelle more del versamento delle somme di cui al primo periodo all'entrata del bilancio dello Stato, il Ministro dell'economia e delle finanze e' autorizzato ad accantonare e a rendere indisponibile per l'anno 2016, nello stato di previsione del Ministero dell'istruzione, dell'universita' e della ricerca e a valere sulle disponibilita' di cui all'articolo 1, comma 601, della legge 27 dicembre 2006, n. 296, la somma di 16 milioni di euro al netto di quanto effettivamente versato.

233. Agli oneri derivanti dal comma 231, pari a 7,5 milioni di euro per ciascuno degli anni 2019 e 2020, nonche' a 5,8 milioni di euro per l'anno 2021, si provvede mediante corrispondente riduzione del Fondo di cui all'articolo 1, comma 202, della legge 13 luglio 2015, n. 107.

234. Per le amministrazioni pubbliche interessate ai processi di mobilita' in attuazione dei commi 424 e 425 dell'articolo 1 della legge 23 dicembre 2014, n. 190, le ordinarie facolta' di assunzione previste dalla normativa vigente sono ripristinate nel momento in cui nel corrispondente ambito regionale e' stato ricollocato il personale interessato alla relativa mobilita'. Per le amministrazioni di cui al citato comma 424 dell'articolo 1 della legge n. 190 del 2014, il completamento della predetta ricollocazione nel relativo ambito regionale e' reso noto mediante comunicazione pubblicata nel portale «Mobilita.gov», a conclusione di ciascuna fase del processo disciplinato dal decreto del Ministro per la semplificazione e la pubblica amministrazione 14 settembre 2015, pubblicato nella Gazzetta Ufficiale n. 227 del 30 settembre 2015. Per le amministrazioni di cui al comma 425 dell'articolo 1 della legge n. 190 del 2014 si procede mediante autorizzazione delle assunzioni secondo quanto previsto dalla normativa vigente.

235. All'articolo 4, comma 4, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, e successive modificazioni, le parole: «e, ove riassegnabili, in base alle vigenti disposizioni, al fondo per il finanziamento del trattamento economico accessorio» sono soppresse.

236. COMMA ABROGATO DAL D.LGS. 25 MAGGIO 2017, N. 75.

237. A decorrere dall'anno 2016, e' autorizzata l'ulteriore spesa di 2 milioni di euro annui in favore dei parchi nazionali di cui all'articolo 1, comma 43, della legge 28 dicembre 1995, n. 549.

238. All'allegato A della legge 28 dicembre 2001, n. 448, e' aggiunta, in fine, la seguente voce: «Isola del lago d'Iseo 16-bis. Monte Isola».

239. All'articolo 6, comma 17, del decreto legislativo 3 aprile 2006, n. 152, il secondo e il terzo periodo sono sostituiti dai seguenti: «Il divieto e' altresi' stabilito nelle zone di mare poste entro dodici miglia dalle linee di costa lungo l'intero perimetro costiero nazionale e dal perimetro esterno delle suddette aree marine e costiere protette. I titoli abilitativi gia' rilasciati sono fatti salvi per la durata di vita utile del giacimento, nel rispetto degli standard di sicurezza e di salvaguardia ambientale. Sono sempre assicurate le attivita' di manutenzione finalizzate all'adeguamento tecnologico necessario alla sicurezza degli impianti e alla tutela dell'ambiente, nonche' le operazioni finali di ripristino ambientale».

240. All'articolo 38 del decreto-legge 12 settembre 2014, n. 133, convertito, con modificazioni, dalla legge 11 novembre 2014, n. 164, sono apportate le seguenti modificazioni:

- a) il comma 1 e' sostituito dal seguente: «1. Le attivita' di prospezione, ricerca e coltivazione di idrocarburi e quelle di stoccaggio sotterraneo di gas naturale sono di pubblica utilita'. I relativi titoli abilitativi comprendono pertanto la dichiarazione di pubblica utilita'»;
- b) il comma 1-bis e' abrogato;
- c) il comma 5 e' sostituito dal seguente: «5. Le attivita' di ricerca e coltivazione di idrocarburi liquidi e gassosi sono svolte con le modalita' di cui alla legge 9 gennaio 1991, n. 9, o a seguito del rilascio di un titolo concessorio unico, sulla base di un programma generale di lavori articolato in una prima fase di ricerca, per la durata di sei anni, a cui seguono, in caso di rinvenimento di un giacimento tecnicamente ed economicamente coltivabile, riconosciuto dal Ministero dello sviluppo economico, la fase di coltivazione della durata di trent'anni, salvo l'anticipato esaurimento del giacimento, nonche' la fase di ripristino finale».

241. All'articolo 57, comma 3-bis, del decreto-legge 9 febbraio 2012, n. 5, convertito, con modificazioni, dalla legge 4 aprile 2012, n. 35, le parole: «con le modalita' di cui all'articolo 1, comma 8-bis, della legge 23 agosto 2004, n. 239, nonche'» sono soppresse.

242. All'articolo 1, comma 8-bis, della legge 23 agosto 2004, n. 239, le parole: «ai commi 7 e» sono sostituite dalle seguenti: «al comma».

243. Nelle more dei processi di riordino previsti dall'articolo 8 della legge 7 agosto 2015, n. 124, a decorrere dal 1º gennaio 2016 lo stanziamento per il personale degli uffici di cui all'articolo 14, comma 2, del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni, compresi gli incarichi di collaborazione coordinata e continuativa, e' ridotto in misura pari al 10 per cento rispetto allo stanziamento dell'anno 2015. Per le amministrazioni che dopo il 31 dicembre 2010 hanno disposto riduzioni corrispondenti a quella prescritta dal presente comma, questa si intende gia' adempiuta.

244. All'articolo 4 del decreto-legge 1º gennaio 2010, n. 1, convertito, con modificazioni, dalla legge 5 marzo 2010, n. 30, sono apportate le seguenti modificazioni:

- a) al comma 3, primo periodo, dopo le parole: «nei cinque anni 2010-2014» sono inserite le seguenti: «e nel triennio 2016-2018» e le parole da: «, comma 102» fino alla fine del periodo sono sostituite dalle seguenti: «del decreto-legge 24 giugno 2014, n. 90, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 114»;
- b) al comma 6 e' aggiunto, in fine, il seguente periodo: «E' altresi' autorizzata la spesa di euro 670.984 per l'anno 2016, di euro 4.638.414 per l'anno 2017 e di euro 6.205.577 a decorrere dall'anno 2018».

245. Il Ministero della giustizia e' autorizzato nell'anno 2016, in aggiunta alle facolta' assunzionali previste dalla normativa vigente, ad assumere magistrati ordinari vincitori di concorso. A tal fine, e' autorizzata la spesa nel limite di euro 20.943.084 per l'anno 2016, di euro 25.043.700 per l'anno 2017, di euro 27.387.210 per l'anno 2018, di euro 27.926.016 per l'anno 2019, di euro 35.423.877 per l'anno 2020, di euro 35.632.851 per l'anno 2021, di euro 36.273.804 per l'anno 2022, di euro 37.021.584 per l'anno 2023, di euro 37.662.540 per l'anno 2024 e di euro 38.410.320 annui a decorrere dall'anno 2025.

246. Per il finanziamento di interventi in favore dei collegi universitari di merito legalmente riconosciuti di cui agli articoli 15, 16 e 17 del decreto legislativo 29 marzo 2012, n. 68, e' autorizzata una spesa integrativa di 3 milioni di euro per ciascuno degli anni 2016, 2017 e 2018.

247. Al fine di sostenere l'accesso dei giovani alla ricerca, l'autonomia responsabile delle universita' e la competitivita' del sistema universitario e della ricerca italiano a livello internazionale, il Fondo per il finanziamento ordinario delle universita' e' incrementato di 47 milioni di euro per l'anno 2016 e di 50,5 milioni di euro a decorrere dall'anno 2017, per l'assunzione di ricercatori di cui all'articolo 24, comma 3, lettera b), della legge 30 dicembre 2010, n. 240, e per il conseguente eventuale consolidamento nella posizione di professore di seconda fascia e il Fondo ordinario per il finanziamento degli enti e istituzioni di ricerca e' incrementato di 8 milioni di euro per l'anno 2016 e di 9,5 milioni di euro a decorrere dall'anno 2017 per l'assunzione di ricercatori negli enti pubblici di ricerca.

248. L'assegnazione alle singole universita' dei fondi di cui al comma 247 e' effettuata con decreto del Ministro dell'istruzione, dell'universita' e della ricerca tenendo conto dei risultati della valutazione della qualita' della ricerca (VQR).

249. L'assegnazione agli enti pubblici di ricerca dei fondi di cui al comma 247 e' effettuata con decreto del Ministro dell'istruzione, dell'universita' e della ricerca tenendo conto dei medesimi criteri di riparto del Fondo ordinario per il finanziamento degli enti e istituzioni di ricerca.

250. La quota parte delle risorse di cui al comma 247 eventualmente non utilizzata per le finalita' di cui ai commi da 247 a 249 rimane a disposizione, nel medesimo esercizio finanziario, per le altre finalita' del Fondo per il finanziamento ordinario delle universita' e del Fondo ordinario per il finanziamento degli enti e istituzioni di ricerca.

251. Per il medesimo fine di cui al comma 247 e tenendo conto della situazione di bilancio delle singole universita', all'articolo 66, comma 13-bis, del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, le parole: «A decorrere dall'anno 2015» sono sostituite dalle seguenti: «Per l'anno 2015» e dopo il terzo periodo sono inseriti i seguenti: «A decorrere dall'anno 2016, alle sole universita' che si trovano nella condizione di cui al periodo precedente, e' consentito procedere alle assunzioni di ricercatori di cui all'articolo 24, comma 3, lettera a), della legge 30 dicembre 2010, n. 240, senza che a queste siano applicate le limitazioni da turn over. Resta fermo quanto disposto dal decreto legislativo 29 marzo 2012, n. 49, e dal decreto del Presidente del Consiglio dei ministri 31 dicembre 2014, pubblicato nella Gazzetta Ufficiale n. 66 del 20 marzo 2015, con riferimento alle facolta' assunzionali del personale a tempo indeterminato e dei ricercatori di cui all'articolo 24, comma 3, lettera b), della legge 30 dicembre 2010, n. 240».

252. Al fine di aumentare il numero dei contratti di formazione specialistica dei medici di cui all'articolo 37 del decreto legislativo 17 agosto 1999, n. 368, e successive modificazioni, l'autorizzazione di spesa di cui all'articolo 1, comma 424, della legge 27 dicembre 2013, n. 147, e' incrementata di 57 milioni di euro per l'anno 2016, di 86 milioni di euro per l'anno 2017, di 126 milioni di euro per l'anno 2018, di 70 milioni di euro per l'anno 2019 e di 90 milioni di euro a decorrere dall'anno 2020. (38) (47)

253. All'articolo 10 del decreto-legge 28 giugno 2013, n. 76, convertito, con modificazioni, dalla legge 9 agosto 2013, n. 99, dopo il comma 2 e' inserito il seguente: «2-bis. Ferma restando la disposizione di cui all'articolo 21 del decreto legislativo del Capo provvisorio dello Stato 13 settembre 1946, n. 233, gli iscritti ai corsi di laurea in medicina e chirurgia e in odontoiatria, a partire dal quinto anno di corso e sino all'iscrizione nel relativo albo professionale, al fine di rafforzare la propria posizione previdenziale, possono facoltativamente provvedere all'iscrizione e al pagamento della relativa contribuzione presso la "Quota A" del Fondo di previdenza generale gestito dall'ente di previdenza di cui all'elenco A, nono capoverso, annesso al decreto legislativo 30 giugno 1994, n. 509. L'ammontare del contributo e le modalita' del versamento vengono determinati dal consiglio di amministrazione dell'ente di cui al primo periodo, tenendo conto della capacita' reddituale degli interessati. Per le finalita' di cui al presente comma, l'ente puo' favorire l'iscrizione e il pagamento della contribuzione da parte degli studenti di cui al primo periodo anche attraverso prestiti d'onore. Dall'applicazione delle disposizioni del presente comma non devono derivare nuovi o maggiori oneri per la finanza pubblica».

254. Al fine di sostenere l'accesso dei giovani all'universita', e in particolare dei giovani provenienti da famiglie meno abbienti, il Fondo integrativo statale per la concessione delle borse di studio iscritto nello stato di previsione del Ministero dell'istruzione, dell'universita' e della ricerca e' incrementato di 54.750.000 euro per l'anno 2016 e di 4.750.000 euro annui a decorrere dall'anno 2017.

255. A decorrere dall'anno 2016 l'autorizzazione di spesa per gli interventi di cui all'articolo 4 della legge 23 novembre 1998, n. 407, e' incrementata di 250.000 euro annui.

256. All'articolo 1, comma 169, della legge 23 dicembre 2014, n. 190, le parole: «annui a decorrere dall'anno 2015» sono sostituite dalle seguenti: «per l'anno 2015 e di 228.000.000 di euro annui a decorrere dall'anno 2016».

257. Al fine di assicurare continuita' alle attivita' previste negli accordi sottoscritti con scuole o universita' dei Paesi stranieri, il personale della scuola impegnato in innovativi e riconosciuti progetti didattici internazionali svolti in lingua straniera, al raggiungimento dei requisiti per la quiescenza, puo' chiedere di essere autorizzato al trattenimento in servizio retribuito per non piu' di tre anni. Il trattenimento in servizio e' autorizzato, con provvedimento motivato, dal dirigente scolastico e dal direttore generale dell'ufficio scolastico regionale. Dall'attuazione del presente comma non devono derivare nuovi o maggiori oneri per la finanza pubblica.

258. Per concorrere alle spese sostenute e non coperte da contributi o sostegni pubblici di altra natura per l'acquisto di libri di testo e di altri contenuti didattici, anche digitali, relativi ai corsi d'istruzione scolastica fino all'assolvimento dell'obbligo di istruzione scolastica, e' istituito, presso il Ministero dell'istruzione, dell'universita' e della ricerca, un fondo con una dotazione di 10 milioni di euro per ciascuno degli anni 2016, 2017 e 2018. Con decreto del Ministro dell'istruzione, dell'universita' e della ricerca, da adottare entro novanta giorni dalla data di entrata in vigore della presente legge, sono stabiliti i criteri e le modalita' di individuazione dei destinatari del suddetto contributo sulla base dell'indicatore della situazione economica equivalente (ISEE), nonche' di assegnazione e di erogazione dello stesso.

259. Al comma 4 dell'articolo 16 del decreto legislativo 14 settembre 2015, n. 147, e' aggiunto, in fine, il seguente periodo: «I soggetti di cui all'articolo 2, comma 1, della legge 30 dicembre 2010, n. 238, che si sono trasferiti in Italia entro il 31 dicembre 2015 applicano, per il periodo d'imposta in corso al 31 dicembre 2016 e per quello successivo, le disposizioni di cui alla medesima legge nei limiti e alle condizioni ivi indicati; in alternativa possono optare, con le modalita' definite con provvedimento del direttore dell'Agenzia delle entrate da emanare entro tre mesi dalla data di entrata in vigore della presente disposizione, per il regime agevolativo di cui al presente articolo».

260. All'articolo 60 del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134, sono apportate le seguenti modificazioni:

- a) il comma 3 e' sostituito dal seguente: «3. Sono soggetti ammissibili agli interventi di cui al presente capo le imprese, le universita', gli enti e gli organismi di ricerca, le costituende societa' composte da professori, ricercatori universitari, personale di ricerca dipendente dagli enti di ricerca di cui all'articolo 8 del regolamento di cui al decreto del Presidente del Consiglio dei ministri 30 dicembre 1993, n. 593, l'ENEA, l'ASI e i dottorandi di ricerca e i titolari di assegni di ricerca di cui all'articolo 51, comma 6, della legge 27 dicembre 1997, n. 449, anche congiuntamente ad uno o piu' degli altri soggetti indicati dal presente comma, o qualsiasi altro soggetto giuridico in possesso dei requisiti minimi previsti dai bandi o da altri interventi di sostegno su progetto o programma, purche' residenti ovvero con stabile organizzazione nel territorio nazionale»;
- b) al comma 4, dopo la lettera f) e' aggiunta la seguente: «f-bis) le attivita' di ricerca industriale, sviluppo precompetitivo, diffusione di tecnologie, fino all'avvio e comunque finalizzate a nuove iniziative economiche ad alto contenuto tecnologico, per l'utilizzazione industriale dei risultati della ricerca da parte di soggetti assimilati in fase d'avvio, su progetto o programma, anche autonomamente presentato, da coloro che si impegnano a costituire o a concorrere alla nuova societa'».

261. Al fine di incrementare la quota premiale di cui all'articolo 2, comma 1, del decreto-legge 10 novembre 2008, n. 180, convertito, con modificazioni, dalla legge 9 gennaio 2009, n. 1, e successive modificazioni, il Fondo per il finanziamento ordinario delle universita', di cui all'articolo 5, comma 1, lettera a), della legge 24 dicembre 1993, n. 537, e' incrementato di 25 milioni di euro per l'anno 2016 e di 30 milioni di euro annui a decorrere dall'anno 2017.

262. Al fine di garantire lo sviluppo coordinato della formazione, ricerca e innovazione in settori strategici orientato al design del prodotto, della comunicazione e dei servizi nella regione Abruzzo e nei territori adriatici ad essa viciniori, e' costituito l'Istituto superiore per le industrie artistiche (ISIA) di Pescara, mediante trasformazione dell'attuale sede decentrata dell'ISIA di Roma istituita con autorizzazione del Ministero dell'istruzione, dell'universita' e della ricerca. Entro sessanta giorni dalla data di entrata in vigore della presente legge e' adottato lo statuto dell'Istituto, secondo le procedure definite dal regolamento di cui al decreto del Presidente della Repubblica 28 febbraio 2003, n. 132. In sede di prima applicazione lo statuto e' deliberato da un comitato costituito dal presidente e dal direttore in carica dell'ISIA di Roma, integrato da un esperto nominato dal Ministro dell'istruzione, dell'universita' e della ricerca. In sede di definizione del regolamento didattico dell'Istituto, agli studenti iscritti ai corsi decentrati a Pescara dell'ISIA di Roma e' sempre garantita la possibilita' del completamento del percorso di studi previsto dall'ordinamento in corso. Dall'attuazione del presente comma non devono derivare nuovi o maggiori oneri a carico del bilancio dello Stato.

263. A seguito dell'attivita' di monitoraggio e verifica relativa alle misure di salvaguardia indicate nell'alinea del comma 265 resa possibile in relazione alle misure per le quali la certificazione del diritto al beneficio e' da ritenersi conclusa, i complessivi importi indicati al quarto periodo dell'articolo 1, comma 235, della legge 24 dicembre 2012, n. 228, e successive modificazioni, sono cosi' rideterminati: 243,4 milioni di euro per l'anno 2013, 933,8 milioni di euro per l'anno 2014, 1.871,4 milioni di euro per l'anno 2015, 2.380,0 milioni di euro per l'anno 2016, 2.051,1 milioni di euro per l'anno 2017, 1.340,3 milioni di euro per l'anno 2018, 583,3 milioni di euro per l'anno 2019, 294,1 milioni di euro per l'anno 2020, 138,0 milioni di euro per l'anno 2021, 73,0 milioni di euro per l'anno 2022 e 8,9 milioni di euro per l'anno 2023, cui corrisponde la rideterminazione del limite numerico massimo in 146.166 soggetti. Per effetto delle rideterminazioni di cui al primo periodo del presente comma, ai maggiori oneri pari a 122,1 milioni di euro per l'anno 2020, 89,0 milioni di euro per l'anno 2021, 69,0 milioni di euro per l'anno 2022 e 8,9 milioni di euro per l'anno 2023 si provvede, quanto a 54,5 milioni di euro per l'anno 2020, a 86,7 milioni di euro per l'anno 2021, a 69 milioni di euro per l'anno 2022 e a 8,9 milioni di euro per l'anno 2023, mediante corrispondente riduzione dell'autorizzazione di spesa di cui all'articolo 1, comma 235, primo periodo, della legge 24 dicembre 2012, n. 228, e successive modificazioni. La ripartizione dei complessivi limiti di spesa e numerici di cui al primo periodo del presente comma e' effettuata ai sensi dell'articolo 1, comma 193, della legge 27 dicembre 2013, n. 147. Ai sensi di quanto stabilito dall'articolo 1, comma 235, della legge n. 228 del 2012, l'autorizzazione di spesa di cui al primo periodo del predetto comma 235 e' incrementata di 497 milioni di euro per l'anno 2016, 369,9 milioni di euro per l'anno 2017, 79,7 milioni di euro per l'anno 2018 e 72,7 milioni di euro per l'anno 2019.

264. I lavoratori del comparto scuola e delle istituzioni di alta formazione artistica, musicale e coreutica (AFAM) i quali, a seguito dell'attivita' di monitoraggio e verifica relativa alle misure di salvaguardia che ha dato luogo alla rideterminazione degli oneri di cui al comma 263 del presente articolo e che, in applicazione del procedimento di cui all'articolo 1, comma 193, della legge 27 dicembre 2013, n. 147, che ha disposto il riconoscimento dell'applicazione della salvaguardia anche ai titolari di congedo, ai sensi dell'articolo 42, comma 5, del testo unico di cui al decreto legislativo 26 marzo 2001, n. 151, o di permessi, ai sensi dell'articolo 33, comma 3, della legge 5 febbraio 1992, n. 104, eccedenti il limite numerico previsto dal decreto-legge 31 agosto 2013, n. 102, convertito, con modificazioni, dalla legge 28 ottobre 2013, n. 124, e dalla legge 10 ottobre 2014, n. 147, hanno ricevuto la lettera di certificazione del diritto a pensione con decorrenza dal 1º settembre 2015, possono accedere al trattamento pensionistico a decorrere dal primo giorno successivo alla risoluzione del rapporto di lavoro, anche in deroga alle disposizioni del testo unico di cui al decreto legislativo 16 aprile 1994, n. 297, e dell'articolo 59, comma 9, della legge 27 dicembre 1997, n. 449.

265. Le disposizioni in materia di requisiti di accesso e di regime delle decorrenze vigenti prima della data di entrata in vigore dell'articolo 24 del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, ferme restando, nei limiti definiti ai sensi del comma 263, le salvaguardie previste dall'articolo 24, comma 14, del medesimo decreto-legge n. 201 del 2011, e successive modificazioni, dall'articolo 22 del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, e successive modificazioni, dall'articolo 1, commi da 231 a 234, della legge 24 dicembre 2012, n. 228, e successive modificazioni, dagli articoli 11 e 11-bis del decreto-legge 31 agosto 2013, n. 102, convertito, con modificazioni, dalla legge 28 ottobre 2013, n. 124, e successive modificazioni, dall'articolo 2, commi 5-bis e 5-ter, del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, dall'articolo 1, commi da 194 a 198, della legge 27 dicembre 2013, n. 147, dall'articolo 2 della legge 10 ottobre 2014, n. 147, e dai relativi decreti attuativi del Ministro del lavoro e delle politiche sociali 1º giugno 2012, 8 ottobre 2012, 22 aprile 2013 e 14 febbraio 2014, pubblicati, rispettivamente, nella Gazzetta Ufficiale n. 171 del 24 luglio 2012, n. 17 del 21 gennaio 2013, n. 123 del 28 maggio 2013 e n. 89 del 16 aprile 2014, continuano ad applicarsi ai seguenti soggetti che maturano i requisiti per il pensionamento successivamente al 31 dicembre 2011:

- a) nel limite di 6.300 soggetti, ai lavoratori collocati in mobilita' o in trattamento speciale edile ai sensi degli articoli 4, 11 e 24 della legge 23 luglio 1991, n. 223, e successive modificazioni, o ai sensi dell'articolo 3 del decreto-legge 16 maggio 1994, n. 299, convertito, con modificazioni, dalla legge 19 luglio 1994, n. 451, a seguito di accordi governativi o non governativi, stipulati entro il 31 dicembre 2011, o nel caso di lavoratori provenienti da aziende cessate o interessate dall'attivazione delle vigenti procedure concorsuali quali il fallimento, il concordato preventivo, la liquidazione coatta amministrativa, l'amministrazione straordinaria o l'amministrazione straordinaria speciale, anche in mancanza dei predetti accordi, cessati dall'attivita' lavorativa entro il 31 dicembre 2014 e che perfezionano, entro il periodo di fruizione dell'indennita' di mobilita' o del trattamento speciale edile, ovvero, se cessati entro il 31 dicembre 2012, anche mediante il versamento di contributi volontari, entro dodici mesi dalla fine dello stesso periodo, i requisiti vigenti prima della data di entrata in vigore del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214. Il versamento volontario di cui alla presente lettera, anche in deroga alle disposizioni dell'articolo 6, comma 1, del decreto legislativo 30 aprile 1997, n. 184, puo' riguardare anche periodi eccedenti i sei mesi precedenti la domanda di autorizzazione stessa. Tale versamento, relativo ai lavoratori cessati entro il 31 dicembre 2012 di cui alla presente lettera, puo' comunque essere effettuato solo con riferimento ai dodici mesi successivi al termine di fruizione dell'indennita' di mobilita' o del trattamento speciale edile indicato dalla presente lettera. Eventuali periodi di sospensione dell'indennita' di mobilita', ai sensi dell'articolo 8, commi 6 e 7, della legge 23 luglio 1991, n. 223, e dell'articolo 3 del decreto-legge 16 maggio 1994, n. 299, convertito, con modificazioni, dalla legge 19 luglio 1994, n. 451, per svolgere attivita' di lavoro subordinato, a tempo parziale, a tempo determinato, ovvero di lavoro parasubordinato mantenendo l'iscrizione nella lista, si considerano rilevanti ai fini del prolungamento del periodo di fruizione dell'indennita' stessa e non comportano l'esclusione dall'accesso alle salvaguardie di cui al presente comma;
- b) nel limite di 9.000 soggetti, ai lavoratori di cui all'articolo 1, comma 194, lettere a) e f), della legge 27 dicembre 2013, n. 147, i quali perfezionano i requisiti utili a comportare la decorrenza del trattamento pensionistico, secondo la disciplina vigente prima della data di entrata in vigore del citato decreto-legge n. 201 del 2011, entro il sessantesimo mese successivo alla data di entrata in vigore del medesimo decreto-legge n. 201 del 2011;
- c) nel limite di 6.000 soggetti, ai lavoratori di cui all'articolo 1, comma 194, lettere b), c) e d), della legge 27 dicembre 2013, n. 147, i quali perfezionano i requisiti utili a comportare la decorrenza del trattamento pensionistico, secondo la disciplina vigente prima della data di entrata in vigore del citato decreto-legge n. 201 del 2011, entro il sessantesimo mese successivo alla data di entrata in vigore del medesimo decreto-legge n. 201 del 2011;
- d) nel limite di 2.000 soggetti, ai lavoratori di cui all'articolo 24, comma 14, lettera e-ter), del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, limitatamente ai lavoratori in congedo per assistere figli con disabilita' grave ai sensi dell'articolo 42, comma 5, del testo unico di cui al decreto legislativo 26 marzo 2001, n. 151, i quali perfezionano i requisiti utili a comportare la decorrenza del trattamento pensionistico, secondo la disciplina vigente prima della data di entrata in vigore del citato decreto-legge n. 201 del 2011, entro il sessantesimo mese successivo alla data di entrata in vigore del medesimo decreto-legge n. 201 del 2011;
- e) nel limite di 3.000 soggetti, con esclusione del settore agricolo e dei lavoratori con qualifica di stagionali, ai lavoratori con contratto di lavoro a tempo determinato e ai lavoratori in somministrazione con contratto a tempo determinato, cessati dal lavoro tra il 1º gennaio 2007 e il 31 dicembre 2011, non rioccupati a tempo indeterminato, i quali perfezionano i requisiti utili a comportare la decorrenza del trattamento pensionistico, secondo la disciplina vigente prima della data di entrata in vigore del citato decreto-legge n. 201 del 2011, entro il sessantesimo mese successivo alla data di entrata in vigore del medesimo decreto-legge n. 201 del 2011.

266. Per i lavoratori di cui al comma 265, lettera a), che siano gia' stati autorizzati ai versamenti volontari in data antecedente a quella di entrata in vigore della presente legge e per i quali siano decorsi i termini di pagamento, sono riaperti a domanda i termini dei versamenti relativi ai dodici mesi successivi alla fine del periodo di fruizione dell'indennita' di mobilita' come specificato nel medesimo comma 265.

267. Il trattamento pensionistico, con riferimento ai soggetti di cui al comma 265, non puo' avere decorrenza anteriore alla data di entrata in vigore della presente legge.

268. Ai fini della presentazione delle istanze da parte dei lavoratori, da effettuare entro il termine di decadenza di sessanta giorni dalla data di entrata in vigore della presente legge, si applicano per ciascuna categoria di lavoratori salvaguardati le specifiche procedure previste nei precedenti provvedimenti in materia di salvaguardia dei requisiti di accesso e di regime delle decorrenze vigenti prima della data di entrata in vigore dell'articolo 24 del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, da ultimo stabilite con decreto del Ministro del lavoro e delle politiche sociali 14 febbraio 2014, pubblicato nella Gazzetta Ufficiale n. 89 del 16 aprile 2014. L'Istituto nazionale della previdenza sociale (INPS) provvede al monitoraggio delle domande di pensionamento inoltrate dai lavoratori di cui ai commi da 263 a 270 che intendono avvalersi dei requisiti di accesso e del regime delle decorrenze vigenti prima della data di entrata in vigore del medesimo decreto-legge n. 201 del 2011, sulla base della data di cessazione del rapporto di lavoro, e provvede a pubblicare nel proprio sito internet, in forma aggregata al fine di rispettare le vigenti disposizioni in materia di tutela dei dati personali, i dati raccolti a seguito dell'attivita' di monitoraggio, avendo cura di evidenziare le domande accolte, quelle respinte e le relative motivazioni. Qualora dal monitoraggio risulti il raggiungimento del limite numerico delle domande di pensione e dei limiti di spesa anche in via prospettica determinati ai sensi dei commi 265 e 270, primo periodo, l'INPS non prende in esame ulteriori domande di pensionamento finalizzate ad usufruire dei benefici previsti dai commi da 265 a 267.

269. I dati rilevati nell'ambito del monitoraggio svolto dall'INPS ai sensi del comma 268 sono utilizzati ai fini della predisposizione della relazione di cui all'articolo 2, comma 5, della legge 10 ottobre 2014, n. 147. All'articolo 2, comma 5, della legge 10 ottobre 2014, n. 147, le parole da: «Ministro del lavoro e delle politiche sociali» fino a: «30 giugno» sono sostituite dalle seguenti: «Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, entro il 30 settembre».

270. I benefici di cui ai commi da 265 a 267 sono riconosciuti nel limite di 26.300 soggetti e nel limite massimo di 213 milioni di euro per l'anno 2016, 387 milioni di euro per l'anno 2017, 336 milioni di euro per l'anno 2018, 258 milioni di euro per l'anno 2019, 171 milioni di euro per l'anno 2020, 107 milioni di euro per l'anno 2021, 41 milioni di euro per l'anno 2022 e 3 milioni di euro per l'anno 2023. Conseguentemente, all'articolo 1, comma 235, della legge 24 dicembre 2012, n. 228, e successive modificazioni, gli importi indicati al quarto periodo, come modificati ai sensi del comma 263, sono corrispondentemente incrementati degli importi di cui al precedente periodo, per una rideterminazione pari a: 243,4 milioni di euro per l'anno 2013, 933,8 milioni di euro per l'anno 2014, 1.871,4 milioni di euro per l'anno 2015, 2.593 milioni di euro per l'anno 2016, 2.438,1 milioni di euro per l'anno 2017, 1.676,3 milioni di euro per l'anno 2018, 841,3 milioni di euro per l'anno 2019, 465,1 milioni di euro per l'anno 2020, 245 milioni di euro per l'anno 2021, 114 milioni di euro per l'anno 2022 e 11,9 milioni di euro per l'anno 2023, cui corrisponde la rideterminazione del limite numerico massimo in 172.466 soggetti.

271. L'autorizzazione di spesa di cui all'articolo 1, comma 235, primo periodo, della legge 24 dicembre 2012, n. 228, e successive modificazioni, e' altresi' incrementata, sulla base dei risparmi accertati ai sensi del comma 263 per gli anni 2013 e 2014 ammontanti a complessivi 485,8 milioni di euro, nella misura di 100 milioni di euro per ciascuno degli anni dal 2018 al 2021 e di 85,8 milioni di euro per l'anno 2022. Conseguentemente il Fondo per la compensazione degli effetti finanziari non previsti a legislazione vigente conseguenti all'attualizzazione di contributi pluriennali, di cui all'articolo 6, comma 2, del decreto-legge 7 ottobre 2008, n. 154, convertito, con modificazioni, dalla legge 4 dicembre 2008, n. 189, e successive modificazioni, e' ridotto di 100 milioni di euro per ognuno degli anni dal 2018 al 2021 e di 85,8 milioni di euro per l'anno 2022 e i predetti residui provenienti dagli anni 2013 e 2014 iscritti in bilancio costituiscono economie da registrare in sede di rendiconto 2015.

272. Al fine del concorso alla copertura degli oneri derivanti dai commi da 263 a 270 l'autorizzazione di spesa di cui all'articolo 1, comma 235, primo periodo, della legge 24 dicembre 2012, n. 228, e successive modificazioni, come rifinanziata anche ai sensi dei commi 263 e 271, e' ridotta di 213 milioni di euro per l'anno 2016, 387 milioni di euro per l'anno 2017, 336 milioni di euro per l'anno 2018, 215,7 milioni di euro per l'anno 2019, 100 milioni di euro per l'anno 2020, 100 milioni di euro per l'anno 2021, 41 milioni di euro per l'anno 2022 e 3 milioni di euro per l'anno 2023.

273. Ai fini del concorso alla copertura dei maggiori oneri conseguenti al potenziamento delle misure di sostegno al reddito per le situazioni di disagio previste dalla presente legge, l'autorizzazione di spesa di cui all'articolo 1, comma 235, primo periodo, della legge 24 dicembre 2012, n. 228, e successive modificazioni, come rifinanziata dalla presente legge, e' ridotta di 124 milioni di euro per l'anno 2016.

274. All'articolo 1, comma 117, della legge 23 dicembre 2014, n. 190, le parole: «nel corso dell'anno 2015» sono sostituite dalle seguenti: «nel corso degli anni 2015, 2016, 2017 e 2018».

275. Per i lavoratori indicati all'articolo 1, comma 117, della legge 23 dicembre 2014, n. 190, le disposizioni ivi previste si applicano anche ai lavoratori che, in seguito alla cessazione del rapporto di lavoro, siano transitati in una gestione di previdenza diversa da quella dell'INPS, compresi coloro che, transitati nel pubblico impiego ovvero nella gestione del soppresso Istituto postelegrafonici, abbiano effettuato la ricongiunzione contributiva ai sensi dell'articolo 2 della legge 7 febbraio 1979, n. 29, e risultino iscritti a forme previdenziali obbligatorie diverse dall'assicurazione generale obbligatoria, derogando al disposto dell'articolo 1, comma 115, della citata legge n. 190 del 2014 e che non abbiano maturato il diritto alla decorrenza del trattamento pensionistico nel corso degli anni 2015 e 2016.

276. Nello stato di previsione del Ministero del lavoro e delle politiche sociali e' istituito un fondo con una dotazione pari a 2 milioni di euro per ciascuno degli anni 2016, 2017, 2018, 2019 e 2020 finalizzato all'accompagnamento alla quiescenza, entro l'anno 2020, dei lavoratori di cui all'articolo 1, comma 117, della legge 23 dicembre 2014, n. 190, che non maturino i requisiti previsti da tale disposizione. Le risorse del fondo sono ripartite tra i lavoratori di cui al presente comma sulla base di criteri e modalita' stabiliti con decreto del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, da adottare entro sessanta giorni dalla data di entrata in vigore della presente legge.

277. Ai lavoratori del settore della produzione di materiale rotabile ferroviario che hanno prestato la loro attivita' nel sito produttivo, senza essere dotati degli equipaggiamenti di protezione adeguati all'esposizione alle polveri di amianto, durante le operazioni di bonifica dall'amianto poste in essere mediante sostituzione del tetto, sono riconosciuti, nei limiti stabiliti dal presente comma, i benefici previdenziali di cui all'articolo 13, comma 8, della legge 27 marzo 1992, n. 257, per il periodo corrispondente alla medesima bonifica e per i dieci anni successivi al termine dei lavori di bonifica, a condizione della continuita' del rapporto di lavoro in essere al momento delle suddette operazioni di bonifica. I benefici sono riconosciuti a domanda, da presentare all'INPS, a pena di decadenza, entro sessanta giorni dalla data di entrata in vigore della presente legge, corredata della dichiarazione del datore di lavoro che attesti la sola presenza del richiedente nel sito produttivo nel periodo di effettuazione dei lavori di sostituzione del tetto. I benefici sono riconosciuti nei limiti delle risorse assegnate a un apposito fondo istituito nello stato di previsione del Ministero del lavoro e delle politiche sociali con dotazione pari a 5,5 milioni di euro per l'anno 2016, 7 milioni di euro per l'anno 2017, 10,2 milioni di euro per l'anno 2018, 12,8 milioni di euro per l'anno 2019, 12,7 milioni di euro per l'anno 2020, 12,6 milioni di euro per l'anno 2021, 12,2 milioni di euro per l'anno 2022, 11,6 milioni di euro per l'anno 2023 , 11,5 milioni di euro per l'anno 2024, 12,6 milioni di euro per l'anno 2025, 13,5 milioni di euro per l'anno 2026, 13,2 milioni di euro per l'anno 2027, 12,3 milioni di euro per l'anno 2028, 11,8 milioni di euro per l'anno 2029 e 11 milioni di euro annui a decorrere dall'anno 2030. Con decreto del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, da adottare entro sessanta giorni dalla data di entrata in vigore della presente legge, sono stabilite le modalita' di attuazione del presente comma, con particolare riferimento all'assegnazione dei benefici ai lavoratori interessati e alle modalita' di certificazione da parte degli enti competenti.

277-bis. Entro sessanta giorni dalla data di entrata in vigore della presente disposizione, l'INPS richiede al datore di lavoro la documentazione necessaria ad integrazione delle domande presentate ai sensi del comma 277. Il datore di lavoro adempie entro il termine perentorio di novanta giorni dalla ricezione della richiesta. Entro i successivi quindici giorni l'INPS trasmette le istanze corredate della relativa documentazione all'INAIL che, entro i successivi sessanta giorni, invia all'INPS le certificazioni tecniche attestanti la sussistenza o meno dei requisiti previsti dalla legge.

277-ter. All'esito della procedura indicata al comma 277-bis, e comunque non oltre sessanta giorni dalla ricezione delle certificazioni inviate dall'INAIL, l'INPS procede al monitoraggio delle domande presentate, sulla base dei seguenti criteri:

- a) la data di perfezionamento, nell'anno di riferimento, dei requisiti pensionistici per ciascun lavoratore interessato;
- b) l'onere previsto per l'esercizio finanziario dell'anno di riferimento, connesso all'anticipo pensionistico e all'eventuale incremento di misura dei trattamenti;
- c) la data di presentazione della domanda di accesso al beneficio.

277-quater. Ai fini dell'individuazione di eventuali scostamenti rispetto alle risorse finanziarie annualmente disponibili per legge, entro trenta giorni dalla conclusione delle operazioni di monitoraggio, e comunque con cadenza annuale, l'INPS provvede alla redazione di una graduatoria dei lavoratori aventi diritto al beneficio di cui al comma 277, tenendo conto prioritariamente della data di maturazione dei requisiti pensionistici agevolati e, a parita' degli stessi, della data di presentazione della domanda di accesso al beneficio. Qualora l'onere finanziario accertato sia superiore allo stanziamento previsto per l'anno di riferimento, la decorrenza dei trattamenti pensionistici riconosciuti ai sensi del comma 277 e' differita in ragione dei criteri indicati al precedente periodo del presente comma e nei limiti delle risorse disponibili.

277-quinquies. Per quanto non espressamente regolato dai commi da 277-bis a 277-quater, si applicano, in quanto compatibili le disposizioni contenute nel decreto del Ministro del lavoro e delle politiche sociali 12 maggio 2016, pubblicato nella Gazzetta Ufficiale n. 158 dell'8 luglio 2016.

277-sexies. I soggetti di cui al comma 277 che, entro il 30 giugno 2020, hanno ottenuto la certificazione tecnica da parte dell'INAIL circa la sussistenza dei requisiti previsti dalla legge e che hanno maturato, tenendo conto del riconoscimento del beneficio di cui all'articolo 13, comma 8, della legge 27 marzo 1992, n. 257, la decorrenza teorica del trattamento pensionistico entro il 31 dicembre 2020, possono accedere al medesimo trattamento entro il 31 dicembre 2021 senza attendere l'esito della procedura di monitoraggio di cui ai commi 277-ter e 277-quater. La decorrenza dei trattamenti pensionistici erogati in applicazione del presente comma non puo' essere antecedente al 1° gennaio 2021.

278. E' istituito nello stato di previsione del Ministero del lavoro e delle politiche sociali il Fondo per le vittime dell'amianto, in favore degli eredi di coloro che sono deceduti a seguito di patologie asbesto-correlate per esposizione all'amianto nell'esecuzione delle operazioni portuali nei porti nei quali hanno trovato applicazione le disposizioni della legge 27 marzo 1992, n. 257, con una dotazione di 10 milioni di euro per ciascuno degli anni dal 2016 al 2020 nonche' di 10 milioni di euro per ciascuno degli anni 2021 e 2022. Le prestazioni del Fondo non escludono la fruizione dei diritti derivanti dalle norme generali e speciali dell'ordinamento e si cumulano con essi. Il Fondo concorre al pagamento, in favore dei superstiti di coloro che sono deceduti per le patologie asbesto-correlate, di quanto agli stessi superstiti e' dovuto a titolo di risarcimento del danno, patrimoniale e non patrimoniale, come liquidato con sentenza esecutiva o con verbale di conciliazione giudiziale. Delle risorse del predetto fondo possono avvalersi anche le Autorita' di sistema portuale soccombenti in sentenze esecutive, o comunque parti debitrici in verbali di conciliazione giudiziale, aventi a oggetto risarcimenti liquidati in favore di superstiti di coloro che sono deceduti per patologie asbesto-correlate, compresi coloro che non erano dipendenti diretti delle cessate organizzazioni portuali. Le procedure e le modalita' di erogazione delle prestazioni sono stabilite con decreto del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, da emanare entro sessanta giorni dalla data di entrata in vigore della presente legge.

279. All'articolo 1, comma 115, della legge 23 dicembre 2014, n. 190, le parole: «30 giugno 2015» sono sostituite dalle seguenti: «31 dicembre 2016».

280. Il comma 18 dell'articolo 2 della legge 8 agosto 1995, n. 335, si interpreta nel senso che i lavoratori assunti successivamente al 31 dicembre 1995 ai quali siano accreditati, a seguito di una loro domanda, contributi riferiti a periodi antecedenti al 1º gennaio 1996 non sono soggetti all'applicazione del massimale annuo della base contributiva e pensionabile, di cui alla medesima disposizione, a decorrere dal mese successivo a quello di presentazione della domanda.

281. Al fine di portare a conclusione la sperimentazione di cui all'articolo 1, comma 9, della legge 23 agosto 2004, n. 243, la facolta' prevista al predetto articolo 1, comma 9, e' estesa anche alle lavoratrici che hanno maturato i requisiti previsti dalla predetta disposizione, adeguati agli incrementi della speranza di vita ai sensi dell'articolo 12 del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, e successive modificazioni, entro il 31 dicembre 2015 ancorche' la decorrenza del trattamento pensionistico sia successiva a tale data, fermi restando il regime delle decorrenze e il sistema di calcolo delle prestazioni applicati al pensionamento di anzianita' di cui alla predetta sperimentazione. Al fine del concorso alla copertura degli oneri derivanti dal primo periodo del presente comma l'autorizzazione di spesa di cui all'articolo 1, comma 235, primo periodo, della legge 24 dicembre 2012, n. 228, e successive modificazioni, come rifinanziata anche ai sensi della presente legge, e' ridotta di 160 milioni di euro per l'anno 2016 e di 49 milioni di euro per l'anno 2017. Sulla base dei dati di consuntivo e del monitoraggio, effettuato dall'INPS, il Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, entro il 30 settembre di ogni anno, trasmette alle Camere una relazione sull'attuazione della sperimentazione di cui all'articolo 1, comma 9, della legge 23 agosto 2004, n. 243, con particolare riferimento al numero delle lavoratrici interessate e agli oneri previdenziali conseguenti e, in relazione alla conclusione della medesima sperimentazione, come disciplinata ai sensi del primo periodo del presente comma, anche al raffronto degli specifici oneri previdenziali conseguenti all'attuazione del primo periodo del presente comma con le relative previsioni di spesa. Qualora dall'attivita' di monitoraggio di cui al precedente periodo risulti un onere previdenziale inferiore rispetto alle previsioni di spesa di cui al primo periodo del presente comma, anche avuto riguardo alla proiezione negli anni successivi, con successivo provvedimento legislativo verra' disposto l'impiego delle risorse non utilizzate per interventi con finalita' analoghe a quelle di cui al presente comma, ivi compresa la prosecuzione della medesima sperimentazione.

282. Al fine di sostenere la genitorialita', il beneficio di cui all'articolo 4, comma 24, lettera b), della legge 28 giugno 2012, n. 92, e' riconosciuto nel limite di 20 milioni di euro per l'anno 2016, ferme restando le relative disposizioni attuative. All'onere derivante dal primo periodo del presente comma si provvede, quanto a 10 milioni di euro, mediante corrispondente riduzione del Fondo sociale per occupazione e formazione di cui all'articolo 18, comma 1, lettera a), del decreto-legge 29 novembre 2008, n. 185, convertito, con modificazioni, dalla legge 28 gennaio 2009, n. 2.

283. Ai medesimi fini di cui al comma 282, il beneficio di cui all'articolo 4, comma 24, lettera b), della legge 28 giugno 2012, n. 92, e' riconosciuto, in via sperimentale, nel limite di spesa di 2 milioni di euro per l'anno 2016, anche alle madri lavoratrici autonome o imprenditrici. I criteri di accesso e le modalita' di utilizzo del beneficio sono stabiliti con decreto di natura non regolamentare del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, da adottare entro sessanta giorni dalla data di entrata in vigore della presente legge.

284. I lavoratori dipendenti del settore privato iscritti all'assicurazione generale obbligatoria e alle forme sostitutive ed esclusive della medesima con contratto di lavoro a tempo pieno e indeterminato che maturano entro il 31 dicembre 2018 il diritto al trattamento pensionistico di vecchiaia, di cui all'articolo 24, comma 6, del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, e successive modificazioni, possono, a condizione di avere maturato i requisiti minimi di contribuzione per il diritto al predetto trattamento pensionistico di vecchiaia, d'intesa con il datore di lavoro, per un periodo non superiore al periodo intercorrente tra la data di accesso al beneficio di cui al presente comma e la data di maturazione del requisito anagrafico previsto dal citato articolo 24, comma 6, del predetto decreto-legge n. 201 del 2011, ridurre l'orario del rapporto di lavoro in misura compresa tra il 40 per cento e il 60 per cento, ottenendo mensilmente dal datore di lavoro una somma corrispondente alla contribuzione previdenziale a fini pensionistici a carico del datore di lavoro relativa alla prestazione lavorativa non effettuata. Tale importo non concorre alla formazione del reddito da lavoro dipendente e non e' assoggettato a contribuzione previdenziale. Per i periodi di riduzione della prestazione lavorativa e' riconosciuta la contribuzione figurativa commisurata alla retribuzione corrispondente alla prestazione lavorativa non effettuata. Si applica l'articolo 41, comma 6, del decreto legislativo 14 settembre 2015, n. 148. Il beneficio di cui al presente comma e' riconosciuto nel limite massimo di 60 milioni di euro per l'anno 2016, 120 milioni di euro per l'anno 2017 e 60 milioni di euro per l'anno 2018. La facolta' di cui al presente comma e' concessa, a domanda e nei limiti delle risorse di cui al precedente periodo, previa autorizzazione della Direzione territoriale del lavoro. Il datore di lavoro con riferimento al lavoratore che intende, di intesa con lo stesso datore di lavoro, accedere alla facolta' di ricorso al lavoro a tempo parziale di cui al presente comma deve dare comunicazione all'INPS e alla Direzione territoriale del lavoro della stipulazione del contratto e della relativa cessazione secondo le modalita' stabilite dal decreto di cui al successivo periodo. Il beneficio di cui al presente comma e' riconosciuto dall'INPS, qualora ne ricorrano i necessari presupposti e requisiti, nei limiti delle risorse di cui al quinto periodo del presente comma e secondo le modalita' stabilite con decreto del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, da emanare entro novanta giorni dalla data di entrata in vigore della presente legge. L'INPS provvede al monitoraggio delle domande di accesso al beneficio di cui al presente comma comunicate dalle imprese. Qualora dal predetto monitoraggio risulti il raggiungimento del limite delle risorse anche in via prospettica, l'INPS non prendera' in esame ulteriori domande finalizzate all'accesso al beneficio in esame. Ai maggiori oneri derivanti dal presente comma, pari a 60 milioni di euro per l'anno 2016, a 120 milioni di euro per l'anno 2017 e a 60 milioni di euro per l'anno 2018, si provvede mediante il versamento in entrata al bilancio dello Stato da parte dell'INPS, in deroga a quanto previsto dall'articolo 5 del decreto legislativo 14 settembre 2015, n. 150, di una quota pari a 60 milioni di euro per l'anno 2016, a 120 milioni di euro per l'anno 2017 e a 60 milioni di euro per l'anno 2018 delle entrate derivanti dall'aumento contributivo di cui all'articolo 25 della legge 21 dicembre 1978, n. 845, con esclusione delle somme destinate al finanziamento dei fondi paritetici interprofessionali nazionali per la formazione continua di cui all'articolo 118 della legge 23 dicembre 2000, n. 388, e successive modificazioni. Le somme versate in entrata al bilancio dello Stato ai sensi del periodo precedente sono trasferite all'INPS a copertura dei maggiori oneri derivanti ai sensi del presente comma. In deroga a quanto disposto dall'articolo 5, comma 2, del decreto legislativo 14 settembre 2015, n. 150, la quota residua delle entrate derivanti dall'aumento contributivo di cui all'articolo 25 della legge 21 dicembre 1978, n. 845, relative ai datori di lavoro non aderenti ai fondi paritetici interprofessionali nazionali per la formazione continua, dedotte quelle utilizzate per la copertura degli oneri della presente disposizione, e' versata prioritariamente al Fondo di rotazione di cui all'articolo 9, comma 5, del decreto-legge 20 maggio 1993, n. 148, convertito, con modificazioni, dalla legge 19 luglio 1993, n. 236, fino alla concorrenza di un importo pari al 50 per cento della somma complessiva. (14)

285. All'articolo 41 del decreto legislativo 14 settembre 2015, n. 148, dopo il comma 2 e' inserito il seguente: «2-bis. Nei confronti dei lavoratori interessati da riduzione stabile dell'orario di lavoro con riduzione della retribuzione ai sensi dei commi 1 e 2, con esclusione dei soggetti di cui al comma 5, i datori di lavoro, gli enti bilaterali o i Fondi di solidarieta' di cui al titolo II del presente decreto possono versare la contribuzione ai fini pensionistici correlata alla quota di retribuzione persa, nei casi in cui tale contribuzione non venga gia' riconosciuta dall'INPS. In relazione ai predetti versamenti non sono riconosciute le agevolazioni contributive di cui ai commi 1 e 2».

286. Al fine di concorrere alla copertura dei maggiori oneri derivanti dal comma 281 nonche' delle minori entrate derivanti dalle misure di riduzione della pressione fiscale in favore dei pensionati di cui al comma 290, nel rispetto del principio dell'equilibrio di bilancio e degli obiettivi di finanza pubblica, assicurando la tutela dei livelli essenziali delle prestazioni concernenti i diritti civili e sociali, anche in funzione della salvaguardia della solidarieta' intergenerazionale, all'articolo 1, comma 483, della legge 27 dicembre 2013, n. 147, sono apportate le seguenti modificazioni:

- a) all'alinea, le parole: «Per il triennio 2014-2016» sono sostituite dalle seguenti: «Per il periodo 2014-2018»;
- b) alla lettera e), le parole: «per ciascuno degli anni 2015 e 2016» sono sostituite dalle seguenti: «per ciascuno degli anni 2015, 2016, 2017 e 2018».

287. Con riferimento alle prestazioni previdenziali e assistenziali e ai parametri ad esse connessi, la percentuale di adeguamento corrispondente alla variazione che si determina rapportando il valore medio dell'indice ISTAT dei prezzi al consumo per famiglie di operai ed impiegati, relativo all'anno precedente il mese di decorrenza dell'adeguamento, all'analogo valore medio relativo all'anno precedente non puo' risultare inferiore a zero.

288. Con riferimento alla percentuale di variazione per il calcolo della rivalutazione delle pensioni per l'anno 2014 determinata in via definitiva con decorrenza dal 1º gennaio 2015, le operazioni di conguaglio di cui all'articolo 24, comma 5, della legge 28 febbraio 1986, n. 41, limitatamente ai ratei corrisposti nell'anno 2015 non sono operate in sede di rivalutazione delle pensioni per l'anno 2015; esse sono effettuate in sede di rivalutazione delle pensioni per l'anno 2017, ferme restando le operazioni di conguaglio con riferimento alla rata corrente in sede di rivalutazione delle pensioni per l'anno 2015.

289. Al fine di concorrere alla copertura delle minori entrate derivanti dalle misure di riduzione della pressione fiscale in favore dei pensionati di cui al comma 290:

- a) l'autorizzazione di spesa di cui all'articolo 1, comma 235, primo periodo, della legge 24 dicembre 2012, n. 228, e successive modificazioni, come rifinanziata dalla presente legge, e' ridotta di 58 milioni di euro per l'anno 2018;
- b) il fondo di cui all'articolo 1, comma 3, lettera f), della legge 24 dicembre 2007, n. 247, e' ridotto di 140 milioni di euro per l'anno 2017, 110 milioni di euro per l'anno 2018, 76 milioni di euro per l'anno 2019 e 30 milioni di euro per l'anno 2020 con conseguente corrispondente riduzione degli importi di cui all'articolo 7, comma 1, del decreto legislativo 21 aprile 2011, n. 67, e successive modificazioni.

290. All'articolo 13 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, sono apportate le seguenti modificazioni:

- a) al comma 3: 1) alla lettera a), le parole: «1.725 euro» e «7.500 euro» sono sostituite, rispettivamente, dalle seguenti: «1.783 euro» e «7.750 euro»; 2) la lettera b) e' sostituita dalla seguente: «b) 1.255 euro, aumentata del prodotto fra 528 euro e l'importo corrispondente al rapporto fra 15.000 euro, diminuito del reddito complessivo, e 7.250 euro, se l'ammontare del reddito complessivo e' superiore a 7.750 euro ma non a 15.000 euro»;
- b) al comma 4: 1) alla lettera a), le parole: «1.783 euro» e «7.750 euro» sono sostituite, rispettivamente, dalle seguenti: «1.880 euro» e «8.000 euro»; 2) la lettera b) e' sostituita dalla seguente: «b) 1.297 euro, aumentata del prodotto fra 583 euro e l'importo corrispondente al rapporto fra 15.000 euro, diminuito del reddito complessivo, e 7.000 euro, se l'ammontare del reddito complessivo e' superiore a 8.000 euro ma non a 15.000 euro».

291. Il Fondo sociale per occupazione e formazione, di cui all'articolo 18, comma 1, lettera a), del decreto-legge 29 novembre 2008, n. 185, convertito, con modificazioni, dalla legge 28 gennaio 2009, n. 2, come rifinanziato dal comma 304 del presente articolo, e' ridotto di 300 milioni di euro per l'anno 2016 e incrementato di 89 milioni di euro per l'anno 2017.

292. Le prestazioni assistenziali di cui all'articolo 1, comma 116, della legge 23 dicembre 2014, n. 190, a favore dei malati di mesotelioma che abbiano contratto la patologia o per esposizione familiare a lavoratori impiegati nella lavorazione dell'amianto ovvero per esposizione ambientale comprovata e che siano deceduti nel corso dell'anno 2015 e dell'anno 2016 possono essere erogate agli eredi, nella misura fissata dal decreto del Ministro del lavoro e delle politiche sociali 4 settembre 2015 ripartita tra gli stessi, su domanda, corredata di idonea documentazione, presentata dai medesimi entro il 31 marzo 2017. Le prestazioni di cui al presente comma sono erogate a valere sulle disponibilita' presenti nel Fondo per le vittime dell'amianto, di cui all'articolo 1, comma 241, della legge 24 dicembre 2007, n. 244, istituito presso l'INAIL, nei limiti delle somme individuate dal citato decreto del Ministro del lavoro e delle politiche sociali 4 settembre 2015 e destinate alla copertura delle spese per le prestazioni in favore degli aventi diritto per l'anno 2015 e per l'anno 2016.

293. Il Fondo per la compensazione degli effetti finanziari non previsti a legislazione vigente conseguenti all'attualizzazione di contributi pluriennali, di cui all'articolo 6, comma 2, del decreto-legge 7 ottobre 2008, n. 154, convertito, con modificazioni, dalla legge 4 dicembre 2008, n. 189, e successive modificazioni, e' ridotto di 100 milioni di euro per l'anno 2016 e incrementato di 36 milioni di euro per l'anno 2017.

294. Per l'anno 2016 l'INPS versa all'entrata del bilancio dello Stato, in deroga a quanto previsto dall'articolo 5 del decreto legislativo 14 settembre 2015, n. 150, una quota, pari a 52 milioni di euro, delle entrate derivanti dall'aumento contributivo di cui all'articolo 25 della legge 21 dicembre 1978, n. 845, con esclusione delle somme destinate al finanziamento dei fondi paritetici interprofessionali per la formazione professionale, di cui all'articolo 118 della legge 23 dicembre 2000, n. 388. Per le finalita' di cui all'articolo 5 del decreto legislativo 14 settembre 2015, n. 150, il Fondo sociale per occupazione e formazione, di cui all'articolo 18 del decreto-legge 29 novembre 2008, n. 185, convertito, con modificazioni, dalla legge 28 gennaio 2009, n. 2, e' incrementato di 52 milioni di euro per l'anno 2017.

295. In deroga a quanto previsto dalla lettera g) del comma 1 dell'articolo 11 del regolamento di cui al decreto del Presidente della Repubblica 28 ottobre 2013, n. 157, le disposizioni vigenti alla data del 31 dicembre 2013 in materia di requisiti di accesso e di regime delle decorrenze dei trattamenti pensionistici continuano ad applicarsi ai lavoratori poligrafici collocati in cassa integrazione guadagni straordinaria finalizzata al prepensionamento ai sensi dell'articolo 37, comma 1, lettera a), della legge 5 agosto 1981, n. 416, in forza di accordi di procedura sottoscritti entro il 31 dicembre 2013, ancorche' maturino i requisiti per l'accesso al pensionamento successivamente alla predetta data, nei limiti e alle condizioni di cui al comma 297 del presente articolo.

296. Per le finalita' di cui al comma 295 e' autorizzata la spesa annua di 3 milioni di euro per ciascuno degli anni 2016, 2017 e 2018.

297. I trattamenti di vecchiaia anticipati di cui al comma 295 sono erogati, nell'ambito del limite di spesa di cui al comma 296, secondo l'ordine di sottoscrizione del relativo accordo di procedura presso l'ente competente. L'INPS provvede al monitoraggio, sulla base dell'ordine cronologico di cui al primo periodo del presente comma, delle domande di pensionamento presentate dai lavoratori di cui al comma 295 che intendono avvalersi dei requisiti di accesso e del regime delle decorrenze vigenti alla data indicata al medesimo comma 295. Qualora dal predetto monitoraggio risulti il raggiungimento, anche in termini prospettici, del limite di spesa di cui al comma 296, l'ente previdenziale non prende in esame ulteriori domande di pensionamento finalizzate ad usufruire dei benefici previsti dalla disposizione di cui al comma 295.

298. Il comma 2 dell'articolo 14 del decreto legislativo 30 dicembre 1992, n. 503, e' abrogato. La conseguente cumulabilita' opera anche con riferimento a periodi antecedenti alla data di entrata in vigore della presente legge.

299. Dopo il comma 113 dell'articolo 1 della legge 23 dicembre 2014, n. 190, e' inserito il seguente: «113-bis. Le disposizioni di cui al secondo periodo del comma 2-quater dell'articolo 6 del decreto-legge 29 dicembre 2011, n. 216, convertito, con modificazioni, dalla legge 24 febbraio 2012, n. 14, come sostituito dal comma 113 del presente articolo, si applicano anche ai trattamenti pensionistici decorrenti negli anni 2012, 2013 e 2014. La disposizione del presente comma si applica esclusivamente con riferimento ai ratei di pensione corrisposti a decorrere dal 1º gennaio 2016».

300. Ai fini del concorso alla copertura degli oneri derivanti dai commi 298 e 299, il fondo di cui all'articolo 1, comma 3, lettera f), della legge 24 dicembre 2007, n. 247, e' ridotto di 15,1 milioni di euro per l'anno 2016, 15,4 milioni di euro per l'anno 2017, 15,8 milioni di euro per l'anno 2018, 16,2 milioni di euro per l'anno 2019, 16,5 milioni di euro per l'anno 2020, 16,9 milioni di euro per l'anno 2021, 17,2 milioni di euro per l'anno 2022, 17,7 milioni di euro per l'anno 2023, 18 milioni di euro per l'anno 2024 e 18,4 milioni di euro a decorrere dall'anno 2025, con conseguente corrispondente riduzione degli importi di cui all'articolo 7, comma 1, del decreto legislativo 21 aprile 2011, n. 67, e successive modificazioni.

301. L'INPS e l'INAIL, al fine di prevenire patologie che possano dar luogo a invalidita' o per evitare l'aggravamento di invalidita' dovute alle stesse patologie, da individuare nell'accordo di cui all'articolo 4, comma 4, della legge 24 ottobre 2000, n. 323, e sulla base di specifici protocolli da loro stessi definiti, riconoscono ai propri assistiti che fruiscono di cicli di cure termali per le predette finalita' le prestazioni economiche accessorie di cui all'articolo 5, comma 1, ultimo periodo, della legge 24 ottobre 2000, n. 323.

302. Nelle more dell'individuazione dei protocolli di cui al comma 301 del presente articolo, all'articolo 1, comma 301, della legge 23 dicembre 2014, n. 190, le parole: «1º gennaio 2016» sono sostituite dalle seguenti: «1º gennaio 2019».

303. Con effetto dall'anno 2016, a decorrere dal 1º luglio di ciascun anno, gli importi degli indennizzi del danno biologico erogati dall'INAIL ai sensi dell'articolo 13 del decreto legislativo 23 febbraio 2000, n. 38, e successive modificazioni, sono rivalutati, con decreto del Ministro del lavoro e delle politiche sociali, su proposta del Presidente dell'INAIL, sulla base della variazione dell'indice dei prezzi al consumo per le famiglie di operai e impiegati accertata dall'Istituto nazionale di statistica rispetto all'anno precedente. Gli incrementi annuali di cui al primo periodo del presente comma si aggiungono a quello complessivo del 16,25 per cento di cui all'articolo 1, commi 23 e 24, della legge 24 dicembre 2007, n. 247, nonche' all'articolo 1, comma 129, della legge 27 dicembre 2013, n. 147, e relativi decreti attuativi, e si applicano agli indennizzi dovuti dall'INAIL ai sensi della «Tabella indennizzo danno biologico» di cui al decreto del Ministro del lavoro e della previdenza sociale 12 luglio 2000, pubblicato nel supplemento ordinario alla Gazzetta Ufficiale n. 172 del 25 luglio 2000. Per il triennio 2016-2018, ai fini della compensazione degli effetti finanziari derivanti dalle disposizioni di cui al primo e al secondo periodo del presente comma, il Fondo per la compensazione degli effetti finanziari non previsti a legislazione vigente conseguenti all'attualizzazione di contributi pluriennali, di cui all'articolo 6, comma 2, del decreto-legge 7 ottobre 2008, n. 154, convertito, con modificazioni, dalla legge 4 dicembre 2008, n. 189, e successive modificazioni, e' ridotto di 1 milione di euro per l'anno 2016, di 5 milioni di euro per l'anno 2017 e di 15 milioni di euro per l'anno 2018. A decorrere dall'anno 2019, alla copertura finanziaria degli oneri derivanti dalle disposizioni di cui al primo e al secondo periodo del presente comma si provvede nell'ambito della revisione delle tariffe dei premi per l'assicurazione contro gli infortuni e le malattie professionali, di cui all'articolo 1, comma 128, della legge 27 dicembre 2013, n. 147. A decorrere dall'anno 2019 l'efficacia delle disposizioni di cui al primo e al secondo periodo del presente comma, anche con riferimento alle rivalutazioni relative agli anni 2016-2018, e' subordinata all'attuazione della predetta revisione delle tariffe dei premi per l'assicurazione contro gli infortuni e le malattie professionali.

304. Al fine di favorire la transizione verso il riformato sistema degli ammortizzatori sociali in costanza di rapporto di lavoro, ai sensi del decreto legislativo 14 settembre 2015, n. 148, l'autorizzazione di spesa di cui all'articolo 1, comma 7, del decreto-legge 20 maggio 1993, n. 148, convertito, con modificazioni, dalla legge 19 luglio 1993, n. 236, confluita nel Fondo sociale per occupazione e formazione, di cui all'articolo 18, comma 1, lettera a), del decreto-legge 29 novembre 2008, n. 185, convertito, con modificazioni, dalla legge 28 gennaio 2009, n. 2, e' incrementata, per l'anno 2016, di 250 milioni di euro per essere destinata al rifinanziamento degli ammortizzatori sociali in deroga di cui all'articolo 2, commi 64, 65 e 66, della legge 28 giugno 2012, n. 92. All'onere derivante dal primo periodo del presente comma, pari a 250 milioni di euro per l'anno 2016, si provvede: quanto a 100 milioni di euro mediante corrispondente riduzione del fondo di cui all'articolo 1, comma 107, della legge 23 dicembre 2014, n. 190, e quanto a 150 milioni di euro mediante corrispondente riduzione del Fondo di cui all'articolo 1, comma 3, lettera f), della legge 24 dicembre 2007, n. 247, con conseguente corrispondente riduzione degli importi di cui all'articolo 7, comma 1, del decreto legislativo 21 aprile 2011, n. 67, e successive modificazioni. Fermo restando quanto disposto dal decreto del Ministro del lavoro e delle politiche sociali 1º agosto 2014, n. 83473, il trattamento di integrazione salariale in deroga alla normativa vigente puo' essere concesso o prorogato, a decorrere dal 1º gennaio 2016 e fino al 31 dicembre 2016, per un periodo non superiore a tre mesi nell'arco di un anno. A decorrere dal 1º gennaio 2016 e sino al 31 dicembre 2016, a parziale rettifica di quanto stabilito dall'articolo 3, comma 5, del decreto del Ministro del lavoro e delle politiche sociali n. 83473 del 2014, il trattamento di mobilita' in deroga alla vigente normativa non puo' essere concesso ai lavoratori che alla data di decorrenza del trattamento hanno gia' beneficiato di prestazioni di mobilita' in deroga per almeno tre anni, anche non continuativi. Per i restanti lavoratori il trattamento puo' essere concesso per non piu' di quattro mesi, non ulteriormente prorogabili, piu' ulteriori due mesi nel caso di lavoratori residenti nelle aree individuate dal testo unico di cui al decreto del Presidente della Repubblica 6 marzo 1978, n. 218. Per tali lavoratori il periodo complessivo non puo' comunque eccedere il limite massimo di tre anni e quattro mesi. Le regioni e le province autonome di Trento e di Bolzano possono disporre la concessione dei trattamenti di integrazione salariale e di mobilita', anche in deroga ai criteri di cui agli articoli 2 e 3 del citato decreto del Ministro del lavoro e delle politiche sociali n. 83473 del 2014, in misura non superiore al 5 per cento delle risorse ad esse attribuite, ovvero in eccedenza a tale quota disponendo l'integrale copertura degli oneri connessi a carico delle finanze regionali ovvero delle risorse assegnate alla regione nell'ambito dei piani o programmi coerenti con la specifica destinazione, ai sensi dell'articolo 1, comma 253, della legge 24 dicembre 2012, n. 228, e successive modificazioni. Gli effetti dei suddetti trattamenti non possono prodursi oltre la data del 31 dicembre 2016.

305. In attuazione dell'articolo 46, comma 3, del decreto legislativo 14 settembre 2015, n. 148, le disposizioni di cui all'articolo 5, commi 5 e 8, del decreto-legge 20 maggio 1993, n. 148, convertito, con modificazioni, dalla legge 19 luglio 1993, n. 236, e successive modificazioni, trovano applicazione per l'intera durata stabilita nei contratti collettivi aziendali qualora detti contratti siano stati stipulati in data antecedente al 15 ottobre 2015, e, negli altri casi, esclusivamente sino al 31 dicembre 2016, nel limite massimo di 60 milioni di euro per l'anno 2016. All'onere derivante dal primo periodo del presente comma, pari a euro 60 milioni per l'anno 2016, si provvede a carico del Fondo sociale per occupazione e formazione, di cui all'articolo 18, comma 1, lettera a), del decreto-legge 29 novembre 2008, n. 185, convertito, con modificazioni, dalla legge 28 gennaio 2009, n. 2.

306. Il comma 1 dell'articolo 26 del decreto legislativo 14 settembre 2015, n. 150, e' sostituito dal seguente: «1. Allo scopo di permettere il mantenimento e lo sviluppo delle competenze acquisite, i lavoratori che fruiscono di strumenti di sostegno del reddito in costanza di rapporto di lavoro nonche' i lavoratori sottoposti a procedure di mobilita' possono essere chiamati a svolgere attivita' a fini di pubblica utilita' a beneficio della comunita' territoriale di appartenenza, sotto la direzione e il coordinamento di amministrazioni pubbliche di cui all'articolo 1, comma 2, del decreto legislativo n. 165 del 2001, e successive modificazioni, nel territorio del comune ove siano residenti».

307. Per l'anno 2016, nell'ambito delle risorse del Fondo sociale per occupazione e formazione di cui all'articolo 18, comma 1, lettera a), del decreto-legge 29 novembre 2008, n. 185, convertito, con modificazioni, dalla legge 28 gennaio 2009, n. 2, destinate al finanziamento degli ammortizzatori sociali in deroga di cui all'articolo 2, commi 64, 65 e 66, della legge 28 giugno 2012, n. 92, e successive modificazioni, e' destinata una somma fino a 18 milioni di euro finalizzata al riconoscimento della cassa integrazione guadagni in deroga per il settore della pesca.

308. All'articolo 1, comma 2, secondo periodo, del decreto legislativo 14 settembre 2015, n. 148, le parole: «nel settore industriale» sono soppresse.

309. All'articolo 46, comma 1, lettera b), del decreto legislativo 14 settembre 2015, n. 148, dopo le parole: «12 agosto 1947, n. 869» sono inserite le seguenti: «, ad eccezione dell'articolo 3».

310. L'indennita' di disoccupazione per i lavoratori con rapporto di collaborazione coordinata e continuativa (DIS-COLL), di cui all'articolo 15 del decreto legislativo 4 marzo 2015, n. 22, e' riconosciuta, nei limiti di cui al quinto periodo del presente comma, anche per l'anno 2016, in relazione agli eventi di disoccupazione verificatisi a decorrere dal 1º gennaio 2016 e sino al 31 dicembre 2016. Ai fini del calcolo della durata non sono computati i periodi contributivi che hanno gia' dato luogo ad erogazione della DIS-COLL. Per gli episodi di disoccupazione verificatisi a decorrere dal 1º gennaio 2016 e sino al 31 dicembre 2016, non si applica la disposizione di cui all'articolo 15, comma 2, lettera c), del citato decreto legislativo n. 22 del 2015. Ai fini dell'applicazione dell'articolo 15 del citato decreto legislativo n. 22 del 2015, le disposizioni che hanno a riferimento l'anno solare sono da interpretarsi come riferite all'anno civile. La DIS-COLL e' riconosciuta, in relazione agli eventi di disoccupazione verificatisi a decorrere dal 1º gennaio 2016 e sino al 31 dicembre 2016, nel limite di 54 milioni di euro per l'anno 2016 e di 24 milioni di euro per l'anno 2017, salvo quanto stabilito dall'ultimo periodo del presente comma. L'INPS riconosce il beneficio in base all'ordine cronologico di presentazione delle domande; nel caso di insufficienza delle risorse, valutata anche su base pluriennale con riferimento alla durata della prestazione, l'INPS non prende in considerazione ulteriori domande, fornendo immediata comunicazione anche attraverso il proprio sito internet. Le risorse stanziate dall'articolo 19, comma 1, del decreto-legge 29 novembre 2008, n. 185, convertito, con modificazioni, dalla legge 28 gennaio 2009, n. 2, sono destinate al finanziamento degli interventi previsti dal presente comma nella misura di 54 milioni di euro per l'anno 2016 e di 24 milioni di euro per l'anno 2017. Il limite di cui al quinto periodo del presente comma puo' essere incrementato in misura pari alle risorse residue destinate nell'anno 2016 al finanziamento della DIS-COLL riconosciuta per eventi di disoccupazione verificatisi a decorrere dal 1º gennaio 2015 e sino al 31 dicembre 2015 e non utilizzate, come accertate con il procedimento di cui all'articolo 14 della legge 7 agosto 1990, n. 241, e successive modificazioni, da concludersi entro il 31 maggio 2016, computando le prestazioni in corso al 30 aprile 2016, ai fini del predetto procedimento accertativo, per la loro intera durata teorica, calcolata ai sensi dell'articolo 15, comma 6, del citato decreto legislativo n. 22 del 2015. (15)

311. E' prorogata, per l'anno 2016, l'applicazione della disposizione di cui all'articolo 1, comma 315, della legge 23 dicembre 2014, n. 190, nel limite di 12 milioni di euro.

312. In via sperimentale, per gli anni 2016, 2017, 2018 e 2019, e' istituito presso il Ministero del lavoro e delle politiche sociali un Fondo finalizzato a reintegrare l'INAIL dell'onere conseguente alla copertura degli obblighi assicurativi contro le malattie e gli infortuni, tenuto conto di quanto disposto dall'articolo 4 della legge 11 agosto 1991, n. 266, in favore dei soggetti beneficiari di ammortizzatori e di altre forme di integrazione e sostegno del reddito previste dalla normativa vigente, coinvolti in attivita' di volontariato a fini di utilita' sociale in favore di comuni o enti locali, nonche' in favore dei detenuti e degli internati impegnati in attivita' volontarie e gratuite ai sensi dell'articolo 21, comma 4-ter, della legge 26 luglio 1975, n. 354, dei soggetti impegnati in lavori di pubblica utilita' ai sensi dell'articolo 186, comma 9-bis, e dell'articolo 187, comma 8-bis, del codice della strada, di cui al decreto legislativo 30 aprile 1992, n. 285, dell'articolo 73, comma 5-bis, del testo unico di cui al decreto del Presidente della Repubblica 9 ottobre 1990, n. 309, e dell'articolo 168-bis del codice penale nonche' in favore dei soggetti impegnati in lavori di pubblica utilita' ai sensi dell'articolo 56-bis della legge 24 novembre 1981, n. 689, e degli stranieri richiedenti asilo in possesso del relativo permesso di soggiorno, trascorso il termine di cui all'articolo 22, comma 1, del decreto legislativo 18 agosto 2015, n. 142. (14) (31) (36)

313. Una quota del Fondo di cui al comma 312 non superiore a 100.000 euro annui e' destinata a reintegrare gli oneri assicurativi di cui all'articolo 4 della legge 11 agosto 1991, n. 266, relativi alle organizzazioni di volontariato, gia' costituite alla data di entrata in vigore della presente legge, che esercitano attivita' di utilita' sociale nei territori montani.

314. Alla dotazione del Fondo di cui al comma 312, cui e' assegnato l'importo di 5 milioni di euro per ciascuno degli anni 2016 e 2017, si provvede mediante corrispondente riduzione del Fondo sociale per occupazione e formazione, di cui all'articolo 18, comma 1, lettera a), del decreto-legge 29 novembre 2008, n. 185, convertito, con modificazioni, dalla legge 28 gennaio 2009, n. 2. Con decreto del Ministro dell'economia e delle finanze, su proposta del Ministro del lavoro e delle politiche sociali, sono apportate le necessarie variazioni di bilancio.

315. Al fine di promuovere la prestazione di attivita' di volontariato da parte dei soggetti di cui al comma 312, i comuni e gli altri enti locali interessati promuovono le opportune iniziative informative e pubblicitarie finalizzate a rendere noti i progetti di utilita' sociale, da realizzare anche in collaborazione con le organizzazioni del terzo settore. La condizione di soggetto beneficiario di ammortizzatori e di altre forme di integrazione e sostegno del reddito, di cui al comma 312, e' verificata dall'INPS, su richiesta dei comuni o degli altri enti locali, ovvero direttamente dagli enti locali erogatori.

316. Con decreto del Ministro del lavoro e delle politiche sociali sono stabiliti modalita' e criteri per la valorizzazione, ai fini della certificazione dei crediti formativi, dell'attivita' prestata ai sensi del comma 312. Agli oneri derivanti dalla certificazione delle competenze si provvede mediante le risorse del Fondo di cui al comma 312, secondo limiti e modalita' stabilite con il decreto di cui al presente comma.

317. All'articolo 7 del decreto-legge 23 dicembre 2013, n. 146, convertito, con modificazioni, dalla legge 21 febbraio 2014, n. 10, sono apportate le seguenti modificazioni:

- a) al comma 3, l'ultimo periodo e' sostituito dal seguente: «Ai componenti del Garante nazionale e' attribuita un'indennita' forfetaria annua, determinata in misura pari al 40 per cento dell'indennita' parlamentare annua per il Presidente e pari al 30 per cento per i membri del collegio, fermo restando il diritto al rimborso delle spese effettivamente sostenute di vitto, alloggio e trasporto per gli spostamenti effettuati nello svolgimento delle attivita' istituzionali»;
- b) dopo il comma 5 e' aggiunto il seguente: «5-bis. Per il funzionamento del Garante nazionale e' autorizzata la spesa di euro 200.000 annui a decorrere dall'anno 2016».

318. Al comma 1 dell'articolo 1 del decreto-legge 31 maggio 2014, n. 83, convertito, con modificazioni, dalla legge 29 luglio 2014, n. 106, e successive modificazioni, sono apportate le seguenti modificazioni:

- a) al primo periodo, la parola: «tre» e' soppressa;
- b) le parole: «nella misura del:» sono sostituite dalle seguenti: «nella misura del 65 per cento delle erogazioni effettuate» e le lettere a) e b) sono abrogate.

319. Per l'attuazione del comma 318, e' autorizzata la spesa di 1,8 milioni di euro per l'anno 2017, 3,9 milioni di euro per l'anno 2018, 11,7 milioni di euro per l'anno 2019 e 17,8 milioni di euro a decorrere dall'anno 2020.

320. Dopo il comma 2 dell'articolo 10 del decreto-legge 31 maggio 2014, n. 83, convertito, con modificazioni, dalla legge 29 luglio 2014, n. 106, sono inseriti i seguenti: «2-bis. Il credito d'imposta di cui al comma 1 e' riconosciuto anche nel caso in cui la ristrutturazione edilizia di cui al comma 2 comporti un aumento della cubatura complessiva, nei limiti e secondo le modalita' previste dall'articolo 11 del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, e successive modificazioni. Entro tre mesi dalla data di entrata in vigore della presente disposizione sono stabilite le disposizioni applicative del presente comma, con riferimento, in particolare, a: a) le tipologie di strutture alberghiere ammesse al credito d'imposta; b) le tipologie di interventi ammessi al beneficio, nell'ambito di quelli di cui al comma 2; c) le procedure per l'ammissione al beneficio, che avviene secondo l'ordine cronologico di presentazione delle relative domande, nel rispetto dei limiti di cui ai commi 1 e 7; d) le soglie massime di spesa ammissibile per singola voce di spesa sostenuta; e) le procedure di recupero nei casi di utilizzo illegittimo dei crediti d'imposta, secondo quanto stabilito dall'articolo 1, comma 6, del decreto-legge 25 marzo 2010, n. 40, convertito, con modificazioni, dalla legge 22 maggio 2010, n. 73. 2-ter. Per le medesime finalita' di cui al comma 1, nonche' per promuovere l'adozione e la diffusione della "progettazione universale" e l'incremento dell'efficienza energetica, il Ministro dei beni e delle attivita' culturali e del turismo, con proprio decreto da emanare entro tre mesi dalla data di entrata in vigore della presente disposizione, previa intesa in sede di Conferenza unificata, aggiorna gli standard minimi, uniformi in tutto il territorio nazionale, dei servizi e delle dotazioni per la classificazione delle strutture ricettive e delle imprese turistiche, ivi compresi i condhotel e gli alberghi diffusi, tenendo conto delle specifiche esigenze connesse alle capacita' ricettiva e di fruizione dei contesti territoriali e dei sistemi di classificazione alberghiera adottati a livello europeo e internazionale».

321. Per consentire al Ministero dei beni e delle attivita' culturali e del turismo di far fronte con interventi urgenti al verificarsi di emergenze che possano pregiudicare la salvaguardia dei beni culturali e paesaggistici e di procedere alla realizzazione di progetti di gestione di modelli museali, archivistici e librari, nonche' di progetti di tutela paesaggistica e archeologico-monumentale e di progetti per la manutenzione, il restauro e la valorizzazione di beni culturali e paesaggistici, l'autorizzazione di spesa di cui all'articolo 1, comma 1142, della legge 27 dicembre 2006, n. 296, e' incrementata di 5 milioni di euro a decorrere dall'anno 2017.

322. Al fine di assicurare risparmi della spesa pubblica e di razionalizzare le societa' strumentali del Ministero dei beni e delle attivita' culturali e del turismo, e' disposta la fusione per incorporazione della «Societa' per lo sviluppo dell'arte, della cultura e dello spettacolo - ARCUS Spa», di seguito denominata «ARCUS», nella societa' «ALES - Arte Lavoro e Servizi S.p.A.», di seguito denominata «ALES». La struttura organizzativa della societa' ALES e' conseguentemente articolata in due o piu' divisioni, una delle quali prosegue le funzioni della societa' ARCUS di cui all'articolo 10 della legge 8 ottobre 1997, n. 352, e successive modificazioni.

323. Con decreto del Ministro dei beni e delle attivita' culturali e del turismo, da emanare entro sessanta giorni dalla data di entrata in vigore della presente legge, e' adottato il nuovo statuto della societa' ALES. Lo statuto prevede tra l'altro l'istituzione di un consiglio di amministrazione, con conseguente nomina dei nuovi organi della societa'. Entro novanta giorni dall'insediamento, sulla base di requisiti oggettivi e in considerazione dei nuovi compiti della societa' ALES, il consiglio di amministrazione adotta un piano di riorganizzazione aziendale e del personale, definendo, compatibilmente con le disponibilita' di bilancio, la struttura organizzativa come risultante dalla fusione ai sensi del comma 322. Al fine di assicurare lo svolgimento dei servizi per il pubblico negli istituti e nei luoghi della cultura del Ministero dei beni e delle attivita' culturali e del turismo, alla societa' ALES non si applica l'articolo 9, comma 29, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, e successive modificazioni.

324. La fusione disposta dal comma 322, in deroga agli articoli 2501 e seguenti del codice civile, ha effetto a far data dal quindicesimo giorno successivo all'iscrizione del nuovo statuto della societa' ALES nel registro delle imprese. In tale data, la societa' ARCUS si estingue, con contestuale cessazione dei suoi organi amministrativi e di controllo dalla carica. La societa' ALES procede alla cancellazione di tale societa' dal registro delle imprese. Tutti gli atti connessi alle operazioni di fusione tra le societa' ALES e ARCUS sono esenti da ogni tributo e diritto, comunque denominato, e vengono effettuati in regime di neutralita' fiscale.

325. Il comma 1-ter dell'articolo 39 del decreto-legge 21 giugno 2013, n. 69, convertito, con modificazioni, dalla legge 9 agosto 2013, n. 98, e il decreto del Ministro per i beni e le attivita' culturali 24 settembre 2008, n. 182, sono abrogati.

326. Dall'attuazione delle disposizioni di cui ai commi da 322 a 325 non devono derivare nuovi o maggiori oneri a carico della finanza pubblica.

327. Nelle more dell'adozione dei decreti legislativi attuativi dell'articolo 8 della legge 7 agosto 2015, n. 124, al fine di dare efficace attuazione alle disposizioni di cui all'articolo 17-bis, comma 3, della legge 7 agosto 1990, n. 241, nonche' di garantire il buon andamento dell'amministrazione di tutela del patrimonio culturale, entro trenta giorni dalla data di entrata in vigore della presente legge, con decreto del Ministro dei beni e delle attivita' culturali e del turismo emanato ai sensi dell'articolo 17, comma 4-bis, lettera e), della legge 23 agosto 1988, n. 400, e dell'articolo 4, commi 4 e 4-bis, del decreto legislativo 30 luglio 1999, n. 300, si provvede, nel rispetto delle dotazioni organiche del Ministero dei beni e delle attivita' culturali e del turismo di cui alle tabelle A e B del regolamento di cui al decreto del Presidente del Consiglio dei ministri 29 agosto 2014, n. 171, senza nuovi o maggiori oneri per la finanza pubblica, alla riorganizzazione, anche mediante soppressione, fusione o accorpamento, degli uffici dirigenziali, anche di livello generale, del medesimo Ministero.

328. E' autorizzata l'assunzione a tempo indeterminato presso il Ministero dei beni e delle attivita' culturali e del turismo di 500 funzionari da inquadrare, nel rispetto della dotazione organica di cui alla tabella B allegata al regolamento di cui al decreto del Presidente del Consiglio dei ministri 29 agosto 2014, n. 171, nella III area del personale non dirigenziale, posizione economica F1, nei profili professionali di antropologo, archeologo, architetto, archivista, bibliotecario, demoetnoantropologo, promozione e comunicazione, restauratore e storico dell'arte.

329. Il personale di cui al comma 328 e' assunto, in deroga all'articolo 1, comma 425, della legge 23 dicembre 2014, n. 190, e successive modificazioni, all'articolo 4, comma 3, del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, e successive modificazioni, nonche' ai limiti di cui all'articolo 66 del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, e successive modificazioni, a seguito di procedure di selezione pubblica disciplinate con decreto del Ministro dei beni e delle attivita' culturali e del turismo, di concerto con il Ministro per la semplificazione e la pubblica amministrazione, da emanare entro novanta giorni dalla data di entrata in vigore della presente legge. L'emanazione dei relativi bandi resta comunque subordinata, ove necessario per escludere situazioni di eccedenza nell'ambito di ciascuno dei profili professionali di cui al comma 328 in relazione alle assunzioni da effettuare, alla rimodulazione della ripartizione per profili della dotazione organica dell'area III di cui al decreto del Ministro dei beni e delle attivita' culturali e del turismo 6 agosto 2015.

330. Per l'attuazione delle disposizioni di cui ai commi 328 e 329 e' autorizzata la spesa nel limite di 20 milioni di euro annui a decorrere dal 2017. Il Ministero dei beni e delle attivita' culturali e del turismo comunica alla Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica ed al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato le assunzioni effettuate ai sensi dei commi 328 e 329 e i relativi oneri.

331. All'articolo 1 della legge 24 dicembre 2007, n. 244, sono apportate le seguenti modificazioni:

- a) al comma 325: 1) al primo periodo, dopo le parole: «nella misura» e' inserita la seguente: «massima» e dopo la parola: «produzione» sono inserite le seguenti: «e distribuzione in Italia e all'estero»; 2) e' aggiunto, in fine, il seguente periodo: «Il decreto previsto al comma 333 provvede alla determinazione delle aliquote del beneficio in relazione anche alla cumulabilita' con le diverse misure dei benefici eventualmente spettanti, per la medesima opera, ai sensi del comma 327, lettere a) e b)»;
- b) al comma 326, dopo la parola: «apporti» sono inserite le seguenti: «alla produzione»;
- c) al comma 327, lettera a), le parole: «pari al 15 per cento» sono sostituite dalle seguenti: «non inferiore al 15 per cento e non superiore al 30 per cento, in relazione anche alla cumulabilita' e alla misura del beneficio spettante per la medesima opera ai sensi del comma 325,» e la cifra: «3.500.000» e' sostituita dalla seguente: «6.000.000»;
- d) al comma 327, lettera b): 1) all'alinea, la parola: «pari» e' sostituita dalle seguenti: «non superiore»; 2) al numero 1), dopo la parola: «nazionale» sono inserite le seguenti: «e internazionale», le parole da: «riconosciute» fino a: «articolo 7» sono sostituite dalle seguenti: «ammesse ai benefici ai sensi dell'articolo 9», la cifra: «1.500.000» e' sostituita dalla seguente: «2.000.000» e sono aggiunte, in fine, le seguenti parole: «; il decreto previsto al comma 333 prevede l'aliquota massima con riferimento alla distribuzione internazionale e, per quanto riguarda quella nazionale, in relazione ai piani distributivi che, per tipologia di opera ovvero per modalita' e tempi del piano distributivo, presentino maggiore difficolta' a raggiungere un pubblico vasto»; 3) il numero 2) e' abrogato;
- e) al comma 327, lettera c), numero 1), le parole: «al 30 per cento» sono sostituite dalle seguenti: «a non oltre il 40 per cento», le parole: «l'introduzione e acquisizione» sono sostituite dalle seguenti: «l'acquisizione e la sostituzione» e sono aggiunte, in fine, le seguenti parole: «, nonche' per la ristrutturazione e l'adeguamento strutturale e tecnologico delle sale cinematografiche e dei relativi impianti e servizi accessori, per la realizzazione di nuove sale o il ripristino di sale inattive secondo le specifiche e nei limiti di quanto indicato nel decreto previsto al comma 333, avuto particolare riguardo all'esistenza o meno della sala cinematografica in data anteriore al 1º gennaio 1980»;
- f) il comma 328 e' abrogato;
- g) al comma 332, secondo periodo, le parole da: «l'80 per cento» fino alla fine del periodo sono sostituite dalle seguenti: «la percentuale stabilita, in conformita' alla normativa europea, nel decreto previsto al comma 333»;
- h) al comma 335, la parola: «girati» e' sostituita dalla seguente: «realizzati».

332. Al decreto legislativo 22 gennaio 2004, n. 28, sono apportate le seguenti modificazioni:

- a) la lettera a) del comma 6 dell'articolo 2 e' abrogata;
- b) l'articolo 15 e' abrogato.

333. A decorrere dal 1º gennaio 2016, sono abrogati i commi 2-bis, 2-ter, 2-quater, 2-quinquies e 2-sexies dell'articolo 6 del decreto-legge 31 maggio 2014, n. 83, convertito, con modificazioni, dalla legge 29 luglio 2014, n. 106. Sono fatte comunque salve le procedure in corso di attuazione alla data di entrata in vigore della presente legge, avviate ai sensi del decreto del Ministro dei beni e delle attivita' culturali e del turismo 12 febbraio 2015, pubblicato nella Gazzetta Ufficiale n. 69 del 24 marzo 2015.

334. All'articolo 8 del decreto-legge 8 agosto 2013, n. 91, convertito, con modificazioni, dalla legge 7 ottobre 2013, n. 112, e successive modificazioni, sono apportate le seguenti modificazioni:

- a) al comma 3, le parole: «e di 115 milioni di euro annui a decorrere dall'anno 2015» sono sostituite dalle seguenti: «, di 115 milioni di euro per l'anno 2015 e di 140 milioni di euro annui a decorrere dall'anno 2016»;
- b) al comma 4, le parole da: «, rispettivamente» fino a: «comma 2» sono sostituite dalle seguenti: «a ciascuna delle tipologie di beneficio fiscale previste dai commi 1 e 2».

335. All'articolo 71-octies della legge 22 aprile 1941, n. 633, dopo il comma 3 e' aggiunto il seguente: «3-bis. Al fine di favorire la creativita' dei giovani autori, il 10 per cento di tutti i compensi incassati ai sensi dell'articolo 71-septies, calcolato prima delle ripartizioni effettuate dalla Societa' italiana degli autori ed editori (SIAE) ai sensi dei commi 1 e 3 del presente articolo, e' destinato dalla Societa', sulla base di apposito atto di indirizzo annuale del Ministro dei beni e delle attivita' culturali e del turismo, ad attivita' di promozione culturale nazionale e internazionale».

336. Per l'attuazione delle disposizioni di cui al comma 334 e' autorizzata la spesa di 25 milioni di euro a decorrere dall'anno 2016.

337. Per la realizzazione del Piano strategico «Grandi Progetti Beni culturali» di cui all'articolo 7 del decreto-legge 31 maggio 2014, n. 83, convertito, con modificazioni, dalla legge 29 luglio 2014, n. 106, e' autorizzata la spesa di 70 milioni di euro per l'anno 2017 e di 65 milioni di euro a decorrere dall'anno 2018. (54) (78)

338. Al fine di potenziare gli investimenti infrastrutturali nel settore della cultura, una quota delle risorse destinate agli interventi infrastrutturali, pari a 30 milioni di euro per ciascuno degli anni dal 2016 al 2019, a 5 milioni di euro per l'anno 2022, a 1 milione di euro per l'anno 2023 e a 6 milioni di euro per ciascuno degli anni dal 2024 al 2036, e' destinata agli interventi di conservazione, manutenzione, restauro e valorizzazione dei beni culturali. Con decreto del Ministro dei beni e delle attivita' culturali e del turismo, di concerto con il Ministro delle infrastrutture e dei trasporti, sono approvati gli interventi da finanziare ai sensi del primo periodo del presente comma e le relative modalita' attuative, anche prevedendo il ricorso ai provveditorati interregionali delle opere pubbliche. Le risorse da destinare agli interventi previsti dal presente comma sono individuate con decreto del Ministro delle infrastrutture e dei trasporti, di concerto con il Ministro dell'economia e delle finanze, da emanare entro trenta giorni dalla data di entrata in vigore della presente legge. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

339. All'articolo 60 della legge 27 dicembre 2002, n. 289, i commi 4 e 4-bis sono abrogati.

340. Al comma 11-bis dell'articolo 11 del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125, sono apportate le seguenti modificazioni:

- a) le parole: «che siano beni culturali ai sensi della parte seconda del codice di cui al decreto legislativo 22 gennaio 2004, n. 42,» sono soppresse;
- b) dopo le parole: «edifici di cui al periodo precedente» sono inserite le seguenti: «, che siano beni culturali ai sensi della parte seconda del codice di cui al decreto legislativo 22 gennaio 2004, n. 42,»;
- c) dopo il secondo periodo e' inserito il seguente: «Per i lavori di ricostruzione o riparazione delle chiese o degli altri edifici di cui al primo periodo del presente comma, la cui esecuzione non risalga ad oltre cinquanta anni, la funzione di stazione appaltante di cui al periodo precedente e' svolta dai competenti uffici territoriali del Provveditorato alle opere pubbliche».

341. In considerazione dello specifico rilievo che lo svolgimento del Gran Premio d'Italia di Formula 1 presso l'autodromo di Monza riveste per il settore sportivo, turistico ed economico, nonche' per l'immagine del Paese in ambito internazionale, la Federazione sportiva nazionale-ACI e' autorizzata a sostenere la spesa per costi di organizzazione e gestione della manifestazione per il periodo di vigenza del rapporto di concessione con il soggetto titolare dei diritti di organizzazione e promozione del campionato mondiale di Formula 1 a valere sulle risorse complessivamente iscritte nel proprio bilancio, anche attivando adeguate misure di contenimento dei costi generali di gestione e senza pregiudizio per gli equilibri di bilancio. Dall'attuazione del presente comma non devono derivare nuovi o maggiori oneri per la finanza pubblica.

342. Al fine di assicurare il rispetto dell'Accordo di sede tra la Repubblica italiana e l'Autorita' europea per la sicurezza alimentare, il Ministero dell'istruzione, dell'universita' e della ricerca eroga al comune di Parma, successivamente all'avvenuta riassegnazione di cui al comma 343, la somma di euro 3,9 milioni, a titolo di contributo per la costruzione della nuova sede della Scuola per l'Europa di Parma di cui all'articolo 2, comma 1, della legge 3 agosto 2009, n. 115. Le risorse sono erogate al comune sulla base dello stato di avanzamento dei lavori. Alla Scuola per l'Europa di Parma e' attribuito il diritto di superficie sull'area utilizzata per la costruzione dell'immobile realizzato ai sensi della legge 3 agosto 2009, n. 115, fermo restando quanto previsto dall'articolo 2, comma 2, della medesima legge 3 agosto 2009, n. 115.

343. All'onere derivante dal comma 342, si provvede mediante versamento all'entrata del bilancio dello Stato della somma di euro 3,9 milioni, da effettuare entro il 31 marzo 2016 a cura della Scuola per l'Europa di Parma. La somma cosi' versata alle entrate dello Stato e' successivamente riassegnata allo stato di previsione del Ministero dell'istruzione, dell'universita' e della ricerca per le finalita' di cui al comma 342.

344. La rappresentanza, il patrocinio e l'assistenza in giudizio della Scuola per l'Europa di Parma spettano all'Avvocatura dello Stato, ai sensi del testo unico di cui al regio decreto 30 ottobre 1933, n. 1611.

345. Per la realizzazione del programma di interventi della citta' designata «Capitale europea della cultura» per l'anno 2019 e' autorizzata la spesa di 2 milioni di euro per l'anno 2016, 6 milioni di euro per l'anno 2017, 11 milioni di euro per l'anno 2018 e 9 milioni di euro per l'anno 2019. L'individuazione degli interventi di cui al precedente periodo e' effettuata con decreto del Ministro dei beni e delle attivita' culturali e del turismo, previa intesa con il sindaco di Matera.

346. Al fine di governare e di gestire il ruolo di «Capitale europea della cultura» riconosciuto per il 2019, al comune di Matera non si applicano, fino al 31 dicembre 2019, le norme di contenimento delle spese per l'acquisto di beni e di servizi nonche', fino al 31 dicembre 2021, quelle limitative delle assunzioni di personale, con forme contrattuali flessibili, di cui all'articolo 9, comma 28, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, e successive modificazioni, nei limiti di quanto strettamente necessario allo svolgimento dell'evento. Fino al 31 dicembre 2021, il comune di Matera puo' autorizzare la corresponsione al personale non dirigenziale direttamente impiegato nelle attivita' di cui al periodo precedente, nel limite massimo complessivo di 30 ore pro capite mensili, di compensi per prestazioni di lavoro straordinario effettivamente rese, oltre i limiti previsti dall'articolo 14 del contratto collettivo nazionale di lavoro del personale del comparto 'Regioni-Autonomie locali' del 1° aprile 1999, pubblicato nel supplemento ordinario n. 81 alla Gazzetta Ufficiale n. 95 del 24 aprile 1999. E' altresi' consentita l'instaurazione di un rapporto di lavoro dirigenziale a tempo determinato ai sensi dell'articolo 110, comma 1, del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, anche in deroga alle percentuali ivi previste. Le spese di cui al presente comma non concorrono alla definizione dell'ammontare della riduzione della spesa di personale ai sensi dell'articolo 1, comma 557, della legge 27 dicembre 2006, n. 296, e successive modificazioni. Per garantire l'obiettivo di cui al presente comma, in favore del comune di Matera e' autorizzata la spesa di 500.000 euro per l'anno 2016 e di 1.500.000 euro per ciascuno degli anni dal 2017 al 2020. PERIODO SOPPRESSO DAL D.L. 19 MAGGIO 2020, N. 34, CONVERTITO CON MODIFICAZIONI, DALLA L. 17 LUGLIO 2020, N. 77. Per l'anno 2021 il comune di Matera puo' provvedere, nel limite massimo di spesa di 900.000 euro, a valere sulle risorse finanziarie stanziate dal presente comma per l'anno 2020.

347. Per consentire il completamento del restauro urbanistico ambientale dei rioni Sassi e del prospiciente altopiano murgico di Matera, in esecuzione degli articoli 5 e 13 della legge 11 novembre 1986, n. 771, e' autorizzata la spesa di 5 milioni di euro per ciascuno degli anni 2016, 2017, 2018 e 2019. Alle spese relative al personale assunto con contratto a tempo determinato ai fini dell'attuazione del presente comma, fermo restando il rispetto degli obiettivi di finanza pubblica previsti per gli enti territoriali, fino al 31 dicembre 2020 non si applicano i limiti di cui all'articolo 9, comma 28, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, e le vigenti disposizioni in materia di contenimento della spesa di personale. Per l'anno 2020 il comune di Matera puo' provvedere, nel limite massimo di spesa di 500.000 euro, a valere sulle proprie risorse finanziarie disponibili a legislazione vigente. E' assegnato un contributo di 200.000 euro per l'anno 2020 e di 500.000 euro per ciascuno degli anni 2021 e 2022 al complesso conventuale di San Felice per il completamento delle opere di manutenzione straordinaria e di adeguamento impiantistico. All'onere derivante dal periodo precedente si provvede mediante corrispondente riduzione del Fondo di cui all'articolo 1, comma 200, della legge 23 dicembre 2014, n. 190.

348. All'articolo 9, comma 1, della legge 29 luglio 2015, n. 115, sono apportate le seguenti modificazioni:

- a) alla lettera a), numero 2), le parole: «1º gennaio 2016» sono sostituite dalle seguenti: «30 giugno 2016»;
- b) alla lettera b), le parole: «1º gennaio 2016» sono sostituite dalle seguenti: «30 giugno 2016».

349. Per il funzionamento degli istituti afferenti al settore degli archivi e delle biblioteche, nonche' degli altri istituti centrali e dotati di autonomia speciale di cui all'articolo 30, commi 1 e 2, lettera b), del regolamento di cui al decreto del Presidente del Consiglio dei ministri 29 agosto 2014, n. 171, a decorrere dall'anno 2016 e' autorizzata la spesa di 30 milioni di euro annui da iscrivere nello stato di previsione della spesa del Ministero dei beni e delle attivita' culturali e del turismo.

350. Per ciascuno degli istituti di cui all'articolo 2, comma 1, della legge 30 marzo 2004, n. 92, e' autorizzato un finanziamento di 70.000 euro annui per ciascuno degli anni 2016, 2017 e 2018.

351. Per le finalita' di cui all'articolo 3, comma 83, della legge 23 dicembre 1996, n. 662, e successive modificazioni, e' autorizzata la spesa di 10 milioni di euro annui a decorrere dal 2016, incrementando il fondo di cui all'articolo 2, comma 616, della legge 24 dicembre 2007, n. 244.

352. Per il funzionamento delle istituzioni culturali di cui all'elenco n. 1 allegato alla presente legge e' autorizzata la spesa complessiva di euro 1,34 milioni annui a decorrere dall'anno 2016 secondo la ripartizione ivi indicata.

353. All'articolo 2, comma 16-ter, del decreto-legge 29 dicembre 2010, n. 225, convertito, con modificazioni, dalla legge 26 febbraio 2011, n. 10, e successive modificazioni, le parole: «Fino al 31 dicembre 2015» sono sostituite dalle seguenti: «Fino al 31 dicembre 2018». Per l'attuazione del presente comma e' autorizzata la spesa di 3 milioni di euro annui per gli anni 2016, 2017 e 2018.

354. Per il funzionamento degli Istituti afferenti al settore museale, a decorrere dall'anno 2016, e' autorizzata la spesa di 10 milioni di euro annui da iscrivere nello stato di previsione del Ministero dei beni e delle attivita' culturali e del turismo.

355. Le fondazioni lirico-sinfoniche che, alla data di entrata in vigore della presente legge, hanno presentato il piano di risanamento, ai sensi dell'articolo 11 del decreto-legge 8 agosto 2013, n. 91, convertito, con modificazioni, dalla legge 7 ottobre 2013, n. 112, sono tenute al raggiungimento del pareggio economico, in ciascun esercizio, e del tendenziale equilibrio patrimoniale e finanziario, entro l'esercizio finanziario 2020, previa integrazione, entro novanta giorni dalla data di entrata in vigore della presente legge, del piano di risanamento per il triennio 2016-2018. Il predetto piano di risanamento e' approvato con decreto del Ministro dei beni e delle attivita' culturali e del turismo, di concerto con il Ministro dell'economia e delle finanze. La mancata presentazione dell'integrazione del piano nel termine di cui al primo periodo del presente comma determina la sospensione dell'erogazione alle fondazioni lirico-sinfoniche inadempienti dei contributi a valere sul Fondo unico per lo spettacolo, di cui alla legge 30 aprile 1985, n. 163.

356. La procedura di cui all'articolo 11 del decreto-legge 8 agosto 2013, n. 91, convertito, con modificazioni, dalla legge 7 ottobre 2013, n. 112, si applica anche alle fondazioni lirico-sinfoniche che, alla data di entrata in vigore della presente legge, non versino nelle condizioni indicate nel comma 1 del medesimo articolo 11. Le fondazioni interessate possono presentare, entro il 30 giugno 2016, il piano triennale per il periodo 2016-2018, dopo l'approvazione del bilancio di esercizio per l'anno 2015, secondo le disposizioni definite nel citato articolo 11 del decreto-legge n. 91 del 2013 e nelle linee guida adottate per la redazione dei piani di risanamento. Per i piani di cui al presente comma, ai fini della definizione delle misure di cui alle lettere a) e c) del comma 1 del citato articolo 11 del decreto-legge n. 91 del 2013, si fa riferimento rispettivamente al debito esistente al 31 dicembre 2015 e alla dotazione organica in essere al 31 dicembre 2015. Ai fini dell'attuazione del presente comma, il fondo di rotazione di cui al medesimo articolo 11, comma 6, del decreto-legge n. 91 del 2013 e' incrementato, per l'anno 2016, di 10 milioni di euro. Al fine dell'erogazione delle risorse di cui al presente comma si applicano le disposizioni di cui al comma 7 dell'articolo 11 del decreto-legge n. 91 del 2013.

357. Al fine di consentire la prosecuzione del percorso di risanamento delle fondazioni lirico-sinfoniche di cui al comma 355 e di procedere all'approvazione e al monitoraggio dei nuovi piani di risanamento in attuazione del comma 356 del presente articolo, sono prorogate fino al 31 dicembre 2018 le funzioni del commissario straordinario di cui al comma 3 dell'articolo 11 del citato decreto-legge n. 91 del 2013 e il relativo incarico e' conferito con le modalita' di cui al medesimo articolo 11, commi 3 e 5, con le quali e' determinata anche la misura del compenso, non superiore a 100.000 euro. A supporto delle attivita' del commissario, la Direzione generale Spettacolo del Ministero dei beni e delle attivita' culturali e del turismo puo' conferire fino ad un massimo di tre incarichi di collaborazione, ai sensi dell'articolo 7, comma 6, del decreto legislativo 30 marzo 2001, n. 165, a persone di comprovata qualificazione professionale nella gestione amministrativa e contabile di enti che operano nel settore artistico-culturale, per la durata massima di ventiquattro mesi, entro il limite di spesa complessivo di 75.000 euro annui. Agli oneri derivanti dall'attuazione del presente comma, pari a 175.000 euro annui per ciascuno degli anni 2016, 2017 e 2018, si provvede mediante corrispondente riduzione dell'autorizzazione di spesa di cui all'articolo 2, comma 1, della legge 30 aprile 1985, n. 163, concernente il Fondo unico per lo spettacolo.

358. L'autorizzazione di spesa di cui all'articolo 19, comma 5-bis, del decreto-legge 12 settembre 2013, n. 104, convertito, con modificazioni, dalla legge 8 novembre 2013, n. 128, e' incrementata di 4 milioni di euro annui a decorrere dal 2016.

359. Al fine di tutelare un settore di significativo rilievo culturale e di salvaguardare le relative attivita', anche in considerazione del loro apporto al patrimonio tradizionale del Paese, e' autorizzata la spesa di 1 milione di euro per ciascuno degli anni 2016, 2017 e 2018 per il finanziamento di festival, cori e bande. Ai fini dell'accesso alle relative risorse, i soggetti interessati trasmettono al Ministero dei beni e delle attivita' culturali e del turismo i propri progetti, nei termini e secondo le modalita' e la procedura stabiliti con apposito bando del Ministro dei beni e delle attivita' culturali e del turismo, da adottare entro trenta giorni dalla data di entrata in vigore della presente legge. Entro i successivi due mesi, con decreto del Ministro dei beni e delle attivita' culturali e del turismo, di concerto con il Ministro dell'economia e delle finanze, si provvede all'individuazione dei progetti ammessi al finanziamento e al riparto delle relative risorse, nel rispetto del limite di spesa di cui al primo periodo.

360. Per gli anni 2016, 2017 e 2018 e' concesso un ulteriore contributo straordinario di 1 milione di euro annui a favore della Fondazione EBRI (European Brain Research Institute).

361. All'articolo 1 della legge 23 dicembre 2014, n. 190, il comma 524 e' sostituito dal seguente: «524. La regione Friuli Venezia Giulia e' autorizzata a rimodulare gli interventi e le iniziative di cui agli articoli 3, 8, 16 e 21 della legge 23 febbraio 2001, n. 38, ferma restando la finalizzazione degli interventi e delle iniziative stesse a favore della minoranza linguistica slovena. A decorrere dall'anno 2016 le risorse per le attivita' di cui al presente comma sono stabilite in 10 milioni di euro annui».

362. Per la prosecuzione degli interventi di cui alla legge 16 marzo 2001, n. 72, e' autorizzata la spesa di 2,3 milioni di euro per ciascuno degli anni 2016, 2017 e 2018. Per la prosecuzione degli interventi di cui alla legge 21 marzo 2001, n. 73, e' autorizzata la spesa di 3,5 milioni di euro per ciascuno degli anni 2016, 2017 e 2018.

363. Al fine di rilanciare le spese per investimenti degli enti locali, i comuni con popolazione superiore a 20.000 abitanti, nel cui territorio ricadono interamente i siti di importanza comunitaria, come definiti dall'articolo 2, comma 1, lettera m), del regolamento di cui al decreto del Presidente della Repubblica 8 settembre 1997, n. 357, e successive modificazioni, effettuano le valutazioni di incidenza dei seguenti interventi minori: manutenzione straordinaria, restauro e risanamento conservativo, ristrutturazione edilizia, anche con incrementi volumetrici o di superfici coperte inferiori al 20 per cento delle volumetrie o delle superfici coperte esistenti, opere di sistemazione esterne, realizzazione di pertinenze e volumi tecnici. L'autorita' competente al rilascio dell'approvazione definitiva degli interventi di cui al presente comma provvede entro il termine di sessanta giorni. Restano ferme le disposizioni di cui agli articoli 1, comma 4, 4 e 5, comma 8, del regolamento di cui al decreto del Presidente della Repubblica 8 settembre 1997, n. 357, e successive modificazioni.

364. Al fine della riqualificazione e rigenerazione territoriale dell'ambito costiero della provincia di Barletta-Andria-Trani programmata dal Protocollo di intesa sottoscritto in data 13 novembre 2014 tra la regione Puglia, la provincia di Barletta-Andria-Trani, i comuni di Barletta, Bisceglie, Margherita di Savoia e Trani e' autorizzata la spesa di 5 milioni di euro per ciascuno degli anni 2016, 2017 e 2018. Le risorse di cui al presente comma possono essere utilizzate tramite accordo di programma sottoscritto dalla regione Puglia, dal Ministero dell'ambiente e della tutela del territorio e del mare e dal Ministero delle infrastrutture e dei trasporti.

365. Al comma 1 dell'articolo 32 del decreto-legge 12 settembre 2014, n. 133, convertito, con modificazioni, dalla legge 11 novembre 2014, n. 164, le parole: «dalla data di entrata in vigore della legge di conversione del presente decreto e fino al 31 dicembre 2015» sono sostituite dalle seguenti: «a decorrere dal 1º gennaio 2016».

366. Il comma 2 dell'articolo 16 del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, e' abrogato.

367. Dopo il comma 2 dell'articolo 22 del decreto-legge 21 giugno 2013, n. 69, convertito, con modificazioni, dalla legge 9 agosto 2013, n. 98, sono inseriti i seguenti: «2-bis. Fermo restando quanto previsto al comma 2, in via sperimentale per gli anni 2016, 2017 e 2018, nei porti sede di autorita' portuale presso i quali sia stato registrato nell'anno precedente un volume di traffico di contenitori movimentati in operazioni di trasbordo superiore all'80 per cento del volume complessivo dei contenitori movimentati in ciascuno di detti porti, alle navi porta-contenitori adibite a servizi regolari di linea impiegate in traffici internazionali che fanno scalo nei porti medesimi puo' essere ridotto o data l'esenzione del pagamento della tassa di ancoraggio. Le autorita' portuali deliberano annualmente l'applicazione e il limite della misura. Alle autorita' portuali che adottano i suddetti provvedimenti di esenzione e' riconosciuto un contributo non superiore alla meta' dell'onere residuale a loro carico. A tal fine, con decreto del Ministro delle infrastrutture e dei trasporti da adottare entro sessanta giorni dall'approvazione del rendiconto generale delle autorita' portuali interessate, e' assegnata alle predette autorita' portuali la quota a carico dello Stato di copertura degli oneri di esenzioni richiamati, nel limite massimo complessivo di 3 milioni di euro annui. 2-ter. Per i porti di cui al comma 2-bis, le accise sui prodotti energetici per le navi che fanno esclusivamente movimentazione dentro il porto e manovre strumentali al trasbordo merci all'interno del porto sono ridotte nel limite di spesa di 1,8 milioni di euro. Con decreto del Ministro dell'economia e delle finanze, di concerto con il Ministro delle infrastrutture e dei trasporti, sentita la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, da adottare entro il 15 marzo 2016, sono disciplinate le modalita' di attuazione delle disposizioni recate dal presente comma».

368. Le operazioni di rimborso di cui al comma 2 dell'articolo 38-quater del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, possono essere effettuate da intermediari, purche' regolarmente iscritti all'albo degli istituti di pagamento di cui all'articolo 114-septies del testo unico di cui al decreto legislativo 1º settembre 1993, n. 385. PERIODO SOPPRESSO DAL D.L. 22 OTTOBRE 2016, N. 193, CONVERTITO CON MODIFICAZIONI DALLA L. 1 DICEMBRE 2016, N. 225.

369. L'autorizzazione di spesa di cui all'articolo 1, comma 54, della legge 13 luglio 2015, n. 107, e' incrementata di 5 milioni di euro per l'anno 2016.

370. Per il potenziamento delle azioni dell'ICE-Agenzia per la promozione all'estero e l'internazionalizzazione delle imprese italiane relative al piano straordinario per la promozione del Made in Italy di cui all'articolo 30, comma 1, del decreto-legge 12 settembre 2014, n. 133, convertito, con modificazioni, dalla legge 11 novembre 2014, n. 164, sono stanziati ulteriori 51 milioni di euro per l'anno 2016, di cui 1 milione di euro da assegnare all'Associazione delle camere di commercio italiane all'estero, di cui al comma 3 dell'articolo 5 della legge 31 marzo 2005, n. 56, per le finalita' indicate all'articolo 1, comma 202, quinto periodo, della legge 23 dicembre 2014, n. 190.

371. Per assicurare il sostegno all'esportazione, la somma di 300 milioni di euro delle disponibilita' giacenti nel conto corrente di tesoreria di cui all'articolo 7, comma 2-bis, del decreto legislativo 31 marzo 1998, n. 143, e successive modificazioni, e' versata all'entrata del bilancio dello Stato nel 2016 a cura del titolare del medesimo conto, per essere riassegnata al fondo di cui all'articolo 37, secondo comma, del decreto-legge 26 ottobre 1970, n. 745, convertito, con modificazioni, dalla legge 18 dicembre 1970, n. 1034, come sostituito dall'articolo 3 della legge 28 maggio 1973, n. 295, per le finalita' connesse all'attivita' di credito all'esportazione e di internazionalizzazione del sistema produttivo. Alla compensazione degli effetti finanziari in termini di fabbisogno e indebitamento netto derivanti dall'attuazione del presente comma, pari a 30 milioni di euro annui dall'anno 2016 all'anno 2025, si provvede mediante corrispondente utilizzo del Fondo per la compensazione degli effetti finanziari non previsti a legislazione vigente conseguenti all'attualizzazione di contributi pluriennali, di cui all'articolo 6, comma 2, del decreto-legge 7 ottobre 2008, n. 154, convertito, con modificazioni, dalla legge 4 dicembre 2008, n. 189.

372. Allo scopo di sostenere il settore aerospaziale e la realizzazione di un piano nazionale per lo sviluppo dell'industria italiana nel settore dei piccoli satelliti ad alta tecnologia e' autorizzata , nel rispetto della normativa europea in materia di aiuti di Stato, la spesa di 19 milioni di euro per l'anno 2016, di 50 milioni di euro per l'anno 2017 e di 30 milioni di euro per l'anno 2018. A quota parte degli oneri relativi all'anno 2016 derivanti dal presente comma, pari a 10 milioni di euro, si provvede mediante utilizzo delle risorse del fondo di cui al comma 969. PERIODO SOPPRESSO DALLA L. 27 DICEMBRE 2017, N. 205.

373. La dotazione del fondo ordinario per il finanziamento degli enti e degli istituti di ricerca, di cui all'articolo 7 del decreto legislativo 5 giugno 1998, n. 204, e' incrementata di 15 milioni di euro per ciascuno degli anni dal 2016 al 2018. Le predette somme sono destinate all'Istituto nazionale di fisica nucleare allo scopo di sostenere le attivita' di ricerca nei campi della fisica subnucleare, nucleare e astroparticellare.

374. L'autorizzazione di spesa di cui all'articolo 7 del decreto legislativo 5 giugno 1998, n. 204, e' ridotta di 4 milioni di euro annui a decorrere dall'anno 2016, relativamente alla quota concernente le spese di natura corrente.

375. Al fine di rafforzare l'azione dell'Italia nell'ambito della cooperazione internazionale per lo sviluppo, l'autorizzazione di spesa di cui all'articolo 18, comma 2, lettera c), della legge 11 agosto 2014, n. 125, e' incrementata di euro 120 milioni per l'anno 2016, di euro 240 milioni per l'anno 2017 e di euro 360 milioni a decorrere dall'anno 2018.

376. Le disposizioni previste dai commi dal presente al comma 382 hanno lo scopo di promuovere la costituzione e favorire la diffusione di societa', di seguito denominate «societa' benefit», che nell'esercizio di una attivita' economica, oltre allo scopo di dividerne gli utili, perseguono una o piu' finalita' di beneficio comune e operano in modo responsabile, sostenibile e trasparente nei confronti di persone, comunita', territori e ambiente, beni ed attivita' culturali e sociali, enti e associazioni ed altri portatori di interesse.

377. Le finalita' di cui al comma 376 sono indicate specificatamente nell'oggetto sociale della societa' benefit e sono perseguite mediante una gestione volta al bilanciamento con l'interesse dei soci e con l'interesse di coloro sui quali l'attivita' sociale possa avere un impatto. Le finalita' possono essere perseguite da ciascuna delle societa' di cui al libro V, titoli V e VI, del codice civile, nel rispetto della relativa disciplina.

378. Ai fini di cui ai commi da 376 a 382, si intende per:

- a) «beneficio comune»: il perseguimento, nell'esercizio dell'attivita' economica delle societa' benefit, di uno o piu' effetti positivi, o la riduzione degli effetti negativi, su una o piu' categorie di cui al comma 376;
- b) «altri portatori di interesse»: il soggetto o i gruppi di soggetti coinvolti, direttamente o indirettamente, dall'attivita' delle societa' di cui al comma 376, quali lavoratori, clienti, fornitori, finanziatori, creditori, pubblica amministrazione e societa' civile;
- c) «standard di valutazione esterno»: modalita' e criteri di cui all'allegato 4 annesso alla presente legge, che devono essere necessariamente utilizzati per la valutazione dell'impatto generato dalla societa' benefit in termini di beneficio comune;
- d) «aree di valutazione»: ambiti settoriali, identificati nell'allegato 5 annesso alla presente legge, che devono essere necessariamente inclusi nella valutazione dell'attivita' di beneficio comune.

379. La societa' benefit, fermo restando quanto previsto nel codice civile, deve indicare, nell'ambito del proprio oggetto sociale, le finalita' specifiche di beneficio comune che intende perseguire. Le societa' diverse dalle societa' benefit, qualora intendano perseguire anche finalita' di beneficio comune, sono tenute a modificare l'atto costitutivo o lo statuto, nel rispetto delle disposizioni che regolano le modificazioni del contratto sociale o dello statuto, proprie di ciascun tipo di societa'; le suddette modifiche sono depositate, iscritte e pubblicate nel rispetto di quanto previsto per ciascun tipo di societa' dagli articoli 2252, 2300 e 2436 del codice civile. La societa' benefit puo' introdurre, accanto alla denominazione sociale, le parole: «Societa' benefit» o l'abbreviazione: «SB» e utilizzare tale denominazione nei titoli emessi, nella documentazione e nelle comunicazioni verso terzi.

380. La societa' benefit e' amministrata in modo da bilanciare l'interesse dei soci, il perseguimento delle finalita' di beneficio comune e gli interessi delle categorie indicate nel comma 376, conformemente a quanto previsto dallo statuto. La societa' benefit, fermo quanto disposto dalla disciplina di ciascun tipo di societa' prevista dal codice civile, individua il soggetto o i soggetti responsabili a cui affidare funzioni e compiti volti al perseguimento delle suddette finalita'.

381. L'inosservanza degli obblighi di cui al comma 380 puo' costituire inadempimento dei doveri imposti agli amministratori dalla legge e dallo statuto. In caso di inadempimento degli obblighi di cui al comma 380, si applica quanto disposto dal codice civile in relazione a ciascun tipo di societa' in tema di responsabilita' degli amministratori.

382. Ai fini di cui ai commi da 376 a 384, la societa' benefit redige annualmente una relazione concernente il perseguimento del beneficio comune, da allegare al bilancio societario e che include:

- a) la descrizione degli obiettivi specifici, delle modalita' e delle azioni attuati dagli amministratori per il perseguimento delle finalita' di beneficio comune e delle eventuali circostanze che lo hanno impedito o rallentato;
- b) la valutazione dell'impatto generato utilizzando lo standard di valutazione esterno con caratteristiche descritte nell'allegato 4 annesso alla presente legge e che comprende le aree di valutazione identificate nell'allegato 5 annesso alla presente legge;
- c) una sezione dedicata alla descrizione dei nuovi obiettivi che la societa' intende perseguire nell'esercizio successivo.

383. La relazione annuale e' pubblicata nel sito internet della societa', qualora esistente. A tutela dei soggetti beneficiari, taluni dati finanziari della relazione possono essere omessi.

384. La societa' benefit che non persegua le finalita' di beneficio comune e' soggetta alle disposizioni di cui al decreto legislativo 2 agosto 2007, n. 145, in materia di pubblicita' ingannevole e alle disposizioni del codice del consumo, di cui al decreto legislativo 6 settembre 2005, n. 206. L'Autorita' garante della concorrenza e del mercato svolge i relativi compiti e attivita', nei limiti delle risorse disponibili e senza nuovi o maggiori oneri a carico dei soggetti vigilati.

385. A favore degli italiani nel mondo sono disposti i seguenti interventi:

- a) per un ammontare pari a 150.000 euro per l'anno 2016, per il funzionamento del Consiglio generale degli italiani all'estero;
- b) per un ammontare pari a 100.000 euro per l'anno 2016, per il funzionamento dei Comitati degli italiani all'estero - Comites e dei comitati dei loro presidenti;
- c) per un ammontare pari a 3.400.000 euro per l'anno 2016 per la promozione della lingua e cultura italiana all'estero e per il sostegno degli enti gestori di corsi di lingua e cultura italiana all'estero;
- d) per un ammontare pari a 500.000 euro per l'anno 2016, per l'incremento della dotazione finanziaria degli istituti italiani di cultura di cui alla legge 22 dicembre 1990, n. 401;
- e) per un ammontare pari a 650.000 euro per l'anno 2016, ad integrazione della dotazione finanziaria per i contributi diretti in favore della stampa italiana all'estero di cui all'articolo 1-bis del decreto-legge 18 maggio 2012, n. 63, convertito, con modificazioni, dalla legge 16 luglio 2012, n. 103;
- f) per un ammontare pari a 100.000 euro per l'anno 2016, in favore delle agenzie specializzate per i servizi stampa dedicati agli italiani residenti all'estero;
- g) per un ammontare pari a 150.000 euro per l'anno 2016, per promuovere l'attrattivita' delle universita' attraverso la diffusione dei corsi di lingua italiana online e avviare campagne informative di carattere didattico, amministrativo e logistico per favorire l'iscrizione di studenti stranieri in Italia;
- h) per un ammontare pari a 100.000 euro per ciascuno degli anni 2016, 2017 e 2018 in favore della societa' Dante Alighieri per garantire la continuita' delle sue iniziative di promozione del patrimonio culturale italiano all'estero e per un ammontare pari a 250.000 euro per ciascuno degli anni 2016, 2017 e 2018 in favore della Fondazione «I Lincei per la scuola» presso l'Accademia nazionale dei Lincei; (38) (48) (59) (72)(81)
- i) per un ammontare pari a 1 milione di euro per ciascuno degli anni 2016, 2017 e 2018, per contributi alle scuole italiane non statali paritarie all'estero.

386. Al fine di garantire l'attuazione di un Piano nazionale per la lotta alla poverta' e all'esclusione sociale, e' istituito presso il Ministero del lavoro e delle politiche sociali un fondo denominato «Fondo per la lotta alla poverta' e all'esclusione sociale», al quale sono assegnate le risorse di 600 milioni di euro per l'anno 2016 e di 1.000 milioni di euro a decorrere dall'anno 2017, che costituiscono i limiti di spesa ai fini dell'attuazione dei commi dal presente al comma 390. Il Piano, adottato con cadenza triennale mediante decreto del Presidente del Consiglio dei ministri, su proposta del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, d'intesa con la Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, individua una progressione graduale, nei limiti delle risorse disponibili, nel raggiungimento di livelli essenziali delle prestazioni assistenziali da garantire su tutto il territorio nazionale per il contrasto alla poverta'. (14) (28) (31)(56)

387. Per l'anno 2016 le risorse di cui al comma 386 sono destinate ai seguenti interventi che costituiscono le priorita' del Piano di cui al medesimo comma:

- a) avvio su tutto il territorio nazionale di una misura di contrasto alla poverta', intesa come estensione, rafforzamento e consolidamento della sperimentazione di cui all'articolo 60 del decreto-legge 9 febbraio 2012, n. 5, convertito, con modificazioni, dalla legge 4 aprile 2012, n. 35. Nelle more dell'adozione del Piano di cui al comma 386, all'avvio del Programma si procede con rinnovati criteri e procedure definiti ai sensi del citato articolo 60 del decreto-legge n. 5 del 2012, garantendo in via prioritaria interventi per nuclei familiari in modo proporzionale al numero di figli minori o disabili, tenendo conto della presenza, all'interno del nucleo familiare, di donne in stato di gravidanza accertata da definire con decreto del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, da emanare entro trenta giorni dalla data di entrata in vigore della presente legge. Nel 2016 al Programma sono destinati 380 milioni di euro incrementando a tal fine in misura pari al predetto importo il Fondo di cui all'articolo 81, comma 29, del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, oltre alle risorse gia' destinate alla sperimentazione dall'articolo 3, comma 2, del decreto-legge 28 giugno 2013, n. 76, convertito, con modificazioni, dalla legge 9 agosto 2013, n. 99, nonche' dall'articolo 1, comma 216, della legge 27 dicembre 2013, n. 147. Conseguentemente l'autorizzazione di spesa di cui al comma 386 e' corrispondentemente ridotta di 380 milioni di euro per l'anno 2016; (28)
- b) fermo restando quanto stabilito dall'articolo 43, comma 5, del decreto legislativo 14 settembre 2015, n. 148, all'ulteriore incremento dell'autorizzazione di spesa di cui all'articolo 16, comma 7, del decreto legislativo 4 marzo 2015, n. 22, relativa all'assegno di disoccupazione (ASDI), per 220 milioni di euro con conseguente corrispondente riduzione dell'autorizzazione di spesa di cui al comma 386.

388. Per gli anni successivi al 2016 le risorse di cui al comma 386 sono destinate al finanziamento di uno o piu' provvedimenti legislativi di riordino della normativa in materia di trattamenti, indennita', integrazioni di reddito e assegni di natura assistenziale o comunque sottoposti alla prova dei mezzi, anche rivolti a beneficiari residenti all'estero, nonche' in materia di accesso alle prestazioni sociali, finalizzati all'introduzione di un'unica misura nazionale di contrasto alla poverta', correlata alla differenza tra il reddito familiare del beneficiario e la soglia di poverta' assoluta, e alla razionalizzazione degli strumenti e dei trattamenti esistenti.

389. Al Fondo di cui al comma 386 sono altresi' destinate, a decorrere dall'anno 2017, le risorse stanziate dall'articolo 19, comma 1, del decreto-legge 29 novembre 2008, n. 185, convertito, con modificazioni, dalla legge 28 gennaio 2009, n. 2, nella misura di 30 milioni di euro per l'anno 2017 e di 54 milioni di euro annui a decorrere dall'anno 2018.

390. Sono abrogati i commi da 51 a 53 dell'articolo 2 della legge 28 giugno 2012, n. 92.

391. A decorrere dall'anno 2016 e' istituita la carta della famiglia, destinata alle famiglie costituite da cittadini italiani ovvero appartenenti a Paesi membri dell'Unione europea regolarmente residenti nel territorio italiano, con almeno tre figli conviventi di eta' non superiore a 26 anni. La carta e' rilasciata alle famiglie che ne facciano richiesta secondo i criteri e le modalita' stabiliti con decreto del Presidente del Consiglio dei ministri ovvero del Ministro per la famiglia e le disabilita', di concerto con il Ministro dell'economia e delle finanze, da emanare entro tre mesi dalla data di entrata in vigore della presente disposizione. La carta consente l'accesso a sconti sull'acquisto di beni o servizi ovvero a riduzioni tariffarie concessi dai soggetti pubblici o privati aderenti all'iniziativa. I soggetti che partecipano all'iniziativa, i quali concedono sconti o riduzioni maggiori di quelli normalmente praticati sul mercato, possono valorizzare la loro partecipazione all'iniziativa a scopi promozionali e pubblicitari. Ai fini dell'attuazione del presente comma e' autorizzata la spesa nel limite massimo di 1 milione di euro per ciascun anno del triennio 2019-2021 a valere sulla dotazione del Fondo per le politiche della famiglia di cui all'articolo 19, comma 1, del decreto-legge 4 luglio 2006, n. 223, convertito, con modificazioni, dalla legge 4 agosto 2006, n. 248. (51)

392. In via sperimentale, per gli anni 2016, 2017 e 2018, e' istituito il «Fondo per il contrasto della poverta' educativa minorile », alimentato dai versamenti effettuati su un apposito conto corrente postale dalle fondazioni di cui al decreto legislativo 17 maggio 1999, n. 153, nell'ambito della propria attivita' istituzionale. Le modalita' di gestione del conto di cui al presente comma sono definite nel protocollo d'intesa di cui al comma 393.(38) (58) (66)

393. Con protocollo d'intesa stipulato tra le fondazioni di cui al decreto legislativo 17 maggio 1999, n. 153, la Presidenza del Consiglio dei ministri, il Ministero dell'economia e delle finanze e il Ministero del lavoro e delle politiche sociali sono definite le modalita' di intervento di contrasto alla poverta' educativa minorile e sono individuate le caratteristiche dei progetti da finanziare, le modalita' di valutazione e selezione, anche con il ricorso a valutatori indipendenti, e di monitoraggio, al fine di assicurare la trasparenza, il migliore utilizzo delle risorse e l'efficacia degli interventi. Con il protocollo di cui al primo periodo, sono altresi' regolate le modalita' di organizzazione e governo del Fondo di cui al comma 392.

394. Agli enti di cui al comma 392 e' riconosciuto un contributo, sotto forma di credito d'imposta, pari al 75 per cento dei versamenti effettuati al Fondo di cui al medesimo comma 392, negli anni 2016, 2017, 2018, 2024, 2025, 2026 e 2027 e pari al 65 per cento negli anni 2019, 2020, 2021, 2022 e 2023. Il contributo e' assegnato, fino ad esaurimento delle risorse disponibili, pari a 100 milioni di euro annui per ciascuno degli anni 2016, 2017 e 2018, a 55 milioni di euro per ciascuno degli anni dal 2019 al 2022, a 45 milioni di euro per l'anno 2023, a 25 milioni di euro per l'anno 2024 e a 3 milioni di euro per ciascuno degli anni 2025, 2026 e 2027, secondo l'ordine temporale in cui le fondazioni comunicano l'impegno a finanziare i progetti individuati secondo il protocollo d'intesa di cui al comma 393. Il credito e' riconosciuto dall'Agenzia delle entrate con apposita comunicazione che da' atto della trasmissione della delibera di impegno irrevocabile al versamento al Fondo delle somme da ciascuna stanziate, nei termini e secondo le modalita' previsti nel protocollo d'intesa. Dell'eventuale mancato versamento al Fondo delle somme indicate nella delibera di impegno rispondono solidalmente tutte le fondazioni aderenti allo stesso. Il credito e' indicato nella dichiarazione dei redditi relativa al periodo d'imposta di riconoscimento e puo' essere utilizzato esclusivamente in compensazione ai sensi dell'articolo 17 del decreto legislativo 9 luglio 1997, n. 241, e successive modificazioni, a decorrere dal periodo d'imposta nel quale lo stesso e' stato riconosciuto. PERIODO SOPPRESSO DAL D.L. 27 DICEMBRE 2024, N. 202, CONVERTITO CON MODIFICAZIONI DALLA L. 21 FEBBRAIO 2025, N. 15. PERIODO SOPPRESSO DAL D.L. 27 DICEMBRE 2024, N. 202, CONVERTITO CON MODIFICAZIONI DALLA L. 21 FEBBRAIO 2025, N. 15. Al credito d'imposta non si applicano i limiti di cui all'articolo 1, comma 53, della legge 24 dicembre 2007, n. 244, e all'articolo 34 della legge 23 dicembre 2000, n. 388, e successive modificazioni.

395. Con decreto del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, sono definite le disposizioni applicative necessarie, ivi comprese le procedure per la concessione del contributo di cui al comma 394 nel rispetto del limite di spesa stabilito. Ai fini del riconoscimento del credito d'imposta relativo al 2025, le fondazioni, entro il 30 aprile dello stesso anno, trasmettono all'Associazione di fondazioni e di casse di risparmio Spa (ACRI), le delibere di impegno irrevocabile al versamento al Fondo delle somme da ciascuna stanziate per il sostegno dei progetti da finanziare. Conseguentemente, l'ACRI, nei successivi venti giorni, trasmette l'elenco delle fondazioni finanziatrici all'Agenzia delle entrate e il direttore della medesima Agenzia, nei successivi trenta giorni, comunica alle fondazioni il credito d'imposta ad esse attribuito.

396. All'articolo 2, comma 2, lettera a), ultimo periodo, del regolamento di cui al decreto del Presidente della Repubblica 10 novembre 1997, n. 441, le parole: «superiore a lire dieci milioni» sono sostituite dalle seguenti: «superiore a euro quindicimila o si tratti di beni facilmente deperibili ».

397. Al decreto legislativo 28 settembre 2012, n. 178, sono apportate le seguenti modificazioni:

- a) all'articolo 4, comma 2, e' aggiunto, in fine, il seguente periodo: «Fino alla conclusione delle procedure di cui al presente comma non possono essere intraprese o proseguite azioni esecutive, atti di sequestro o di pignoramento presso il conto di tesoreria della CRI o dell'Ente ovvero presso terzi, per la riscossione coattiva di somme liquidate ai sensi della normativa vigente in materia. Tutti gli atti esecutivi sono nulli»;
- b) all'articolo 5, comma 5, primo periodo, dopo le parole: «nel ruolo di cui al comma 3» e' aggiunto il seguente periodo: «Resta ferma la non liquidazione del trattamento di fine servizio in quanto il transito sopradetto interviene senza soluzione di continuita' nel rapporto di lavoro con la CRI ovvero con l'Ente»;
- c) all'articolo 5, comma 5, secondo periodo, le parole: «, fino all'applicazione delle disposizioni di cui all'articolo 6, commi 2 e 3,» sono soppresse e dopo le parole: «e il trattamento del corrispondente personale civile della CRI come assegno ad personam riassorbibile in caso di adeguamenti retributivi» sono aggiunte le seguenti: «e di riconoscimento degli istituti del trattamento economico determinati dalla contrattazione collettiva correlati ad obiettivi»;
- d) all'articolo 6, i commi 6 e 7 sono sostituiti dai seguenti: «6. Al personale civile e militare della CRI e quindi dell'Ente, compreso quello di cui all'articolo 8, comma 2, assunto da altre amministrazioni si applica l'articolo 5, comma 5, secondo periodo. I processi di mobilita' previsti dall'articolo 7, comma 2-bis, del decreto-legge 31 dicembre 2014, n. 192, convertito, con modificazioni, dalla legge 27 febbraio 2015, n. 11, si applicano al personale risultante eccedentario rispetto al fabbisogno definito ai sensi dell'articolo 3, comma 4, terzo periodo, per ciascun profilo professionale nell'ambito territoriale regionale. 7. Gli enti e le aziende del Servizio sanitario nazionale, anche delle regioni sottoposte ai piani di rientro dai deficit sanitari e ai programmi operativi in prosecuzione degli stessi, sono tenuti ad assumere con procedure di mobilita', anche in posizione di sovrannumero e ad esaurimento, il personale con rapporto di lavoro a tempo indeterminato della CRI e quindi dell'Ente con funzioni di autista soccorritore e autisti soccorritori senior, limitatamente a coloro che abbiano prestato servizio in attivita' convenzionate con gli enti medesimi per un periodo non inferiore a cinque anni. Tali assunzioni sono disposte senza apportare nuovi o maggiori oneri alla finanza pubblica in quanto finanziate con il trasferimento delle relative risorse occorrenti al trattamento economico del personale assunto, derivanti dalla quota di finanziamento del Servizio sanitario nazionale erogata annualmente alla CRI e quindi all'Ente. Le spese per il trattamento economico del personale trasferito al Servizio sanitario nazionale non sono considerate ai fini del rispetto dei limiti di spesa di cui all'articolo 2, comma 71, della legge 23 dicembre 2009, n. 191. Agli enti e alle aziende sopradette e' fatto divieto di assunzione del personale corrispondente fino al totale assorbimento del personale della CRI ovvero dell'Ente sopradetto. 7-bis. I rapporti con gli enti previdenziali derivanti dalle procedure di mobilita' del personale della CRI ovvero dell'Ente sono definiti in sede di applicazione delle disposizioni di cui all'articolo 8, comma 2, con relativo trasferimento della quota corrispondente dell'attivo patrimoniale»;
- e) all'articolo 6, comma 9, terzo periodo, dopo le parole: «31 dicembre 2015» sono aggiunte le seguenti: «ovvero fino alla conclusione delle procedure di cui all'articolo 5, comma 6»;
- f) all'articolo 8, comma 2, secondo periodo: 1) dopo le parole: «gestione liquidatoria » e' aggiunto il seguente periodo: «Il personale gia' individuato nella previsione di fabbisogno ai sensi dell'articolo 3, comma 4, come funzionale alle attivita' propedeutiche alla gestione liquidatoria verra' individuato con specifico provvedimento del presidente nazionale della CRI ovvero dell'Ente entro il 30 marzo 2016 e successivamente aggiornato. Detto personale non partecipa alle procedure previste dall'articolo 7, comma 2-bis, del decreto-legge 31 dicembre 2014, n. 192, convertito, con modificazioni, dalla legge 27 febbraio 2015, n. 11. Il 1º gennaio 2018 il suddetto personale viene trasferito, con corrispondente trasferimento delle risorse finanziarie, presso pubbliche amministrazioni che presentano carenze in organico nei corrispondenti profili professionali ovvero anche in sovrannumero»; 2) le parole: «; il predetto personale,» sono sostituite dalle seguenti: «. Il personale, ad eccezione di quello funzionale alle attivita' propedeutiche alla gestione liquidatoria di cui al precedente capoverso,»; 3) sono aggiunte, in fine, le seguenti parole: «Il personale della CRI ovvero dell'Ente, nelle more della conclusione delle procedure di cui all'articolo 7, comma 2-bis, del decreto-legge 31 dicembre 2014, n. 192, convertito, con modificazioni, dalla legge 27 febbraio 2015, n. 11, previa convenzione tra le parti, puo' prestare temporaneamente la propria attivita' presso altre pubbliche amministrazioni per garantire fini di interesse pubblico di cui all'articolo 1, comma 4, anche con oneri a carico del finanziamento pubblico della CRI ovvero dell'Ente, che rimane esclusivamente responsabile nei confronti del lavoratore del trattamento economico e normativo».

398. All'articolo 7, comma 2-bis, del decreto-legge 31 dicembre 2014, n. 192, convertito, con modificazioni, dalla legge 27 febbraio 2015, n. 11, le parole: «Le disposizioni dei commi 425, 426, 427, 428 e 429» sono sostituite dalle seguenti: «Le disposizioni dei commi 424, 425, 426, 427 e 428».

399. Il fondo di cui all'articolo 58, comma 1, del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134, e' rifinanziato di 2 milioni di euro per l'anno 2016 e di 5 milioni di euro a decorrere dall'anno 2017.

400. E' istituito un Fondo presso il Ministero del lavoro e delle politiche sociali, con una dotazione di 90 milioni di euro annui a decorrere dall'anno 2016, destinato alla copertura finanziaria di interventi legislativi recanti misure per il sostegno di persone con disabilita' grave, prive di sostegno familiare.

401. Al fine di garantire la compiuta attuazione della legge 18 agosto 2015, n. 134, e' istituito nello stato di previsione del Ministero della salute il Fondo per la cura dei soggetti con disturbo dello spettro autistico, con una dotazione di 5 milioni di euro annui a decorrere dall'anno 2016.La dotazione del Fondo di cui al primo periodo e' incrementata di 50 milioni di euro per l'anno 2021 e di 27 milioni di euro per l'anno 2022. (14) (54)

402. Con decreto del Ministro della salute, di concerto con il Ministro per le disabilita', con il Ministro dell'economia e delle finanze e con il Ministro dell'universita' e della ricerca, previa intesa in sede di Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, sono definiti i criteri e le modalita' per l'utilizzazione delle risorse del Fondo di cui al comma 401 del presente articolo, fatto salvo quanto previsto al comma 402-bis, prevedendo che tali risorse siano destinate, nel rispetto della legge 18 agosto 2015, n. 134, e fermo restando quanto stabilito dal decreto del Ministro della salute 30 dicembre 2016, ai seguenti settori di intervento:

- a) per una quota pari al 15 per cento, allo sviluppo di progetti di ricerca di base o applicata, nonche' su modelli clinico-organizzativi e sulle buone pratiche terapeutiche ed educative, da parte di enti di ricerca e strutture pubbliche e private accreditate da parte del Servizio sanitario nazionale, selezionati attraverso procedure di evidenza pubblica;
- b) per una quota pari al 50 per cento, da ripartire tra le regioni e le province autonome di Trento e di Bolzano, all'incremento del personale del Servizio sanitario nazionale preposto all'erogazione degli interventi previsti dalle linee guida sulla diagnosi e sul trattamento dei disturbi dello spettro autistico elaborate dall'Istituto superiore di sanita';
- c) per una quota pari al 15 per cento, a iniziative di formazione quali l'organizzazione di corsi di perfezionamento e master universitari in analisi applicata del comportamento e altri interventi previsti dalle linee guida di cui alla lettera b) indirizzati al personale e agli operatori del Servizio sanitario nazionale e al personale socio-sanitario, compreso il personale di cui alla medesima lettera b), sulla base di convenzioni tra universita' e strutture del Servizio sanitario nazionale;
- d) per una quota pari al 20 per cento, a iniziative delle regioni e delle province autonome di Trento e di Bolzano finalizzate, con il supporto dell'Istituto superiore di sanita', allo sviluppo di: 1) una rete di cura territoriale con funzioni di riconoscimento, diagnosi e intervento precoce sui disturbi del neurosviluppo, nel quadro di un'attivita' di sorveglianza della popolazione soggetta a rischio e della popolazione generale, nell'ambito dei servizi educativi della prima infanzia e dei bilanci di salute pediatrici, nei servizi di neuropsichiatria dell'infanzia e dell'adolescenza e nei reparti di terapia intensiva neonatale e di neonatologia; 2) progetti di vita individualizzati basati sul concetto di qualita' della vita, come definito dall'Organizzazione mondiale della sanita', assicurando percorsi diagnostico-terapeutici, assistenziali ed educativi e la continuita' di cura in tutto l'arco della vita, l'integrazione scolastica e l'inclusione sociale e lavorativa.

402-bis. Con decreto del Ministro della salute, di concerto con il Ministro per le disabilita' e con il Ministro dell'economia e delle finanze, previa intesa in sede di Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, sono definiti i criteri e le modalita' per l'utilizzazione delle risorse di cui all'articolo 1, comma 181, lettera a), della legge 30 dicembre 2021, n. 234, nell'ambito delle finalita' previste all'articolo 1, comma 182, della medesima legge.

403. E' autorizzata la spesa di un milione di euro per l'anno 2016 in favore dell'ente «Ente Nazionale per la protezione e l'assistenza dei Sordi (Onlus)», di cui alla legge 12 maggio 1942, n. 889, alla legge 21 agosto 1950, n. 698, e al decreto del Presidente della Repubblica 31 marzo 1979, pubblicato nella Gazzetta Ufficiale n. 125 del 9 maggio 1979, con vincolo di destinazione alla creazione e funzionamento annuale del costituendo Centro per l'autonomia della persona sorda (C.A.P.S.) con sede in Roma.

404. E' autorizzata la spesa di 1 milione di euro, per l'anno 2016, in favore dell'Istituto di studi politici, economici e sociali - Eurispes, con vincolo di destinazione alla creazione di progetti e iniziative informative finalizzate a sostenere l'attivita' sociale ed economica nazionale.

405. Lo stanziamento del Fondo per le non autosufficienze, di cui all'articolo 1, comma 1264, della legge 27 dicembre 2006, n. 296, anche ai fini del finanziamento degli interventi a sostegno delle persone affette da sclerosi laterale amiotrofica, e' incrementato di 150 milioni di euro annui a decorrere dall'anno 2016.

406. Al fine di potenziare i progetti riguardanti misure atte a rendere effettivamente indipendente la vita delle persone con disabilita' grave come previsto dalle disposizioni di cui alla legge 21 maggio 1998, n. 162, e' stanziata la somma di 5 milioni di euro per l'anno 2016.

407. A decorrere dall'anno 2016, al fine di favorire la realizzazione di progetti di integrazione dei disabili mentali attraverso lo sport, una quota pari a 500.000 euro del contributo di cui all'articolo 1, comma 580, della legge 23 dicembre 2005, n. 266, e successivi rifinanziamenti, e' attribuita al programma internazionale di allenamento sportivo e competizioni atletiche per le persone, ragazzi ed adulti, con disabilita' intellettiva, «Special Olympics Italia».

407-bis. Al fine di favorire la realizzazione dei progetti di integrazione di cui al comma 407 e lo sviluppo dei predetti progetti in tutto il territorio nazionale, la quota del contributo per l'attuazione del programma internazionale di allenamento sportivo e competizioni atletiche per le persone, ragazzi e adulti, "Special Olympics Italia", e' incrementata di 300.000 euro per ciascuno degli anni 2019, 2020 e 2021.

408. Ai fini dell'attuazione del comma 407 il contributo al Comitato italiano paralimpico di cui all'articolo 1, comma 580, della legge 23 dicembre 2005, n. 266, e' incrementato di 0,5 milioni di euro annui a decorrere dall'anno 2016.

409. L'articolo 2 del decreto-legge 25 marzo 2013, n. 24, convertito, con modificazioni, dalla legge 23 maggio 2013, n. 57, e' sostituito dal seguente: «Art. 2. - (Sperimentazioni cliniche con l'impiego di medicinali per terapie avanzate a base di cellule staminali per la cura di malattie rare). - 1. Per lo svolgimento di una o piu' sperimentazioni cliniche, concernenti l'impiego di medicinali per terapie avanzate a base di cellule staminali per la cura di malattie rare, da condurre, nel rispetto delle modalita' e dei termini previsti dal decreto legislativo 24 giugno 2003, n. 211, nonche' secondo la normativa internazionale vigente e in accordo con le vigenti linee guida europee, con cellule prodotte secondo il regime GMP (Good Manufacturing Practice) certificato dall'Agenzia italiana del farmaco, il Comitato interministeriale per la programmazione economica, in attuazione dell'articolo 1, comma 34, della legge 23 dicembre 1996, n. 662, vincola una quota del Fondo sanitario nazionale, per un importo fino a 2 milioni di euro per l'anno 2017 e fino a 4 milioni di euro per l'anno 2018, su proposta del Ministro della salute, di concerto con il Ministro dell'economia e delle finanze, previa intesa in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio. 2. Al fine di garantire il piu' elevato potenziale terapeutico e il migliore livello scientifico, la selezione delle sperimentazioni da finanziare ai sensi del comma 1 avviene mediante procedura a evidenza pubblica, coordinata dall'Agenzia italiana del farmaco e dall'Istituto superiore di sanita', che possono avvalersi di un comitato di esperti esterni ai fini della valutazione delle predette sperimentazioni».

410. Il Fondo sanitario nazionale, determinato ai sensi dell'articolo 1, comma 556, della legge 23 dicembre 2014, n. 190, e' incrementato nella misura di 1 milione di euro per l'anno 2017 e di 2 milioni di euro per l'anno 2018.

411. Al fine di sostenere le politiche in materia di adozioni internazionali e di assicurare il funzionamento della Commissione per le adozioni internazionali e' istituito, nello stato di previsione del Ministero dell'economia e delle finanze, per il successivo trasferimento al bilancio autonomo della Presidenza del Consiglio dei ministri, un fondo denominato «Fondo per le adozioni internazionali» con una dotazione di 15 milioni di euro annui a decorrere dal 2016. In attesa della riorganizzazione delle strutture della Presidenza del Consiglio dei ministri, di cui all'articolo 8 della legge 7 agosto 2015, n. 124, la gestione delle risorse del Fondo e della Commissione di cui al presente comma e' assegnata al Centro di responsabilita' del Segretariato generale della Presidenza del Consiglio dei ministri. (14) (47)

412. La dotazione del Fondo per le politiche della famiglia di cui all'articolo 19, comma 1, del decreto-legge 4 luglio 2006, n. 223, convertito, con modificazioni, dalla legge 4 agosto 2006, n. 248, come rifinanziato dall'articolo 1, comma 132, della legge 23 dicembre 2014, n. 190, e' ridotta nella misura di 15 milioni di euro annui a decorrere dal 2016.

413. All'articolo 1, comma 1250, della legge 27 dicembre 2006, n. 296, e successive modificazioni, le parole: «; per sostenere le adozioni internazionali e garantire il pieno funzionamento della Commissione per le adozioni internazionali» sono soppresse.

414. E' istituito, in via sperimentale, nello stato di previsione del Ministero della giustizia, con una dotazione di 250.000 euro per l'anno 2016 e di 500.000 euro per l'anno 2017, il Fondo di solidarieta' a tutela del coniuge in stato di bisogno.

415. A valere sulle risorse del Fondo di cui al comma 414, il coniuge in stato di bisogno che non e' in grado di provvedere al mantenimento proprio e dei figli minori, oltre che dei figli maggiorenni portatori di handicap grave, conviventi, qualora non abbia ricevuto l'assegno determinato ai sensi dell'articolo 156 del codice civile per inadempienza del coniuge che vi era tenuto, puo' rivolgere istanza da depositare nella cancelleria del tribunale del luogo ove ha residenza, per l'anticipazione di una somma non superiore all'importo dell'assegno medesimo. Il presidente del tribunale o un giudice da lui delegato, ritenuti sussistenti i presupposti di cui al periodo precedente, assumendo, ove occorra, informazioni, nei trenta giorni successivi al deposito dell'istanza, valuta l'ammissibilita' dell'istanza medesima e la trasmette al Ministero della giustizia ai fini della corresponsione della somma di cui al periodo precedente. Il Ministero della giustizia si rivale sul coniuge inadempiente per il recupero delle risorse erogate. Quando il presidente del tribunale o il giudice da lui delegato non ritiene sussistenti i presupposti per la trasmissione dell'istanza al Ministero della giustizia, provvede al rigetto della stessa con decreto non impugnabile. Il procedimento introdotto con la presentazione dell'istanza di cui al primo periodo non e' soggetto al pagamento del contributo unificato.

416. Con decreto del Ministro della giustizia, di concerto con il Ministro dell'economia e delle finanze, sono adottate, entro trenta giorni dalla data di entrata in vigore della presente legge, le disposizioni necessarie per l'attuazione dei commi 414 e 415, con particolare riguardo all'individuazione dei tribunali presso i quali avviare la sperimentazione, alle modalita' per la corresponsione delle somme e per la riassegnazione al Fondo di cui al comma 414 delle somme recuperate ai sensi del terzo periodo del comma 415.

417. Per lo svolgimento delle azioni e degli interventi connessi alla realizzazione del programma unico di emersione, assistenza e integrazione sociale previsto dall'articolo 18, comma 3-bis, del testo unico di cui al decreto legislativo 25 luglio 1998, n. 286, attuativo del Piano nazionale d'azione contro la tratta e il grave sfruttamento degli esseri umani, di cui all'articolo 13, comma 2-bis, della legge 11 agosto 2003, n. 228, nonche' per la realizzazione delle correlate azioni di supporto e di sistema da parte della Presidenza del Consiglio dei ministri - Dipartimento per le pari opportunita', e' destinata al bilancio della Presidenza del Consiglio dei ministri una somma pari a 3 milioni di euro per ciascuno degli anni 2016, 2017 e 2018, a 2 milioni di euro per l'anno 2023 e a 7 milioni di euro annui a decorrere dall'anno 2024.

418. Il comma 466 dell'articolo 2 della legge 24 dicembre 2007, n. 244, e' sostituito dal seguente: «466. Il contributo di cui alla legge 23 settembre 1993, n. 379, e' erogato, per l'85 per cento, agli enti di formazione destinatari e, per la restante parte, all'Associazione nazionale privi della vista e ipovedenti Onlus, per le esigenze del Centro autonomie e mobilita' e dell'annessa Scuola cani guida per ciechi e al Polo tattile multimediale della Stamperia regionale Braille Onlus di Catania. La ripartizione e' operata dal Ministero dell'interno con proprio provvedimento adottato su proposta dell'Unione italiana ciechi tenuto conto dei progetti di attivita' presentati dagli enti di cui al periodo precedente. I medesimi enti sono tenuti agli adempimenti di rendicontazione gia' previsti dall'articolo 2 della medesima legge n. 379 del 1993 per l'Unione italiana ciechi».

419. Al fine di contribuire al funzionamento dell'Istituto nazionale di genetica molecolare (INGM) di cui all'articolo 1, comma 1, lettera b), del decreto-legge 29 marzo 2004, n. 81, convertito, con modificazioni, dalla legge 26 maggio 2004, n. 138, e' autorizzata a decorrere dall'anno 2016 una spesa ulteriore di 1 milione di euro annui.

420. Il contributo in favore della Biblioteca italiana per i ciechi «Regina Margherita» di Monza di cui all'articolo 1 della legge 13 novembre 2002, n. 260, e' incrementato dell'importo di 2 milioni di euro per ciascuno degli anni 2016, 2017 e 2018 , e di 1 milione di euro per l'anno 2019.

421. Alla biblioteca italiana per ipovedenti «B.I.I. Onlus» e' assegnato un contributo di 100.000 euro per ciascuno degli anni 2016, 2017, 2018, 2019, 2020 e 2021.

422. Al fine di dare avvio alle misure per fare fronte ai danni occorsi al patrimonio privato ed alle attivita' economiche e produttive, in attuazione della lettera d) del comma 2 dell'articolo 5 della legge 24 febbraio 1992, n. 225, e successive modificazioni, relativamente alle ricognizioni dei fabbisogni completate dai Commissari delegati e trasmesse al Dipartimento della protezione civile della Presidenza del Consiglio dei ministri per la successiva istruttoria si provvede, per le finalita' e secondo i criteri da stabilire con apposite deliberazioni del Consiglio dei ministri, assunte ai sensi della lettera e) del citato articolo 5, comma 2, della legge n. 225 del 1992 mediante concessione, da parte delle Amministrazioni pubbliche indicate nelle medesime deliberazioni, di contributi a favore di soggetti privati e attivita' economiche e produttive, con le modalita' del finanziamento agevolato.

423. Per le finalita' di cui al comma 422, i soggetti autorizzati all'esercizio del credito operanti nei territori individuati nelle deliberazioni del Consiglio dei ministri adottate ai sensi del medesimo comma, possono contrarre finanziamenti, secondo contratti tipo definiti con apposita convenzione con l'Associazione bancaria italiana, assistiti dalla garanzia dello Stato, ai sensi dell'articolo 5, comma 7, lettera a), secondo periodo, del decreto-legge 30 settembre 2003, n. 269, convertito, con modificazioni, dalla legge 24 novembre 2003, n. 326, al fine di concedere finanziamenti agevolati assistiti da garanzia dello Stato ai soggetti danneggiati dagli eventi calamitosi rispettivamente indicati, nel limite massimo di 1.500 milioni di euro, e comunque nei limiti delle disponibilita' di cui al comma 427. Con decreti del Ministro dell'economia e delle finanze e' concessa la garanzia dello Stato di cui ai commi da 422 a 428 e sono definiti i criteri e le modalita' di operativita' della stessa, nonche' le modalita' di monitoraggio ai fini del rispetto dell'importo massimo di cui al periodo precedente. La garanzia dello Stato di cui al presente comma e' elencata nell'allegato allo stato di previsione del Ministero dell'economia e delle finanze di cui all'articolo 31 della legge 31 dicembre 2009, n. 196.

424. In caso di accesso ai finanziamenti agevolati accordati dalle banche ai sensi dei commi da 422 a 428, in capo al beneficiario del finanziamento matura un credito di imposta, fruibile esclusivamente in compensazione, in misura pari, per ciascuna scadenza di rimborso, all'importo ottenuto sommando alla sorte capitale gli interessi dovuti, nonche' le spese strettamente necessarie alla gestione dei medesimi finanziamenti. Le modalita' di fruizione del credito di imposta sono stabilite con provvedimento del direttore dell'Agenzia delle entrate nel limite di 60 milioni di euro annui a decorrere dal 2016. Il credito di imposta e' revocato, in tutto o in parte, nell'ipotesi di risoluzione totale o parziale del contratto di finanziamento agevolato.

425. Il soggetto che eroga il finanziamento agevolato comunica con modalita' telematiche all'Agenzia delle entrate gli elenchi dei soggetti beneficiari, l'ammontare del finanziamento concesso a ciascun beneficiario, il numero e l'importo delle singole rate. L'ammontare del finanziamento e' erogato al netto di eventuali indennizzi per polizze assicurative stipulate per le medesime finalita' da dichiarare al momento della richiesta del finanziamento agevolato.

426. I finanziamenti agevolati, di durata massima venticinquennale, sono erogati e posti in ammortamento sulla base degli stati di avanzamento lavori relativi all'esecuzione dei lavori, alle prestazioni di servizi e alle acquisizioni di beni necessari all'esecuzione degli interventi ammessi a contributo dalle amministrazioni pubbliche di cui al comma 422. I contratti di finanziamento prevedono specifiche clausole risolutive espresse, anche parziali, per i casi di mancato o ridotto impiego del finanziamento, ovvero di utilizzo anche parziale del finanziamento per finalita' diverse da quelle indicate nei commi da 422 a 428. In tutti i casi di risoluzione del contratto di finanziamento, il soggetto finanziatore chiede al beneficiario la restituzione del capitale, degli interessi e di ogni altro onere dovuto. In mancanza di tempestivo pagamento spontaneo, lo stesso soggetto finanziatore comunica alle amministrazioni pubbliche di cui al comma 422, per la successiva iscrizione a ruolo, i dati identificativi del debitore e l'ammontare dovuto, fermo restando il recupero da parte del soggetto finanziatore delle somme erogate e dei relativi interessi nonche' delle spese strettamente necessarie alla gestione dei finanziamenti, non rimborsati spontaneamente dal beneficiario, mediante compensazione ai sensi dell'articolo 17 del decreto legislativo 9 luglio 1997, n. 241. Le somme riscosse a mezzo ruolo sono versate in apposito capitolo di entrata del bilancio dello Stato per essere riassegnate al Fondo per le emergenze nazionali istituito presso la Presidenza del Consiglio dei ministri - Dipartimento della protezione civile.

427. Al fine di assicurare l'invarianza finanziaria degli effetti delle disposizioni di cui ai commi da 422 a 428, entro il 31 marzo di ciascun anno, il Ministero dell'economia e delle finanze verifica l'andamento della concessione di finanziamenti agevolati e del relativo tiraggio, con riferimento alle disposizioni vigenti riguardanti la concessione di finanziamenti con oneri a carico dello Stato per interventi connessi a calamita' naturali, al fine di valutare l'importo dei finanziamenti di cui ai commi da 422 a 428 che possono essere annualmente concessi nel rispetto dei saldi di finanza pubblica, fermo restando il limite massimo di cui al comma 423. Il Ministero dell'economia e delle finanze comunica al Dipartimento della protezione civile l'esito della verifica effettuata entro il medesimo termine del 31 marzo.

428. Le modalita' attuative dei commi da 422 a 428, anche al fine di assicurare uniformita' di trattamento, un efficace monitoraggio sull'utilizzo delle risorse, nonche' il rispetto del limite di 1.500 milioni di euro di cui al comma 423, sono definite con ordinanze adottate dal Capo del Dipartimento della protezione civile d'intesa con le regioni rispettivamente interessate e di concerto con il Ministero dell'economia e delle finanze, ai sensi dell'articolo 5 della legge 24 febbraio 1992, n. 225, e successive modificazioni.

428-bis. Con ordinanza adottata ai sensi dell'articolo 5 della legge 24 febbraio 1992, n. 225, di concerto con i Ministeri dell'economia e delle finanze e delle politiche agricole alimentari e forestali, sono disciplinati, per le imprese agricole che nell'ambito della ricognizione dei fabbisogni di cui al comma 422 hanno reso, nei termini, la segnalazione preliminare dei danni subiti utilizzando una modulistica diversa, le modalita' e i termini con i quali si procede alla regolarizzazione delle istanze presentate, garantendo l'omogenea definizione delle voci ammissibili e dei massimali previsti nella scheda 'C' allegata alle ordinanze di protezione civile rispettivamente adottate, e fermi restando i limiti complessivi dei fabbisogni finanziari ivi indicati.

428-ter. Conseguentemente, con apposite delibere del Consiglio dei ministri, sono riconosciuti alle imprese agricole di cui al comma 428-bis i benefici previsti dai commi da 422 a 428 e dai relativi provvedimenti attuativi, entro i limiti delle disponibilita' finanziarie comunicate dal Ministero dell'economia e delle finanze.

429. All'articolo 9 della legge 27 luglio 2000, n. 212, dopo il comma 2 sono aggiunti i seguenti: «2-bis. La ripresa dei versamenti dei tributi sospesi o differiti ai sensi del comma 2 avviene, senza applicazione di sanzioni, interessi e oneri accessori relativi al periodo di sospensione, anche mediante rateizzazione fino a un massimo di diciotto rate mensili di pari importo, a decorrere dal mese successivo alla data di scadenza della sospensione. Con decreto del Ministro dell'economia e delle finanze sono definiti le modalita' e i termini della ripresa dei versamenti, tenendo anche conto della durata del periodo di sospensione, nei limiti delle risorse preordinate allo scopo. 2-ter. Per i tributi non sospesi ne' differiti ai sensi del comma 2, nei limiti delle risorse preordinate allo scopo, i contribuenti residenti o aventi sede legale o sede operativa nei territori colpiti da eventi calamitosi con danni riconducibili all'evento e individuati con la medesima ordinanza della Presidenza del Consiglio dei ministri con la quale e' dichiarato lo stato di emergenza possono chiedere la rateizzazione, fino a un massimo di diciotto rate mensili di pari importo, dei tributi che scadono nei sei mesi successivi alla dichiarazione dello stato di emergenza, con istanza da presentare al competente ufficio, secondo modalita' e termini stabiliti con decreto del Ministro dell'economia e delle finanze, da adottare entro novanta giorni dalla data di entrata in vigore della presente disposizione».

430. Nello stato di previsione del Ministero dell'economia e delle finanze e' istituito un fondo rotativo per far fronte alle esigenze che derivano dal differimento di riscossione a seguito di eventi calamitosi, disposto ai sensi dell'articolo 9 della legge 27 luglio 2000, n. 212, con una dotazione di 5 milioni di euro per l'anno 2016. Con apposito decreto del Ministro dell'economia e delle finanze, sono stabilite le modalita' attuative e di alimentazione del medesimo fondo. Al relativo onere per l'anno 2016 si provvede mediante riduzione di pari importo dell'autorizzazione di spesa di cui all'articolo 3-bis, comma 6, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135. (29)

431. All'articolo 12, comma 1, ultimo periodo, del decreto legislativo 24 settembre 2015, n. 159, le parole: «entro trenta giorni dal» sono sostituite dalle seguenti: «entro il mese successivo al».

432. Per gli anni 2016 e 2017, al fine di completare le attivita' finalizzate alla fase di ricostruzione del tessuto urbano, sociale e occupazionale dei territori colpiti dal sisma del 6 aprile 2009, i comuni del cratere sismico sono autorizzati a prorogare o rinnovare, alle medesime condizioni giuridiche ed economiche, i contratti stipulati sulla base della normativa emergenziale, in deroga alle vigenti normative in materia di vincoli alle assunzioni a tempo determinato presso le amministrazioni pubbliche. Alle proroghe o rinnovi dei suddetti contratti, eseguiti in deroga alla legge, non sono applicabili le sanzioni previste dalla normativa vigente, ivi compresa la sanzione della trasformazione del contratto a tempo indeterminato.

433. Agli oneri derivanti dall'applicazione del comma 432, quantificati sulla base delle esigenze effettive documentate dalle amministrazioni centrali e locali istituzionalmente preposte all'attivita' della ricostruzione, si provvede mediante l'utilizzo delle somme stanziate con la legge 23 dicembre 2014, n. 190, Tabella E, nell'ambito della quota destinata dal CIPE al finanziamento di servizi di natura tecnica e assistenza qualificata.

433-bis. Le disposizioni di cui ai commi 432 e 433 si applicano negli anni 2017 e 2018, nel limite di spesa di euro 1.700.000 per il comune dell'Aquila e di euro 1.152.209 per i comuni del cratere.

434. Il termine di un triennio, di cui all'articolo 67-ter, comma 3, del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134, relativo alla dotazione di risorse umane a tempo determinato, nel limite massimo di 25 unita', assegnata agli Uffici speciali per la ricostruzione di cui all'articolo 67-ter, comma 2, del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134, e' prorogato di un ulteriore triennio.

435. I contratti a tempo determinato stipulati con il personale in servizio presso gli Uffici speciali per la ricostruzione, selezionato all'esito della procedura comparativa pubblica, di cui alle Intese sulla costituzione dell'Ufficio speciale per la citta' dell'Aquila, del 7 agosto 2012, e sulla costituzione dell'Ufficio speciale per i comuni del cratere, del 9-10 agosto 2012, stipulate ai sensi dell'articolo 67-ter, comma 3, del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134, possono essere prorogati per un ulteriore triennio, alle medesime condizioni giuridiche ed economiche, anche in deroga alle vigenti normative in materia di vincoli alle assunzioni a tempo determinato presso le amministrazioni pubbliche. Alle proroghe dei suddetti contratti, eseguite in deroga alla legge, non sono applicabili le sanzioni previste dalla normativa vigente, ivi compresa la sanzione della trasformazione del contratto a tempo indeterminato.

436. Agli oneri derivanti dall'applicazione delle previsioni di cui ai commi 434 e 435, quantificati nel limite di spesa di euro 2.320.000 per ciascuno degli anni 2016, 2017 e 2018, si provvede mediante l'utilizzo delle somme stanziate con la legge 23 dicembre 2014, n. 190, Tabella E, recante il rifinanziamento dell'autorizzazione di spesa dell'articolo 7-bis del decreto-legge 26 aprile 2013, n. 43, convertito, con modificazioni, dalla legge 24 giugno 2013, n. 71, nell'ambito della quota destinata dal CIPE al finanziamento di servizi di natura tecnica e assistenza qualificata, ai sensi del comma 437 dell'articolo 1 della citata legge 23 dicembre 2014, n. 190.

437. Gli oneri di cui al comma 436 comprendono quelli derivanti dalla prosecuzione dell'attivita' dei titolari degli Uffici speciali per la ricostruzione, di cui all'articolo 67-ter, comma 2, del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134, quantificati nel limite di spesa di euro 400.000 per ciascuno degli anni 2016, 2017 e 2018.

438. Al decreto-legge 6 giugno 2012, n. 74, convertito, con modificazioni, dalla legge 1º agosto 2012, n. 122, sono apportate le seguenti modificazioni:

- a) all'articolo 1: 1) al comma 5, dopo la parola: «stessi» sono inserite le seguenti: «, nonche' delle strutture regionali competenti per materia»; 2) al comma 5-bis, dopo la parola: «normativa» sono inserite le seguenti: «nonche' alle strutture regionali competenti per materia»;
- b) all'articolo 4, dopo il comma 5-bis e' inserito il seguente: «5-bis.1. Nell'ambito del piano di cui al comma 1, lettera a), i presidenti delle regioni di cui all'articolo 1, comma 2, possono destinare quota parte delle risorse messe a disposizione per la ricostruzione delle aree terremotate di cui al presente articolo anche per gli interventi di riparazione e ripristino strutturale degli edifici privati inclusi nelle aree cimiteriali ed individuati come cappelle private, al fine di consentire il pieno utilizzo delle strutture cimiteriali»;
- c) all'articolo 5, dopo il comma 1-bis e' inserito il seguente: «1-ter. Nell'ambito del piano di cui all'articolo 4, comma 1, lettera a), e nei limiti delle risorse messe a disposizione dai commi 1 e 1-bis del presente articolo, i Presidenti delle regioni di cui all'articolo 1, comma 2, possono altresi' destinare quota parte delle risorse messe a disposizione dal Ministero dell'istruzione, dell'universita' e della ricerca per la realizzazione di interventi di miglioramento sismico su edifici scolastici o utilizzati per attivita' educativa della prima infanzia e per l'universita' che abbiano subito danni lievi, nel limite delle risorse assegnate per gli interventi specifici».

439. All'articolo 10 del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134, dopo il comma 4 sono inseriti i seguenti: «4-bis. I Commissari delegati consentono l'utilizzo a titolo gratuito a favore delle amministrazioni pubbliche degli edifici temporanei destinati ad attivita' scolastica ovvero a uffici pubblici e delle relative aree di sedime e pertinenziali nonche' dei prefabbricati modulari abitativi. 4-ter. I Commissari delegati provvedono al trasferimento a titolo gratuito dei beni immobili di cui al comma 4-bis a favore delle amministrazioni pubbliche di riferimento. I trasferimenti sono operati mediante adozione di atto ricognitivo con esenzione da ogni effetto fiscale. 4-quater. Il termine di cui al comma 3 dell'articolo 6-sexies del decreto-legge 26 aprile 2013, n. 43, convertito, con modificazioni, dalla legge 24 giugno 2013, n. 71, e' prorogato al 31 dicembre 2016. Al relativo onere si provvede nel limite delle risorse disponibili allo scopo finalizzate sulle contabilita' dei Commissari di cui all'articolo 1, comma 2, del decreto-legge 6 giugno 2012, n. 74, convertito, con modificazioni, dalla legge 1º agosto 2012, n. 122».

440. Al fine di soddisfare le ulteriori esigenze delle popolazioni colpite dal sisma del 20 e 29 maggio 2012, connesse alla necessita' di completare e sostenere ulteriormente la ripresa economica, in favore dei Presidenti delle regioni Lombardia ed Emilia-Romagna, in qualita' di commissari delegati, per il 2016 sono autorizzati 160 milioni di euro in favore dell'Emilia-Romagna e 30 milioni di euro in favore della Lombardia a completamento delle attivita' connesse al processo di ricostruzione pubblica. Ai relativi oneri si provvede mediante riduzione di pari importo dell'autorizzazione di spesa di cui all'articolo 3-bis, comma 6, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135.

441. Per l'anno 2016, nel saldo individuato ai sensi del comma 710 non sono considerate le spese sostenute dagli enti locali individuati ai sensi dell'articolo 1, comma 1, del decreto-legge 6 giugno 2012, n. 74, convertito, con modificazioni, dalla legge 1º agosto 2012, n. 122, e dell'articolo 67-septies del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134, con risorse proprie provenienti da erogazioni liberali e donazioni da parte di cittadini privati e imprese, nonche' da indennizzi derivanti da polizze assicurative, puntualmente finalizzate a fronteggiare gli eccezionali eventi sismici e la ricostruzione, per un importo massimo complessivo di 15 milioni di euro. L'ammontare delle spese da escludere dal saldo di cui al comma 710 ai sensi del periodo precedente e' determinato dalla regione Emilia-Romagna nel limite di 12 milioni di euro e dalle regioni Lombardia e Veneto nel limite di 1,5 milioni di euro per ciascuna regione. Le regioni comunicano al Ministero dell'economia e delle finanze e ai comuni interessati, entro il 30 settembre 2016, gli importi di cui al periodo precedente. Ai relativi oneri si provvede mediante riduzione di pari importo dell'autorizzazione di spesa di cui all'articolo 3-bis, comma 6, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135.

442. Al comma 13 dell'articolo 10 del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134, dopo le parole: «dei capannoni e degli impianti industriali» sono aggiunte le seguenti: «, nonche' delle strutture destinate alla produzione agricola e alle attivita' connesse,».

443. Al fine di soddisfare le ulteriori esigenze derivanti dalla messa in sicurezza, anche attraverso la loro ricostruzione, delle strutture destinate alla produzione agricola situate nei territori dei comuni colpiti dal sisma del 20 e 29 maggio 2012, nonche' per gli scopi di cui alle lettere a), b) e b-bis) del comma 1 dell'articolo 3 del decreto-legge 6 giugno 2012, n. 74, convertito, con modificazioni, dalla legge 1° agosto 2012, n. 122, sono destinati ai presidenti delle regioni Lombardia e Veneto, in qualita' di commissari delegati alla ricostruzione, 3,5 milioni di euro alla regione Lombardia e 1,5 milioni di euro alla regione Veneto per l'anno 2016. Ai relativi oneri si provvede mediante riduzione di pari importo dell'autorizzazione di spesa di cui all'articolo 3-bis, comma 6, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135.

444. Al fine di soddisfare le ulteriori esigenze delle popolazioni colpite dal sisma del 20 e 29 maggio 2012, connesse alla necessita' di completare il processo di ricostruzione, in favore del presidente della regione Lombardia, in qualita' di commissario delegato alla ricostruzione, e' autorizzata la spesa di 70 milioni di euro per il 2016 ai fini del completamento delle attivita' connesse alla ricostruzione privata. Ai relativi oneri si provvede mediante riduzione di pari importo dell'autorizzazione di spesa di cui all'articolo 3-bis, comma 6, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135.

445. Nei comuni della regione Lombardia colpiti dal sisma del 20 e 29 maggio 2012, con zone rosse nei centri storici, e' istituita una zona franca ai sensi dei commi 340 e seguenti dell'articolo 1 della legge 27 dicembre 2006, n. 296. La perimetrazione della zona franca comprende i centri storici o centri abitati dei comuni di San Giacomo delle Segnate, Quingentole, San Giovanni del Dosso, Quistello, San Benedetto Po, Moglia, Gonzaga, Poggio Rusco e Suzzara. (18) (31)

446. Possono beneficiare delle agevolazioni di cui ai commi da 445 a 453 le imprese localizzate all'interno della zona franca di cui al comma 445 con le seguenti caratteristiche:

- a) rispettare la definizione di micro imprese, ai sensi di quanto stabilito dalla raccomandazione 2003/361/CE della Commissione, del 6 maggio 2003, e del decreto del Ministro delle attivita' produttive 18 aprile 2005, pubblicato nella Gazzetta Ufficiale n. 238 del 12 ottobre 2005, e avere avuto nel 2014 un reddito lordo inferiore a 80.000 euro e un numero di addetti inferiore o uguale a cinque;
- b) appartenere ai settori di attivita' individuati dai codici ATECO 45, 46, 47, 55, 56, 79, 93, 95 e 96;
- c) essere gia' costituite alla data di presentazione dell'istanza presentata in base a quanto stabilito dal decreto di cui al comma 453, purche' la data di costituzione dell'impresa non sia successiva al 31 dicembre 2014;
- d) svolgere la propria attivita' all'interno della zona franca, ai sensi di quanto previsto al comma 448;
- e) essere nel pieno e libero esercizio dei propri diritti civili, non essere in liquidazione volontaria o sottoposte a procedure concorsuali. (18) (31)

447. Gli aiuti di Stato corrispondenti all'ammontare delle agevolazioni di cui ai commi da 445 a 453 sono concessi ai sensi e nei limiti del regolamento (UE) n. 1407/ 2013 della Commissione, del 18 dicembre 2013, relativo all'applicazione degli articoli 107 e 108 del Trattato sul funzionamento dell'Unione europea agli aiuti «de minimis» e del regolamento (UE) n. 1408/2013 della Commissione, del 18 dicembre 2013, relativo all'applicazione degli articoli 107 e 108 del Trattato sul funzionamento dell'Unione europea agli aiuti «de minimis» nel settore agricolo. (18) (31)

448. Per accedere alle agevolazioni di cui ai commi da 445 a 453, i soggetti individuati ai sensi dei commi 445 e 446 devono avere la sede principale o l'unita' locale all'interno della zona franca e rispettare i limiti e le procedure previsti dai regolamenti dell'Unione europea di cui al comma 447. (18) (31)

449. Il rispetto di quanto previsto al comma 448 e' attestato mediante dichiarazione sostitutiva dell'atto di notorieta', ai sensi dell'articolo 47 del testo unico di cui al decreto del Presidente della Repubblica 28 dicembre 2000, n. 445. (18) (31)

450. I soggetti di cui ai commi 445 e 446 possono beneficiare, nel rispetto del comma 447 nonche' del limite previsto al comma 451 e delle risorse finanziarie di cui al comma 452, delle seguenti agevolazioni:

- a) esenzione dalle imposte sui redditi del reddito derivante dallo svolgimento dell'attivita' svolta dall'impresa nella zona franca fino a concorrenza dell'importo di euro 100.000 per ciascun periodo d'imposta;
- b) esenzione dall'imposta regionale sulle attivita' produttive del valore della produzione netta derivante dallo svolgimento dell'attivita' svolta dall'impresa nella zona franca nel limite di euro 300.000 per ciascun periodo d'imposta;
- c) esenzione dalle imposte municipali proprie per gli immobili siti nella zona franca, posseduti e utilizzati dai soggetti di cui al comma 446 per l'esercizio dell'attivita' economica. (18) (31)

451. Le esenzioni di cui al comma 450 sono concesse esclusivamente per il periodo d'imposta in corso alla data di entrata in vigore della presente legge. (18) (31)

452. Per le finalita' di cui ai commi da 445 a 453, l'autorizzazione di spesa di cui all'articolo 22-bis, comma 1, del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, e' incrementata di 5 milioni di euro nell'anno 2016. Al relativo onere, pari a 5 milioni di euro per l'anno 2016, si provvede mediante corrispondente riduzione di pari importo dell'autorizzazione di spesa di cui all'articolo 3-bis, comma 6, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135. Le somme di cui al primo periodo non utilizzate nell'esercizio 2017 possono esserlo in quello successivo, per le medesime finalita' di cui ai commi da 445 a 453, nel limite di 750.000 euro annui per ciascuno degli anni 2018 e 2019. (18) (31)

453. Per l'attuazione degli interventi di cui ai commi da 445 a 452, si applicano, in quanto compatibili, le disposizioni del decreto del Ministro dello sviluppo economico 10 aprile 2013, pubblicato nella Gazzetta Ufficiale n. 161 dell'11 luglio 2013. (18) (31)

454. All'articolo 5 del decreto-legge 5 maggio 2015, n. 51, convertito, con modificazioni, dalla legge 2 luglio 2015, n. 91, sono apportate le seguenti modificazioni:

- a) al comma 2, le parole: «entro il termine perentorio di sessanta giorni dall'entrata in vigore del presente decreto» sono sostituite dalle seguenti: «entro il termine perentorio del 29 febbraio 2016»;
- b) al comma 3-bis: 1) al secondo periodo, le parole da: «e la data di entrata in vigore del presente decreto» fino a: «legge di conversione del presente decreto» sono sostituite dalle seguenti: «e il 31 luglio 2015, individuati ai sensi del comma 4 del citato articolo 14 del decreto legislativo n. 154 del 2004, e successive modificazioni, possono presentare domanda, entro il 29 febbraio 2016»; 2) dopo il secondo periodo sono inseriti i seguenti: «E' data priorita' alle domande delle imprese che hanno subito un maggior danno. Con decreto del Ministro delle politiche agricole alimentari e forestali sono individuati i criteri di priorita' per l'assegnazione del contributo alle aziende danneggiate ».

455. Al fine di coordinare le politiche di finanziamento nazionali del settore ittico, le disposizioni di cui all'articolo 17 del decreto legislativo 29 marzo 2004, n. 102, e all'articolo 1, comma 512, della legge 30 dicembre 2004, n. 311, si applicano in favore delle imprese della pesca e dell'acquacoltura anche a valere sulle risorse europee del Fondo europeo per gli affari marittimi e per la pesca (FEAMP) di cui al regolamento (UE) n. 508/2014 del Parlamento europeo e del Consiglio, del 15 maggio 2014.

456. Per gli enti locali colpiti dal sisma del 20 e 29 maggio 2012, individuati ai sensi dell'articolo 1, comma 1, del decreto-legge 6 giugno 2012, n. 74, convertito, con modificazioni, dalla legge 1º agosto 2012, n. 122, e dell'articolo 67-septies del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134, gli oneri relativi al pagamento delle rate dei mutui concessi dalla Cassa depositi e prestiti Spa, trasferiti al Ministero dell'economia e delle finanze in attuazione dell'articolo 5, commi 1 e 3, del decreto-legge 30 settembre 2003, n. 269, convertito, con modificazioni, dalla legge 24 novembre 2003, n. 326, da corrispondere nell'anno 2016, ad esclusione di quelle il cui pagamento e' stato differito ai sensi dell'articolo 1, comma 426, della legge 24 dicembre 2012, n. 228, e dell'articolo 1, comma 356, della legge 27 dicembre 2013, n. 147, sono pagati, senza applicazione di sanzioni e interessi, a decorrere dall'anno 2017, in rate di pari importo per dieci anni sulla base della periodicita' di pagamento prevista nei provvedimenti e nei contratti regolanti i mutui stessi. Ai relativi oneri, pari a 5,2 milioni di euro per l'anno 2016 e a 4,5 milioni di euro per l'anno 2017, si provvede con le risorse delle contabilita' speciali, di cui all'articolo 2, comma 6, del decreto-legge 6 giugno 2012, n. 74, convertito, con modificazioni, dalla legge 1º agosto 2012, n. 122, che sono versate all'entrata del bilancio dello Stato. (15) (31) (43) (71)

457. Al comma 436 dell'articolo 1 della legge 23 dicembre 2014, n. 190, le parole: «Per l'anno 2015» sono sostituite dalle seguenti: «Per gli anni 2015 e 2016».

458. Alla Prefettura - Ufficio territoriale del Governo di Salerno e' assegnata la somma di 7,5 milioni di euro per ciascuno degli anni 2016 e 2017 per la stipulazione delle transazioni di cui al comma 462, relativamente all'alluvione verificatasi il 5 maggio 1998 a Sarno. Le somme non impegnate nel 2016 possono esserlo nell'esercizio successivo.

459. La Prefettura - Ufficio territoriale del Governo di Salerno, nei limiti dell'autorizzazione di spesa di cui al comma 458, individua i familiari delle vittime, entro il 31 dicembre 2016, e determina, avvalendosi a tal fine anche dell'INPS, dell'INAIL e di altri enti competenti in materia infortunistica e previdenziale, la somma spettante, nel limite di euro 100.000 per ciascuna delle vittime, nonche' la quota di rimborso delle eventuali spese legali sostenute e documentate. Il rimborso delle spese legali e' definito previa acquisizione del parere di congruita' dell'Avvocatura dello Stato.

460. Le elargizioni di cui al comma 458 spettanti ai familiari delle vittime sono assegnate e corrisposte secondo il seguente ordine:

- a) al coniuge superstite, con esclusione del coniuge rispetto al quale sia stata pronunciata sentenza anche non definitiva di scioglimento o di cessazione degli effetti civili del matrimonio e del coniuge cui sia stata addebitata la separazione con sentenza passata in giudicato, e ai figli se a carico;
- b) ai figli, in mancanza del coniuge superstite o nel caso di coniuge rispetto al quale sia stata pronunciata sentenza anche non definitiva di scioglimento o di cessazione degli effetti civili del matrimonio o di coniuge cui sia stata addebitata la separazione con sentenza passata in giudicato;
- c) ai genitori;
- d) ai fratelli e alle sorelle se conviventi a carico;
- e) ai conviventi a carico negli ultimi tre anni precedenti l'evento;
- f) al convivente more uxorio.

461. Qualora sia intervenuto il decesso dei soggetti beneficiari ai sensi del comma 460, gli eredi in successione legittima hanno diritto al pagamento pro quota della medesima somma, nei limiti individuati ai sensi dei commi 459 e 460, previa presentazione di documentazione attestante la qualita' di erede e la quota di partecipazione all'asse ereditario, secondo le disposizioni vigenti in materia di successione legittima.

462. La Prefettura - Ufficio territoriale del Governo di Salerno, acquisito il parere dell'Avvocatura dello Stato ai sensi dell'articolo 14 del regio decreto 18 novembre 1923, n. 2440, congiuntamente con il Comune di Sarno stipula appositi atti transattivi con i soggetti individuati ai sensi del comma 460 o, ove questi ultimi siano deceduti, con i soggetti di cui al comma 461, ferma restando l'applicazione delle norme vigenti in materia di prescrizione.

463. Le transazioni di cui al comma 462 sono stipulate a totale soddisfazione di ogni pretesa nei confronti delle Amministrazioni statali e territoriali individuate nella sentenza della Corte di cassazione penale del 7 maggio 2013 e tengono conto di quanto eventualmente gia' percepito a seguito di sentenze riguardanti la responsabilita' civile dello Stato e del comune di Sarno.

464. I procedimenti giudiziari in corso, anche in sede di esecuzione, sono sospesi fino alla conclusione degli accordi transattivi. Successivamente alla stipulazione degli atti, di transazione, che deve intervenire entro e non oltre il 31 dicembre 2017, tutti i processi sono estinti ai sensi della normativa vigente. Ove le parti private non intendano stipulare gli accordi transattivi ne danno comunicazione scritta alla Prefettura - Ufficio territoriale del Governo di Salerno e i processi in corso proseguono su istanza delle parti. Le transazioni sono esenti da ogni imposta o tassa e le relative somme sono assegnate in aggiunta a ogni altra somma cui i soggetti beneficiari abbiano diritto a qualsiasi titolo ai sensi della normativa vigente. Dopo la stipulazione degli atti transattivi la Prefettura - Ufficio territoriale del Governo di Salerno trasmette un elenco riepilogativo al Ministero dell'interno e al Ministero dell'economia e delle finanze.

465. Al comune di Sarno e' riconosciuto un trasferimento straordinario di 1 milione di euro per ciascuno degli anni 2016 e 2017, a compensazione di quanto gia' erogato ai familiari delle vittime a seguito di sentenze riguardanti la responsabilita' civile dello Stato e del comune stesso.

466. Per il triennio 2016-2018, in applicazione dell'articolo 48, comma 1, del decreto legislativo 30 marzo 2001, n. 165, e per i miglioramenti economici del personale dipendente dalle amministrazioni statali in regime di diritto pubblico, gli oneri posti a carico del bilancio statale sono quantificati, complessivamente, in 300 milioni di euro a decorrere dall'anno 2016.

467. Le somme di cui al comma 466, comprensive degli oneri contributivi ai fini previdenziali e dell'imposta regionale sulle attivita' produttive (IRAP) di cui al decreto legislativo 15 dicembre 1997, n. 446, concorrono a costituire l'importo complessivo massimo di cui all'articolo 11, comma 3, lettera g), della legge 31 dicembre 2009, n. 196.

468. Al decreto legislativo 30 marzo 2001, n. 165, sono apportate le seguenti modificazioni:

- a) all'articolo 41, comma 2, primo periodo, le parole: «, per uno dei comparti di cui all'articolo 40, comma 2,» sono soppresse;
- b) all'articolo 41, comma 2, secondo periodo, le parole: «, per uno dei comparti di cui all'articolo 40, comma 2,» sono soppresse;
- c) all'articolo 41, comma 5, dopo le parole: «istituti comuni a piu' comparti» sono inserite le seguenti: «o che si applicano a un comparto per il quale operano piu' comitati di settore».

469. Per il personale dipendente da amministrazioni, istituzioni ed enti pubblici diversi dall'amministrazione statale, gli oneri per i rinnovi contrattuali per il triennio 2016-2018, nonche' quelli derivanti dalla corresponsione dei miglioramenti economici al personale di cui all'articolo 3, comma 2, del decreto legislativo 30 marzo 2001, n. 165, sono posti a carico dei rispettivi bilanci ai sensi dell'articolo 48, comma 2, del medesimo decreto legislativo n. 165 del 2001. Con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro per la semplificazione e la pubblica amministrazione, di concerto con il Ministro dell'economia e delle finanze, da emanare entro trenta giorni dalla data di entrata in vigore della presente legge, sono fissati i criteri di determinazione dei predetti oneri in coerenza con quanto previsto dal comma 466.

470. Le disposizioni recate dal comma 469 si applicano anche al personale convenzionato con il Servizio sanitario nazionale.

471. Al fine di assicurare l'omogenea applicazione sul territorio di riferimento di quanto previsto, in materia di personale, dall'articolo 5 dell'intesa concernente l'attribuzione di funzioni statali e dei relativi oneri finanziari riferiti al Parco nazionale dello Stelvio, ai sensi dell'articolo 1, comma 515, della legge 27 dicembre 2013, n. 147, e dell'articolo 11, comma 8, del decreto-legge 24 giugno 2014, n. 91, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 116, la regione Lombardia o l'ente dalla stessa individuato provvede, nel rispetto delle limitazioni assunzionali e finanziarie vigenti in materia di personale, ad attivare procedure concorsuali pubbliche, prevedendo nei bandi il riconoscimento dell'esperienza maturata da parte del personale gia' dipendente al 31 dicembre 2013 dal Consorzio del Parco nazionale dello Stelvio da almeno dieci anni, con mansioni impiegatizie, amministrative, tecniche, scientifiche e didattiche di educazione ambientale, in esito a procedure diverse da quelle previste per l'accesso al pubblico impiego.

472. Al fine di assicurare, anche in relazione alle straordinarie esigenze di prevenzione e contrasto alla criminalita' ed al terrorismo, la prosecuzione degli interventi di cui all'articolo 24, commi 74 e 75, del decreto-legge 1º luglio 2009, n. 78, convertito, con modificazioni, dalla legge 3 agosto 2009, n. 102, nonche' di quelli previsti dall'articolo 3, comma 2, del decreto-legge 10 dicembre 2013, n. 136, convertito, con modificazioni, dalla legge 6 febbraio 2014, n. 6, e' prorogato, limitatamente ai servizi di vigilanza a siti ed obiettivi sensibili, fino al 31 dicembre 2016, l'impiego di un contingente pari a 4.800 unita' di personale delle Forze armate. Si applicano le disposizioni di cui all'articolo 7-bis, commi 1, 2 e 3, del decreto-legge 23 maggio 2008, n. 92, convertito, con modificazioni, dalla legge 24 luglio 2008, n. 125.

473. Ai fini dell'attuazione del comma 472, e' autorizzata, per gli interventi di cui all'articolo 24, commi 74 e 75, del decreto-legge 1º luglio 2009, n. 78, convertito, con modificazioni, dalla legge 3 agosto 2009, n. 102, nonche' di quelli di cui all'articolo 3, comma 2, del decreto-legge 10 dicembre 2013, n. 136, convertito, con modificazioni, dalla legge 6 febbraio 2014, n. 6, la spesa di euro 83.000.000 per l'anno 2016, con specifica destinazione di euro 81.100.000 per il personale di cui al comma 74 e di euro 1.900.000 per il personale di cui al comma 75 dell'articolo 24 del decreto-legge 1º luglio 2009, n. 78, convertito, con modificazioni, dalla legge 3 agosto 2009, n. 102, al cui onere si provvede, nel limite di 10 milioni di euro, mediante corrispondente riduzione dell'autorizzazione di spesa di cui all'articolo 1, comma 199, della legge 23 dicembre 2014, n. 190, gia' destinata alla prosecuzione del concorso delle Forze armate alle operazioni di sicurezza e di controllo del territorio, per l'anno 2016.

474. Entro il 31 marzo 2016 il Ministro dell'interno provvede alla ricognizione del personale di polizia assegnato a funzioni di carattere amministrativo ovvero di scorta personale, onde valutarne, nel rispetto dell'ordinamento vigente e presso le sedi competenti, l'assegnazione ad operazioni di sicurezza e controllo del territorio, al fine di una gestione efficiente ed efficace delle risorse organiche, anche in relazione alle contingenti esigenze di sicurezza nazionale.

475. Nello stato di previsione del Ministero dell'economia e delle finanze, e' istituito un fondo con una dotazione di 150 milioni di euro per ciascuno degli anni 2016 e 2017, finalizzato ad interventi di carattere economico, sociale e ambientale nei territori della terra dei fuochi e, nel limite massimo di 3 milioni di euro per ciascun anno considerato, di bonifica del sito inquinato dell'ex area industriale «Isochimica». Con decreto del Presidente del Consiglio dei ministri, da emanare entro novanta giorni dalla data di entrata in vigore della presente legge, sono individuati gli interventi e le amministrazioni competenti cui destinare le predette somme. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare con propri decreti le occorrenti variazioni di bilancio.

476. Al fine di contribuire all'attuazione dei necessari interventi urgenti di messa in sicurezza e bonifica dei siti contaminati, per garantire la maggior tutela dell'ambiente e della salute pubblica, nello stato di previsione del Ministero dell'ambiente e della tutela del territorio e del mare e' istituito un fondo con una dotazione di 10 milioni di euro per ciascuno degli anni 2016, 2017 e 2018, di cui 5 milioni di euro per ciascuno degli anni 2016 e 2017 destinati agli interventi di bonifica del sito di interesse nazionale Valle del Sacco e i restanti 5 milioni di euro per ciascuno degli anni 2016 e 2017 e 10 milioni di euro per l'anno 2018 da destinare con priorita' ai siti di interesse nazionale per i quali e' necessario provvedere con urgenza al corretto adempimento di obblighi europei.

477. Al fine di studiare e valutare gli effetti dei cambiamenti climatici, mediante la realizzazione di modelli del sistema climatico italiano e delle sue interazioni con la societa' e l'ambiente, attraverso le attivita' di ricerca svolte dalla grande infrastruttura di ricerca, gia' denominata «Centro euro-mediterraneo per i cambiamenti climatici», nonche' per la valorizzazione degli investimenti effettuati con la delibera CIPE n. 42 del 13 maggio 2010, e' autorizzato, a decorrere dall'anno 2016, un contributo annuo di 5 milioni di euro.

478. All'articolo 39-bis, comma 1, del decreto-legge 1º ottobre 2007, n. 159, convertito, con modificazioni, dalla legge 29 novembre 2007, n. 222, dopo le parole: «della legge 24 dicembre 2003, n. 350,» sono inserite le seguenti: «e di corrispettivi a carico delle societa' di gestione aeroportuale relativamente ai servizi antincendi negli aeroporti, di cui all'articolo 1, comma 1328, della legge 27 dicembre 2006, n. 296,». (35)

479. Al fine di assicurare la piena ed efficace realizzazione degli obiettivi istituzionali perseguiti, non si applicano alle federazioni sportive nazionali affiliate al Comitato olimpico nazionale italiano (CONI) e all'ENIT-Agenzia nazionale del turismo le norme di contenimento delle spese previste dalla legislazione vigente a carico dei soggetti inclusi nell'elenco dell'Istituto nazionale di statistica (ISTAT) delle amministrazioni pubbliche di cui all'articolo 1 della legge 31 dicembre 2009, n. 196, e successive modificazioni. All'attuazione della disposizione di cui al precedente periodo si provvede nell'ambito degli stanziamenti autorizzati a legislazione vigente.

480. Lo stanziamento di cui all'articolo 5 della legge 26 gennaio 1963, n. 91, e' fissato in 1 milione di euro annui a decorrere dall'anno 2016.

481. Al fine di fare fronte alle spese per la costituzione e il funzionamento dei collegi arbitrali internazionali inseriti nelle clausole di arbitrato internazionale dei trattati sottoscritti dallo Stato italiano o, per esso, dall'Unione europea, a decorrere dall'esercizio finanziario 2016, nello stato di previsione del Ministero dell'economia e delle finanze e' istituito un apposito fondo denominato «Fondo per le spese di costituzione e funzionamento dei collegi arbitrali internazionali». A tal fine e' autorizzata la spesa di 1 milione di euro a decorrere dall'anno 2016. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

482. Al fine di consentire la promozione e lo svolgimento delle iniziative funzionali alle celebrazioni del settantesimo anniversario della nascita della Repubblica italiana, del settantesimo anniversario della Costituzione della Repubblica italiana e del riconoscimento dei diritti elettorali delle donne nonche' del centenario della nascita di Aldo Moro e' autorizzata la spesa di 3 milioni di euro per l'anno 2016 e di 2,5 milioni di euro per ciascuno degli anni 2017 e 2018.

483. A decorrere dall'anno 2016 e' autorizzata l'ulteriore spesa di 1 milione di euro annui in favore delle istituzioni culturali di cui all'articolo 1 della legge 17 ottobre 1996, n. 534.

484. Fino al complessivo riordino della disciplina dei canoni demaniali marittimi, i procedimenti amministrativi pendenti alla data del 15 novembre 2015, avviati dalle amministrazioni competenti per la sospensione, la revoca e la decadenza di concessioni demaniali marittime con finalita' turistico-ricreative, con esclusivo riferimento a quelle inerenti alla conduzione delle pertinenze demaniali, derivanti da procedure di contenzioso connesse all'applicazione dei criteri per il calcolo dei canoni di cui all'articolo 03, comma 1, del decreto-legge 5 ottobre 1993, n. 400, convertito, con modificazioni, dalla legge 4 dicembre 1993, n. 494, come sostituito dall'articolo 1, comma 251, della legge 27 dicembre 2006, n. 296, sono sospesi. La disposizione di cui al presente comma non si applica per i beni pertinenziali che risultano comunque oggetto di procedimenti giudiziari di natura penale, nonche' nei comuni e nei municipi sciolti o commissariati ai sensi degli articoli 143 e 146 del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267.

485. All'articolo 8, comma 13-septies, del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125, e' aggiunto, in fine, il seguente periodo: «Nelle more dell'attuazione del primo periodo e, comunque, non oltre il 30 giugno 2016, le risorse di cui al presente comma possono essere utilizzate nel limite di 6,5 milioni di euro per assicurare i servizi di collegamento marittimo attualmente convenzionato con la regione anche tramite la prosecuzione del contratto con la marittima SAREMAR S.p.A.».

486. COMMA ABROGATO DALLA L. 27 DICEMBRE 2019, N. 160. (47)

487. All'articolo 10, comma 1, del decreto-legge 31 dicembre 2014, n. 192, convertito, con modificazioni, dalla legge 27 febbraio 2015, n. 11, le parole: «31 dicembre 2015» sono sostituite dalle seguenti: «31 dicembre 2016».

488. La durata della contabilita' speciale n. 5458 di cui all'articolo 1, comma 5, dell'ordinanza del Capo del Dipartimento della protezione civile n. 43 del 24 gennaio 2013, pubblicata nella Gazzetta Ufficiale n. 28 del 2 febbraio 2013, come prorogata dal comma 364 dell'articolo 1 della legge 27 dicembre 2013, n. 147, e' ulteriormente prorogata fino al 31 dicembre 2016, anche al fine di attuare interventi urgenti per la messa in sicurezza del territorio contro i rischi derivanti dal dissesto idrogeologico, cui provvede, d'intesa con il titolare della contabilita' speciale n. 5458, a valere sulle risorse disponibili della medesima contabilita', il commissario straordinario delegato per il rischio idrogeologico nel Veneto, di cui all'articolo 10 del decreto-legge 24 giugno 2014, n. 91, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 116.

489. L'autorizzazione di spesa di cui all'articolo 1, comma 1063, della legge 27 dicembre 2006, n. 296, e' rifinanziata per l'importo di 1 milione di euro per l'anno 2016 e di 4 milioni di euro per l'anno 2017, quale dotazione del fondo per la razionalizzazione e la riconversione della produzione bieticolo-saccarifera in Italia per il quinto anno del quinquennio previsto dalla normativa europea. Agli oneri derivanti dall'attuazione della disposizione di cui al primo periodo si provvede, quanto a 1 milione di euro per l'anno 2016 e a 4 milioni di euro per l'anno 2017, mediante utilizzo del fondo di conto capitale iscritto nello stato di previsione del Ministero delle politiche agricole alimentari e forestali ai sensi dell'articolo 49, comma 2, lettera d), del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89.

490. Il Programma nazionale triennale della pesca e dell'acquacoltura vigente, di cui all'articolo 2, comma 5-decies, del decreto-legge 29 dicembre 2010, n. 225, convertito, con modificazioni, dalla legge 26 febbraio 2011, n. 10, adottato con decreto del Ministro delle politiche agricole alimentari e forestali 31 gennaio 2013, pubblicato nel supplemento ordinario alla Gazzetta Ufficiale n. 141 del 18 giugno 2013, e' prorogato al 31 dicembre 2016.

491. Al fine di provvedere al miglioramento delle condizioni di sicurezza, in particolare sanitarie, per le specifiche esigenze dei reparti operativi del Raggruppamento subacquei e incursori «Teseo Tesei» (COM-SUBIN) della Marina militare, posto alle dipendenze del Comando interforze operazioni forze speciali - CO.F.S. dello Stato maggiore della Difesa, e' autorizzata una spesa di 1.000.000 di euro per l'anno 2016.

492. All'articolo 19 del decreto legislativo 13 marzo 2013, n. 30, il comma 5 e' sostituito dal seguente: «5. Il 50 per cento dei proventi derivanti dalle singole aste e' riassegnato con i decreti di cui al comma 3 ad apposito capitolo di spesa dello stato di previsione del Ministero dello sviluppo economico, ai fini di cui al comma 5 dell'articolo 2 del decreto-legge 20 maggio 2010, n. 72, convertito, con modificazioni, dalla legge 19 luglio 2010, n. 111, sino a concorrenza dei crediti previsti dal comma 3 dell'articolo 2 del citato decreto-legge n. 72 del 2010. A seguito del completamento dei rimborsi di tali crediti la quota di detti proventi e' riassegnata, ai sensi dell'articolo 25, comma 1, del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, al Fondo per l'ammortamento dei titoli di Stato, di cui all'articolo 44 del testo unico di cui al decreto del Presidente della Repubblica 30 dicembre 2003, n. 398, e successive modificazioni».

493. Al fine di mantenere l'efficienza delle strutture della Marina militare di Taranto e' autorizzata la spesa di 1,5 milioni di euro per ciascuno degli anni 2016, 2017 e 2018, da destinare ai servizi di pulizia e manovalanza.

494. All'articolo 1, comma 7, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, il terzo e il quarto periodo sono sostituiti dai seguenti: «E' fatta salva la possibilita' di procedere ad affidamenti, nelle indicate categorie merceologiche, anche al di fuori delle predette modalita', a condizione che gli stessi conseguano ad approvvigionamenti da altre centrali di committenza o a procedure di evidenza pubblica, e prevedano corrispettivi inferiori almeno del 10 per cento per le categorie merceologiche telefonia fissa e telefonia mobile e del 3 per cento per le categorie merceologiche carburanti extra-rete, carburanti rete, energia elettrica, gas e combustibili per il riscaldamento rispetto ai migliori corrispettivi indicati nelle convenzioni e accordi quadro messi a disposizione da Consip SpA e dalle centrali di committenza regionali. Tutti i contratti stipulati ai sensi del precedente periodo devono essere trasmessi all'Autorita' nazionale anticorruzione. In tali casi i contratti dovranno comunque essere sottoposti a condizione risolutiva con possibilita' per il contraente di adeguamento ai migliori corrispettivi nel caso di intervenuta disponibilita' di convenzioni Consip e delle centrali di committenza regionali che prevedano condizioni di maggior vantaggio economico in percentuale superiore al 10 per cento rispetto ai contratti gia' stipulati. Al fine di concorrere al raggiungimento degli obiettivi di finanza pubblica attraverso una razionalizzazione delle spese delle pubbliche amministrazioni riguardanti le categorie merceologiche di cui al primo periodo del presente comma, in via sperimentale, dal 1º gennaio 2017 al 31 dicembre 2019 non si applicano le disposizioni di cui al terzo periodo del presente comma».

495. All'articolo 1 della legge 27 dicembre 2006, n. 296, sono apportate le seguenti modificazioni:

- a) al comma 449, dopo le parole: «le istituzioni universitarie,» sono inserite le seguenti: «nonche' gli enti nazionali di previdenza e assistenza sociale pubblici e le agenzie fiscali di cui al decreto legislativo 30 luglio 1999, n. 300,»;
- b) al comma 450, dopo le parole: «delle istituzioni universitarie,» sono inserite le seguenti: «nonche' gli enti nazionali di previdenza e assistenza sociale pubblici e le agenzie fiscali di cui al decreto legislativo 30 luglio 1999, n. 300,».

496. All'articolo 2, comma 573, della legge 24 dicembre 2007, n. 244, le parole: «, i soggetti aggiudicatori di cui all'articolo 3, comma 25,» sono sostituite dalle seguenti: «, le stazioni appaltanti di cui all'articolo 3, comma 33,».

497. All'articolo 2 della legge 23 dicembre 2009, n. 191, sono apportate le seguenti modificazioni:

- a) al comma 225, primo periodo, le parole: «le amministrazioni pubbliche di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni, e le amministrazioni aggiudicatrici di cui all'articolo 3, comma 25» sono sostituite dalle seguenti: «le stazioni appaltanti di cui all'articolo 3, comma 33» e, al secondo periodo, le parole: «medesime amministrazioni» sono sostituite dalle seguenti: «medesime stazioni appaltanti»;
- b) al comma 225, sono aggiunte, in fine, le seguenti parole: «e comunque quanto previsto dalla normativa in tema di obblighi di approvvigionarsi attraverso gli strumenti messi a disposizione da Consip SpA».

498. Le societa' controllate dallo Stato e dagli enti locali che siano organismi di diritto pubblico ai sensi dell'articolo 3, comma 26, del codice di cui al decreto legislativo 12 aprile 2006, n. 163, ad eccezione di quelle che emettono strumenti finanziari quotati nei mercati regolamentati, utilizzano i parametri di prezzo-qualita' di cui all'articolo 26, comma 3, della legge 23 dicembre 1999, n. 488.

499. All'articolo 9 del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, sono apportate le seguenti modificazioni:

- a) al comma 2, dopo il primo periodo, e' inserito il seguente: «I soggetti aggregatori di cui al presente comma possono stipulare, per gli ambiti territoriali di competenza, le convenzioni di cui all'articolo 26, comma 1, della legge 23 dicembre 1999, n. 488, e successive modificazioni. L'ambito territoriale di competenza dei soggetti di cui al presente comma coincide con la regione di riferimento esclusivamente per le categorie merceologiche e le soglie individuate con il decreto del Presidente del Consiglio dei ministri di cui al comma 3»;
- b) al comma 3, le parole: «Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano» sono sostituite dalle seguenti: «Conferenza unificata»;
- c) al comma 3, le parole: «l'Autorita' per la vigilanza sui contratti pubblici di lavori, servizi e forniture» sono sostituite dalle seguenti: «l'Autorita' nazionale anticorruzione»;
- d) al comma 3, dopo le parole: «gli enti regionali,» sono inserite le seguenti: «gli enti locali di cui all'articolo 2 del decreto legislativo 18 agosto 2000, n. 267,»;
- e) al comma 3, le parole: «di cui al periodo precedente, l'Autorita' per la vigilanza sui contratti pubblici di lavori, servizi e forniture» sono sostituite dalle seguenti: «di cui al periodo precedente, l'Autorita' nazionale anticorruzione».

500. All'articolo 3 del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, dopo il comma 4 e' inserito il seguente: «4-bis. Per le caserme delle Forze dell'ordine e del Corpo nazionale dei vigili del fuoco ospitate presso proprieta' private, i comuni appartenenti al territorio di competenza delle stesse possono contribuire al pagamento del canone di locazione come determinato dall'Agenzia delle entrate».

501. All'articolo 23-ter, comma 3, del decreto-legge 24 giugno 2014, n. 90, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 114, sono apportate le seguenti modificazioni:

- a) sono premesse le seguenti parole: «Fermi restando l'articolo 26, comma 3, della legge 23 dicembre 1999, n. 488, l'articolo 1, comma 450, della legge 27 dicembre 2006, n. 296, e l'articolo 9, comma 3, del decreto-legge 24 aprile 2014, n. 66,»;
- b) le parole: «con popolazione superiore a 10.000 abitanti» sono soppresse.

502. All'articolo 1, comma 450, della legge 27 dicembre 2006, n. 296, sono apportate le seguenti modificazioni:

- a) le parole: «Dal 1º luglio 2007,» sono soppresse;
- b) al primo periodo, dopo le parole: «per gli acquisti di beni e servizi» sono inserite le seguenti: «di importo pari o superiore a 1.000 euro e»;
- c) al secondo periodo, dopo le parole: «per gli acquisti di beni e servizi di importo » sono inserite le seguenti: «pari o superiore a 1.000 euro e».

503. All'articolo 15, comma 13, lettera d), del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, dopo le parole: «per l'acquisto di beni e servizi» sono aggiunte le seguenti: «di importo pari o superiore a 1.000 euro».

504. All'articolo 4, comma 3-ter, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, dopo il primo periodo e' inserito il seguente: «Ferme restando le disposizioni di cui all'articolo 12, commi da 2 a 10, del decreto-legge 6 luglio 2011, n. 98, convertito, con modificazioni, dalla legge 15 luglio 2011, n. 111, gli strumenti di acquisto e di negoziazione messi a disposizione da Consip S.p.A. possono avere ad oggetto anche attivita' di manutenzione».

505. COMMA ABROGATO DAL D.LGS. 18 APRILE 2016, N. 50, COME MODIFICATO DAL D.LGS. 19 APRILE 2017, N. 56.

506. Il versamento al capitolo dell'entrata del bilancio dello Stato previsto per i risparmi conseguiti a seguito dell'applicazione delle norme che prevedono riduzioni di spesa per le amministrazioni inserite nel conto economico consolidato della pubblica amministrazione, come individuate dall'Istituto nazionale di statistica (ISTAT) ai sensi del comma 3 dell'articolo 1 della legge 31 dicembre 2009, n. 196, con riferimento alle societa' e' da intendersi come versamento da effettuare in sede di distribuzione del dividendo, ove nel corso dell'esercizio di riferimento la societa' abbia conseguito un utile e nei limiti dell'utile distribuibile ai sensi di legge. Ai fini di cui al precedente periodo, in sede di approvazione del bilancio di esercizio, i soggetti che esercitano i poteri dell'azionista deliberano, in presenza di utili di esercizio, la distribuzione di un dividendo almeno corrispondente al risparmio di spesa evidenziato nella relazione sulla gestione ovvero per un importo inferiore qualora l'utile distribuibile non risulti capiente.

507. Il Ministro dell'economia e delle finanze definisce, con proprio decreto, sentita l'Autorita' nazionale anticorruzione, tenendo conto degli aspetti maggiormente incidenti sul prezzo della prestazione nonche' degli aspetti qualificanti ai fini del soddisfacimento della domanda pubblica, le caratteristiche essenziali delle prestazioni principali che saranno oggetto delle convenzioni stipulate da Consip SpA ai sensi dell'articolo 26 della legge 23 dicembre 1999, n. 488. Conseguentemente all'attivazione delle convenzioni di cui al periodo precedente, sono pubblicati nel sito istituzionale del Ministero dell'economia e delle finanze e nel portale degli acquisti in rete i valori delle caratteristiche essenziali e i relativi prezzi, che costituiscono i parametri di prezzo-qualita' di cui all'articolo 26, comma 3, della legge 23 dicembre 1999, n. 488.

508. Nei casi di indisponibilita' della convenzione stipulata da Consip SpA ai sensi dell'articolo 26 della legge 23 dicembre 1999, n. 488, ed in mancanza dei prezzi di riferimento forniti dall'Autorita' nazionale anticorruzione ai sensi dell'articolo 9, comma 7, del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, la predetta Autorita', sentito il Ministero dell'economia e delle finanze, individua, con proprio provvedimento, le modalita' per l'elaborazione adeguativa dei prezzi della precedente edizione della convenzione stipulata da Consip SpA. I prezzi forniti dall'Autorita' ai sensi del periodo precedente costituiscono prezzo massimo di aggiudicazione per il periodo temporale indicato dall'Autorita' medesima.

509. All'articolo 9, comma 7, del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, le parole da: «nelle more del perfezionamento» fino a: «la predetta Autorita',» sono sostituite dalle seguenti: «l'Autorita' nazionale anticorruzione,».

510. Le amministrazioni pubbliche obbligate ad approvvigionarsi attraverso le convenzioni di cui all'articolo 26 della legge 23 dicembre 1999, n. 488, stipulate da Consip SpA, ovvero dalle centrali di committenza regionali, possono procedere ad acquisti autonomi esclusivamente a seguito di apposita autorizzazione specificamente motivata resa dall'organo di vertice amministrativo e trasmessa al competente ufficio della Corte dei conti, qualora il bene o il servizio oggetto di convenzione non sia idoneo al soddisfacimento dello specifico fabbisogno dell'amministrazione per mancanza di caratteristiche essenziali.

511. A decorrere dalla data di entrata in vigore della presente legge, anche con riferimento ai contratti in corso a tale data, nei contratti pubblici relativi a servizi e forniture ad esecuzione continuata o periodica stipulati da un soggetto aggregatore di cui all'articolo 9 del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, per l'adesione dei singoli soggetti contraenti, in cui la clausola di revisione e adeguamento dei prezzi sia collegata o indicizzata al valore di beni indifferenziati, qualora si sia verificata una variazione nel valore dei predetti beni, che abbia determinato un aumento o una diminuzione del prezzo complessivo in misura non inferiore al 10 per cento e tale da alterare significativamente l'originario equilibrio contrattuale, come accertato dall'autorita' indipendente preposta alla regolazione del settore relativo allo specifico contratto ovvero, in mancanza, dall'Autorita' garante della concorrenza e del mercato, l'appaltatore o il soggetto aggregatore hanno facolta' di richiedere, con decorrenza dalla data dell'istanza presentata ai sensi del presente comma, una riconduzione ad equita' o una revisione del prezzo medesimo. In caso di raggiungimento dell'accordo, i soggetti contraenti possono, nei trenta giorni successivi a tale accordo, esercitare il diritto di recesso ai sensi dell'articolo 1373 del codice civile. Nel caso di mancato raggiungimento dell'accordo le parti possono consensualmente risolvere il contratto senza che sia dovuto alcun indennizzo come conseguenza della risoluzione del contratto, fermo restando quanto previsto dall'articolo 1467 del codice civile. Le parti possono chiedere all'autorita' che provvede all'accertamento di cui al presente comma di fornire, entro trenta giorni dalla richiesta, le indicazioni utili per il ripristino dell'equilibrio contrattuale ovvero, in caso di mancato accordo, per la definizione di modalita' attuative della risoluzione contrattuale finalizzate a evitare disservizi.

512. Al fine di garantire l'ottimizzazione e la razionalizzazione degli acquisti di beni e servizi informatici e di connettivita', fermi restando gli obblighi di acquisizione centralizzata previsti per i beni e servizi dalla normativa vigente, le amministrazioni pubbliche e le societa' inserite nel conto economico consolidato della pubblica amministrazione, come individuate dall'Istituto nazionale di statistica (ISTAT) ai sensi dell'articolo 1 della legge 31 dicembre 2009, n. 196, provvedono ai propri approvvigionamenti esclusivamente tramite gli strumenti di acquisto e di negoziazione di Consip Spa o dei soggetti aggregatori, ivi comprese le centrali di committenza regionali, per i beni e i servizi disponibili presso gli stessi soggetti. Le regioni sono autorizzate ad assumere personale strettamente necessario ad assicurare la piena funzionalita' dei soggetti aggregatori di cui all'articolo 9 del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, in deroga ai vincoli assunzionali previsti dalla normativa vigente, nei limiti del finanziamento derivante dal Fondo di cui al comma 9 del medesimo articolo 9 del decreto-legge n. 66 del 2014.

513. L'Agenzia per l'Italia digitale (Agid) predispone il Piano triennale per l'informatica nella pubblica amministrazione che e' approvato dal Presidente del Consiglio dei ministri o dal Ministro delegato. Il Piano contiene, per ciascuna amministrazione o categoria di amministrazioni, l'elenco dei beni e servizi informatici e di connettivita' e dei relativi costi, suddivisi in spese da sostenere per innovazione e spese per la gestione corrente, individuando altresi' i beni e servizi la cui acquisizione riveste particolare rilevanza strategica.

514. Ai fini di cui al comma 512, Consip SpA o il soggetto aggregatore interessato sentita l'Agid per l'acquisizione dei beni e servizi strategici indicati nel Piano triennale per l'informatica nella pubblica amministrazione di cui al comma 513, programma gli acquisti di beni e servizi informatici e di connettivita', in coerenza con la domanda aggregata di cui al predetto Piano. Agid, Con-sip SpA e i soggetti aggregatori, sulla base di analisi delle informazioni in loro possesso relative ai contratti di acquisto di beni e servizi in materia informatica, propongono alle amministrazioni e alle societa' di cui al comma 512 iniziative e misure, anche organizzative e di processo, volte al contenimento della spesa. Consip SpA e gli altri soggetti aggregatori promuovono l'aggregazione della domanda funzionale all'utilizzo degli strumenti messi a disposizione delle pubbliche amministrazioni su base nazionale, regionale o comune a piu' amministrazioni.

514-bis. Per i beni e servizi la cui acquisizione riveste particolare rilevanza strategica secondo quanto indicato nel Piano triennale di cui al comma 513, le amministrazioni statali, centrali e periferiche, ad esclusione degli istituti e delle scuole di ogni ordine e grado, delle istituzioni educative e delle istituzioni universitarie, nonche' gli enti nazionali di previdenza ed assistenza sociale pubblici e le agenzie fiscali di cui al decreto legislativo 30 luglio 1999, n. 300, ricorrono a Consip Spa, nell'ambito del Programma di razionalizzazione degli acquisti della pubblica amministrazione del Ministero dell'economia e delle finanze. A tal fine Consip Spa puo' supportare i soggetti di cui al periodo precedente nell'individuazione di specifici interventi di semplificazione, innovazione e riduzione dei costi dei processi amministrativi. Per le attivita' di cui al presente comma e' previsto un incremento delle dotazioni destinate al finanziamento del Programma di razionalizzazione degli acquisti della pubblica amministrazione del Ministero dell'economia e delle finanze pari a euro 3.000.000 per l'anno 2017, a euro 7.000.000 per l'anno 2018, a euro 4.300.000 per l'anno 2019 e a euro 1.500.000 annui a decorrere dal 2020.

515. La procedura di cui ai commi 512 e 514 ha un obiettivo di risparmio di spesa annuale, da raggiungere alla fine del triennio 2016-2018, pari al 50 per cento della spesa annuale media per la gestione corrente del solo settore informatico, relativa al triennio 2013-2015, al netto dei canoni per servizi di connettivita' e della spesa effettuata tramite Consip SpA o i soggetti aggregatori documentata nel Piano triennale di cui al comma 513, compresa quella relativa alle acquisizioni di particolare rilevanza strategica di cui al comma 514-bis, nonche' tramite la societa' di cui all'articolo 83, comma 15, del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133. Sono esclusi dal predetto obiettivo di risparmio gli enti disciplinati dalla legge 8 marzo 1989, n. 88, nonche', per le prestazioni e i servizi erogati alle amministrazioni committenti, la societa' di cui all'articolo 83, comma 15, del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, la societa' di cui all'articolo 10, comma 12, della legge 8 maggio 1998, n. 146, e la Consip SpA, nonche' l'amministrazione della giustizia in relazione alle spese di investimento necessarie al completamento dell'informatizzazione del processo civile e penale negli uffici giudiziari. I risparmi derivanti dall'attuazione del presente comma sono utilizzati dalle medesime amministrazioni prioritariamente per investimenti in materia di innovazione tecnologica.

515-bis. Al fine di facilitare la partecipazione ai programmi comunitari, le amministrazioni pubbliche di cui al comma 510, possono procedere, al di fuori delle modalita' di cui al comma 512 e successivi, per attivita' di ricerca, istruzione, formazione e culturali a richiedere l'accesso alla rete del GARR in quanto unica rete nazionale della ricerca e facente parte della rete della ricerca Europea GEANT, ai sensi dell'articolo 40, comma 6, della legge 1 agosto 2002, n. 166. I relativi costi non sono inclusi nel computo della spesa annuale informatica. La procedura di affidamento segue le disposizioni del comma 516.

516. Le amministrazioni e le societa' di cui al comma 512 possono procedere ad approvvigionamenti al di fuori delle modalita' di cui ai commi 512 e 514 esclusivamente a seguito di apposita autorizzazione motivata dell'organo di vertice amministrativo, qualora il bene o il servizio non sia disponibile o idoneo al soddisfacimento dello specifico fabbisogno dell'amministrazione ovvero in casi di necessita' ed urgenza comunque funzionali ad assicurare la continuita' della gestione amministrativa. Gli approvvigionamenti effettuati ai sensi del presente comma sono comunicati all'Autorita' nazionale anti-corruzione e all'Agid.

517. La mancata osservanza delle disposizioni dei commi da 512 a 516 rileva ai fini della responsabilita' disciplinare e per danno erariale.

518. Il comma 3-quinquies dell'articolo 4 del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, e' abrogato.

519. Nelle acquisizioni di beni e servizi di cui ai commi da 512 al presente comma, gli organi costituzionali adottano le misure idonee a realizzare le economie previste nella rispettiva autonomia, secondo le modalita' stabilite nel proprio ordinamento.

520. Per le finalita' di cui al comma 512, al fine di consentire l'interoperabilita' dei sistemi informativi degli enti del Servizio sanitario nazionale e garantire omogeneita' dei processi di approvvigionamento sul territorio nazionale, con accordo sancito in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, previo parere dell'Agid e della Consip SpA, sono definiti criteri uniformi per gli acquisti di beni e servizi informatici e di connettivita' da parte degli enti del Servizio sanitario nazionale.

521. Al fine di favorire la corretta ed appropriata allocazione delle risorse programmate per il finanziamento del Servizio sanitario nazionale e per l'erogazione dei livelli essenziali di assistenza (LEA), le disposizioni di cui ai commi dal presente comma al comma 547 disciplinano le procedure per conseguire miglioramenti nella produttivita' e nell'efficienza degli enti del Servizio sanitario nazionale, nel rispetto dell'equilibrio economico-finanziario e nel rispetto della garanzia dei LEA.

522. Fermo restando quanto previsto dall'articolo 29 del decreto legislativo 14 marzo 2013, n. 33, e successive modificazioni, dall'articolo 32, comma 7, del decreto legislativo 23 giugno 2011, n. 118, nonche' dall'articolo 7 del decreto del Presidente del Consiglio dei ministri 22 settembre 2014, pubblicato nella Gazzetta Ufficiale n. 265 del 14 novembre 2014, gli enti del Servizio sanitario nazionale, di cui all'articolo 19, comma 2, lettere b) e c), del decreto legislativo 23 giugno 2011, n. 118, assicurano la massima trasparenza dei dati di bilancio pubblicando integralmente nel proprio sito internet il bilancio d'esercizio entro sessanta giorni dalla data di relativa approvazione. Gli enti del Servizio sanitario nazionale, senza nuovi o maggiori oneri a carico della finanza pubblica, attivano, altresi', un sistema di monitoraggio delle attivita' assistenziali e della loro qualita', in raccordo con il sistema di monitoraggio regionale di cui all'articolo 4, comma 4, del decreto-legge 13 settembre 2012, n. 158, convertito, con modificazioni, dalla legge 8 novembre 2012, n. 189, e in coerenza con il programma nazionale valutazione esiti, pubblicando entro il 30 giugno di ogni anno i relativi esiti.

523. Il mancato rispetto delle disposizioni di cui al comma 522 costituisce illecito disciplinare ed e' causa di responsabilita' amministrativa del direttore generale e del responsabile per la trasparenza e la prevenzione della corruzione.

524. Ciascuna regione, entro il 30 giugno di ciascun anno, individua, con apposito provvedimento della Giunta regionale, ovvero del Commissario ad acta, ove nominato ai sensi dell'articolo 2, commi 79 e 83, della legge 23 dicembre 2009, n. 191, e dell'articolo 4, commi 1 e 2, del decreto-legge 1º ottobre 2007, n. 159, convertito, con modificazioni, dalla legge 29 novembre 2007, n. 222, le aziende ospedaliere (AO), le aziende ospedaliere universitarie (AOU), gli istituti di ricovero e cura a carattere scientifico pubblici (IRCCS) o gli altri enti pubblici che erogano prestazioni di ricovero e cura, ad esclusione degli enti di cui al comma 536, che presentano una o entrambe le seguenti condizioni:

- a) uno scostamento tra costi rilevati dal modello di rilevazione del conto economico (CE) consuntivo e ricavi determinati come remunerazione dell'attivita', ai sensi dell'articolo 8-sexies del decreto legislativo 30 dicembre 1992, n. 502, e successive modificazioni, pari o superiore al 7 per cento dei suddetti ricavi, o, in valore assoluto, pari ad almeno 7 milioni di euro. Le modalita' di individuazione dei costi e di determinazione dei ricavi sono individuate dal decreto di cui al comma 526;
- b) il mancato rispetto dei parametri relativi a volumi, qualita' ed esiti delle cure, valutato secondo la metodologia prevista dal decreto di cui al comma 526. (14)(26)

525. In sede di prima applicazione, per l'anno 2016, entro il 31 marzo le regioni individuano, con apposito provvedimento della Giunta regionale, ovvero del Commissario ad acta, ove nominato ai sensi dell'articolo 2, commi 79 e 83, della legge 23 dicembre 2009, n. 191, e dell'articolo 4, commi 1 e 2, del decreto-legge 1º ottobre 2007, n. 159, convertito, con modificazioni, dalla legge 29 novembre 2007, n. 222, gli enti del proprio Servizio sanitario regionale che presentano una o entrambe le condizioni di cui al comma 524, lettere a) e b). Per la verifica delle condizioni di cui al comma 524, lettera a), sono utilizzati i dati dei costi relativi al quarto trimestre 2015 e dei ricavi come determinati ai sensi del decreto di cui al comma 526; per la verifica delle condizioni di cui al comma 524, lettera b), sono utilizzati i dati relativi all'anno 2014 indicati dal medesimo decreto di cui al comma 526. (14)(26)

526. Con decreto del Ministro della salute, di concerto con il Ministro dell'economia e delle finanze, sentita la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, da adottare entro trenta giorni dalla data di entrata in vigore della presente legge, e' definita la metodologia di valutazione dello scostamento di cui al comma 524, lettera a), in coerenza con quanto disposto dall'articolo 8-sexies del decreto legislativo 30 dicembre 1992, n. 502, e successive modificazioni, in materia di modalita' di remunerazione delle prestazioni sanitarie, tenendo conto dei diversi assetti organizzativi ed erogativi regionali. Con il medesimo decreto sono definiti anche gli ambiti assistenziali e i parametri di riferimento relativi a volumi, qualita' ed esiti delle cure, anche tenendo conto di quanto previsto dal regolamento di cui al decreto del Ministro della salute 2 aprile 2015, n. 70, recante la definizione degli standard qualitativi, strutturali, tecnologici e quantitativi relativi all'assistenza ospedaliera. Il decreto definisce, altresi', le linee guida per la predisposizione dei piani di cui ai commi 529 e 530. (14)(26)

527. Ai sensi dell'articolo 34 del decreto legislativo 23 giugno 2011, n. 118, entro il 31 dicembre 2016, con apposito decreto del Ministro della salute, di concerto con il Ministro dell'economia e delle finanze, d'intesa con la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, sono apportati i necessari aggiornamenti agli schemi allegati al medesimo decreto legislativo, al fine di dare evidenza e trasparenza del risultato di esercizio nei documenti di bilancio degli enti del Servizio sanitario nazionale delle voci di costo e di ricavo coerentemente con quanto previsto dall'articolo 8-sexies del decreto legislativo 30 dicembre 1992, n. 502, e successive modificazioni. (14)

528. Gli enti individuati ai sensi dei commi 524 e 525 presentano alla regione, entro i novanta giorni successivi all'emanazione del provvedimento di individuazione, il piano di rientro di durata non superiore al triennio, contenente le misure atte al raggiungimento dell'equilibrio economico-finanziario e patrimoniale e al miglioramento della qualita' delle cure o all'adeguamento dell'offerta, al fine di superare ciascuno dei disallineamenti rilevati. (14)

529. Le regioni non in piano di rientro regionale, entro trenta giorni dalla presentazione del piano da parte dell'ente, valutano l'adeguatezza delle misure previste dai piani, la loro coerenza con la programmazione sanitaria regionale e con le linee guida di cui al comma 526, e approvano i piani di rientro degli enti con provvedimento della Giunta regionale. I piani di rientro degli enti approvati dalla Giunta regionale sono immediatamente efficaci ed esecutivi per l'ente interessato. (14)(26)

530. Le regioni in piano di rientro regionale, anche commissariate per l'attuazione dello stesso, entro trenta giorni dalla presentazione del piano da parte dell'ente, valutano l'adeguatezza delle misure previste dai piani di rientro, la loro coerenza con il piano di rientro regionale e con le linee guida di cui al comma 526, e approvano i piani di rientro degli enti con provvedimento della Giunta o del Commissario ad acta, ove nominato. Le regioni medesime evidenziano, in apposita sezione del programma operativo di prosecuzione del piano di rientro regionale, predisposto ai sensi dell'articolo 2, comma 88, della legge 23 dicembre 2009, n. 191, e successive modificazioni, e ai sensi dell'articolo 15, comma 20, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, e successive modificazioni, l'eventuale sussistenza di piani di rientro di enti del proprio Servizio sanitario regionale, nonche' dei relativi obiettivi di riequilibrio economico-finanziario e di miglioramento dell'erogazione dei LEA. I piani di rientro degli enti approvati dalla Giunta regionale, o dal Commissario ad acta ove nominato, sono immediatamente efficaci ed esecutivi per l'ente interessato. Restano ferme le valutazioni dei tavoli tecnici di cui agli articoli 9 e 12 dell'Intesa sancita in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano in data 23 marzo 2005, pubblicata nel supplemento ordinario alla Gazzetta Ufficiale n. 105 del 7 maggio 2005, e dei Ministeri della salute e dell'economia e delle finanze nell'ambito dell'attivita' di monitoraggio ed affiancamento nell'attuazione del piano di rientro regionale. (14)

531. Fermo restando quanto previsto dall'articolo 1, comma 174, della legge 30 dicembre 2004, n. 311, e successive modificazioni, e quanto previsto dall'articolo 2, commi 77 e 86, della legge 23 dicembre 2009, n. 191, al fine di garantire l'equilibrio del Servizio sanitario regionale nel suo complesso, la Gestione sanitaria accentrata, di cui all'articolo 19, comma 2, lettera b), punto i), del decreto legislativo 23 giugno 2011, n. 118, iscrive nel proprio bilancio una quota di fondo sanitario regionale corrispondente alla somma degli eventuali scostamenti negativi di cui ai piani di rientro degli enti del Servizio sanitario regionale. Nel caso in cui si verifichino le condizioni di cui ai commi 524 e 525, le regioni che si sono avvalse della facolta' di cui all'articolo 23 del decreto legislativo 23 giugno 2011, n. 118, sono tenute ad istituire la Gestione sanitaria accentrata, di cui all'articolo 19, comma 2, lettera b), punto i), del medesimo decreto legislativo n. 118 del 2011. I tavoli tecnici di cui agli articoli 9 e 12 dell'Intesa sancita in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano in data 23 marzo 2005 verificano il rispetto del presente comma. A tal fine le regioni comunicano ai suddetti tavoli tecnici l'avvenuta approvazione dei piani di rientro degli enti del proprio Servizio sanitario regionale entro cinque giorni dall'adozione del provvedimento di approvazione e l'importo degli scostamenti negativi di cui ai medesimi piani di rientro. (14)

532. Fermo restando quanto previsto dall'articolo 2, comma 80, della legge 23 dicembre 2009, n. 191, gli interventi individuati dai piani di cui ai commi 529 e 530 sono vincolanti per gli enti interessati e le determinazioni in essi previste possono comportare effetti di variazione dei provvedimenti amministrativi gia' adottati dagli stessi in materia di programmazione e pianificazione aziendale, per renderli coerenti con i contenuti dei piani. (14)

533. La regione, ovvero il Commissario ad acta ove nominato, verifica trimestralmente l'adozione e la realizzazione delle misure previste dai piani di rientro di cui ai commi 529 e 530 nel rispetto della tempistica ivi indicata. In caso di verifica trimestrale positiva, la Gestione sanitaria accentrata puo' erogare a titolo di anticipazione una quota parte delle risorse iscritte, ai sensi del comma 531, nel proprio bilancio, al fine di salvaguardare l'equilibrio finanziario degli enti territoriali interessati. In caso di verifica trimestrale negativa, la regione, ovvero il Commissario ad acta ove nominato, adotta le misure per la riconduzione in equilibrio della gestione, nel rispetto dei livelli di assistenza, come individuati nel piano di rientro dell'ente. Al termine di ogni esercizio la regione pubblica nel proprio sito internet i risultati economici raggiunti dai singoli enti interessati, raffrontati agli obiettivi programmati nel piano di rientro. (14)

534. Per garantire il pieno rispetto delle disposizioni di cui ai commi da 521 a 547, tutti i contratti dei direttori generali, ivi inclusi quelli in essere, prevedono la decadenza automatica del direttore generale degli enti di cui all'articolo 19, comma 2, lettera c), del decreto legislativo 23 giugno 2011, n. 118, in caso di mancata trasmissione del piano di rientro all'ente interessato, ovvero in caso di esito negativo della verifica annuale dello stato di attuazione del medesimo piano di rientro. (14)

535. A decorrere dal 2017, le disposizioni di cui ai commi da 521 a 547, coerentemente con le previsioni normative di cui agli articoli 2, comma 2-sexies, lettera d), e 4, commi 8 e 9, del decreto legislativo 30 dicembre 1992, n. 502, e successive modificazioni, e nel rispetto delle modalita' e dei criteri stabiliti dal decreto di cui al comma 536, primo periodo, si applicano alle aziende sanitarie locali e ai relativi presidi a gestione diretta, ovvero ad altri enti pubblici che erogano prestazioni di ricovero e cura, individuati da leggi regionali, che presentano un significativo scostamento tra costi e ricavi ovvero il mancato rispetto dei parametri relativi a volumi, qualita' ed esiti delle cure. (14)

536. Con decreto del Ministro della salute, di concerto con il Ministro dell'economia e delle finanze, sentita la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, da adottare entro il 30 giugno 2016, sono definiti i criteri di valutazione, i dati da prendere in considerazione, le modalita' di calcolo e i relativi parametri di riferimento per l'individuazione, da parte delle regioni, delle aziende, dei presidi e degli enti di cui al comma 535, da sottoporre ad un piano di rientro, in caso di mancato conseguimento dell'equilibrio di bilancio o di disallineamento rispetto ai parametri di qualita' ed esiti delle cure. Con successivo decreto del Ministro della salute, di concerto con il Ministro dell'economia e delle finanze, d'intesa con la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, da adottare entro il 31 dicembre 2016, sono apportati i necessari aggiornamenti ai modelli di rilevazione dei costi dei presidi ospedalieri a gestione diretta delle aziende sanitarie, anche al fine di valutare l'equilibrio della gestione dei presidi ospedalieri in rapporto alla loro remunerazione, tariffaria ed extra-tariffaria, in coerenza con quanto previsto dall'articolo 4, commi 8 e 9, del decreto legislativo 30 dicembre 1992, n. 502, e successive modificazioni. (14)(26)

537. Al fine di garantire una piu' efficace ed efficiente attivita' di programmazione sanitaria, con particolare riguardo alle specifiche funzioni di monitoraggio, di verifica e di affiancamento nell'attuazione dei piani di rientro regionali e' autorizzata, a favore del Ministero della salute, la spesa di 1,2 milioni di euro per l'anno 2016, di 1 milione di euro per l'anno 2017 e di 0,8 milioni di euro a decorrere dall'anno 2018.

538. La realizzazione delle attivita' di prevenzione e gestione del rischio sanitario rappresenta un interesse primario del Sistema sanitario nazionale perche' consente maggiore appropriatezza nell'utilizzo delle risorse disponibili e garantisce la tutela del paziente.

539. Per la realizzazione dell'obiettivo di cui al comma 538, ai fini di cui all'articolo 3-bis del decreto-legge 13 settembre 2012, n. 158, convertito, con modificazioni, dalla legge 8 novembre 2012, n. 189, le regioni e le province autonome di Trento e di Bolzano dispongono che tutte le strutture pubbliche e private che erogano prestazioni sanitarie attivino un'adeguata funzione di monitoraggio, prevenzione e gestione del rischio sanitario (risk management), per l'esercizio dei seguenti compiti:

- a) attivazione dei percorsi di audit o altre metodologie finalizzati allo studio dei processi interni e delle criticita' piu' frequenti, con segnalazione anonima del quasi-errore e analisi delle possibili attivita' finalizzate alla messa in sicurezza dei percorsi sanitari. I verbali e gli atti conseguenti all'attivita' di gestione del rischio clinico non possono essere acquisiti o utilizzati nell'ambito di procedimenti giudiziari;
- b) rilevazione del rischio di inappropriatezza nei percorsi diagnostici e terapeutici e facilitazione dell'emersione di eventuali attivita' di medicina difensiva attiva e passiva;
- c) predisposizione e attuazione di attivita' di sensibilizzazione e formazione continua del personale finalizzata alla prevenzione del rischio sanitario;
- d) assistenza tecnica verso gli uffici legali della struttura sanitaria nel caso di contenzioso e nelle attivita' di stipulazione di coperture assicurative o di gestione di coperture auto-assicurative.
- d-bis) predisposizione di una relazione annuale consuntiva sugli eventi avversi verificatisi all'interno della struttura, sulle cause che hanno prodotto l'evento avverso e sulle conseguenti iniziative messe in atto. Detta relazione e' pubblicata nel sito internet della struttura sanitaria.

540. L'attivita' di gestione del rischio sanitario e' coordinata da personale medico dotato delle specializzazioni in igiene, epidemiologia e sanita' pubblica o equipollenti , in medicina legale ovvero da personale dipendente con adeguata formazione e comprovata esperienza almeno triennale nel settore.

541. Nell'ambito della cornice finanziaria programmata per il Servizio sanitario nazionale e in relazione alle misure di accrescimento dell'efficienza del settore sanitario previste dai commi da 521 a 552 e alle misure di prevenzione e gestione del rischio sanitario di cui ai commi da 538 a 540, al fine di assicurare la continuita' nell'erogazione dei servizi sanitari, nel rispetto delle disposizioni dell'Unione europea in materia di articolazione dell'orario di lavoro, le regioni e le province autonome:

- a) ove non abbiano ancora adempiuto a quanto previsto dall'articolo 1, comma 2, del regolamento di cui al decreto del Ministro della salute 2 aprile 2015, n. 70, adottano il provvedimento generale di programmazione di riduzione della dotazione dei posti letto ospedalieri accreditati ed effettivamente a carico del Servizio sanitario regionale nonche' i relativi provvedimenti attuativi. Le regioni sottoposte ai piani di rientro, in coerenza con quanto definito dall'articolo 1, comma 4, del medesimo decreto, adottano i relativi provvedimenti nei tempi e con le modalita' definiti nei programmi operativi di prosecuzione dei piani di rientro;(30)
- b) predispongono un piano concernente il fabbisogno di personale, contenente l'esposizione delle modalita' organizzative del personale, tale da garantire il rispetto delle disposizioni dell'Unione europea in materia di articolazione dell'orario di lavoro attraverso una piu' efficiente allocazione delle risorse umane disponibili, in coerenza con quanto disposto dall'articolo 14 della legge 30 ottobre 2014, n. 161;
- c) trasmettono entro il 29 febbraio 2016 i provvedimenti di cui alle lettere a) e b) al Tavolo di verifica degli adempimenti e al Comitato permanente per la verifica dell'erogazione dei LEA, di cui rispettivamente agli articoli 12 e 9 dell'Intesa 23 marzo 2005, sancita dalla Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, pubblicata nel supplemento ordinario n. 83 alla Gazzetta Ufficiale n. 105 del 7 maggio 2005, nonche' al Tavolo per il monitoraggio dell'attuazione del regolamento di cui al decreto del Ministro della salute 2 aprile 2015, n. 70, istituito ai sensi della lettera C.5 dell'Intesa sancita dalla Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano nella seduta del 2 luglio 2015; il Tavolo di verifica degli adempimenti e il Comitato permanente per la verifica dell'erogazione dei LEA valutano congiuntamente, entro il 31 marzo 2016, i provvedimenti di cui alle lettere a) e b), anche sulla base dell'istruttoria condotta dal Tavolo di cui alla lettera C.5 dell'Intesa sancita dalla Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano nella seduta del 2 luglio 2015;
- d) ferme restando le disposizioni vigenti in materia sanitaria, ivi comprese quelle in materia di contenimento del costo del personale e quelle in materia di piani di rientro, se sulla base del piano del fabbisogno del personale emergono criticita', si applicano i commi 543 e 544.

542. Nelle more della predisposizione e della verifica dei piani di cui al comma 541, lettera b), nel periodo dal 1º gennaio 2016 al 31 luglio 2016, le regioni e le province autonome, previa attuazione delle modalita' organizzative del personale al fine di garantire il rispetto delle disposizioni dell'Unione europea in materia di articolazione dell'orario di lavoro, qualora si evidenzino criticita' nell'erogazione dei livelli essenziali di assistenza, possono ricorrere, in deroga a quanto previsto dall'articolo 9, comma 28, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, e successive modificazioni, a forme di lavoro flessibile, nel rispetto delle disposizioni vigenti in materia sanitaria, ivi comprese quelle relative al contenimento del costo del personale e in materia di piani di rientro. Se al termine del medesimo periodo temporale permangono le predette condizioni di criticita', i contratti di lavoro stipulati ai sensi del precedente periodo possono essere prorogati fino al termine massimo del 31 ottobre 2016. Del ricorso a tali forme di lavoro flessibile nel rispetto delle disposizioni vigenti in materia sanitaria, ivi comprese quelle relative al contenimento del costo del personale e in materia di piani di rientro, e' data tempestiva comunicazione ai Ministeri della salute e dell'economia e delle finanze.

543. In deroga a quanto previsto dal decreto del Presidente del Consiglio dei ministri 6 marzo 2015, pubblicato nella Gazzetta Ufficiale n. 94 del 23 aprile 2015, in attuazione dell'articolo 4, comma 10, del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, gli enti del Servizio sanitario nazionale possono indire, entro il 31 dicembre 2017, e concludere, entro il 31 dicembre 2018, procedure concorsuali straordinarie per l'assunzione di personale medico, tecnico-professionale e infermieristico, necessario a far fronte alle eventuali esigenze assunzionali emerse in relazione alle valutazioni operate nel piano di fabbisogno del personale secondo quanto previsto dal comma 541. Nell'ambito delle medesime procedure concorsuali, gli enti del Servizio sanitario nazionale possono riservare i posti disponibili, nella misura massima del 50 per cento, al personale medico, tecnico-professionale e infermieristico in servizio alla data di entrata in vigore della presente legge, che abbia maturato alla data di pubblicazione del bando almeno tre anni di servizio, anche non continuativi, negli ultimi cinque anni con contratti a tempo determinato, con contratti di collaborazione coordinata e continuativa o con altre forme di rapporto di lavoro flessibile con i medesimi enti. Nelle more della conclusione delle medesime procedure, gli enti del Servizio sanitario nazionale continuano ad avvalersi del personale di cui al precedente periodo, anche in deroga ai limiti di cui all'articolo 9, comma 28, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122. In relazione a tale deroga, gli enti del Servizio sanitario nazionale, oltre alla prosecuzione dei rapporti di cui al precedente periodo, sono autorizzati a stipulare nuovi contratti di lavoro flessibile esclusivamente ai sensi del comma 542 fino al termine massimo del 31 ottobre 2017. (20) (47)

544. Le previsioni di cui al comma 543, per il biennio 2016-2017, sono comunque attuate nel rispetto della cornice finanziaria programmata e delle disposizioni di cui all'articolo 2, comma 71, della legge 23 dicembre 2009, n. 191, e dell'articolo 17, commi 3, 3-bis e 3-ter, del decreto-legge 6 luglio 2011, n. 98, convertito, con modificazioni, dalla legge 15 luglio 2011, n. 111, e successive modificazioni, e, per le regioni sottoposte a piani di rientro, degli obiettivi previsti in detti piani. E' autorizzata a decorrere dal 1º gennaio 2016, nel limite massimo di spesa di 400.000 euro annui, la stipulazione di una convenzione tra il Dipartimento dell'amministrazione penitenziaria del Ministero della giustizia, il Dipartimento per la giustizia minorile e di comunita' del medesimo Ministero, le aziende sanitarie e i comuni (ANCI-Federsanita'), per l'integrazione socio-sanitaria e per la realizzazione all'interno del Servizio sanitario nazionale di una piattaforma informatica di trasmissione dei dati sanitari delle persone detenute sviluppata dalla Direzione generale per i sistemi informativi automatizzati del Ministero della giustizia cui sono assegnate le risorse; la piattaforma e' finalizzata alla gestione di un servizio di telemedicina in ambito carcerario, sia adulto che minorile. Per l'attuazione delle disposizioni di cui al periodo precedente e' autorizzata la spesa di 400.000 euro a decorrere dall'anno 2016.

545. Il comma 10 dell'articolo 4 del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, si applica anche all'Istituto nazionale per la promozione della salute delle popolazioni migranti e per il contrasto delle malattie della poverta', che opera nell'ambito del Servizio sanitario nazionale ed e' assoggettato alla disciplina per questo prevista. Conseguentemente il Fondo per la compensazione degli effetti finanziari non previsti a legislazione vigente conseguenti all'attualizzazione di contributi pluriennali, di cui all'articolo 6, comma 2, del decreto-legge 7 ottobre 2008, n. 154, convertito, con modificazioni, dalla legge 4 dicembre 2008, n. 189, e successive modificazioni, e' ridotto di 780.983 euro a decorrere dall'anno 2016.

546. Al fine di perseguire una piu' efficace e sinergica integrazione tra le attivita' di prevenzione, cura e riabilitazione e le attivita' di didattica e di ricerca, nonche' allo scopo di conseguire risparmi di spesa, nelle regioni a statuto speciale che nel biennio antecedente alla data di entrata in vigore della presente legge hanno riorganizzato il proprio Servizio sanitario regionale, o ne hanno avviato la riorganizzazione, attraverso processi di accorpamento delle aziende sanitarie preesistenti, la collaborazione tra Servizio sanitario nazionale e universita' puo' realizzarsi anche mediante la costituzione di aziende sanitarie uniche, risultanti dall'incorporazione delle aziende ospedaliere universitarie nelle aziende sanitarie locali, secondo modalita' definite preventivamente con protocolli di intesa tra le regioni e le universita' interessate, da stipulare ai sensi del decreto legislativo 21 dicembre 1999, n. 517.

547. Le disposizioni di cui al comma 546 non si applicano alle regioni sottoposte a piani di rientro dal disavanzo sanitario.

548. Al fine di garantire la effettiva realizzazione degli interventi di razionalizzazione della spesa mediante aggregazione degli acquisti di beni e servizi, gli enti del Servizio sanitario nazionale sono tenuti ad approvvigionarsi, relativamente alle categorie merceologiche del settore sanitario, come individuate dal decreto del Presidente del Consiglio dei ministri di cui all'articolo 9, comma 3, del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, avvalendosi, in via esclusiva, delle centrali regionali di committenza di riferimento, ovvero della Consip SpA.

549. Qualora le centrali di committenza individuate sulla base del comma 548 non siano disponibili ovvero operative, gli enti del Servizio sanitario nazionale sono tenuti ad approvvigionarsi, relativamente alle categorie merceologiche del settore sanitario di cui al comma 548, avvalendosi, in via esclusiva, delle centrali di committenza iscritte nell'elenco dei soggetti aggregatori, di cui all'articolo 9, comma 1, del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89. In tale ipotesi, spetta alla centrale regionale di committenza di riferimento l'individuazione, ai fini dell'approvvigionamento, di altra centrale di committenza. La violazione degli adempimenti previsti dal presente comma costituisce illecito disciplinare ed e' causa di responsabilita' per danno erariale.

550. I singoli contratti relativi alle categorie merceologiche individuate dal decreto di cui al comma 548, in essere alla data di entrata in vigore della presente legge, non possono essere prorogati oltre la data di attivazione del contratto aggiudicato dalla centrale di committenza individuata ai sensi dei commi da 548 a 552. Le proroghe disposte in violazione della presente disposizione sono nulle e costituiscono illecito disciplinare e sono causa di responsabilita' amministrativa.

551. Entro trenta giorni dalla data di entrata in vigore della presente legge, le regioni adottano provvedimenti volti a garantire che gli enti del Servizio sanitario nazionale non istituiscano unita' organizzative di valutazione delle tecnologie ovvero sopprimano quelle esistenti, ricorrendo a strutture di valutazione istituite a livello regionale o nazionale.

552. A livello nazionale la Cabina di regia istituita con decreto del Ministro della salute 12 marzo 2015, in attuazione dell'articolo 26 del Patto per la salute 2014-2016, provvede a:

- a) definire le priorita' per la valutazione tecnica multidimensionale dei dispositivi medici sulla base dei criteri di rilevanza del problema di salute nonche' di rilevanza, sicurezza, efficacia, impatto economico ed impatto organizzativo dei dispositivi medici, in coerenza con le linee guida europee in materia (EUnetHTA);
- b) promuovere e coordinare le attivita' di valutazione multidimensionale realizzate dall'Agenzia nazionale per i servizi sanitari regionali (AGENAS) e dai presidi regionali e dai soggetti pubblici e privati di comprovata esperienza di HTA (Health Technology assessment) operanti nel Programma nazionale di HTA dei dispositivi medici;
- c) validare gli indirizzi metodologici che verranno applicati per la produzione dei rapporti di valutazione tecnica multidimensionale nel Programma nazionale di HTA;
- d) curare la pubblicazione, la diffusione e la verifica degli impatti a livello nazionale degli esiti delle valutazioni di cui alla lettera b) secondo i metodi validati di cui alla lettera c), promuovendone l'utilizzo da parte delle regioni e delle aziende sanitarie per informare le decisioni in merito all'adozione e all'introduzione dei dispositivi medici e al disinvestimento.

553. In attuazione dell'articolo 1, comma 3, del Patto per la salute 2014-2016, approvato con l'Intesa tra lo Stato, le regioni e le province autonome di Trento e di Bolzano del 10 luglio 2014, nel rispetto di quanto previsto dall'articolo 1, comma 556, della legge 23 dicembre 2014, n. 190, e dall'articolo 9-septies del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 7 agosto 2015, n. 125, e in misura non superiore a 800 milioni di euro annui, entro sessanta giorni dalla data di entrata in vigore della presente legge si provvede all'aggiornamento del decreto del Presidente del Consiglio dei ministri 29 novembre 2001, pubblicato nel supplemento ordinario alla Gazzetta Ufficiale n. 33 dell'8 febbraio 2002, recante «Definizione dei livelli essenziali di assistenza», nel rispetto degli equilibri programmati della finanza pubblica.

554. La definizione e l'aggiornamento dei LEA di cui all'articolo 1, comma 7, del decreto legislativo 30 dicembre 1992, n. 502, sono effettuati con decreto del Presidente del Consiglio dei ministri su proposta del Ministro della salute, di concerto con il Ministro dell'economia e delle finanze, d'intesa con la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano e previo parere delle competenti Commissioni parlamentari nonche' con la procedura di cui al comma 559. Il Ministro della salute, entro il 31 dicembre di ogni anno, presenta alle Camere una relazione sullo stato di attuazione dei commi da 553 a 565. L'articolo 5 del decreto-legge 13 settembre 2012, n. 158, convertito, con modificazioni, dalla legge 8 novembre 2012, n. 189, e' abrogato.

555. Per l'attuazione del comma 553, per l'anno 2016 e' finalizzato l'importo di 800 milioni di euro, a valere sulla quota indistinta del fabbisogno sanitario standard nazionale, di cui all'articolo 26 del decreto legislativo 6 maggio 2011, n. 68. L'erogazione della quota e' condizionata all'adozione del provvedimento di cui al comma 553.

556. Nel rispetto degli equilibri programmati di finanza pubblica, al fine di garantire l'efficacia e l'appropriatezza clinica e organizzativa delle prestazioni erogate dal Servizio sanitario nazionale nell'ambito dei LEA, anche in relazione all'evoluzione scientifica e tecnologica, e' istituita, presso il Ministero della salute, la Commissione nazionale per l'aggiornamento dei LEA e la promozione dell'appropriatezza nel Servizio sanitario nazionale, nominata e presieduta dal Ministro della salute e composta dal direttore della Direzione generale della programmazione sanitaria del Ministero della salute e da quindici esperti qualificati e da altrettanti supplenti, di cui quattro designati dal Ministro della salute, uno dall'Istituto superiore di sanita' (ISS), uno dall'AGENAS, uno dall'Agenzia italiana del farmaco (AIFA), uno dal Ministero dell'economia e delle finanze e sette dalla Conferenza delle regioni e delle province autonome. La Commissione dura in carica tre anni. Su richiesta del presidente, alle riunioni della Commissione possono partecipare, per fornire il proprio contributo tecnico-scientifico, rappresentanti del Consiglio superiore di sanita', delle societa' scientifiche, delle Federazioni dei medici ed esperti esterni competenti nelle specifiche materie trattate.

557. La Commissione di cui al comma 556, nel rispetto degli equilibri programmati di finanza pubblica, nonche' degli obblighi di pubblicita', trasparenza e diffusione di informazioni di cui al decreto legislativo 14 marzo 2013, n. 33, anche su proposta dei suoi componenti, svolge in particolare le seguenti attivita':

- a) procede ad una valutazione sistematica delle attivita', dei servizi e delle prestazioni di assistenza sanitaria e socio-sanitaria a rilevanza sanitaria inclusi nei LEA, per valutarne il mantenimento ovvero per definire condizioni di erogabilita' o indicazioni di appropriatezza;
- b) acquisisce e valuta le proposte di inserimento nei LEA di nuovi servizi, attivita' e prestazioni;
- c) per l'aggiornamento dei LEA e l'individuazione di condizioni di erogabilita' o indicazioni di appropriatezza, si avvale delle valutazioni di HTA su tecnologie sanitarie e biomediche e su modelli e procedure organizzativi;
- d) valuta l'impatto economico delle modifiche ai LEA;
- e) valuta le richieste, provenienti da strutture del Servizio sanitario nazionale, di autorizzazione all'esecuzione di prestazioni innovative nell'ambito di programmi di sperimentazione, ai sensi dell'articolo 1, comma 8, del decreto legislativo 30 dicembre 1992, n. 502, e successive modificazioni;
- f) valuta che l'applicazione dei LEA avvenga in tutte le regioni con lo stesso standard di qualita' e includa tutte le prestazioni previste dagli specifici LEA.

558. Sulla base dell'attivita' svolta ai sensi del comma 557, la Commissione di cui al comma 556 formula annualmente una proposta di aggiornamento dei LEA.

559. Se la proposta attiene esclusivamente alla modifica degli elenchi di prestazioni erogabili dal Servizio sanitario nazionale ovvero alla individuazione di misure volte ad incrementare l'appropriatezza della loro erogazione e la sua approvazione non comporta ulteriori oneri a carico della finanza pubblica, l'aggiornamento dei LEA e' effettuato con decreto del Ministro della salute, adottato di concerto con il Ministro dell'economia e delle finanze, sentita la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, previo parere delle competenti Commissioni parlamentari, da pubblicare nella Gazzetta Ufficiale previa registrazione della Corte dei conti.

560. La partecipazione alla Commissione di cui al comma 556 e' onorifica; essa puo' dar luogo esclusivamente al rimborso delle spese sostenute, ove spettante, nel rispetto della disciplina prevista in materia dalla legislazione vigente.

561. Per lo svolgimento delle attivita' di cui ai commi da 553 a 560, la Commissione e' supportata da una segreteria tecnico-scientifica operante presso la Direzione generale della programmazione sanitaria del Ministero della salute, che puo' avvalersi di personale messo a disposizione, in posizione di comando o distacco, da ISS, AIFA, AGENAS, regioni, enti del Servizio sanitario nazionale ed altri enti rappresentati nell'ambito della Commissione, nel numero massimo di cinque unita'.

562. Per le attivita' di supporto di cui al comma 561 che richiedono specifiche attivita' di ricerca, il Ministero della salute puo' avvalersi, anche tramite specifiche convenzioni, della collaborazione di istituti di ricerca, societa' scientifiche e strutture pubbliche o private, anche non nazionali, nonche' di esperti, nel numero massimo di cinque.

563. Gli oneri derivanti dai commi 556, 561 e 562 ammontano ad euro 1 milione.

564. Al comma 3 dell'articolo 54 della legge 27 dicembre 2002, n. 289, dopo le parole: «Consiglio dei Ministri», sono inserite le seguenti: «su proposta del Ministro della salute, di concerto con il Ministro dell'economia e delle finanze,».

565. A decorrere dalla costituzione della Commissione di cui al comma 556, e' abrogato il comma 10 dell'articolo 4-bis del decreto-legge 15 aprile 2002, n. 63, convertito, con modificazioni, dalla legge 15 giugno 2002, n. 112, e al regolamento di cui al decreto del Presidente della Repubblica 28 marzo 2013, n. 44, sono apportate le seguenti modifiche:

- a) all'articolo 2, comma 1, la lettera a) e' abrogata;
- b) all'articolo 3, comma 1: 1) alla lettera a), la parola: «sessantadue» e' sostituita dalla seguente: «cinquantanove»; 2) alla lettera b), la parola: «quattro» e' sostituita dalla seguente: «due»; 3) alla lettera n), la parola: «trentanove» e' sostituita dalla seguente: «trentaquattro»;
- c) all'allegato 1, il punto 22 e' soppresso.

566. Nell'ambito delle risorse destinate al finanziamento del Servizio sanitario nazionale, per la revisione delle tariffe massime delle prestazioni di assistenza termale, ai sensi di quanto previsto all'articolo 1, comma 170, della legge 30 dicembre 2004, n. 311, e successive modificazioni, e' autorizzata la spesa di 5 milioni di euro per ciascuno degli anni 2016, 2017 e 2018.

567. A decorrere dal 1º gennaio 2016, i cittadini che usufruiscono delle cure termali, con esclusione dei soggetti individuati dall'articolo 8, comma 16, della legge 24 dicembre 1993, n. 537, e successive modificazioni, dei soggetti individuati dal regolamento di cui al decreto del Ministro della sanita' 28 maggio 1999, n. 329, degli invalidi di guerra titolari di pensione diretta vitalizia, dei grandi invalidi per servizio, degli invalidi civili al 100 per cento e dei grandi invalidi del lavoro, sono tenuti a partecipare alla spesa ai sensi dell'articolo 52, comma 2, della legge 27 dicembre 2002, n. 289, in misura pari a 55 euro o nella misura superiore che potra' essere individuata in sede di accordo di cui all'articolo 4, comma 4, della legge 24 ottobre 2000, n. 323. Il livello del finanziamento del fabbisogno sanitario standard cui concorre ordinariamente lo Stato e' incrementato di 2 milioni di euro per ciascuno degli anni 2016, 2017 e 2018.

568. Il livello del finanziamento del fabbisogno sanitario nazionale standard cui concorre lo Stato, come stabilito dall'articolo 1, commi 167 e 556, della legge 23 dicembre 2014, n. 190, e dall'articolo 9-septies, comma 1, del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125, e' rideterminato, per l'anno 2016, in 111.000 milioni di euro. Sono sterilizzati gli effetti derivanti dal periodo precedente sugli obiettivi di finanza pubblica delle autonomie speciali.

569. Ai fini di consentire la regolare somministrazione dei farmaci innovativi nel rispetto della cornice finanziaria programmata per il Servizio sanitario nazionale e in relazione alle misure di efficientamento del settore sanitario previste dai commi da 521 a 552 e dalle disposizioni di cui all'articolo 9-ter, commi 10 e 11, del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125, per gli anni 2015 e 2016, la spesa per l'acquisto di farmaci innovativi concorre al raggiungimento del tetto di spesa per l'assistenza farmaceutica territoriale di cui all'articolo 15, comma 3, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, per l'ammontare eccedente annualmente, per ciascuno degli anni 2015 e 2016, l'importo del fondo di cui all'articolo 1, comma 593, della legge 23 dicembre 2014, n. 190. Il presente comma entra in vigore il giorno successivo a quello della pubblicazione della presente legge nella Gazzetta Ufficiale.

570. Allo scopo di consentire l'accesso ai trattamenti innovativi in una prospettiva di sostenibilita' del sistema e di programmazione delle cure, il Ministero della salute, sentita l'AIFA, in coerenza con la cornice finanziaria programmata per il Servizio sanitario nazionale, predispone annualmente un programma strategico volto a definire le priorita' di intervento, le condizioni di accesso ai trattamenti, i parametri di rimborsabilita' sulla base di risultati clinici significativi, il numero dei pazienti potenzialmente trattabili e le relative previsioni di spesa, le condizioni di acquisto, gli schemi di prezzo condizionato al risultato e gli indicatori di performance degli stessi, gli strumenti a garanzia e trasparenza di tutte le procedure, le modalita' di monitoraggio e valutazione degli interventi in tutto il territorio nazionale. Il programma e' approvato annualmente d'intesa con la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano.

571. E' istituito, nello stato di previsione del Ministero della salute, il fondo per finanziare la prima applicazione da parte delle farmacie del servizio di revisione dell'uso dei medicinali (Medicine Use Review), finalizzato, in via sperimentale, ad assicurare l'aderenza farmacologica alle terapie con conseguente riduzione dei costi per le spese sanitarie relative ai pazienti affetti da asma.

572. Il fondo di cui al comma 571 e' assegnato alle regioni e alle province autonome di Trento e di Bolzano in proporzione alla popolazione residente ed e' destinato in via esclusiva e diretta a finanziare la remunerazione del servizio reso dal farmacista.

573. Per il finanziamento del fondo di cui al comma 571 e' stanziata, per l'anno 2016, la somma di euro 1.000.000.

574. All'articolo 15, comma 14, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, sono apportate le seguenti modificazioni:

- a) al primo periodo, le parole: «A tutti i singoli contratti e a tutti i singoli accordi» sono sostituite dalle seguenti: «Ai contratti e agli accordi» e le parole: «percentuale fissa,» sono soppresse;
- b) dopo il primo periodo sono inseriti i seguenti: «A decorrere dall'anno 2016, in considerazione del processo di riorganizzazione del settore ospedaliero privato accreditato in attuazione di quanto previsto dal regolamento di cui al decreto del Ministro della salute 2 aprile 2015, n. 70, al fine di valorizzare il ruolo dell'alta specialita' all'interno del territorio nazionale, le regioni e le province autonome di Trento e di Bolzano possono programmare l'acquisto di prestazioni di assistenza ospedaliera di alta specialita', nonche' di prestazioni erogate da parte degli istituti di ricovero e cura a carattere scientifico (IRCCS) a favore di cittadini residenti in regioni diverse da quelle di appartenenza ricomprese negli accordi per la compensazione della mobilita' interregionale di cui all'articolo 9 del Patto per la salute sancito in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano con intesa del 10 luglio 2014 (atto rep. 82/CSR), e negli accordi bilaterali fra le regioni per il governo della mobilita' sanitaria interregionale, di cui all'articolo 19 del Patto per la salute sancito con intesa del 3 dicembre 2009, pubblicata nella Gazzetta Ufficiale n. 3 del 5 gennaio 2010, in deroga ai limiti previsti dal primo periodo. Al fine di garantire, in ogni caso, l'invarianza dell'effetto finanziario connesso alla deroga di cui al periodo precedente, le regioni e le province autonome di Trento e di Bolzano provvedono ad adottare misure alternative, volte, in particolare, a ridurre le prestazioni inappropriate di bassa complessita' erogate in regime ambulatoriale, di pronto soccorso, in ricovero ordinario e in riabilitazione e lungodegenza, acquistate dagli erogatori privati accreditati, in misura tale da assicurare il rispetto degli obiettivi di riduzione di cui al primo periodo, nonche' gli obiettivi previsti dall'articolo 9-quater, comma 7, del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125; possono contribuire al raggiungimento del predetto obiettivo finanziario anche misure alternative a valere su altre aree della spesa sanitaria. Le prestazioni di assistenza ospedaliera di alta specialita' e i relativi criteri di appropriatezza sono definiti con successivo accordo sancito in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano. In sede di prima applicazione sono definite prestazioni di assistenza ospedaliera di alta specialita' i ricoveri individuati come "ad alta complessita'" nell'ambito del vigente Accordo interregionale per la compensazione della mobilita' sanitaria, sancito in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano. Le regioni trasmettono trimestralmente ai Ministeri della salute e dell'economia e delle finanze i provvedimenti di propria competenza di compensazione della maggiore spesa sanitaria regionale per i pazienti extraregionali presi in carico dagli IRCCS. Ne danno altresi' comunicazione alle regioni di residenza dei medesimi pazienti e al coordinamento regionale per la salute e per gli affari finanziari al fine di permettere, alla fine dell'esercizio, le regolazioni in materia di compensazione della mobilita' sanitaria nell'ambito del riparto delle disponibilita' finanziarie del Servizio sanitario nazionale. Le regioni pubblicano per ciascun IRCCS su base trimestrale il valore delle prestazioni rese ai pazienti extraregionali di ciascuna regione».(30)

575. Gli accordi per la compensazione della mobilita' interregionale di cui all'articolo 9 del Patto per la salute sancito in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano con intesa del 10 luglio 2014 (atto rep. 82/CSR), sono sanciti dalla medesima Conferenza, nel rispetto degli equilibri di bilancio programmati.

576. Dalla data di entrata in vigore della presente legge, gli accordi bilaterali fra le regioni per il governo della mobilita' sanitaria interregionale, di cui all'articolo 19 del Patto per la salute sancito con intesa del 3 dicembre 2009, pubblicata nella Gazzetta Ufficiale n. 3 del 5 gennaio 2010, devono essere obbligatoriamente conclusi entro il 31 dicembre 2016.

577. Le strutture sanitarie che erogano prestazioni a carico del Servizio sanitario nazionale applicano ai pazienti, residenti in regioni diverse da quella in cui insistono le strutture, le medesime regole di accesso e di erogazione delle prestazioni previste per i pazienti residenti nella regione in cui sono ubicate le strutture. Le regioni individuano, nell'ambito del contratto stipulato con le strutture sanitarie, le misure sanzionatorie da applicare alle strutture che non rispettano la presente disposizione.

578. All'articolo 1, comma 171, della legge 30 dicembre 2004, n. 311, le parole: «importi tariffari diversi» sono sostituite dalle seguenti: «livelli di remunerazione complessivi diversi».

579. Il Ministero della salute, di concerto con il Ministero dell'economia e delle finanze, avvalendosi dell'Agenzia nazionale per i servizi sanitari regionali (AGENAS), assicura, su richiesta della regione interessata, senza nuovi o maggiori oneri a carico della finanza pubblica, il necessario supporto agli enti interessati dai piani di rientro di cui ai commi da 528 a 536 e mette a disposizione, ove necessario, strumenti operativi per la presentazione del piano ed il perseguimento dei suoi obiettivi, nonche' per l'affiancamento, da parte dell'AGENAS con oneri a carico del bilancio della medesima Agenzia, degli enti del Servizio sanitario nazionale per tutta la durata dei piani di rientro. Alla compensazione degli effetti finanziari in termini di fabbisogno e indebitamento netto derivanti dal presente comma, pari a 3,4 milioni di euro per ciascuno degli anni 2016, 2017 e 2018, si provvede mediante corrispondente riduzione del Fondo per la compensazione degli effetti finanziari non previsti a legislazione vigente conseguenti all'attualizzazione di contributi pluriennali, di cui all'articolo 6, comma 2, del decreto-legge 7 ottobre 2008, n. 154, convertito, con modificazioni, dalla legge 4 dicembre 2008, n. 189, e successive modificazioni.

580. Al fine di dotare il Paese di una infrastruttura dedicata ad un progetto nazionale di genomica applicata alla sanita' pubblica, denominato «Progetto genomi Italia», volto alla realizzazione di un piano nazionale di implementazione medico-sanitaria delle conoscenze e tecnologie genomiche con particolare riguardo al sequenziamento, all'analisi e alla valorizzazione scientifica delle sequenze genomiche della popolazione italiana, e' istituito presso il Ministero della salute un fondo denominato «Progetto genomi Italia», al quale e' assegnata la somma di 5 milioni di euro per ciascuno degli anni 2016, 2017 e 2018.

581. Gli atti e i provvedimenti concernenti l'utilizzazione del fondo, la progettazione e gestione del «Progetto genomi Italia», di cui al comma 580, sono adottati da una Commissione, denominata «Commissione nazionale genomi italiani», istituita con decreto di natura non regolamentare del Ministero della salute. La Commissione, di durata triennale, individua entro novanta giorni dalla data di entrata in vigore della presente legge il soggetto o i soggetti, pubblici o privati, che si impegnano a cofinanziare il progetto, con lettera di intenti da acquisire entro sei mesi dalla data di entrata in vigore della presente legge, nella misura non inferiore alle risorse destinate annualmente dallo Stato come individuate dal comma 580. Decorsi sei mesi dalla data di entrata in vigore della presente legge senza l'individuazione di cofinanziatori del progetto, la Commissione di cui al presente comma cessa le proprie funzioni relazionando al Ministro della salute sulle circostanze che hanno impedito la realizzazione del progetto.

582. Le risorse di cui all'articolo 2-ter, comma 3, del decreto-legge 29 marzo 2004, n. 81, convertito, con modificazioni, dalla legge 26 maggio 2004, n. 138, e le risorse di cui all'articolo 2, comma 307, della legge 24 dicembre 2007, n. 244, annualmente stanziate sui pertinenti capitoli dello stato di previsione del Ministero della salute, sono assegnate dal Ministero della salute direttamente al Centro nazionale trapianti per lo svolgimento delle attivita' di coordinamento della rete trapiantologica.

583. Le risorse di cui all'articolo 12 del decreto legislativo 9 novembre 2007, n. 207, e all'articolo 5 del decreto legislativo 9 novembre 2007, n. 208, annualmente stanziate sui pertinenti capitoli dello stato di previsione del Ministero della salute, sono equamente ripartite destinando il 50 per cento alle regioni e il 50 per cento al Centro nazionale sangue per le attivita' di coordinamento della rete trasfusionale.

584. A seguito dell'effettivo trasferimento al Servizio sanitario regionale delle funzioni in materia di assistenza sanitaria ai soggetti ospitati presso le residenze per l'esecuzione delle misure di sicurezza (REMS), alle regioni a statuto speciale sono trasferite le somme loro assegnate in sede di riparto della quota vincolata del Fondo sanitario nazionale per gli anni 2012, 2013, 2014, 2015 , 2016 e 2017, di cui all'articolo 3-ter, comma 7, del decreto-legge 22 dicembre 2011, n. 211, convertito, con modificazioni, dalla legge 17 febbraio 2012, n. 9.

585. E' autorizzata la spesa di 1 milione di euro per l'anno 2016, di 2 milioni di euro per ciascuno degli anni 2017 e 2018 e di 1 milione di euro annui a decorrere dall'anno 2019 in favore dell'Istituto Giannina Gaslini di Genova.

586. Gli indennizzi dovuti alle persone danneggiate da trasfusioni, somministrazioni di emoderivati o vaccinazioni, in base alla legge 25 febbraio 1992, n. 210, riconosciuti dopo il 1º maggio 2001, demandati alle regioni, in attesa del trasferimento dallo Stato delle somme dovute, vengono anticipati da ogni regione agli aventi diritto.

587. A decorrere dall'anno 2016, le dotazioni di bilancio in termini di competenza e di cassa relative alle missioni e ai programmi di spesa degli stati di previsione dei Ministeri sono ridotte per gli importi indicati nell'elenco n. 2, allegato alla presente legge.

588. Ai fini del concorso al raggiungimento degli obiettivi programmati di finanza pubblica, gli stanziamenti di bilancio iscritti a favore della Presidenza del Consiglio dei ministri sono ridotti per l'importo di 23.002.000 euro per l'anno 2016, di 21.756.000 euro per l'anno 2017 e di 18.006.000 euro a decorrere dall'anno 2018, come indicato nell'elenco n. 3, allegato alla presente legge.

589. Al fine di razionalizzare e ridurre i costi delle strutture tecniche del Dipartimento per la programmazione e il coordinamento della politica economica della Presidenza del Consiglio dei ministri, l'Unita' tecnica - Finanza di progetto, di cui all'articolo 7 della legge 17 maggio 1999, n. 144, e' soppressa e le relative funzioni e competenze sono trasferite al medesimo Dipartimento. Il Dipartimento, per lo svolgimento delle funzioni trasferite e di quelle esercitate a supporto del Nucleo di consulenza per l'attuazione delle linee guida per la regolazione dei servizi di pubblica utilita', previste dal decreto del Presidente del Consiglio dei ministri 25 novembre 2008, pubblicato nella Gazzetta Ufficiale n. 42 del 20 febbraio 2009, puo' avvalersi complessivamente di un massimo di diciotto esperti in materia di investimenti pubblici e finanza di progetto. Con decreto del Presidente del Consiglio dei ministri, da emanare entro sessanta giorni dalla data di entrata in vigore della presente legge, sono definiti i requisiti professionali, i criteri per l'attribuzione degli incarichi, la durata, le cause di incompatibilita' e il trattamento economico degli esperti. I richiami all'Unita' tecnica - Finanza di progetto contenuti in atti normativi devono intendersi riferiti al Dipartimento per la programmazione e il coordinamento della politica economica. Dall'attuazione della presente disposizione non devono derivare nuovi o maggiori oneri a carico della finanza pubblica.

590. Al fine di garantire, senza soluzione di continuita', la prosecuzione delle attivita' concernenti l'allertamento, il monitoraggio e il coordinamento operativo del sistema nazionale di protezione civile nonche' l'adempimento degli impegni derivanti dall'articolo 3 del decreto-legge 28 gennaio 2014, n. 4, convertito, con modificazioni, dalla legge 28 marzo 2014, n. 50, nelle more del rinnovo della contrattazione integrativa riguardante il personale della Presidenza del Consiglio dei ministri, continuano a produrre effetti le disposizioni in materia di riconoscimento delle integrazioni al trattamento economico accessorio di cui al comma 7 del medesimo articolo 3 del decreto-legge n. 4 del 2014, convertito, con modificazioni, dalla legge n. 50 del 2014, nel limite di spesa di 1,5 milioni di euro, a valere sui pertinenti stanziamenti del bilancio della Presidenza del Consiglio dei ministri.

591. Nell'ambito del programma «Regolazione giurisdizione e coordinamento del sistema della fiscalita'» della missione di spesa «Politiche economico-finanziarie e di bilancio», le dotazioni finanziarie iscritte sul capitolo 3845 dello stato di previsione del Ministero dell'economia e delle finanze sono ridotte di 40 milioni di euro per l'anno 2016, di 70 milioni di euro per ciascuno degli anni 2017 e 2018 e di 100 milioni di euro annui a decorrere dall'anno 2019. Con decreto del Ministro dell'economia e delle finanze, da adottare entro trenta giorni dalla data di entrata in vigore della presente legge, sono rideterminati i compensi spettanti ai centri autorizzati di assistenza fiscale in misura tale da realizzare i risparmi di spesa di cui al periodo precedente.

592. L'autorizzazione di spesa di cui all'articolo 47, secondo comma, della legge 20 maggio 1985, n. 222, relativamente alla quota destinata allo Stato dell'otto per mille dell'imposta sul reddito delle persone fisiche (IRPEF), e' ridotta di 10 milioni di euro a decorrere dall'anno 2016.

593. L'articolo 41, comma 16-sexiesdecies, del decreto-legge 30 dicembre 2008, n. 207, convertito, con modificazioni, dalla legge 27 febbraio 2009, n. 14, e' abrogato a decorrere dal 1º gennaio 2017.

594. A decorrere dal 1º gennaio 2017 e' istituito un fondo con una dotazione di 5 milioni di euro annui in favore delle regioni a statuto ordinario confinanti con l'Austria o con la Svizzera per la riduzione del prezzo alla pompa della benzina e del gasolio per autotrazione nelle aree di confine. Entro novanta giorni dalla data di entrata in vigore della presente legge, con decreto del Ministro dell'economia e delle finanze, sono definite le modalita' di ripartizione del fondo tra le regioni interessate.

595. Il Fondo di cui all'articolo 1, comma 200, della legge 23 dicembre 2014, n. 190, e' ridotto nella misura di 2 milioni di euro per l'anno 2016.

596. A decorrere dall'anno 2016 cessano i trasferimenti erariali in favore delle regioni a statuto speciale previsti dall'articolo 34, comma 4, del decreto legislativo 30 aprile 1992, n. 285, e dall'articolo 72, comma 3, del regolamento di cui al decreto del Presidente della Repubblica 16 dicembre 1992, n. 495, concernenti gli indennizzi di usura derivanti dall'uso dei mezzi d'opera.

597. All'articolo 201, comma 1-bis, del decreto legislativo 30 aprile 1992, n. 285, la lettera g-bis) e' sostituita dalla seguente: «g-bis) accertamento delle violazioni di cui agli articoli 80, 141, 143, commi 11 e 12, 146, 167, 170, 171, 193, 213 e 214, per mezzo di appositi dispositivi o apparecchiature di rilevamento».

598. A titolo di ristoro per le maggiori spese sostenute dagli enti locali della Regione siciliana in relazione all'accoglienza di profughi e rifugiati extracomunitari, e' autorizzata la spesa di 3 milioni di euro per l'anno 2016. Con decreto del Ministro dell'interno, da adottare di concerto con il Ministro dell'economia e delle finanze entro novanta giorni dalla data di entrata in vigore della presente legge, sono definite le modalita' di riparto delle risorse di cui al presente comma.

599. Al comma 1 dell'articolo 1-bis del decreto-legge 24 gennaio 2015, n. 4, convertito, con modificazioni, dalla legge 24 marzo 2015, n. 34, le parole: «15 dicembre 2015» sono sostituite dalle seguenti: «15 dicembre 2016».

600. Al fine di assicurare la razionalizzazione delle risorse finanziarie disponibili e l'ottimizzazione dell'impiego del personale nei procedimenti in materia di cittadinanza, immigrazione e asilo, quota parte delle risorse di cui all'articolo 9-bis della legge 5 febbraio 1992, n. 91, connesse alle attivita' istruttorie di competenza del Dipartimento per le liberta' civili e l'immigrazione e resesi disponibili a seguito di riassegnazioni nel corso dell'anno, individuata con decreto del Ministro dell'interno, di concerto con il Ministro dell'economia e delle finanze, puo' essere destinata alla corresponsione dei compensi per prestazioni di lavoro straordinario del personale del Dipartimento per le liberta' civili e l'immigrazione del Ministero dell'interno e delle Prefetture - Uffici territoriali del Governo, anche in deroga alla normativa vigente. Con il medesimo decreto si provvede all'autorizzazione delle prestazioni di lavoro straordinario del personale interessato.

601. L'autorizzazione di spesa di cui all'articolo 1, comma 431, della legge 27 dicembre 2013, n. 147, relativa al Fondo per la riduzione della pressione fiscale, e' ridotta di 809.608.622 euro per l'anno 2016, di 413.413.755 euro per l'anno 2017, di 410.985.329 euro per l'anno 2018 e di 387.985.329 euro a decorrere dall'anno 2019.

602. All'articolo 12, comma 4, del decreto-legge 28 dicembre 2013, n. 149, convertito, con modificazioni, dalla legge 21 febbraio 2014, n. 13, le parole: «27,7 milioni di euro per l'anno 2016 e di 45,1 milioni di euro» sono sostituite dalle seguenti: «17,7 milioni di euro per l'anno 2016 e di 25,1 milioni di euro».

603. Fermo restando quanto previsto dagli articoli 12 e 13-bis del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125, le risorse disponibili sull'autorizzazione di spesa di cui all'articolo 22-bis del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, sono destinate al finanziamento delle agevolazioni nelle sole zone franche urbane individuate dalla delibera CIPE n. 14/2009 dell'8 maggio 2009 ricadenti nelle regioni non comprese nell'obiettivo «Convergenza».

604. Nelle zone franche urbane gia' finanziate ai sensi dell'articolo 37, comma 1, del decreto-legge 18 ottobre 2012, n. 179, convertito, con modificazioni, dalla legge 17 dicembre 2012, n. 221, ivi inclusa la zona franca del comune di Lampedusa, istituita dall'articolo 23, comma 45, del decreto-legge 6 luglio 2011, n. 98, convertito, con modificazioni, dalla legge 15 luglio 2011, n. 111, il Ministero dello sviluppo economico adotta nuovi bandi finanziati con le risorse rivenienti da rinunce e da revoche relative alle agevolazioni gia' concesse nelle predette zone franche ai sensi dell'articolo 37 del citato decreto-legge n. 179 del 2012, nonche' da eventuali ulteriori risorse apportate dalle regioni.

605. Con riferimento all'esercizio finanziario 2016 gli specifici stanziamenti iscritti nello stato di previsione del Ministero del lavoro e delle politiche sociali per il finanziamento degli istituti di cui al comma 1 dell'articolo 13 della legge 30 marzo 2001, n. 152, sono complessivamente e proporzionalmente ridotti di 15 milioni di euro. I risparmi derivanti dal primo periodo conseguono a maggiori somme effettivamente affluite al bilancio dello Stato in deroga a quanto previsto dal citato articolo 13, comma 1, della legge 30 marzo 2001, n. 152. Con effetto dall'esercizio finanziario 2017, la percentuale, ai fini della determinazione degli stanziamenti in sede previsionale, di cui ai commi 4 e 5 dell'articolo 13 della legge 30 marzo 2001, n. 152, e' stabilita nella misura del 68 per cento, restando ferma la procedura di rideterminazione degli stanziamenti medesimi sulla base delle entrate affluite al bilancio dello Stato in relazione ai versamenti degli enti previdenziali. A valere sul gettito dei contributi previdenziali obbligatori incassati dall'anno 2015, l'aliquota di prelevamento di cui al comma 1 dell'articolo 13 della legge 30 marzo 2001, n. 152, e' rideterminata nella misura dello 0,199 per cento.

606. Al comma 5 dell'articolo 13 della legge 30 marzo 2001, n. 152, sono aggiunte, in fine, le seguenti parole: «e una ulteriore erogazione pari all'80 per cento dell'eventuale assegnazione disposta con la legge di assestamento del bilancio dello Stato di cui al comma 4».

607. A seguito dell'entrata in vigore della riforma complessiva degli istituti di patronato, anche al fine di garantire la corretta organizzazione dell'attivita' degli stessi, alla lettera c-bis) del comma 2 dell'articolo 16 della legge 30 marzo 2001, n. 152, introdotta dall'articolo 1, comma 310, lettera e), della legge 23 dicembre 2014, n. 190, la parola: «2014» e' sostituita dalla seguente: «2016».

608. Ferme restando le misure di contenimento della spesa gia' previste dalla legislazione vigente, gli enti nazionali di previdenza e assistenza sociale pubblici, nell'ambito della propria autonomia organizzativa, adottano ulteriori interventi di razionalizzazione per la riduzione delle proprie spese correnti diverse da quelle per le prestazioni previdenziali e assistenziali, in modo da conseguire, per il triennio 2016-2018, risparmi aggiuntivi complessivamente non inferiori a 53 milioni di euro annui, anche attraverso l'attuazione delle misure previste dai commi da 494 a 510, da versare entro il 30 giugno di ciascun anno ad apposito capitolo dell'entrata del bilancio dello Stato. Con decreto del Ministro del lavoro e delle politiche sociali, di concerto con il Ministro dell'economia e delle finanze, da adottare entro sessanta giorni dalla data di entrata in vigore della presente legge, e' stabilito il riparto dell'importo di cui al primo periodo tra gli enti ivi citati.

609. Il Ministero della giustizia adotta misure volte alla razionalizzazione delle indennita' da corrispondere ai giudici di pace, ai giudici onorari aggregati, ai giudici onorari di tribunale e ai vice procuratori onorari, in modo da assicurare risparmi non inferiori a euro 6.650.275 per l'anno 2016 e a euro 7.550.275 a decorrere dall'anno 2017.

610. I giudici onorari di tribunale e i vice procuratori onorari il cui mandato scade il 31 dicembre 2015 e per i quali non e' consentita un'ulteriore conferma a norma dell'articolo 42-quinquies, primo comma, dell'ordinamento giudiziario, di cui al regio decreto 30 gennaio 1941, n. 12, nonche' i giudici di pace il cui mandato scade entro il 31 maggio 2016 e per i quali non e' consentita un'ulteriore conferma a norma dell'articolo 7, comma 1, della legge 21 novembre 1991, n. 374, e successive modificazioni, sono ulteriormente prorogati nell'esercizio delle rispettive funzioni a far data dal 1º gennaio 2016 fino alla riforma organica della magistratura onoraria e, comunque, non oltre il 31 maggio 2016.

611. All'articolo 3, comma 79, della legge 24 dicembre 2003, n. 350, dopo le parole: «presso la Corte di cassazione e la relativa Procura generale,» sono inserite le seguenti: «nonche' a quelli in servizio presso la Direzione nazionale antimafia e antiterrorismo, ».

612. Per le finalita' di cui al comma 611 e' autorizzata la spesa di 193.515,35 euro annui a decorrere dall'anno 2016.

613. All'articolo 245, comma 1, del decreto legislativo 19 febbraio 1998, n. 51, le parole: «non oltre il 31 dicembre 2015» sono sostituite dalle seguenti: «non oltre il 31 maggio 2016».

614. Il Fondo di cui all'articolo 1, comma 96, della legge 23 dicembre 2014, n. 190, e' ridotto di 4 milioni di euro per l'anno 2016.

615. All'articolo 19 della legge 30 marzo 1981, n. 119, dopo il secondo comma e' aggiunto il seguente: «I mutui suddetti possono essere altresi' impiegati, nel caso in cui il finanziamento e' stato concesso ma non ancora erogato o utilizzato, per la realizzazione di opere di ricostruzione, ristrutturazione, sopraelevazione, ampliamento, restauro o rifunzionalizzazione di edifici pubblici da destinare a finalita' anche differente dall'edilizia giudiziaria e il cui riuso, a seguito di intese tra le amministrazioni interessate e il Ministero della giustizia, e' funzionale alla realizzazione di progetti di edilizia giudiziaria. In questo caso, gli enti locali ai quali e' stato concesso il finanziamento devono presentare alla Cassa depositi e prestiti, previo parere favorevole del Ministero della giustizia, istanza di autorizzazione all'impiego degli importi anche per le destinazioni diverse da quelle per le quali era stato concesso il finanziamento. Nel caso in cui i mutui concessi siano stati estinti per essere stati gli obblighi derivanti dal finanziamento interamente assolti nei confronti della Cassa depositi e prestiti, l'immobile puo' essere destinato dall'amministrazione interessata a finalita' diverse dall'edilizia giudiziaria previo parere favorevole del Ministero della giustizia».

616. All'articolo 1, comma 99-bis, della legge 23 dicembre 2014, n. 190, sono apportate le seguenti modificazioni:

- a) al primo periodo, le parole: «31 dicembre 2015» sono sostituite dalle seguenti: «31 dicembre 2016»;
- b) al secondo periodo, le parole: «30 settembre 2015» sono sostituite dalle seguenti: «28 febbraio 2016».

617. All'articolo 21-quinquies del decreto-legge 27 giugno 2015, n. 83, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 132, sono apportate le seguenti modificazioni:

- a) al comma 1, le parole: «31 dicembre 2015» sono sostituite dalle seguenti: «31 dicembre 2016»;
- b) al comma 3, dopo le parole: «15 per cento» sono aggiunte le seguenti: «, per l'anno 2015 e del 20 per cento per l'anno 2016».

618. All'articolo 21-bis del decreto-legge 27 giugno 2015, n. 83, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 132, sono apportate le seguenti modificazioni:

- a) il comma 1 e' sostituito dal seguente: «1. Alle parti che corrispondono o che hanno corrisposto il compenso agli avvocati abilitati ad assisterli nel procedimento di negoziazione assistita ai sensi del capo II del decreto-legge 12 settembre 2014, n. 132, convertito, con modificazioni, dalla legge 10 novembre 2014, n. 162, nonche' alle parti che corrispondono o che hanno corrisposto il compenso agli arbitri nel procedimento di cui al capo I del medesimo decreto, e' riconosciuto, in caso di successo della negoziazione, ovvero di conclusione dell'arbitrato con lodo, un credito di imposta commisurato al compenso fino a concorrenza di 250 euro, nel limite di spesa di 5 milioni di euro annui a decorrere dall'anno 2016»;
- b) al comma 2, le parole: «sessanta giorni dalla data di entrata in vigore della legge di conversione del presente decreto» sono sostituite dalle seguenti: «il 30 marzo 2016»;
- c) al comma 3, le parole: «dell'anno 2016» sono sostituite dalle seguenti: «di ciascun anno successivo a quello di corresponsione dei compensi di cui al comma 1»;
- d) al comma 4, le parole: «per l'anno 2015» sono soppresse;
- e) al comma 5, le parole: «agli oneri derivanti dall'attuazione del presente articolo, pari a 5 milioni di euro per l'anno 2016,» sono sostituite dalle seguenti: «per l'attuazione del presente articolo e' autorizzata la spesa di 5 milioni di euro annui a decorrere dall'anno 2016. Agli oneri per l'anno 2016».

619. COMMA ABROGATO DALLA L. 30 DICEMBRE 2018, N. 145.

620. In deroga a quanto previsto dall'allegato 8 di cui all'articolo 1, comma 318, della legge 23 dicembre 2014, n. 190, dall'anno 2016 e' autorizzato il pagamento del contributo obbligatorio per la conferma dell'adesione dell'Italia all'Accordo parziale del Consiglio d'Europa istitutivo del Gruppo Pompidou. Al relativo onere, pari a 225.000 euro annui a decorrere dall'anno 2016, si provvede mediante corrispondente utilizzo delle risorse disponibili nel bilancio autonomo della Presidenza del Consiglio dei ministri.

621. Alla tabella dei diritti consolari da riscuotere dagli uffici diplomatici e consolari, allegata al decreto legislativo 3 febbraio 2011, n. 71, sono apportate le seguenti modificazioni:

- a) gli importi dei diritti fissi di cui alle sezioni I, IV e VII, eccetto quello previsto dall'articolo 7-bis, sono aumentati del 20 per cento con arrotondamento all'importo intero superiore;
- b) gli importi dei diritti fissi di cui alle sezioni II, VI, VIII e IX sono aumentati del 40 per cento con arrotondamento all'importo intero superiore;
- c) alla sezione III, all'articolo 29 e' aggiunta, in fine, la seguente voce: «visto nazionale (tipo D) per motivi di studio: euro 50»;
- d) alla sezione VI gli articoli 41, 43 e 52 sono abrogati e i diritti di cui all'articolo 55 sono fissati in euro 25. (11)
- d-bis) i diritti di cui all'articolo 74 sono fissati in euro 50. (11)

622. Per le rappresentanze diplomatiche e gli uffici consolari e' autorizzata la spesa di 2 milioni di euro per l'anno 2016 da destinare alle seguenti tipologie di spesa:

- a) manutenzione degli immobili;
- b) attivita' di istituto, su iniziativa della rappresentanza diplomatica o dell'ufficio consolare interessati;
- c) assistenza alle comunita' di italiani residenti nella circoscrizione consolare di riferimento.

623. Le maggiori entrate rispetto all'esercizio finanziario 2015 derivanti dal comma 621, pari ad euro 6 milioni a decorrere dal 2016, rimangono acquisite all'entrata e non si applicano le disposizioni di cui all'articolo 1, comma 568, della legge 27 dicembre 2006, n. 296, e all'articolo 2, comma 58, della legge 24 dicembre 2007, n. 244.

624. Le maggiori entrate derivanti dalle operazioni di dismissione immobiliare realizzate nel triennio 2016-2018 dal Ministero degli affari esteri e della cooperazione internazionale in attuazione dell'articolo 1, commi 1311 e 1312, della legge 27 dicembre 2006, n. 296, per euro 20 milioni per l'anno 2016, euro 26 milioni per ciascuno degli anni 2017 e 2018 ed euro 16 milioni per l'anno 2019, rimangono acquisite all'entrata e non si applicano le disposizioni di cui all'articolo 1, comma 1314, della legge 27 dicembre 2006, n. 296. Nelle more del versamento delle predette risorse all'entrata del bilancio dello Stato, il Ministro dell'economia e delle finanze e' autorizzato ad accantonare e a rendere indisponibile per gli anni 2017, 2018 e 2019, nello stato di previsione del Ministero degli affari esteri e della cooperazione internazionale, a valere sulle disponibilita' di cui all'articolo 18, comma 2, lettera c), della legge 11 agosto 2014, n. 125, la somma di 26 milioni di euro per ciascuno degli anni 2017 e 2018 e di 16 milioni di euro per l'anno 2019, al netto di quanto effettivamente versato per ciascun anno del triennio 2017-2019.

625. La spesa relativa al trattamento economico del personale supplente delle istituzioni scolastiche all'estero, di cui all'articolo 651 del testo unico di cui al decreto legislativo 16 aprile 1994, n. 297, e' ridotta di euro 2.000.000 per ciascuno degli anni 2016, 2017 e 2018.

626. Le somme assegnate alle istituzioni scolastiche per le supplenze brevi e saltuarie prima del passaggio al sistema di pagamento di cui all'articolo 4, comma 4-septies, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, e giacenti sui bilanci delle medesime istituzioni, pari a 60 milioni di euro, sono versate all'entrata del bilancio dello Stato nell'anno 2016 e sono acquisite all'Erario. Nelle more del versamento delle predette somme all'entrata del bilancio dello Stato, il Ministro dell'economia e delle finanze e' autorizzato ad accantonare e a rendere indisponibile per l'anno 2016, nello stato di previsione del Ministero dell'istruzione, dell'universita' e della ricerca e a valere sulle disponibilita' di cui all'articolo 1, comma 601, della legge 27 dicembre 2006, n. 296, la somma di 60 milioni di euro al netto di quanto effettivamente versato.

627. Le risorse finanziarie dei soppressi Istituti regionali di ricerca educativa (IRRE) confluite nel bilancio dell'Istituto nazionale di documentazione, innovazione e ricerca educativa (INDIRE), relative a progetti in affidamento agli ex IRRE non attuati, pari a 1 milione di euro per l'anno 2016, sono versate all'entrata del bilancio dello Stato nell'anno 2016 e sono acquisite all'Erario. Nelle more del versamento delle predette risorse all'entrata del bilancio dello Stato, il Ministro dell'economia e delle finanze e' autorizzato ad accantonare e a rendere indisponibile per l'anno 2016, nello stato di previsione del Ministero dell'istruzione, dell'universita' e della ricerca e a valere sulle disponibilita' di cui all'articolo 7 del decreto legislativo 5 giugno 1998, n. 204, la somma di 1 milione di euro al netto di quanto effettivamente versato.

628. Le risorse finanziarie assegnate e trasferite alle universita', nell'ambito dei finanziamenti per l'attuazione degli interventi di edilizia universitaria negli anni dal 1998 al 2008 a valere sugli stanziamenti disponibili nel bilancio dello Stato e per i quali gli atenei hanno provveduto alla definizione degli interventi da realizzare, per ciascun tipo di edilizia generale, dipartimentale o sportiva, che al 31 dicembre 2014 risultano ancora non totalmente spese, sono versate all'entrata del bilancio dello Stato nell'esercizio finanziario 2016.

629. Con apposito decreto, il Ministro dell'istruzione, dell'universita' e della ricerca procede alla individuazione degli atenei interessati, alla definizione delle modalita' di recupero delle somme, anche eventualmente a valere sul Fondo per il finanziamento ordinario delle universita' per l'esercizio finanziario 2016, alla quantificazione delle somme non spese fino all'importo massimo di 30 milioni di euro. Al fine di assicurare il versamento degli importi individuati, il Ministero provvede al versamento in apposito capitolo dell'entrata del bilancio dello Stato a valere sul «Fondo per il finanziamento ordinario delle universita' e dei consorzi interuniversitari» per l'esercizio finanziario 2016.

630. Nelle more del versamento delle somme di cui al comma 629 all'entrata del bilancio dello Stato, il Ministro dell'economia e delle finanze e' autorizzato ad accantonare e a rendere indisponibile per l'anno 2016, nello stato di previsione del Ministero dell'istruzione, dell'universita' e della ricerca e a valere sulle disponibilita' di cui all'articolo 5, comma 1, della legge 24 dicembre 1993, n. 537, la somma di 30 milioni di euro al netto di quanto effettivamente versato.

631. L'autorizzazione di spesa di cui all'articolo 19-ter, comma 16, lettera e), del decreto-legge 25 settembre 2009, n. 135, convertito, con modificazioni, dalla legge 20 novembre 2009, n. 166, e' ridotta di 7.900.000 euro a decorrere dal 2016.

632. Le risorse di cui all'articolo 39, comma 2, della legge 1º agosto 2002, n. 166, sono ridotte di 2.700.000 euro per ciascuno degli anni 2016, 2017 e 2018.

633. Le risorse di cui all'articolo 1, comma 1230, della legge 27 dicembre 2006, n. 296, sono ridotte di 3.765.800 euro per il 2016 e di 3.700.000 euro a decorrere dal 2017.

634. All'articolo 1, comma 38, della legge 27 dicembre 2013, n. 147, il secondo periodo e' soppresso.

635. All'articolo 1, comma 374, della legge 23 dicembre 2014, n. 190, sono apportate le seguenti modificazioni:

- a) al primo periodo, le parole: «e a 100 milioni di euro annui negli anni 2016 e 2017» sono sostituite dalle seguenti: «, a 300 milioni di euro nell'anno 2016 e a 100 milioni di euro nell'anno 2017»;
- b) il secondo periodo e' sostituito dal seguente: «A tal fine, i proventi delle dismissioni sono versati all'entrata del bilancio dello Stato e non si da' luogo a riassegnazione»;
- c) al terzo periodo, le parole: «e di 100 milioni di euro annui per ciascuno degli anni 2016 e 2017» sono sostituite dalle seguenti: «, di 300 milioni di euro per l'anno 2016 e di 100 milioni di euro per l'anno 2017».

636. Il termine di cui all'articolo 1, comma 1, primo periodo, del decreto-legge 31 agosto 2013, n. 101, convertito, con modificazioni, dalla legge 30 ottobre 2013, n. 125, e' prorogato al 31 dicembre 2016.

637. All'articolo 1, comma 667, della legge 23 dicembre 2014, n. 190, sono apportate le seguenti modificazioni:

- a) la parola: «libri» e' sostituita dalle seguenti: «giornali, notiziari quotidiani, dispacci delle agenzie di stampa, libri e periodici»;
- b) dopo le parole: «codice ISBN» sono inserite le seguenti: «o ISSN».

638. Il Fondo per interventi strutturali di politica economica, di cui all'articolo 10, comma 5, del decreto-legge 29 novembre, 2004, n. 282, convertito, con modificazioni, dalla legge 27 dicembre 2004, n. 307, e' ridotto di 5,201 milioni di euro per l'anno 2016 ed e' incrementato di 39,604 milioni di euro per l'anno 2017, di 90,504 milioni di euro per l'anno 2018, di 177,294 milioni di euro per l'anno 2019, di 180,494 milioni di euro per l'anno 2020, di 177,594 milioni di euro per l'anno 2021, di 186,794 milioni di euro per l'anno 2022, di 197,294 milioni di euro per ciascuno degli anni 2023, 2024, 2025 e 2026, di 245,894 milioni di euro per l'anno 2027 e di 226,084 milioni di euro a decorrere dall'anno 2028.

639. Il Fondo di cui all'articolo 1, comma 200, della legge 23 dicembre 2014, n. 190, e' rifinanziato nella misura di 20 milioni di euro per l'anno 2016 e di 10 milioni di euro a decorrere dall'anno 2017.

640. Per la progettazione e la realizzazione di un sistema nazionale di ciclovie turistiche, con priorita' per i percorsi Verona-Firenze (Ciclovia del Sole), Venezia-Torino (Ciclovia VENTO), da Caposele (AV) a Santa Maria di Leuca (LE) attraverso la Campania, la Basilicata e la Puglia (Ciclovia dell'acquedotto pugliese), Grande raccordo anulare delle biciclette (GRAB) di Roma, ciclovia del Garda, ciclovia Trieste - Lignano Sabbiadoro - Venezia, ciclovia Sardegna, ciclovia Magna Grecia (Basilicata, Calabria, Sicilia), ciclovia Tirrenica e ciclovia Adriatica, nonche' per la progettazione e la realizzazione di ciclostazioni e di interventi concernenti la sicurezza della circolazione ciclistica cittadina, e' autorizzata la spesa di 17 milioni di euro per l'anno 2016 e di 37 milioni di euro per ciascuno degli anni 2017 e 2018. Per la progettazione e la realizzazione di itinerari turistici a piedi, denominati «cammini», e' autorizzata la spesa di un milione di euro per ciascuno degli anni 2016, 2017 e 2018. I progetti e gli interventi sono individuati con decreto del Ministro delle infrastrutture e dei trasporti e, per quanto concerne quelli relativi alle ciclovie turistiche, con decreto del Ministro delle infrastrutture e dei trasporti, di concerto con il Ministro dei beni e delle attivita' culturali e del turismo. (14)

641. Al comma 56 dell'articolo 1 della legge 27 dicembre 2013, n. 147, le parole: «composte da almeno quindici individui che si uniscono» sono sostituite dalle seguenti: «che si uniscono in numero almeno pari a cinque».

642. Al comma 57 dell'articolo 1 della legge 27 dicembre 2013, n. 147, l'alinea e' sostituito dal seguente: «Le risorse del fondo sono destinate ai soggetti di cui al comma 56, ammessi attraverso procedure selettive indette dal Ministero dello sviluppo economico in grado anche di valorizzare il coinvolgimento di istituti di ricerca pubblici, universita', istituzioni scolastiche autonome ed enti autonomi con funzioni di rappresentanza del tessuto produttivo nella realizzazione dei programmi proposti, ovvero nella fruizione dei relativi risultati. Ai fini della loro ammissibilita', i programmi devono avere durata almeno biennale e essere finalizzati a sviluppare i seguenti principi e contenuti:».

643. Con decreto del Ministro dello sviluppo economico sono apportate le modificazioni necessarie per l'attuazione delle disposizioni di cui ai commi 641 e 642 alle previsioni di cui al decreto del Ministro dello sviluppo economico 17 febbraio 2015, pubblicato nella Gazzetta Ufficiale n. 82 del 9 aprile 2015.

644. Agli oneri derivanti dal comma 640 si provvede:

- a) quanto a 5 milioni di euro per l'anno 2016, mediante riduzione dell'autorizzazione di spesa di cui all'articolo 18, comma 1, del decreto-legge 21 giugno 2013, n. 69, convertito, con modificazioni, dalla legge 9 agosto 2013, n. 98;
- b) quanto a 10,4 milioni di euro per l'anno 2017 e a 10,4 milioni di euro per l'anno 2018, mediante corrispondente riduzione delle risorse destinate all'erogazione del contributo per le spese di trasporto delle piccole e medie imprese siciliane di cui all'articolo 133 della legge 23 dicembre 2000, n. 388;
- c) quanto a 2,6 milioni di euro per l'anno 2017 e a 4,6 milioni di euro per l'anno 2018, mediante corrispondente utilizzo del fondo di parte corrente iscritto nello stato di previsione del Ministero delle infrastrutture e dei trasporti ai sensi dell'articolo 49, comma 2, lettere a) e b), del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89;
- d) quanto a 13 milioni di euro per l'anno 2016, a 25 milioni di euro per l'anno 2017 e a 23 milioni di euro per l'anno 2018, a valere sui risparmi derivanti dall'attuazione del comma 645.

645. A decorrere dal 1º gennaio 2016 il credito d'imposta relativo all'agevolazione sul gasolio per autotrazione degli autotrasportatori, di cui all'elenco 2 allegato alla legge 27 dicembre 2013, n. 147, non spetta per i veicoli di categoria euro 2 o inferiore. I risparmi conseguenti all'attuazione del primo periodo sono valutati in 160 milioni di euro per ciascuno degli anni dal 2016 al 2020, in 80 milioni di euro per l'anno 2021 e in 40 milioni di euro per l'anno 2022. Con decreto del Ministro dell'economia e delle finanze, di concerto con il Ministro delle infrastrutture e dei trasporti, sono stabilite, entro trenta giorni dalla data di entrata in vigore della presente legge, le modalita' di monitoraggio delle risorse derivanti dall'attuazione della misura di cui al primo periodo. Qualora si verifichino o siano in procinto di verificarsi scostamenti rispetto agli importi stimati, l'Agenzia delle dogane e dei monopoli, entro il 31 ottobre di ciascun anno, comunica il valore dello scostamento al Ministero dell'economia e delle finanze e al Ministero delle infrastrutture e dei trasporti. Tali somme sono quantificate con decreto del Ministro delle infrastrutture e dei trasporti, di concerto con il Ministro dell'economia e delle finanze. Qualora si verifichino maggiori risparmi rispetto a quanto stimato, i corrispondenti importi sono assegnati, anche mediante riassegnazione, allo stato di previsione del Ministero delle infrastrutture e dei trasporti. Qualora si verifichino minori risparmi rispetto a quanto stimato, il Ministro dell'economia e delle finanze, sentito il Ministro delle infrastrutture e dei trasporti, provvede, con proprio decreto, alla rideterminazione delle dotazioni finanziarie delle risorse assegnate agli interventi di cui ai commi 640, 647, 648, 650, 651, 654, 655 e 866, oppure di altre spese rimodulabili iscritte nello stato di previsione del Ministero delle infrastrutture e dei trasporti, in modo da assicurare la neutralita' rispetto ai saldi di finanza pubblica. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

646. Gli eventuali maggiori risparmi accertati di cui al comma 645 sono assegnati:

- a) fino al 15 per cento a interventi per favorire l'acquisto di mezzi di ultima generazione destinati al servizio dell'autotrasporto di merci su strada. Con decreto del Ministro delle infrastrutture e dei trasporti, di concerto con il Ministro dell'economia e delle finanze, sono stabilite le modalita' attuative della disposizione di cui alla presente lettera. L'efficacia di tale disposizione e' subordinata alla preventiva notifica alla Commissione europea, ai sensi dell'articolo 108 del Trattato sul funzionamento dell'Unione europea;
- b) fino all'85 per cento al Fondo cui al comma 866.

647. Il Ministero delle infrastrutture e dei trasporti e' autorizzato a concedere contributi per l'attuazione di progetti per migliorare la catena intermodale e decongestionare la rete viaria, riguardanti l'istituzione, l'avvio e la realizzazione di nuovi servizi marittimi per il trasporto combinato delle merci o il miglioramento dei servizi su rotte esistenti, in arrivo e in partenza da porti situati in Italia, che collegano porti situati in Italia o negli Stati membri dell'Unione europea o dello Spazio economico europeo. A tal fine e' autorizzata la spesa annua di 45,4 milioni di euro per l'anno 2016, di 44,1 milioni di euro per l'anno 2017 e di 48,9 milioni di euro per l'anno 2018.

648. Per il completo sviluppo del sistema di trasporto intermodale, il Ministero delle infrastrutture e dei trasporti e' altresi' autorizzato a concedere contributi per servizi di trasporto ferroviario intermodale in arrivo e in partenza da nodi logistici e portuali in Italia. A tal fine e' autorizzata la spesa annua di 20 milioni di euro per ciascuno degli anni 2016, 2017 e 2018. Agli stessi fini puo' essere utilizzata quota parte delle risorse di cui all'articolo 1, comma 150, della legge 23 dicembre 2014, n. 190.

649. L'individuazione dei beneficiari, la commisurazione degli aiuti, le modalita' e le procedure per l'attuazione degli interventi di cui ai commi 647 e 648 sono disciplinate con regolamento adottato, ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400, con decreto del Ministro delle infrastrutture e dei trasporti, di concerto con il Ministro dell'economia e delle finanze, da sottoporre, entro trenta giorni dalla data di entrata in vigore della presente legge, a notifica preventiva alla Commissione europea, ai sensi dell'articolo 108 del Trattato sul funzionamento dell'Unione europea.

650. Per consentire l'operativita' della sezione speciale per l'autotrasporto istituita nell'ambito del Fondo di garanzia per le piccole e medie imprese con il decreto del Ministro delle infrastrutture e dei trasporti 27 luglio 2009, pubblicato nella Gazzetta Ufficiale n. 233 del 7 ottobre 2009, per l'anno 2016 e' autorizzata la spesa di 10 milioni di euro.

651. A decorrere dal 1º gennaio 2016, a titolo sperimentale per un periodo di tre anni, per i conducenti che esercitano la propria attivita' con veicoli a cui si applica il regolamento (CE) n. 561/2006 del Parlamento europeo e del Consiglio, del 15 marzo 2006, equipaggiati con tachigrafo digitale e prestanti la propria attivita' in servizi di trasporto internazionale per almeno 100 giorni annui, e' riconosciuto, a domanda, l'esonero dai complessivi contributi previdenziali a carico dei datori di lavoro, con esclusione dei premi e contributi dovuti all'INAIL, nella misura dell'80 per cento nei limiti di quanto stabilito dal presente comma. Tale esonero e' riconosciuto entro i limiti e secondo le disposizioni del regolamento (UE) n. 1407/ 2013 della Commissione, del 18 dicembre 2013. A tal fine e' autorizzata la spesa di 65,5 milioni di euro per l'anno 2016, di 0,5 milioni di euro per l'anno 2017 e di 0,5 milioni di euro per l'anno 2018. L'esonero contributivo di cui al primo periodo e' riconosciuto dall'ente previdenziale in base all'ordine cronologico di presentazione delle domande; nel caso di insufficienza delle risorse indicate al secondo periodo, valutata anche su base pluriennale con riferimento alla durata dell'esonero, l'ente previdenziale non prende in considerazione ulteriori domande, fornendo immediata comunicazione anche attraverso il proprio sito internet. L'ente previdenziale provvede al monitoraggio delle minori entrate, valutate con riferimento alla durata dell'incentivo, inviando relazioni mensili al Ministero del lavoro e delle politiche sociali, al Ministero delle infrastrutture e dei trasporti e al Ministero dell'economia e delle finanze.

652. A decorrere dal 1º gennaio 2016 le deduzioni forfetarie delle spese non documentate disposte dall'articolo 66, comma 5, del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e dall'articolo 1, comma 106, della legge 23 dicembre 2005, n. 266, spettano in un'unica misura per i trasporti effettuati personalmente dall'imprenditore oltre il territorio del comune in cui ha sede l'impresa e, nella misura del 35 per cento dell'importo cosi' definito, per i trasporti personalmente effettuati dall'imprenditore all'interno del comune in cui ha sede l'impresa, nei limiti delle dotazioni di bilancio previste per lo scopo.

653. Dopo l'articolo 46-bis della legge 6 giugno 1974, n. 298, e' inserito il seguente: «Art. 46-ter. - (Documentazione relativa allo svolgimento di trasporti internazionali). 1. Fermo restando quanto previsto dall'articolo 46-bis, chiunque, durante l'effettuazione di un trasporto internazionale di merci, non e' in grado di esibire agli organi di controllo la prova documentale relativa al trasporto stesso, e' punito con la sanzione amministrativa pecuniaria del pagamento di una somma da euro 400 a euro 1.200. All'atto dell'accertamento della violazione e' sempre disposto il fermo amministrativo del veicolo, che e' restituito al conducente, al proprietario o al legittimo detentore, ovvero a persona da essi delegata, solo dopo che sia stata esibita la predetta documentazione e, comunque, trascorsi sessanta giorni dalla data dell'accertamento. Il veicolo sottoposto a fermo amministrativo e' affidato in custodia, a spese del responsabile della violazione, a uno dei soggetti individuati ai sensi del comma 1 dell'articolo 214-bis del codice della strada, di cui al decreto legislativo 30 aprile 1992, n. 285. Si applicano le disposizioni degli articoli 207 e 214 del medesimo codice. 2. La prova documentale di cui al comma 1 puo' essere fornita mediante l'esibizione di qualsiasi documento di accompagnamento delle merci previsto, per i trasporti internazionali, dalle vigenti norme nazionali o internazionali. 3. Fatta salva l'applicazione degli articoli 44 e 46, qualora il veicolo sia stato posto in circolazione privo della prova documentale di cui ai commi 1 e 2, ovvero questa sia stata compilata non conformemente alle norme di cui al comma 2, si applica la sanzione amministrativa pecuniaria del pagamento di una somma da euro 2.000 a euro 6.000. Se l'omessa o incompleta compilazione determina l'impossibilita' di verificare la regolarita' del trasporto internazionale di merci oggetto del controllo, si applicano le sanzioni di cui all'articolo 46, commi primo e secondo. Si osservano le disposizioni dell'articolo 207 del codice della strada, di cui al decreto legislativo 30 aprile 1992, n. 285».

654. Per la copertura degli oneri connessi al funzionamento dell'Autostrada ferroviaria alpina attraverso il tunnel del Frejus, e' autorizzata la spesa complessiva di euro 29.026.383 per il periodo dal 1º gennaio 2013 al 30 giugno 2018, di cui euro 2.226.383 a copertura dell'ultimo periodo della fase sperimentale dal 1º gennaio 2013 al 30 giugno 2013, gia' autorizzato dalla Commissione europea, e 26,8 milioni di euro per il periodo transitorio a decorrere dal 1º luglio 2013 al 30 giugno 2018, di cui 2,6 milioni di euro dal 1º luglio 2013 al 31 dicembre 2013, 5,4 milioni di euro per ciascuno degli anni dal 2014 al 2017 e 2,6 milioni di euro per il periodo dal 1º gennaio 2018 al 30 giugno 2018. L'onere di cui al primo periodo e' conseguentemente pari a 21.026.383 euro per l'anno 2016, a 5,4 milioni di euro per l'anno 2017 e a 2,6 milioni di euro per l'anno 2018. Il Ministero delle infrastrutture e dei trasporti provvede a stipulare l'accordo di programma con l'impresa ferroviaria Trenitalia Spa, beneficiaria del contributo per l'Autostrada ferroviaria alpina, per tutto l'arco temporale di cui al primo periodo, nonche' a modificare la convenzione stipulata con la societa' Cassa depositi e prestiti Spa al fine di provvedere, a condizioni piu' vantaggiose, all'erogazione da parte di quest'ultima dei relativi finanziamenti all'impresa ferroviaria Trenitalia Spa, secondo le modalita' indicate dal citato Ministero in un apposito addendum alla convenzione gia' stipulata. Per ciascuno degli anni dal 2018 al 2022 e', altresi', autorizzato un contributo di 10 milioni di euro finalizzato alla compensazione totale o parziale degli oneri derivanti dallo svolgimento dei servizi ferroviari di Autostrada ferroviaria alpina, effettuati attraverso il valico fra Italia e Francia, in particolare attraverso il Frejus. I predetti contributi sono concessi alle imprese aggiudicatarie dei servizi di Autostrada ferroviaria alpina mediante gara ad evidenza pubblica. Le compensazioni sono erogate a consuntivo, una volta all'anno, sulla base delle rendicontazioni fornite dall'aggiudicatario del servizio ferroviario, sia esso un'impresa ferroviaria, un operatore intermodale o un altro soggetto giuridico, ivi compresi i raggruppamenti d'impresa. La rendicontazione delle somme erogate e' effettuata annualmente, entro il mese di aprile dell'anno successivo, dal soggetto aggiudicatario della gara per la prestazione del servizio di Autostrada ferroviaria alpina, secondo i meccanismi previsti dall'accordo di programma firmato fra le parti.

655. Al fine di avviare un programma straordinario di prove su veicoli nuovi di fabbrica e su veicoli circolanti, tese a verificare l'effettivita' dei livelli di emissioni inquinanti su strada comparati con i valori rilevati durante le prove di omologazione sui rulli, nonche' di incrementare le verifiche di conformita' su veicoli e dispositivi a tutela della sicurezza stradale e della salute pubblica, e' autorizzata la spesa di 5 milioni di euro per l'anno 2016. Le modalita' tecniche e le procedure per l'attuazione delle disposizioni del primo periodo sono stabilite con decreto dirigenziale del Ministero delle infrastrutture e dei trasporti.

656. In attuazione dell'articolo 99, comma 2, del decreto legislativo 31 marzo 1998, n. 112, la societa' ANAS Spa e' autorizzata a stipulare accordi, previa intesa con il Ministero delle infrastrutture e dei trasporti, fino ad un massimo di 100 milioni di euro, a valere sulle risorse di cui all'articolo 1, comma 68, della legge 27 dicembre 2013, n. 147, come rifinanziata ai sensi della Tabella E allegata alla presente legge. Gli accordi stipulati in applicazione del predetto decreto legislativo n. 112 del 1998 sono pubblicati integralmente nei siti internet istituzionali della societa' ANAS Spa e degli enti locali interessati, ai sensi del decreto legislativo 14 marzo 2013, n. 33. (7)

657. Nelle more del completamento dell'attuazione delle disposizioni di cui all'articolo 21 del decreto-legge 24 giugno 2014, n. 90, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 114, e dell'emanazione del decreto legislativo di attuazione dell'articolo 11 della legge 7 agosto 2015, n. 124, e in particolare di quanto disposto dal comma 1, lettera d), del citato articolo 11, si provvede alla riorganizzazione della Scuola nazionale dell'amministrazione in modo da assicurare una riduzione dei servizi strumentali, una riduzione del numero complessivo dei docenti e un risparmio di spesa non inferiore al 10 per cento dei trasferimenti dal bilancio dello Stato. A tal fine, entro trenta giorni dalla data di entrata in vigore della presente legge, il Presidente del Consiglio dei ministri nomina un commissario straordinario. Conseguentemente, a far data dalla nomina del commissario, decadono il Comitato di gestione e il Presidente in carica. Entro i successivi trenta giorni il commissario straordinario propone al Ministro delegato per la semplificazione e la pubblica amministrazione e al Ministro dell'economia e delle finanze un piano di riorganizzazione diretto a realizzare gli obiettivi di cui al primo periodo. Il piano acquista efficacia mediante l'approvazione con apposito decreto del Presidente del Consiglio dei ministri, su proposta del Ministro delegato per la semplificazione e la pubblica amministrazione e del Ministro dell'economia e delle finanze, e rimane efficace fino all'adozione del decreto legislativo di cui al primo periodo. Fino alla data di entrata in vigore del medesimo decreto legislativo, rimane fermo quanto previsto dall'articolo 21, comma 4, del citato decreto-legge n. 90 del 2014, convertito, con modificazioni, dalla legge n. 114 del 2014, e l'adeguamento dei trattamenti economici ivi previsto ha comunque effetto a decorrere dalla data di entrata in vigore della presente legge.

658. All'articolo 4-bis del decreto-legge 20 giugno 2012, n. 79, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 131, sono apportate le seguenti modificazioni:

- a) al comma 1, lettera b), le parole: «della Scuola superiore dell'Amministrazione dell'interno» sono sostituite dalle seguenti: «della sede didattico-residenziale del Dipartimento per le politiche del personale dell'amministrazione civile e per le risorse strumentali e finanziarie del Ministero dell'interno»;
- b) dopo il comma 1 e' inserito il seguente: «1-bis. Le convenzioni previste al comma 1, lettera b), possono avere ad oggetto, in luogo del versamento del corrispettivo, la fornitura di un servizio in misura corrispondente al costo sostenuto per l'utilizzazione delle strutture della sede didattico-residenziale di cui al comma 1, lettera b)».

659. Al fine di razionalizzare e aumentare l'efficacia degli interventi pubblici per il finanziamento degli investimenti e l'accesso al credito e al mercato dei capitali delle imprese agricole e agroalimentari, nonche' al fine di razionalizzare e contenere la spesa pubblica, la societa' Istituto sviluppo agroalimentare (ISA) Spa e la Societa' gestione fondi per l'agroalimentare (SGFA) s.r.l. sono incorporate di diritto, alla data di entrata in vigore della presente legge, nell'Istituto di servizi per il mercato agricolo alimentare (ISMEA), che conserva la natura di ente pubblico economico, e l'Ufficio del registro delle imprese provvede alla iscrizione delle incorporazioni di ISA e SGFA su semplice richiesta di ISMEA. Le incorporazioni di cui al presente comma e le altre operazioni ad esse connesse sono esenti da tasse, nonche' da imposte dirette o indirette. Per la gestione delle garanzie, l'Istituto puo' costituire patrimoni separati ai sensi delle disposizioni di cui al libro quinto, titolo V, capo V, sezione XI, del codice civile.

660. L'ISMEA subentra nei rapporti giuridici attivi e passivi delle societa' di cui al comma 659, ivi inclusi i compiti e le funzioni ad esse attribuiti dalle disposizioni vigenti. Il personale a tempo indeterminato in servizio presso le medesime societa' e da esse dipendente alla data del 15 ottobre 2015 e' trasferito, a domanda, alle dipendenze di ISMEA ed inquadrato in base al contratto collettivo nazionale di lavoro applicato dallo stesso. L'inquadramento del personale dipendente a tempo indeterminato di ISA Spa e' disposto con provvedimento del commissario di cui al comma 661, assicurando che la spesa massima sostenuta per il medesimo personale non ecceda quella prevista alla data del 15 ottobre 2015 e garantendo l'allineamento ai livelli retributivi del contratto collettivo nazionale di lavoro applicato dall'ISMEA. Fino all'emanazione del provvedimento di cui al terzo periodo, al predetto personale e' corrisposto il trattamento economico fondamentale in godimento alla data del 15 ottobre 2015. Entro sessanta giorni dalla data di entrata in vigore della presente legge, il bilancio di chiusura delle societa' di cui al comma 659 e' deliberato dagli organi in carica alla data di incorporazione e trasmesso per l'approvazione al Ministero delle politiche agricole alimentari e forestali e al Ministero dell'economia e delle finanze. Ai componenti degli organi delle societa' di cui al comma 659 sono corrisposti compensi, indennita' o altri emolumenti comunque denominati soltanto fino alla data di incorporazione. Per gli adempimenti di cui al quinto periodo, ai componenti dei predetti organi spetta esclusivamente, ove dovuto, il rimborso delle spese sostenute, entro il termine di cui al medesimo periodo, nella misura prevista dal rispettivo ordinamento.

661. Ai fini dell'attuazione delle disposizioni di cui ai commi 659 e 660 e' nominato un commissario straordinario con le modalita' di cui al comma 662. Il commissario, entro centoventi giorni dalla data della sua nomina, predispone un piano triennale per il rilancio, la razionalizzazione e lo sviluppo delle attivita' finalizzate al finanziamento degli investimenti e all'accesso al credito, al mercato dei capitali delle imprese agricole e agroalimentari e alla gestione del rischio, delle politiche per l'internazionalizzazione, la promozione, la competitivita' e l'innovazione tecnologica, anche finalizzata alla tracciabilita' dei prodotti, delle filiere agricole e agroalimentari e delle start-up e delle reti di imprese, nonche' delle attivita' di monitoraggio dei prezzi dei prodotti agricoli, dei costi dei fattori di produzione e dell'andamento congiunturale dell'economia agricola e agroalimentare e delle filiere; predispone altresi' lo statuto dell'ISMEA e gli interventi di incremento dell'efficienza organizzativa ed economica finalizzati alla riduzione delle spese di gestione pari ad almeno il 10 per cento. In caso di inottemperanza, entro il termine di cui al quinto periodo del comma 660, degli organi in carica alla data dell'incorporazione, il commissario provvede altresi' all'adozione del bilancio di chiusura delle societa' di cui al comma 659 entro il termine di cui al secondo periodo del presente comma e ferme restando le responsabilita' gestorie dei predetti organi. Il Ministro delle politiche agricole alimentari e forestali, con uno o piu' decreti di concerto con il Ministro dell'economia e delle finanze, tenuto conto delle proposte del commissario, approva il piano degli interventi necessari ad assicurare il contenimento della spesa dell'ISMEA e adotta lo statuto dell'ISMEA.

662. Il commissario di cui al comma 661 e' nominato con decreto del Ministro delle politiche agricole alimentari e forestali, entro trenta giorni dalla data di entrata in vigore della presente legge, e dura in carica un anno, prorogabile, per motivate esigenze, una sola volta. Con il medesimo decreto sono stabiliti il mandato del commissario, che si sostituisce al presidente e al consiglio di amministrazione di ISMEA, assumendone le funzioni e i poteri statutariamente previsti, e l'ammontare del suo compenso. Con il decreto di cui al primo periodo, il Ministro delle politiche agricole alimentari e forestali puo' nominare anche due subcommissari, che affiancano il commissario nell'esercizio delle sue funzioni, fissando il relativo compenso, che non puo' comunque eccedere l'80 per cento di quello del commissario. Il compenso per il commissario e i subcommissari non puo' comunque eccedere il 50 per cento della spesa cumulativamente prevista per gli organi statutari sostituiti o soppressi ai sensi delle disposizioni di cui ai commi da 659 a 664. Al trattamento economico del commissario e dei subcommissari si provvede a valere sui capitoli di bilancio dell'ISMEA.

663. In attuazione delle disposizioni di cui ai commi da 659 a 664, il contributo ordinario annuo a carico dello Stato in favore di ISMEA e' soppresso e l'Istituto versa annualmente all'entrata del bilancio dello Stato la somma di 1 milione di euro.

664. Relativamente alle disposizioni di cui ai commi da 659 a 663, il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

665. Al fine di garantire il rilancio delle attivita' di ricerca e sperimentazione in agricoltura ai sensi dell'articolo 1, comma 381, della legge 23 dicembre 2014, n. 190, e favorire lo sviluppo di nuove tecnologie a supporto delle produzioni agricole, nonche' per accrescere il sistema delle conoscenze a sostegno dello sviluppo del settore agricolo nazionale e della tutela del made in Italy, il Consiglio per la ricerca in agricoltura e l'analisi dell'economia agraria (CREA) promuove un piano triennale di ricerca straordinario per lo sviluppo di un sistema informatico integrato di trasferimento tecnologico, analisi e monitoraggio delle produzioni agricole attraverso strumenti di sensoristica, diagnostica, meccanica di precisione, biotecnologie e bioinformatica.

666. Entro trenta giorni dalla data di entrata in vigore della presente legge, il CREA presenta al Ministro delle politiche agricole alimentari e forestali il piano di cui al comma 665, individuando i settori e le filiere di maggiore interesse su cui concentrare le risorse, gli enti di ricerca e le universita' da coinvolgere, le tecnologie da sviluppare e i risultati attesi. Entro sessanta giorni dalla ricezione del piano di cui al comma 665, il Ministro delle politiche agricole alimentari e forestali lo approva, con proprio decreto di natura non regolamentare, sentita la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano e previo parere delle Commissioni parlamentari competenti per materia, che si esprimono entro il termine di trenta giorni dalla richiesta, decorso il quale il decreto puo' comunque essere adottato.

667. Per le finalita' di cui ai commi 665 e 666 e' autorizzata la spesa di 5 milioni di euro per l'anno 2016 e di 8 milioni di euro per ciascuno degli anni 2017 e 2018.

668. All'articolo 1, comma 381, della legge 23 dicembre 2014, n. 190, sono apportate le seguenti modificazioni:

- a) al decimo periodo, le parole: «, lo statuto del Consiglio» sono soppresse;
- b) dopo il decimo periodo e' inserito il seguente: «Lo statuto del Consiglio e' adottato con regolamento del Ministro delle politiche agricole alimentari e forestali emanato ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400, anche in deroga alle disposizioni di cui al decreto legislativo 29 ottobre 1999, n. 454, che sono abrogate a decorrere dalla data di entrata in vigore del medesimo regolamento, previo parere delle Commissioni parlamentari competenti, che si pronunciano entro il termine di trenta giorni dalla richiesta, decorso il quale il regolamento puo' comunque essere adottato.».

669. Nelle more dell'adozione del decreto legislativo di attuazione dell'articolo 8 della legge 7 agosto 2015, n. 124, e in particolare del criterio direttivo di cui al comma 1, lettera a), del citato articolo 8, l'associazione Formez PA, di cui al decreto legislativo 25 gennaio 2010, n. 6, persegue per l'anno 2016 obiettivi di riduzione delle spese di funzionamento. A tal fine il Commissario straordinario di cui all'articolo 20 del decreto-legge 24 giugno 2014, n. 90, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 114, realizza una riduzione delle spese di struttura in misura non inferiore al 20 per cento di quelle sostenute nell'esercizio 2015, da ottenere anche attraverso il contenimento del costo del personale e la fissazione di limiti alla retribuzione dei dirigenti, ferma restando l'applicazione dei limiti di cui agli articoli 23-bis e 23-ter del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, e successive modificazioni, e all'articolo 13 del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89. Al fine della rapida realizzazione delle suddette riduzioni di spesa, nelle more dell'adozione del decreto legislativo di cui al primo periodo, si procede alle conseguenti modifiche dello statuto della suddetta associazione, anche in deroga a quanto previsto dal decreto legislativo n. 6 del 2010.

670. Al fine di migliorare i saldi di finanza pubblica e di razionalizzare e potenziare le attivita' di servizio svolte a favore delle imprese nei settori dell'energia elettrica, del gas e del sistema idrico e, in particolare, allo scopo di valorizzare i ricavi delle prevalenti attivita' economiche di accertamento, riscossione, versamento, supporto finanziario, informatico e amministrativo, la Cassa conguaglio per il settore elettrico, a decorrere dalla data di entrata in vigore della presente legge, e' trasformata in ente pubblico economico, denominato «Cassa per i servizi energetici e ambientali» (CSEA), operante con autonomia organizzativa, tecnica e gestionale e sottoposto alla vigilanza del Ministero dell'economia e delle finanze e dell'Autorita' per l'energia elettrica, il gas e il sistema idrico. Il patrimonio iniziale dell'ente, pari a 100 milioni di euro, e' costituito, con provvedimento del Ministero dell'economia e delle finanze, da una somma prelevata dai conti gestiti dalla Cassa conguaglio per il settore elettrico e versata all'entrata del bilancio dello Stato per essere riassegnata ad apposito capitolo di spesa dello stato di previsione del Ministero dell'economia e delle finanze per le finalita' di cui al presente comma. A decorrere dal 2016, gli eventuali utili derivanti dalla gestione economica dell'ente sono versati all'entrata del bilancio dello Stato. Restano organi dell'ente il presidente, il comitato di gestione e il collegio dei revisori; i relativi procedimenti di nomina continuano ad essere disciplinati dalle norme vigenti per gli omologhi organi della Cassa conguaglio per il settore elettrico. Entro quarantacinque giorni dalla data di entrata in vigore della presente legge, con decreto del Ministro dell'economia e delle finanze, sentita l'Autorita' per l'energia elettrica, il gas e il sistema idrico, e' approvato lo statuto, e' stabilita la dotazione organica dell'ente in misura non superiore a sessanta unita' e sono apportate al regolamento di organizzazione e funzionamento le modifiche necessarie a dare attuazione al presente comma. Allo scopo di assicurare la continuita' nell'esercizio delle funzioni dell'ente, in sede di prima applicazione, la CSEA, entro quarantacinque giorni dalla data di entrata in vigore della presente legge, avvia procedure di selezione pubblica, per titoli ed esami, finalizzate alla copertura del proprio fabbisogno di organico; allo scopo di consolidare le specifiche esperienze professionali maturate all'interno dell'ente e non agevolmente acquisibili all'esterno, e' considerato titolo preferenziale, ma non essenziale, il servizio prestato presso la Cassa conguaglio per il settore elettrico per un periodo di almeno dodici mesi antecedente alla data di scadenza del termine utile per la presentazione della candidatura. Il rapporto di lavoro del personale dipendente della CSEA e' disciplinato dalle norme di diritto privato e dalla contrattazione collettiva di settore. Tutti gli atti connessi alle operazioni di trasformazione in ente pubblico economico sono esclusi da ogni tributo e diritto e sono effettuati in regime di neutralita' fiscale. Dall'attuazione del presente comma non devono derivare nuovi o maggiori oneri a carico della finanza pubblica.

671. A seguito delle sentenze della Corte costituzionale n. 1 del 14-18 gennaio 2008 e n. 205 del 4-13 luglio 2011, al comma 6-quinquies dell'articolo 15 del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, le parole: «e dallo Stato», ovunque ricorrono, sono soppresse. Al fine di completare la restituzione delle somme trattenute dallo Stato ai concessionari delle grandi derivazioni idroelettriche e' autorizzata la spesa di 12 milioni di euro. Le disponibilita' iscritte nello stato di previsione del Ministero dello sviluppo economico per l'anno 2015, ai sensi dell'articolo 19, comma 2, del decreto legislativo 13 marzo 2013, n. 30, sono destinate, nel limite di 12 milioni di euro, alla restituzione ai concessionari delle somme trattenute dallo Stato di cui al periodo precedente. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio in termini di residui, di competenza e di cassa. La disposizione di cui al presente comma entra in vigore il giorno stesso della pubblicazione della presente legge nella Gazzetta Ufficiale.

672. All'articolo 23-bis del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, il comma 1 e' sostituito dal seguente: «1. Fatto salvo quanto previsto dall'articolo 19, comma 6, del decreto-legge 1º luglio 2009, n. 78, convertito, con modificazioni, dalla legge 3 agosto 2009, n. 102, con decreto del Ministro dell'economia e delle finanze, da emanare entro il 30 aprile 2016, sentita la Conferenza unificata per i profili di competenza, previo parere delle Commissioni parlamentari competenti, per le societa' direttamente o indirettamente controllate da amministrazioni dello Stato e dalle altre amministrazioni pubbliche di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni, ad esclusione delle societa' emittenti strumenti finanziari quotati nei mercati regolamentati e loro controllate, sono definiti indicatori dimensionali quantitativi e qualitativi al fine di individuare fino a cinque fasce per la classificazione delle suddette societa'. Per ciascuna fascia e' determinato, in proporzione, il limite dei compensi massimi al quale i consigli di amministrazione di dette societa' devono fare riferimento, secondo criteri oggettivi e trasparenti, per la determinazione del trattamento economico annuo onnicomprensivo da corrispondere agli amministratori, ai dirigenti e ai dipendenti, che non potra' comunque eccedere il limite massimo di euro 240.000 annui al lordo dei contributi previdenziali e assistenziali e degli oneri fiscali a carico del beneficiario, tenuto conto anche dei compensi corrisposti da altre pubbliche amministrazioni. Le societa' di cui al primo periodo verificano il rispetto del limite massimo del trattamento economico annuo onnicomprensivo dei propri amministratori e dipendenti fissato con il decreto di cui al presente comma. Sono in ogni caso fatte salve le disposizioni legislative e regolamentari che prevedono limiti ai compensi inferiori a quelli previsti dal decreto di cui al presente comma».

673. Il regolamento di cui al decreto del Ministro dell'economia e delle finanze 24 dicembre 2013, n. 166, continua a produrre i propri effetti fino all'adozione del decreto previsto dall'articolo 23-bis, comma 1, del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, come sostituito dal comma 672 del presente articolo.

674. I commi 5-bis e 5-ter dell'articolo 23-bis del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, sono abrogati dalla data di adozione del decreto di cui all'articolo 23-bis, comma 1, del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, come sostituito dal comma 672 del presente articolo.

675. COMMA ABROGATO DAL D.LGS. 25 MAGGIO 2016, N. 97.

676. COMMA ABROGATO DAL D.LGS. 25 MAGGIO 2016, N. 97.

677. Qualora entro il 31 dicembre 2016 si proceda all'alienazione di quote o a un aumento di capitale riservato al mercato del gruppo Ferrovie dello Stato italiane Spa, il Ministero dell'economia e delle finanze presenta alle Camere una relazione che evidenzia in modo puntuale l'impatto economico, industriale e occupazionale derivante dalla privatizzazione nella quale sono indicati in particolare:

- a) i dati finanziari e industriali degli effetti dell'alienazione o dell'eventuale aumento di capitale sulle societa' interessate e sul bilancio dello Stato;
- b) la minore spesa per interessi derivante dall'utilizzo delle risorse incassate dall'alienazione per la riduzione del debito pubblico;
- c) i minori dividendi versati al bilancio dello Stato in conseguenza dell'alienazione;
- d) gli effetti dell'alienazione o dell'aumento di capitale riservato al mercato sul piano industriale del gruppo.

678. Nelle more della stipulazione del contratto di programma tra il Ministero delle infrastrutture e dei trasporti e la societa' Ferrovie dello Stato italiane Spa, le risorse gia' destinate alla realizzazione della nuova linea ferroviaria Torino-Lione sono direttamente trasferite alla societa' Ferrovie dello Stato italiane Spa. Il presente comma entra in vigore il giorno stesso della pubblicazione della presente legge nella Gazzetta Ufficiale.

679. Al fine di valorizzare ENAV Spa, assicurando maggiore certezza e stabilita' nei rapporti giuridici, nonche' la coerenza dell'assetto regolatorio nazionale della fornitura dei servizi della navigazione aerea al quadro normativo europeo di riferimento, anche nella prospettiva dell'apertura del capitale della societa' ai privati:

- a) all'articolo 9 della legge 23 dicembre 1996, n. 665, sono apportate le seguenti modificazioni: 1) il comma 1 e' sostituito dal seguente: «1. Il contratto di programma tra lo Stato ed ENAV Spa ha durata coincidente con il periodo di riferimento di cui all'articolo 8 del regolamento di esecuzione (UE) n. 390/2013 della Commissione, del 3 maggio 2013, ed e' stipulato tra ENAV Spa e il Ministro delle infrastrutture e dei trasporti, di concerto con il Ministro dell'economia e delle finanze e, per quanto di competenza, con il Ministro della difesa. Entro il 30 giugno dell'anno precedente l'inizio del periodo di riferimento, il Ministero delle infrastrutture e dei trasporti, d'intesa con ENAV Spa, trasmette uno schema di contratto di programma ai soggetti di cui al periodo precedente, che si esprimono entro il 30 settembre del medesimo anno e sottoscrivono il contratto entro il 31 dicembre. Qualora entro tale termine non si pervenga al perfezionamento del nuovo contratto, continua ad applicarsi il contratto relativo al periodo di riferimento precedente»; 2) al comma 2, lettera a), le parole: «anche di rilevanza sociale o comunque resi in condizione di non remunerazione dei costi» sono sostituite dalle seguenti: «nonche' gli standard di sicurezza e di qualita' dei servizi erogati anche in base alla normativa europea» ed e' aggiunto, in fine, il seguente periodo: «Lo Stato garantisce a ENAV Spa il rimborso delle risorse necessarie per la fornitura dei servizi della navigazione aerea prestati in favore dei voli esonerati, in conformita' all'articolo 10, paragrafo 5, del regolamento di esecuzione (UE) n. 391/2013 della Commissione, del 3 maggio 2013»; 3) i commi 3, 4, 5 e 6 sono abrogati;
- b) in sede di prima applicazione del comma 1 dell'articolo 9 della legge 23 dicembre 1996, n. 665, come sostituito dalla lettera a) del presente comma, il contratto di programma tra lo Stato ed ENAV Spa ha durata quadriennale e regola il periodo dal 1º gennaio 2016 al 31 dicembre 2019. Il Ministero delle infrastrutture e dei trasporti, d'intesa con ENAV Spa, trasmette lo schema di contratto di programma relativo al predetto periodo ai soggetti di cui al citato comma 1 dell'articolo 9 della legge n. 665 del 1996 entro il termine del 29 febbraio 2016, ai fini della sua definitiva sottoscrizione entro il 30 aprile 2016;
- c) qualora sopraggiunte variazioni dello scenario economico e strategico nazionale e, in ogni caso, il verificarsi di eventi indipendenti da ENAV Spa implichino la riduzione o cessazione dell'operativita' aeroportuale, ENAV Spa, previo parere favorevole dell'Ente nazionale per l'aviazione civile e del Ministero delle infrastrutture e dei trasporti, rivede il livello dei servizi di navigazione aerea prestati, da comunicare al Ministero delle infrastrutture e dei trasporti e al Ministero dell'economia e delle finanze.

680. Le regioni e le province autonome di Trento e di Bolzano, in conseguenza dell'adeguamento dei propri ordinamenti ai principi di coordinamento della finanza pubblica di cui alla presente legge e a valere sui risparmi derivanti dalle disposizioni ad esse direttamente applicabili ai sensi dell'articolo 117, secondo comma, della Costituzione, assicurano un contributo alla finanza pubblica pari a 3.980 milioni di euro per l'anno 2017 e a 5.480 milioni di euro per ciascuno degli anni 2018, 2019 e 2020, in ambiti di spesa e per importi proposti, nel rispetto dei livelli essenziali di assistenza, in sede di autocoordinamento dalle regioni e province autonome medesime, da recepire con intesa sancita dalla Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, entro il 31 gennaio di ciascun anno. PERIODO SOPPRESSO DAL D.L. 24 APRILE 2017, N. 50, CONVERTITO CON MODIFICAZIONI DALLA L. 21 GIUGNO 2017, N. 96. Fermo restando il concorso complessivo di cui al primo periodo, il contributo di ciascuna autonomia speciale e' determinato previa intesa con ciascuna delle stesse. Le regioni e le province autonome di Trento e di Bolzano assicurano il finanziamento dei livelli essenziali di assistenza come eventualmente rideterminato ai sensi del presente comma e dei commi da 681 a 684 del presente articolo e dell'articolo 1, commi da 400 a 417, della legge 23 dicembre 2014, n. 190. Per la regione Trentino-Alto Adige e per le province autonome di Trento e di Bolzano l'applicazione del presente comma avviene nel rispetto dell'Accordo sottoscritto tra il Governo e i predetti enti in data 15 ottobre 2014, e recepito con legge 23 dicembre 2014, n. 190, con il concorso agli obiettivi di finanza pubblica previsto dai commi da 406 a 413 dell'articolo 1 della medesima legge. (31)

681. Al comma 6 dell'articolo 46 del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, e successive modificazioni, al primo e al terzo periodo, la parola: «2018» e' sostituita dalla seguente: «2019».

682. Il concorso agli obiettivi di finanza pubblica delle regioni a statuto ordinario di cui all'articolo 46, comma 6, del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, come modificato dal comma 681 del presente articolo, al netto del contenimento della spesa sanitaria e della corrispondente riduzione del livello del finanziamento del Servizio sanitario nazionale per le regioni a statuto ordinario di cui agli articoli da 9-bis a 9-septies del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125, e' realizzato per l'anno 2016 secondo modalita' da stabilire mediante intesa sancita dalla Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, entro il 31 gennaio 2016. In caso di mancata intesa, si applica quanto previsto dal secondo periodo del predetto articolo 46, comma 6. Per gli anni dal 2017 al 2019 si provvede secondo le modalita' di cui al comma 680.

683. Ai fini della riduzione del debito, nell'anno 2016 e' attribuito alle regioni a statuto ordinario un contributo di complessivi 1.900 milioni di euro, ripartito fra ciascuna regione come indicato nell'allegato n. 7 annesso alla presente legge. Gli importi di ciascun contributo possono essere modificati a invarianza del contributo complessivo, mediante accordo da sancire, entro il 31 gennaio 2016, in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano. Il contributo non rileva ai fini del pareggio di bilancio di cui ai commi da 707 a 734.

684. Le disponibilita' in conto residui iscritte in bilancio per l'anno 2015, relative all'autorizzazione di spesa di cui all'articolo 1, comma 10, del decreto-legge 8 aprile 2013, n. 35, convertito, con modificazioni, dalla legge 6 giugno 2013, n. 64, e successive modificazioni, sono destinate, nel limite di 1.300 milioni di euro, al finanziamento del contributo di cui al comma 683. La disposizione di cui al presente comma entra in vigore il giorno stesso della pubblicazione della presente legge nella Gazzetta Ufficiale. A tal fine le predette somme sono versate all'entrata del bilancio dello Stato nell'anno 2016.

685. Nelle more dell'adeguamento delle norme di attuazione dello statuto della Regione siciliana alle modifiche intervenute nella legislazione tributaria, al fine di omogeneizzare il comparto delle autonomie speciali, in modo da addivenire, tra l'altro, a un chiarimento sulla compartecipazione regionale e sulla revisione della percentuale di compartecipazione al gettito tributario, alla ridefinizione delle competenze secondo il principio della leale collaborazione istituzionale, nonche' alla luce dell'adempimento, nel 2015, da parte della Regione, degli impegni in materia di contenimento delle spese e a condizione di un aggiornamento dell'intesa tra lo Stato e la Regione siciliana in materia di obiettivi di contenimento della spesa per l'anno 2016, sono assegnati alla Regione siciliana 900 milioni di euro per il medesimo anno 2016.

686. Nelle more dell'attuazione del punto 7 dell'Accordo del 25 luglio 2015 tra il Presidente della regione Valle d'Aosta e il Ministro dell'economia e delle finanze, a compensazione della perdita di gettito subita, per gli anni 2011/2014, dalla regione Valle d'Aosta nella determinazione dell'accisa di cui all'articolo 4, comma 1, lettere a) e b), della legge 26 novembre 1981, n. 690, e' corrisposto alla medesima regione l'importo di 50 milioni di euro per l'anno 2016.

687. Le somme giacenti sulla contabilita' speciale di cui all'articolo 45, comma 2, del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, non utilizzate per le finalita' di cui al medesimo articolo, sono versate all'entrata del bilancio dello Stato, nell'anno 2016, per un importo pari a 1.550 milioni di euro.

688. L'importo di 6,6 milioni di euro per l'anno 2016, di 9,8 milioni di euro per l'anno 2017, di 12,1 milioni di euro per l'anno 2018 e di 14,2 milioni di euro annui a decorrere dall'anno 2019 e' recuperato all'erario tramite versamento all'entrata del bilancio dello Stato da parte di ciascuna regione e, in caso di mancato versamento, attraverso corrispondente riduzione dei trasferimenti a qualunque titolo dovuti alle regioni interessate. Il predetto importo e' ripartito tra le regioni interessate in proporzione agli importi di cui all'allegato n. 7 annesso alla presente legge, ovvero mediante l'accordo di cui al secondo periodo del comma 683.

688-bis. Anche per l'esercizio 2016, per le sole regioni che nell'anno 2015 abbiano registrato indicatori annuali di tempestivita' dei pagamenti, calcolati e pubblicati secondo le modalita' stabilite dal decreto del Presidente del Consiglio dei ministri 22 settembre 2014, pubblicato nella Gazzetta Ufficiale n. 265 del 14 novembre 2014, tenendo conto di quanto disposto dall'articolo 4, comma 4, del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125, con un valore inferiore rispetto ai tempi di pagamento di cui all'articolo 4 del decreto legislativo 9 ottobre 2002, n. 231, e successive modificazioni, sono valide le disposizioni di cui al comma 2, dell'articolo 40, del decreto legislativo 23 giugno 2011, n. 118, con riferimento alla copertura degli investimenti autorizzati.

689. L'importo di 9,9 milioni di euro per l'anno 2016, di 14,8 milioni di euro per l'anno 2017, di 18,2 milioni di euro per l'anno 2018 e di 21,2 milioni di euro annui a decorrere dall'anno 2019 e' recuperato all'erario attraverso un maggiore accantonamento nei confronti della Regione siciliana a valere sulle quote di compartecipazione ai tributi erariali ed e' corrispondentemente migliorato per ciascun anno l'obiettivo di finanza pubblica della Regione siciliana.

690. All'articolo 1, comma 462, lettera d), della legge 24 dicembre 2012, n. 228, e' aggiunto, in fine, il seguente periodo: «Alle regioni di cui al comma 12-sexiesdecies, secondo periodo, dell'articolo 10 del decreto-legge 31 dicembre 2014, n. 192, convertito, con modificazioni, dalla legge 27 febbraio 2015, n. 11, si applicano esclusivamente le disposizioni previste dal comma 12-septiesdecies del medesimo articolo».

691. All'articolo 9, comma 5, del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125, la parola: «sette» e' sostituita dalla seguente: «dieci».

692. Le regioni contabilizzano le anticipazioni di liquidita' di cui al decreto-legge 8 aprile 2013, n. 35, convertito, con modificazioni, dalla legge 6 giugno 2013, n. 64, e successivi rifinanziamenti, incassate a decorrere dall'esercizio 2015, secondo le seguenti modalita' anche alternative:

- a) iscrivendo, nel titolo di spesa riguardante il rimborso dei prestiti, un fondo anticipazione di liquidita', di importo pari alle anticipazioni di liquidita' incassate nell'esercizio, non impegnabile e pagabile, destinato a confluire nel risultato di amministrazione, come quota accantonata definita dall'articolo 42 del decreto legislativo 23 giugno 2011, n. 118;
- b) nel rispetto di quanto previsto dal comma 697.

693. Il fondo anticipazione di liquidita' costituito ai sensi del comma 692 e' annualmente utilizzato secondo le seguenti modalita':

- a) in caso di disavanzo al 31 dicembre dell'esercizio di incasso dell'anticipazione, applicando in entrata del bilancio di previsione dell'esercizio successivo, come «Utilizzo fondo anticipazione di liquidita'», la quota del fondo di cui al comma 692, corrispondente all'importo del disavanzo 2014, anche nelle more dell'approvazione del rendiconto dell'esercizio precedente. La medesima quota del fondo e' iscritta in spesa al netto del rimborso dell'anticipazione effettuato nell'esercizio. Negli esercizi successivi, fino al completo utilizzo del fondo, in entrata del bilancio di previsione e' applicato il fondo stanziato in spesa dell'esercizio precedente, e in spesa e' stanziato il medesimo fondo al netto del rimborso dell'anticipazione effettuato nell'esercizio;
- b) la quota del fondo eccedente il disavanzo al 31 dicembre 2014 di cui alla lettera a) e' utilizzata secondo le modalita' previste dall'articolo 2, comma 6, del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125.

694. L'eventuale disavanzo risultante nell'esercizio di erogazione dell'anticipazione, per un importo pari al fondo di cui al comma 693, lettera a), e' annualmente ripianato per un importo pari all'ammontare del rimborso dell'anticipazione stessa, effettuato nel corso dell'esercizio.

695. Con riferimento alle anticipazioni erogate a decorrere dall'esercizio 2015 ai sensi dell'articolo 3, comma 1, lettera a), del decreto-legge 8 aprile 2013, n. 35, convertito, con modificazioni, dalla legge 6 giugno 2013, n. 64, e successivi rifinanziamenti, il fondo anticipazione di liquidita' costituito ai sensi del comma 692 e' annualmente utilizzato secondo le seguenti modalita':

- a) in caso di disavanzo nell'esercizio di incasso dell'anticipazione, il fondo di cui al comma 692 e' applicato in entrata del bilancio di previsione dell'esercizio successivo, come «Utilizzo fondo anticipazione di liquidita'», anche nelle more dell'approvazione del rendiconto dell'esercizio precedente, per un importo non superiore al predetto disavanzo. La medesima quota del fondo e' iscritta in spesa al netto del rimborso dell'anticipazione effettuato nell'esercizio. Negli esercizi successivi, fino al completo utilizzo del fondo, in entrata del bilancio di previsione e' applicato il fondo stanziato in spesa dell'esercizio precedente, e in spesa e' stanziato il medesimo fondo al netto del rimborso dell'anticipazione effettuato nell'esercizio;
- b) la quota del fondo eccedente l'importo del disavanzo formatosi nell'esercizio di erogazione dell'anticipazione e' utilizzata secondo le modalita' previste dall'articolo 2, comma 6, del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125.

696. Con riferimento alle anticipazioni erogate a decorrere dall'esercizio 2015 ai sensi dell'articolo 3, comma 1, lettera a), del decreto-legge 8 aprile 2013, n. 35, convertito, con modificazioni, dalla legge 6 giugno 2013, n. 64, e successivi rifinanziamenti, il disavanzo formatosi nel corso dell'esercizio di erogazione dell'anticipazione, per un importo non superiore a quello dell'anticipazione, e' annualmente ripianato per un importo pari all'ammontare del rimborso dell'anticipazione che lo ha determinato, effettuato nel corso dell'esercizio.

697. Le disposizioni di cui agli articoli 2 e 3 del decreto-legge 8 aprile 2013, n. 35, convertito, con modificazioni, dalla legge 6 giugno 2013, n. 64, e successive modificazioni, si interpretano nel senso che le anticipazioni di liquidita' possono essere registrate contabilmente riducendo gli stanziamenti di entrata, riguardanti il finanziamento del disavanzo di amministrazione derivante dal debito autorizzato e non contratto per finanziare spesa di investimento, di un importo pari a quello dell'anticipazione di liquidita'.

698. Le regioni che, nei casi diversi dal comma 697, a seguito dell'incasso delle anticipazioni di liquidita' di cui al decreto-legge 8 aprile 2013, n. 35, convertito, con modificazioni, dalla legge 6 giugno 2013, n. 64, e successivi rifinanziamenti, non hanno stanziato in bilancio, tra le spese, un fondo diretto ad evitare il finanziamento di nuove e maggiori spese e non hanno accantonato tale fondo nel risultato di amministrazione, previo parere dell'organo di revisione economico-finanziaria, provvedono a rideterminare, alla data del 1º gennaio 2015, con deliberazione della Giunta regionale da trasmettere al Consiglio regionale:

- a) il proprio risultato di amministrazione disponibile al 31 dicembre 2014 definito ai fini del rendiconto 2014, anche se approvato dal Consiglio, riferendolo al 1º gennaio 2015, accantonandone una quota al fondo anticipazione di liquidita', per un importo pari alle anticipazioni acquisite nel 2013 e nel 2014, al netto delle quote gia' rimborsate, se hanno partecipato alla sperimentazione prevista dall'articolo 78 del decreto legislativo 23 giugno 2011, n. 118, e non hanno effettuato il riaccertamento straordinario dei residui di cui all'articolo 3, comma 17-bis, del predetto decreto legislativo n. 118 del 2011;
- b) il proprio risultato di amministrazione disponibile al 1º gennaio 2015, definito nell'ambito del riaccertamento straordinario dei residui, accantonandone una quota al fondo anticipazione di liquidita', per un importo pari alle anticipazioni acquisite nel 2013 e nel 2014, al netto delle quote gia' rimborsate, se non hanno partecipato alla sperimentazione prevista dall'articolo 78 del decreto legislativo 23 giugno 2011, n. 118, o hanno effettuato il riaccertamento straordinario dei residui di cui all'articolo 3, comma 17-bis, del predetto decreto legislativo n. 118 del 2011.

699. L'eventuale disavanzo di amministrazione derivante dall'accantonamento al fondo anticipazione di liquidita' di cui al comma 698 e' ripianato annualmente, a decorrere dal 2016, per un importo pari all'ammontare dell'anticipazione rimborsata nel corso dell'esercizio precedente. Il risultato di amministrazione presunto in sede di bilancio di previsione 2016-2018 e' calcolato considerando, tra le quote accantonate, anche il fondo anticipazione di liquidita' previsto dal comma 698 e quello derivante dalle anticipazioni di liquidita' incassate nell'esercizio 2015 contabilizzate ai sensi del comma 692, lettera a).

700. Il fondo anticipazione di liquidita' costituito ai sensi del comma 698 e' annualmente utilizzato secondo le seguenti modalita':

- a) la quota del fondo accantonata nel risultato di amministrazione, per un importo pari al maggiore disavanzo di amministrazione formatosi in attuazione del comma 698, e' applicata in entrata del bilancio di previsione dell'esercizio 2016 come «Utilizzo fondo anticipazioni di liquidita'» anche nelle more dell'approvazione del rendiconto dell'esercizio precedente. Il medesimo fondo e' iscritto in spesa al netto del rimborso dell'anticipazione effettuato nell'esercizio precedente. Dall'esercizio 2017, fino al completo utilizzo del fondo, in entrata del bilancio di previsione e' applicato il fondo stanziato in spesa dell'esercizio precedente, e in spesa e' stanziato il medesimo fondo al netto del rimborso dell'anticipazione effettuato nell'esercizio precedente;
- b) la quota del fondo eccedente l'importo del disavanzo di amministrazione formatosi in attuazione del comma 698 e' utilizzata secondo le modalita' previste dall'articolo 2, comma 6, del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125.

701. La regione Piemonte ridetermina i propri risultati di amministrazione nel rispetto della sentenza della Corte costituzionale n. 181 del 2015 secondo le modalita' individuate dalla Corte dei conti - sezione regionale di controllo per il Piemonte e, a decorrere dal 2016, ripiana annualmente il conseguente maggiore disavanzo per un importo pari al contributo erogato nell'esercizio precedente ai sensi dell'articolo 1, comma 456, della legge 23 dicembre 2014, n. 190. Nel bilancio di previsione 2016, la regione applica in entrata il fondo vincolato costituito nel risultato di amministrazione in applicazione della sentenza, come «Utilizzo fondo vincolato da anticipazioni di liquidita'» anche nelle more dell'approvazione del rendiconto dell'esercizio precedente. Il medesimo fondo e' iscritto in spesa al netto del contributo erogato nell'esercizio precedente ai sensi dell'articolo 1, comma 456, della legge 23 dicembre 2014, n. 190. Dall'esercizio 2017, fino al completo utilizzo del fondo, in entrata del bilancio di previsione e' applicato il fondo stanziato in spesa dell'esercizio precedente, e in spesa e' stanziato il medesimo fondo al netto del contributo erogato nell'esercizio precedente ai sensi dell'articolo 1, comma 456, della legge 23 dicembre 2014, n. 190. La regione Piemonte accantona nel proprio risultato di amministrazione anche un fondo di importo pari alle passivita' trasferite alla gestione commissariale, ai sensi dell'articolo 1, comma 454, lettera a), della legge 23 dicembre 2014, n. 190. Tale fondo e' utilizzato con le stesse modalita' previste per l'utilizzo del fondo vincolato da anticipazione di liquidita'. Il conseguente disavanzo aggiuntivo e' ripianato, dopo avere coperto il disavanzo determinato dall'applicazione della sentenza, con le medesime modalita'.

702. Nelle more della conclusione, da parte dell'Agenzia italiana del farmaco (AIFA), delle procedure di ripiano dell'eventuale sfondamento del tetto della spesa farmaceutica territoriale ed ospedaliera per gli anni 2013 e 2014 e al fine di garantire il rispetto degli equilibri di finanza pubblica, le regioni, in coerenza con quanto disposto dall'articolo 20 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni, accertano ed impegnano nel bilancio regionale dell'anno 2015, nella misura del 90 per cento e al netto degli importi eventualmente gia' contabilizzati, le somme indicate nella tabella di cui all'allegato A alla presente legge a titolo di ripiano per ciascuno degli anni 2013 e 2014. I predetti accertamenti e impegni sono effettuati nel bilancio finanziario dell'anno 2015, entro dieci giorni dalla data di entrata in vigore del decreto-legge 13 novembre 2015, n. 179. Conseguentemente, gli enti del Servizio sanitario nazionale, di cui all'articolo 19, comma 2, lettere b) e c), del decreto legislativo 23 giugno 2011, n. 118, iscrivono le predette somme nel proprio conto economico dandone evidenza nel modello CE IV trimestre 2015, di cui al decreto del Ministro della salute 15 giugno 2012, pubblicato nel supplemento ordinario alla Gazzetta Ufficiale n. 159 del 10 luglio 2012, nelle voci relative ai codici AA0900 e AA0910.

703. A conclusione delle procedure di ripiano, da parte dell'AIFA, dell'eventuale sfondamento del tetto della spesa farmaceutica territoriale ed ospedaliera per gli anni 2013 e 2014, ove si verifichi una differenza tra l'importo che ha formato oggetto di accertamento e di impegno ai sensi del comma 702 e quello risultante dalle determinazioni AIFA, pubblicate nella Gazzetta Ufficiale, conclusive delle predette procedure con riferimento a ciascuno degli anni 2013 e 2014, le regioni procedono alle relative regolazioni contabili, ai sensi di quanto disposto dal decreto legislativo 23 giugno 2011, n. 118.

704. All'articolo 32 del decreto-legge 24 giugno 2014, n. 90, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 114, sono apportate le seguenti modifiche:

- a) al comma 1, alinea, dopo le parole: «servizi o forniture,» sono inserite le seguenti: «nonche' ad una impresa che esercita attivita' sanitaria per conto del Servizio sanitario nazionale in base agli accordi contrattuali di cui all'articolo 8-quinquies del decreto legislativo 30 dicembre 1992, n. 502,»;
- b) al comma 1, lettera a), la parola: «appaltatrice» e' soppressa e dopo le parole: «d'appalto» sono inserite le seguenti: «ovvero dell'accordo contrattuale»;
- c) al comma 1, lettera b), la parola: «appaltatrice» e' soppressa e dopo le parole: «d'appalto» sono inserite le seguenti: «ovvero dell'accordo contrattuale»;
- d) al comma 2, dopo le parole: «del contratto» sono inserite le seguenti: «ovvero dell'accordo contrattuale»;
- e) dopo il comma 2 e' inserito il seguente: «2-bis. Nell'ipotesi di impresa che esercita attivita' sanitaria per conto del Servizio sanitario nazionale in base agli accordi contrattuali di cui all'articolo 8-quinquies del decreto legislativo 30 dicembre 1992, n. 502, il decreto del Prefetto di cui al comma 2 e' adottato d'intesa con il Ministro della salute e la nomina e' conferita a soggetti in possesso di curricula che evidenzino qualificate e comprovate professionalita' ed esperienza di gestione sanitaria»;
- f) al comma 10, al primo periodo, dopo la parola: «contratto» sono inserite le seguenti: «ovvero dell'accordo contrattuale» e dopo il secondo periodo e' inserito il seguente: «Nei casi di cui al comma 2-bis, le misure sono disposte con decreto del Prefetto, d'intesa con il Ministro della salute»;
- g) dopo il comma 10 e' aggiunto il seguente: «10-bis. Le misure di cui al presente articolo, nel caso di accordi contrattuali con il Servizio sanitario nazionale di cui all'articolo 8-quinquies del decreto legislativo 30 dicembre 1992, n. 502, si applicano ad ogni soggetto privato titolare dell'accordo, anche nei casi di soggetto diverso dall'impresa, e con riferimento a condotte illecite o eventi criminosi posti in essere ai danni del Servizio sanitario nazionale».

705. Il decreto-legge 13 novembre 2015, n. 179, e' abrogato. Restano validi gli atti e i provvedimenti adottati e sono fatti salvi gli effetti prodottisi ed i rapporti giuridici sorti sulla base del medesimo decreto-legge n. 179 del 2015.

706. All'articolo 41, comma 5, del decreto-legge 12 settembre 2014, n. 133, convertito, con modificazioni, dalla legge 11 novembre 2014, n. 164, la parola: «2015» e' sostituita dalla seguente: «2016».

707. A decorrere dall'anno 2016 cessano di avere applicazione l'articolo 31 della legge 12 novembre 2011, n. 183, e tutte le norme concernenti la disciplina del patto di stabilita' interno degli enti locali nonche' i commi 461, 463, 464, 468, 469 e i commi da 474 a 483 dell'articolo 1 della legge 23 dicembre 2014, n. 190. Restano fermi gli adempimenti degli enti locali relativi al monitoraggio e alla certificazione del patto di stabilita' interno 2015, di cui ai commi 19, 20 e 20-bis dell'articolo 31 della legge 12 novembre 2011, n. 183, nonche' l'applicazione delle sanzioni in caso di mancato rispetto del patto di stabilita' interno relativo all'anno 2015 o relativo agli anni precedenti accertato ai sensi dei commi 28, 29 e 31 dell'articolo 31 della legge 12 novembre 2011, n. 183. Restano altresi' fermi gli adempimenti delle regioni relativi al monitoraggio e alla certificazione del pareggio di bilancio per l'anno 2015, di cui ai commi da 470 a 473 dell'articolo 1 della legge 23 dicembre 2014, n. 190, nonche' l'applicazione delle sanzioni in caso di mancato rispetto dell'obiettivo del pareggio relativo all'anno 2015. Sono fatti salvi gli effetti connessi all'applicazione negli anni 2014 e 2015 dei patti orizzontali recati al comma 141 dell'articolo 1 della legge 13 dicembre 2010, n. 220, al comma 483 dell'articolo 1 della legge 23 dicembre 2014, n. 190, e al comma 7 dell'articolo 4-ter del decreto-legge 2 marzo 2012, n. 16, convertito, con modificazioni, dalla legge 26 aprile 2012, n. 44.

708. Il termine per l'invio delle deliberazioni, esclusivamente in via telematica, fissato al 10 settembre 2014 dall'articolo 1, comma 688, della legge 27 dicembre 2013, n. 147, si applica ai soli comuni che non hanno inviato in via telematica, entro il 23 maggio 2014, le deliberazioni di approvazione delle aliquote e delle detrazioni ai fini del versamento della prima rata TASI entro il 16 giugno 2014.

709. Ai fini della tutela dell'unita' economica della Repubblica, gli enti di cui al comma 1 dell'articolo 9 della legge 24 dicembre 2012, n. 243, concorrono alla realizzazione degli obiettivi di finanza pubblica nel rispetto delle disposizioni di cui ai commi da 707 a 734 del presente articolo, che costituiscono principi fondamentali di coordinamento della finanza pubblica, ai sensi degli articoli 117, terzo comma, e 119, secondo comma, della Costituzione. (14)

710. Ai fini del concorso al contenimento dei saldi di finanza pubblica, gli enti di cui al comma 709 devono conseguire un saldo non negativo, in termini di competenza, tra le entrate finali e le spese finali, come eventualmente modificato ai sensi dei commi 728, 730, 731 e 732. (14)

710-bis. A decorrere dall'anno 2017, alle regioni che rispettano il vincolo sul pareggio di bilancio di cui al comma 710 e che conseguono un saldo finale di cassa non negativo fra le entrate finali e le spese finali, sono assegnate con decreto del Ministero dell'economia e delle finanze entro il 30 luglio di ciascun anno le eventuali risorse incassate dal bilancio dello Stato alla data del 30 giugno ai sensi della lettera b), comma 723, del presente articolo. Nell'esercizio 2016, alle regioni che nel 2015 hanno rispettato i vincoli sul pareggio di bilancio di cui al comma 463 dell'articolo 1 della legge 23 dicembre 2014, n. 190, sono assegnate le risorse incassate ai sensi della lettera a) del comma 474 dell'articolo 1 della legge 23 dicembre 2014, n. 190. L'ammontare delle risorse per ciascuna regione e' determinato d'intesa con la Conferenza permanente per i rapporti fra lo Stato, le regioni e le Province autonome di Trento e di Bolzano. Le regioni che conseguono il saldo finale di cassa non negativo, trasmettono al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato, le informazioni concernenti il monitoraggio al 31 dicembre del saldo di cui al comma 710, e la certificazione dei relativi risultati, in termini di competenza e in termini di cassa, secondo, le modalita' previste dal decreto di cui al comma 720. Ai fini del saldo di cassa rileva l'anticipazione erogata dalla tesoreria statale nel corso dell'esercizio per il finanziamento della sanita' registrata nell'apposita voce delle partite di giro, al netto delle relative regolazioni contabili imputate contabilmente al medesimo esercizio. (14)

711. Ai fini dell'applicazione del comma 710, le entrate finali sono quelle ascrivibili ai titoli 1, 2, 3, 4 e 5 dello schema di bilancio previsto dal decreto legislativo 23 giugno 2011, n. 118, e le spese finali sono quelle ascrivibili ai titoli 1, 2 e 3 del medesimo schema di bilancio. Limitatamente all'anno 2016, nelle entrate e nelle spese finali in termini di competenza e' considerato il fondo pluriennale vincolato, di entrata e di spesa, al netto della quota riveniente dal ricorso all'indebitamento. (14)

712. A decorrere dall'anno 2016, al bilancio di previsione e' allegato un prospetto obbligatorio contenente le previsioni di competenza triennali rilevanti in sede di rendiconto ai fini della verifica del rispetto del saldo di cui al comma 710, come declinato al comma 711. A tal fine, il prospetto allegato al bilancio di previsione non considera gli stanziamenti del fondo crediti di dubbia esigibilita' e dei fondi spese e rischi futuri concernenti accantonamenti destinati a confluire nel risultato di amministrazione. Il prospetto concernente il rispetto del predetto saldo e' definito secondo le modalita' previste dall'articolo 11, comma 11, del decreto legislativo 23 giugno 2011, n. 118. Con riferimento all'esercizio 2016, il prospetto e' allegato al bilancio di previsione gia' approvato mediante delibera di variazione del bilancio approvata dal Consiglio entro sessanta giorni dalla data di entrata in vigore del decreto di cui all'articolo 11, comma 11, del decreto legislativo 23 giugno 2011, n. 118. (14)

712-bis. Per l'anno 2016 le regioni, le province autonome, le citta' metropolitane e le province conseguono il saldo di cui al comma 710 solo in sede di rendiconto e non sono tenute all'adempimento di cui al comma 712.

712-ter. Per l'anno 2016, nel saldo di cui al comma 710 non rilevano gli impegni del perimetro sanitario del bilancio, finanziati dagli utilizzi del risultato di amministrazione relativo alla gestione sanitaria formatosi nell'esercizio 2015 e in quelli antecedenti, e gli impegni effettuati in funzione dell'acquisizione nel medesimo anno 2016 delle anticipazioni di liquidita' di cui all'articolo 3, comma 1, lettera a), del decreto-legge 8 aprile 2013, n. 35, convertito, con modificazioni, dalla legge 6 giugno 2013, n. 64. Conseguentemente, la regione e' autorizzata ad assumere impegni sull'esercizio 2016 per la parte corrispondente, ivi compresi quelli derivanti dalle economie sull'esercizio 2016, entro i termini previsti per l'approvazione da parte del Consiglio regionale del rendiconto 2016.

713. Per l'anno 2016, nel saldo individuato ai sensi del comma 710 non sono considerate le spese sostenute dagli enti locali per interventi di edilizia scolastica effettuati a valere sull'avanzo di amministrazione e su risorse rivenienti dal ricorso al debito. L'esclusione opera nel limite massimo di 480 milioni di euro. A tal fine gli enti locali comunicano, entro il termine perentorio del 1º marzo, alla Presidenza del Consiglio dei ministri - Struttura di missione per il coordinamento e impulso nell'attuazione di interventi di riqualificazione dell'edilizia scolastica, secondo modalita' individuate e pubblicate nel sito istituzionale della medesima Struttura, gli spazi finanziari di cui necessitano per sostenere interventi di edilizia scolastica nel rispetto del vincolo di cui ai commi 710 e 711. Gli spazi finanziari sono attribuiti secondo il seguente ordine prioritario:

- a) spese sostenute per gli interventi di edilizia scolastica avviati dai comuni a seguito dell'articolo 48, comma 1, del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, spese sostenute dalle province e dalle citta' metropolitane per interventi di edilizia scolastica, nell'ambito delle risorse assegnate ai sensi dell'articolo 1, comma 467, della legge 23 dicembre 2014, n. 190, nonche' spese sostenute dai comuni a compartecipazioni e finanziamenti della Banca europea degli investimenti (B. E.I.) destinati ad interventi di edilizia scolastica esclusi dal beneficio di cui al citato articolo 48, comma 1, del decreto-legge 24 aprile 2014, n. 66;
- b) spese sostenute dagli enti locali a valere su stanziamenti di bilancio ovvero su risorse acquisite mediante contrazione di mutuo, per interventi di edilizia scolastica finanziati con le risorse di cui all'articolo 10 del decreto-legge 12 novembre 2013, n. 104, convertito, con modificazioni, dalla legge 8 novembre 2013, n. 128, e successive modificazioni;
- c) spese per interventi di edilizia scolastica sostenute da parte degli enti locali. Gli enti locali beneficiari dell'esclusione e l'importo dell'esclusione stessa sono individuati, sentita la Conferenza Stato-citta' ed autonomie locali, con decreto del Presidente del Consiglio dei ministri, da emanare entro il 15 aprile 2016. Qualora la richiesta complessiva risulti superiore agli spazi finanziari disponibili, gli stessi sono attribuiti in misura proporzionale alle singole richieste. Il monitoraggio degli interventi di edilizia scolastica avviene ai sensi del decreto legislativo 29 dicembre 2011, n. 229.

714. Fermi restando i tempi di pagamento dei creditori, gli enti locali che hanno presentato il piano di riequilibrio finanziario pluriennale o ne hanno conseguito l'approvazione ai sensi dell'articolo 243-bis del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267, prima dell'approvazione del rendiconto per l'esercizio 2014, se alla data della presentazione o dell'approvazione del medesimo piano di riequilibrio finanziario pluriennale non avevano ancora provveduto ad effettuare il riaccertamento straordinario dei residui attivi e passivi di cui all'articolo 3, comma 7, del decreto legislativo 23 giugno 2011, n. 118, possono rimodulare o riformulare il predetto piano, entro il 31 maggio 2017, scorporando la quota di disavanzo risultante dalla revisione straordinaria dei residui di cui all'articolo 243-bis, comma 8, lettera e), limitatamente ai residui antecedenti al 1º gennaio 2015, e ripianando tale quota secondo le modalita' previste dal decreto del Ministero dell'economia e delle finanze 2 aprile 2015, pubblicato nella Gazzetta Ufficiale n. 89 del 17 aprile 2015. La restituzione delle anticipazioni di liquidita' erogate agli enti di cui al periodo precedente, ai sensi degli articoli 243-ter e 243-quinquies del citato testo unico di cui al decreto legislativo n. 267 del 2000, e' effettuata in un periodo massimo di trenta anni decorrente dall'anno successivo a quello in cui e' stata erogata l'anticipazione. A decorrere dalla data di rimodulazione o riformulazione del piano, gli enti di cui ai periodi precedenti presentano alla Commissione di cui all'articolo 155 del medesimo testo unico di cui al decreto legislativo n. 267 del 2000 apposita attestazione del rispetto dei tempi di pagamento di cui alla direttiva 2011/7/UE del Parlamento europeo e del Consiglio, del 16 febbraio 2011. (39)

714-bis. Gli enti locali che hanno presentato il piano di' riequilibrio finanziario pluriennale o ne hanno conseguito l'approvazione ai sensi dell'articolo 243-bis del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, con delibera da adottarsi dal Consiglio dell'ente entro la data del 30 settembre 2016, possono provvedere a rimodulare o riformulare il piano stesso, fermo restando la sua durata originaria e quanto previsto nel comma 7 dell'articolo 243-bis del medesimo decreto legislativo n. 267 del 2000, per tenere conto dell'eventuale disavanzo risultante dal rendiconto approvato o dei debiti fuori bilancio anche emersi dopo la approvazione del piano di riequilibrio finanziario pluriennale, ancorche' relativi a obbligazioni sorte antecedentemente alla dichiarazione di predissesto, anche in deroga agli articoli 188 e 194 del decreto legislativo n. 267 del 2000. Dalla adozione della delibera consiliare discendono gli effetti previsti dai commi 3 e 4 dell'articolo 243-bis del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo n. 267 del 2000.

714-ter. Le province che hanno presentato il piano di riequilibrio finanziario pluriennale nel corso del 2016 e che non ne hanno ancora conseguito l'approvazione possono provvedere a riformulare il piano stesso, ferma restando la sua durata originaria, per tenere conto degli interventi di carattere finanziario nel frattempo intervenuti.

715. Gli enti locali che hanno conseguito l'approvazione del piano di riequilibrio finanziario pluriennale ai sensi dell'articolo 243-bis del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, per il periodo della durata del piano possono utilizzare le risorse derivanti da operazioni di rinegoziazione di mutui nonche' dal riacquisto dei titoli obbligazionari emessi senza vincoli di destinazione.

716. Per l'anno 2016, nel saldo individuato ai sensi del comma 710 non sono considerate le spese sostenute dagli enti locali per interventi di bonifica ambientale, conseguenti ad attivita' minerarie, effettuati a valere sull'avanzo di amministrazione e su risorse rivenienti dal ricorso al debito. L'esclusione opera nel limite massimo di 20 milioni di euro. A tale fine gli enti locali comunicano, entro il termine perentorio del 1º marzo, alla Presidenza del Consiglio dei ministri - Struttura di missione contro il dissesto idrogeologico e per lo sviluppo delle infrastrutture idriche, secondo modalita' individuate e pubblicate nel sito istituzionale della medesima Struttura, gli spazi finanziari di cui necessitano per sostenere gli interventi di cui al presente comma nel rispetto del vincolo di cui ai commi 710 e 711. Gli enti locali beneficiari dell'esclusione e l'importo dell'esclusione stessa sono individuati, sentita la Conferenza Stato-citta' ed autonomie locali, con decreto del Presidente del Consiglio dei ministri, da emanare entro il 15 aprile 2016. Qualora la richiesta complessiva risulti superiore agli spazi finanziari disponibili, gli stessi sono attribuiti in misura proporzionale alle singole richieste.

717. L'Istituto nazionale per l'assicurazione contro gli infortuni sul lavoro (INAIL), nell'ambito degli investimenti immobiliari previsti dal piano di impiego dei fondi disponibili di cui all'articolo 65 della legge 30 aprile 1969, n. 153, e successive modificazioni, destina ulteriori 50 milioni di euro rispetto alle somme indicate all'articolo 18, comma 8, del decreto-legge 21 giugno 2013, n. 69, convertito, con modificazioni, dalla legge 9 agosto 2013, n. 98, per la realizzazione delle scuole innovative, ivi compresa l'acquisizione delle relative aree di intervento di cui all'articolo 1, comma 153, della legge 13 luglio 2015, n. 107. Rispetto alle citate risorse i canoni di locazione da corrispondere all'INAIL sono posti a carico dello Stato nella misura di euro 1,5 milioni annui a decorrere dall'anno 2018, mediante corrispondente riduzione del Fondo «La Buona Scuola» per il miglioramento e la valorizzazione dell'istruzione scolastica di cui all'articolo 1, comma 202, della legge 13 luglio 2015, n. 107. Le somme incassate dagli enti locali attraverso la cessione delle aree di loro proprieta' in favore dell'INAIL sono vincolate prioritariamente alla realizzazione delle ulteriori fasi progettuali finalizzate alla cantierizzazione e al completamento dell'intervento oggetto del concorso di cui al comma 155 dell'articolo 1 della citata legge n. 107 del 2015, in deroga a quanto previsto dal decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125. Le eventuali somme residue sono trasferite dagli enti locali al bilancio dello Stato per la riduzione dei canoni di cui al comma 158 dell'articolo 1 della citata legge n. 107 del 2015.

718. Al fine di assicurare lo svolgimento delle attivita' di cui all'articolo 1, comma 153, della legge 13 luglio 2015, n. 107, e quelle di cui all'articolo 1, comma 317, della legge 23 dicembre 2014, n. 190, aventi ad oggetto principalmente investimenti in strutture scolastiche, l'Istituto nazionale per l'assicurazione contro gli infortuni sul lavoro (INAIL) e' autorizzato a reclutare un apposito contingente di 20 unita' di personale delle amministrazioni pubbliche in possesso delle necessarie competenze tecnico-amministrative in materia di investimenti immobiliari e di appalti pubblici, selezionato con apposito bando di mobilita' e a valere sulle facolta' assunzionali dell'Istituto previste dalla legislazione vigente.

719. Per il monitoraggio degli adempimenti relativi a quanto disposto dai commi da 707 a 734 e per l'acquisizione di elementi informativi utili per la finanza pubblica, gli enti di cui al comma 709 trasmettono al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato le informazioni riguardanti le risultanze del saldo di cui al comma 710, con tempi e modalita' definiti con decreti del predetto Ministero sentite, rispettivamente, la Conferenza Stato-citta' ed autonomie locali e la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano. (14)

720. Ai fini della verifica del rispetto dell'obiettivo di saldo, ciascun ente e' tenuto a inviare, utilizzando il sistema web appositamente previsto nel sito «http://pareggiobilancioentiterritoriali.tesoro.it», entro il termine perentorio del 31 marzo di ciascun anno, al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato una certificazione dei risultati conseguiti, firmata digitalmente, ai sensi dell'articolo 24 del codice di cui al decreto legislativo 7 marzo 2005, n. 82, dal rappresentante legale, dal responsabile del servizio finanziario e dall'organo di revisione economico-finanziaria, ove previsto, secondo un prospetto e con le modalita' definiti dai decreti di cui al comma 719. La trasmissione per via telematica della certificazione ha valore giuridico ai sensi dell'articolo 45, comma 1, del codice di cui al decreto legislativo 7 marzo 2005, n. 82. La mancata trasmissione della certificazione entro il termine perentorio del 31 marzo costituisce inadempimento all'obbligo del pareggio di bilancio. Nel caso in cui la certificazione, sebbene in ritardo, sia trasmessa entro trenta giorni dal termine stabilito per l'approvazione del rendiconto della gestione e attesti il conseguimento dell'obiettivo di saldo di cui al comma 710, si applicano le sole disposizioni di cui al comma 723, lettera e). (14)

721. Decorsi trenta giorni dal termine stabilito per l'approvazione del rendiconto di gestione, in caso di mancata trasmissione da parte dell'ente locale della certificazione, il presidente dell'organo di revisione economico-finanziaria nel caso di organo collegiale, ovvero l'unico revisore nel caso di organo monocratico, in qualita' di commissario ad acta, provvede, pena la decadenza dal ruolo di revisore, ad assicurare l'assolvimento dell'adempimento e a trasmettere la predetta certificazione entro i successivi trenta giorni. Nel caso in cui la certificazione sia trasmessa dal commissario ad acta entro sessanta giorni dal termine stabilito per l'approvazione del rendiconto di gestione e attesti il conseguimento dell'obiettivo di saldo di cui al comma 710, si applicano le sole disposizioni di cui al comma 723, lettere e) e f). Sino alla data di trasmissione da parte del commissario ad acta, le erogazioni di risorse o trasferimenti da parte del Ministero dell'interno relative all'anno successivo a quello di riferimento sono sospese e, a tal fine, il Dipartimento della Ragioneria generale dello Stato provvede a trasmettere apposita comunicazione al predetto Ministero. PERIODO SOPPRESSO DALLA L. 11 DICEMBRE 2016, N. 232. (14)

722. Decorsi sessanta giorni dal termine stabilito per l'approvazione del rendiconto della gestione, gli enti di cui al comma 709 non possono trasmettere nuove certificazioni a rettifica di quelle precedenti. Sono comunque tenuti ad inviare una nuova certificazione, a rettifica della precedente, solo gli enti che rilevano, rispetto a quanto gia' certificato, un peggioramento del proprio posizionamento rispetto all'obiettivo di saldo di cui al comma 710. (14)

723. In caso di mancato conseguimento del saldo di cui al comma 710, nell'anno successivo a quello dell'inadempienza:

- a) l'ente locale e' assoggettato ad una riduzione del fondo sperimentale di riequilibrio o del fondo di solidarieta' comunale in misura pari all'importo corrispondente allo scostamento registrato. Le province della Regione siciliana e della regione Sardegna sono assoggettate alla riduzione dei trasferimenti erariali nella misura indicata al primo periodo. Gli enti locali delle regioni Friuli Venezia Giulia e Valle d'Aosta e delle province autonome di Trento e di Bolzano sono assoggettati ad una riduzione dei trasferimenti correnti erogati dalle medesime regioni o province autonome in misura pari all'importo corrispondente allo scostamento registrato. In caso di incapienza gli enti locali sono tenuti a versare all'entrata del bilancio dello Stato le somme residue presso la competente sezione di tesoreria provinciale dello Stato, al Capo X dell'entrata del bilancio dello Stato, al capitolo 3509, articolo 2. In caso di mancato versamento delle predette somme residue nell'anno successivo a quello dell'inadempienza, il recupero e' operato con le procedure di cui ai commi 128 e 129 dell'articolo 1 della legge 24 dicembre 2012, n. 228;
- b) la regione e' tenuta a versare all'entrata del bilancio dello Stato, entro sessanta giorni dal termine stabilito per la trasmissione della certificazione relativa al rispetto del pareggio di bilancio, l'importo corrispondente allo scostamento registrato. In caso di mancato versamento si procede al recupero di detto scostamento a valere sulle giacenze depositate a qualsiasi titolo nei conti aperti presso la tesoreria statale. Trascorso inutilmente il termine dei trenta giorni dal termine di approvazione del rendiconto della gestione per la trasmissione della certificazione da parte della regione, si procede al blocco di qualsiasi prelievo dai conti della tesoreria statale sino a quando la certificazione non e' acquisita;
- c) l'ente non puo' impegnare spese correnti, per le regioni al netto delle spese per la sanita', in misura superiore all'importo dei corrispondenti impegni effettuati nell'anno precedente a quello di riferimento;
- d) l'ente non puo' ricorrere all'indebitamento per gli investimenti; i mutui e i prestiti obbligazionari posti in essere con istituzioni creditizie o finanziarie per il finanziamento degli investimenti o le aperture di linee di credito devono essere corredati da apposita attestazione da cui risulti il conseguimento dell'obiettivo di cui al primo periodo relativo all'anno precedente. L'istituto finanziatore o l'intermediario finanziario non puo' procedere al finanziamento o al collocamento del prestito in assenza della predetta attestazione;
- e) l'ente non puo' procedere ad assunzioni di personale a qualsiasi titolo, con qualsivoglia tipologia contrattuale, ivi compresi i rapporti di collaborazione coordinata e continuativa e di somministrazione, anche con riferimento ai processi di stabilizzazione in atto. E' fatto altresi' divieto agli enti di stipulare contratti di servizio con soggetti privati che si configurino come elusivi della presente disposizione;
- f) l'ente e' tenuto a rideterminare le indennita' di funzione ed i gettoni di presenza del presidente, del sindaco e dei componenti della giunta in carica nell'esercizio in cui e' avvenuta la violazione, con una riduzione del 30 per cento rispetto all'ammontare risultante alla data del 30 giugno 2014. Gli importi di cui al periodo precedente sono acquisiti al bilancio dell'ente. (14)

724. Agli enti per i quali il mancato conseguimento del saldo di cui al comma 710 sia accertato successivamente all'anno seguente a quello cui la violazione si riferisce, le sanzioni di cui al comma 723 si applicano nell'anno successivo a quello della comunicazione del mancato conseguimento del predetto saldo. La rideterminazione delle indennita' di funzione e dei gettoni di presenza di cui al comma 723, lettera f), e' applicata al presidente, al sindaco e ai componenti della giunta in carica nell'esercizio in cui e' avvenuto il mancato conseguimento. Gli importi di cui al periodo precedente sono acquisiti al bilancio dell'ente. (14)

725. Gli enti di cui al comma 724 sono tenuti a comunicare l'inadempienza entro trenta giorni dall'accertamento della violazione mediante l'invio di una nuova certificazione al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato. (14)

726. I contratti di servizio e gli altri atti posti in essere dagli enti, che si configurano elusivi delle regole di cui ai commi da 707 a 734, sono nulli. (14)

727. Qualora le sezioni giurisdizionali regionali della Corte dei conti accertino che il rispetto delle regole di cui ai commi da 707 a 734 e' stato artificiosamente conseguito mediante una non corretta applicazione dei principi contabili di cui al decreto legislativo 23 giugno 2011, n. 118, o altre forme elusive, le stesse irrogano, agli amministratori che hanno posto in essere atti elusivi delle predette regole, la condanna ad una sanzione pecuniaria fino a un massimo di dieci volte l'indennita' di carica percepita al momento di commissione dell'elusione e, al responsabile amministrativo individuato dalla sezione giurisdizionale regionale della Corte dei conti, una sanzione pecuniaria fino a tre mensilita' del trattamento retributivo, al netto degli oneri fiscali e previdenziali. Gli importi di cui al periodo precedente sono acquisiti al bilancio dell'ente. (14)

728. Le regioni possono autorizzare gli enti locali del proprio territorio a peggiorare il saldo di cui al comma 710 per consentire esclusivamente un aumento degli impegni di spesa in conto capitale, purche' sia garantito l'obiettivo complessivo a livello regionale mediante un contestuale miglioramento, di pari importo, del medesimo saldo dei restanti enti locali della regione e della regione stessa. Per gli anni 2016 e 2017, la Regione siciliana e le regioni Friuli Venezia Giulia e Valle d'Aosta operano la compensazione mediante la riduzione dell'obiettivo del patto di stabilita' in termini di competenza eurocompatibile di cui all'articolo 1, comma 454, della legge 24 dicembre 2012, n. 228, e la regione Trentino-Alto Adige e le province autonome di Trento e di Bolzano mediante il contestuale miglioramento, di pari importo, del proprio saldo programmatico riguardante il patto di stabilita' interno. (14)

729. Gli spazi finanziari ceduti dalla regione sono assegnati tenendo conto prioritariamente delle richieste avanzate dai comuni con popolazione fino a 1.000 abitanti, dai comuni istituiti per fusione a partire dall'anno 2011, nonche' dai comuni che accolgono richiedenti protezione internazionale. (14)

730. Ai fini della rideterminazione degli obiettivi di cui al comma 728, le regioni e le province autonome definiscono criteri di virtuosita' e modalita' operative, previo confronto in sede di Consiglio delle autonomie locali e, ove non istituito, con i rappresentanti regionali delle autonomie locali. Per i medesimi fini, gli enti locali comunicano all'Associazione nazionale dei comuni italiani (ANCI), all'Unione delle province d'Italia (UPI) e alle regioni e alle province autonome, entro il 15 aprile ed entro il 15 settembre, gli spazi finanziari di cui necessitano per effettuare esclusivamente impegni in conto capitale ovvero gli spazi finanziari che sono disposti a cedere. Entro i termini perentori del 30 aprile e del 30 settembre, le regioni e le province autonome comunicano agli enti locali interessati i saldi obiettivo rideterminati e al Ministero dell'economia e delle finanze, con riferimento a ciascun ente locale e alla stessa regione o provincia autonoma, gli elementi informativi occorrenti per la verifica del mantenimento dell'equilibrio dei saldi di finanza pubblica anche con riferimento a quanto disposto dal comma 731. Gli spazi finanziari attribuiti e non utilizzati per impegni in conto capitale non rilevano ai fini del conseguimento del saldo di cui al comma 710. (14)

731. Agli enti locali che cedono spazi finanziari e' riconosciuta, nel biennio successivo, una modifica migliorativa del saldo di cui al comma 710, commisurata al valore degli spazi finanziari ceduti, fermo restando l'obiettivo complessivo a livello regionale. Agli enti locali che acquisiscono spazi finanziari, nel biennio successivo, sono attribuiti saldi obiettivo peggiorati per un importo complessivamente pari agli spazi finanziari acquisiti. La somma dei maggiori spazi finanziari concessi e attribuiti deve risultare, per ogni anno di riferimento, pari a zero. (14)

732. Gli enti locali che prevedono di conseguire, nell'anno di riferimento, un differenziale negativo rispetto al saldo di cui al comma 710 possono richiedere, per la quota di spazi finanziari non soddisfatta tramite il meccanismo di cui al comma 728, al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato, mediante il sito web «http://pareggiobilancioentiterritoriali.tesoro.it» appositamente predisposto, entro il termine perentorio del 15 giugno, gli spazi di cui necessitano nell'esercizio in corso per sostenere impegni di spesa in conto capitale. Gli enti locali che prevedono di conseguire, nell'anno di riferimento, un differenziale positivo rispetto al saldo di cui al comma 710, possono comunicare al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato, mediante il sito web «http://pareggiobilancioentiterritoriali.tesoro.it» appositamente predisposto, entro il termine perentorio del 15 giugno, gli spazi che intendono cedere nell'esercizio in corso. Qualora l'entita' delle richieste pervenute dagli enti superi l'ammontare degli spazi finanziari resi disponibili, l'attribuzione e' effettuata in misura proporzionale agli spazi finanziari richiesti. Il Dipartimento della Ragioneria generale dello Stato, entro il 10 luglio, aggiorna gli obiettivi degli enti interessati dalla acquisizione e cessione di spazi finanziari di cui al presente comma, con riferimento all'anno in corso e al biennio successivo. Agli enti che acquisiscono spazi finanziari e' peggiorato, nel biennio successivo, l'obiettivo per un importo annuale pari alla meta' della quota acquisita, mentre agli enti che cedono spazi finanziari l'obiettivo di ciascun anno del biennio successivo e' migliorato in misura pari alla meta' del valore degli spazi finanziari ceduti. La somma dei maggiori spazi finanziari ceduti e di quelli attribuiti, per ogni anno di riferimento, e' pari a zero. (14)

733. Qualora risultino, anche sulla base dei dati del monitoraggio di cui al comma 719, andamenti di spesa degli enti non coerenti con gli impegni finanziari assunti con l'Unione europea, il Ministro dell'economia e delle finanze, sentite la Conferenza Stato-citta' ed autonomie locali e la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, propone adeguate misure di contenimento della predetta spesa. (14)

734. Per gli anni 2016 e 2017, alle regioni Friuli Venezia Giulia, Valle d'Aosta, Trentino-Alto Adige, alla Regione siciliana e alle province autonome di Trento e di Bolzano non si applicano le disposizioni di cui al comma 723 del presente articolo e resta ferma la disciplina del patto di stabilita' interno recata dall'articolo 1, commi 454 e seguenti, della legge 24 dicembre 2012, n. 228, come attuata dagli accordi sottoscritti con lo Stato. (14)

735. All'articolo 1, comma 466, della legge 23 dicembre 2014, n. 190, dopo il numero 3) e' aggiunto il seguente: «3-bis) nei saldi di competenza, gli impegni del perimetro sanitario del bilancio, finanziati dagli utilizzi del risultato di amministrazione relativo alla gestione sanitaria formatosi negli esercizi antecedenti l'anno 2015».

736. La disposizione di cui al comma 735 entra in vigore dalla data di pubblicazione della presente legge nella Gazzetta Ufficiale.

737. Per gli anni 2016 e 2017, i proventi delle concessioni edilizie e delle sanzioni previste dal testo unico delle disposizioni legislative e regolamentari in materia edilizia, di cui al decreto del Presidente della Repubblica 6 giugno 2001, n. 380, fatta eccezione per le sanzioni di cui all'articolo 31, comma 4-bis, del medesimo testo unico, possono essere utilizzati per una quota pari al 100 per cento per spese di manutenzione ordinaria del verde, delle strade e del patrimonio comunale, nonche' per spese di progettazione delle opere pubbliche.

738. All'articolo 2, comma 3-bis, del decreto-legge 28 gennaio 2014, n. 4, convertito, con modificazioni, dalla legge 28 marzo 2014, n. 50, le parole: «sino alla data del 31 dicembre 2015» sono sostituite dalle seguenti: «sino alla data del 31 dicembre 2016».

739. L'articolo 23, comma 7, del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134, nella parte in cui abroga l'articolo 11, comma 10, della legge 27 dicembre 1997, n. 449, relativo alla facolta' dei comuni di aumentare le tariffe dell'imposta comunale sulla pubblicita', ai sensi e per gli effetti dell'articolo 1 della legge 27 luglio 2000, n. 212, si interpreta nel senso che l'abrogazione non ha effetto per i comuni che si erano gia' avvalsi di tale facolta' prima della data di entrata in vigore del predetto articolo 23, comma 7, del decreto-legge n. 83 del 2012.

740. Al comma 19 dell'articolo 6 del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, le parole: «a favore delle societa' partecipate non quotate che abbiano registrato» sono sostituite dalle seguenti: «a favore delle societa' partecipate, con esclusione delle societa' quotate e degli istituti bancari, che abbiano registrato».

741. Al fine di consentire il finanziamento degli interventi di cui all'articolo 6 della legge 29 novembre 1984, n. 798, e successive modificazioni, e' autorizzata la spesa di 5 milioni di euro per l'anno 2016 e di 10 milioni di euro per ciascuno degli anni dal 2017 al 2022 destinati ai comuni di Venezia, Chioggia e Cavallino-Treporti, previa ripartizione eseguita dal Comitato di indirizzo, coordinamento e controllo di cui all'articolo 4 della medesima legge n. 798 del 1984.

742. L'Autorita' di regolazione dei trasporti, l'Autorita' per l'energia elettrica, il gas e il sistema idrico, l'Istituto per la vigilanza sulle assicurazioni e il Garante per la protezione dei dati personali sono assoggettati alla normativa di tesoreria unica di cui alla legge 29 ottobre 1984, n. 720, e inseriti nella tabella A allegata alla stessa legge.

743. Alla data del 1º marzo 2016 i cassieri delle Autorita' di cui al comma 742 provvedono a versare le disponibilita' liquide depositate presso gli stessi sulle rispettive contabilita' speciali, sottoconto fruttifero, aperte presso la tesoreria statale. Restano escluse dall'applicazione della presente disposizione le disponibilita' liquide rivenienti da operazioni di mutuo, prestito e ogni altra forma di indebitamento non sorrette da alcun contributo in conto capitale o in conto interessi da parte dello Stato, delle regioni o di altre pubbliche amministrazioni.

744. I cassieri delle Autorita' di cui al comma 742 adeguano l'operativita' dei servizi di cassa intrattenuti con le stesse Autorita' alle disposizioni di cui all'articolo 1 della legge 29 ottobre 1984, n. 720, e relative norme amministrative di attuazione.

745. Le Autorita' di cui al comma 742 provvedono a smobilizzare gli eventuali investimenti finanziari entro il 30 giugno 2016, riversando le relative risorse sulle contabilita' speciali aperte presso la tesoreria statale. Sono esclusi dallo smobilizzo i titoli di Stato italiani e le altre tipologie di investimento individuate dal decreto del Ministero dell'economia e delle finanze 27 aprile 2012, pubblicato nella Gazzetta Ufficiale n. 100 del 30 aprile 2012. Le Autorita' possono non smobilizzare gli investimenti in strumenti finanziari, come definiti dal testo unico di cui al decreto legislativo 24 febbraio 1998, n. 58, solo nel caso in cui il loro valore di mercato in uno dei giorni compresi tra il 16 e il 31 maggio 2016 sia inferiore al prezzo di acquisto.

746. Sono considerate assoggettabili al regime di tesoreria unica, con la procedura di cui all'articolo 2, quarto comma, della citata legge n. 720 del 1984, le Autorita' amministrative indipendenti, quali enti e organismi di diritto pubblico, che riscuotono diritti o contributi obbligatori aventi valore di tributi statali, pur in assenza di trasferimenti provenienti dal bilancio dello Stato.

747. Per il triennio 2016-2018 continuano ad applicarsi le disposizioni di cui all'articolo 1, commi 637, 638 e 642, della legge 27 dicembre 2006, n. 296.

748. In considerazione dell'adozione del bilancio unico d'ateneo, previsto dal decreto legislativo 27 gennaio 2012, n. 18, il fabbisogno finanziario programmato per l'anno 2016 del sistema universitario, di cui all'articolo 1, comma 637, della legge 27 dicembre 2006, n. 296, e' determinato incrementando del 3 per cento il fabbisogno programmato per l'anno 2015.

749. Il comma 639 dell'articolo 1 della legge 27 dicembre 2006, n. 296, e' sostituito dal seguente: «639. Il fabbisogno programmato di ciascuno degli enti di ricerca indicati al comma 638 e' determinato annualmente dal Ministero dell'economia e delle finanze nella misura inferiore tra il fabbisogno programmato e quello realizzato nell'anno precedente, incrementato del 4 per cento. Non concorrono alla determinazione del fabbisogno finanziario annuale: a) i pagamenti derivanti dagli accordi di programma e convenzioni per effetto dei quali gli enti medesimi agiscono in veste di attuatori dei programmi e delle attivita' per conto e nell'interesse dei Ministeri che li finanziano, nei limiti dei finanziamenti concessi; b) i pagamenti dell'Agenzia spaziale italiana (ASI) relativi alla contribuzione annuale dovuta all'Agenzia spaziale europea (ESA), in quanto correlati ad accordi internazionali, nonche' i pagamenti per programmi in collaborazione con la medesima ESA e i programmi realizzati con leggi speciali, ivi compresa la partecipazione al programma "Sistema satellitare di navigazione globale GNSS-Galileo" ai sensi della legge 29 gennaio 2001, n. 10, e dell'articolo 15, comma 2, del decreto legislativo 4 giugno 2003, n. 128; c) i pagamenti del Consorzio per l'area di ricerca scientifica e tecnologica di Trieste relativi alla contribuzione annuale dovuta alla Societa' consortile Elettra Sincrotrone di Trieste, di interesse nazionale, di cui all'articolo 10, comma 4, della legge 19 ottobre 1999, n. 370, di cui il Consorzio detiene la maggioranza del capitale sociale. Al fine di consentire il monitoraggio dell'utilizzo del fabbisogno finanziario programmato, gli enti di ricerca indicati al comma 638 comunicano al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato, entro il quindicesimo giorno del mese successivo a quello di riferimento, i pagamenti di cui alle lettere a), b) e c). I Ministeri vigilanti, ciascuno per i propri enti di ricerca, comunicano al Ministero dell'economia e delle finanze - Dipartimento della Ragioneria generale dello Stato, entro il 20 gennaio dell'anno successivo a quello di riferimento, l'ammontare complessivo dei finanziamenti concessi a ciascun ente di ricerca, erogati a fronte dei pagamenti di cui alla lettera a)».

750. Per l'anno 2016, nel saldo individuato ai sensi del comma 710 non sono considerate le spese sostenute da Roma Capitale per la realizzazione del Museo nazionale della Shoah, effettuate a valere sull'avanzo di amministrazione e su risorse rivenienti dal ricorso al debito. L'esclusione opera nel limite massimo di 3 milioni di euro.

751. Il Commissario straordinario del Governo per la gestione del piano di rientro, entro il 31 maggio e il 30 novembre di ciascun anno, propone alla Presidenza del Consiglio dei ministri l'aggiornamento del piano di rientro di cui all'articolo 14, comma 13-bis, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, e successive modificazioni. Con decreto del Presidente del Consiglio dei ministri, sentiti il Ministro dell'economia e delle finanze e il Ministro dell'interno, entro i successivi trenta giorni e' approvato l'aggiornamento del piano di rientro. Per l'anno 2016, l'aggiornamento del piano, secondo le modalita' di cui al periodo precedente, e' proposto entro il 31 gennaio, il 31 maggio e il 30 novembre.

752. Restano validi gli atti e i provvedimenti adottati e sono fatti salvi gli effetti prodottisi e i rapporti giuridici sorti sulla base del decreto del Presidente del Consiglio dei ministri 27 agosto 2015, relativo alla nomina del Commissario straordinario del Governo per la gestione del piano di rientro di cui all'articolo 78 del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, e successive modificazioni, e del decreto del Presidente del Consiglio dei ministri 21 settembre 2015, avente ad oggetto, tra l'altro, la ricognizione della attuale consistenza e della composizione della massa attiva e della massa passiva comprese nel predetto piano.

753. L'articolo 16, comma 4-ter, del decreto-legge 6 marzo 2014, n. 16, convertito, con modificazioni, dalla legge 2 maggio 2014, n. 68, e l'articolo 78, comma 2, lettera b), del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, sono abrogati. Il quinto e il sesto periodo dell'articolo 14, comma 13-ter, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, sono soppressi.

754. Alle province e alle citta' metropolitane delle regioni a statuto ordinario e' attribuito un contributo complessivo di 495 milioni di euro nell'anno 2016, 470 milioni di euro per ciascuno degli anni dal 2017 al 2020 e 400 milioni di euro annui a decorrere dall'anno 2021, di cui 245 milioni di euro per l'anno 2016, 220 milioni di euro per ciascuno degli anni dal 2017 al 2020 e 150 milioni di euro annui a decorrere dall'anno 2021 a favore delle province e 250 milioni di euro a favore delle citta' metropolitane, finalizzato al finanziamento delle spese connesse alle funzioni relative alla viabilita' e all'edilizia scolastica. Con decreto del Ministro dell'interno, di concerto con il Ministro dell'economia e delle finanze e il Ministro delegato per gli affari regionali e le autonomie, da adottare entro il 28 febbraio 2016, sentita la Conferenza Stato-citta' ed autonomie locali, e' stabilito il riparto del contributo di cui al periodo precedente, tenendo anche conto degli impegni desunti dagli ultimi tre rendiconti disponibili relativi alle voci di spesa di cui al primo periodo. (7)

755. Al comma 540 dell'articolo 1 della legge 23 dicembre 2014, n. 190, le parole: «con una dotazione di 125 milioni di euro per l'anno 2016 e di 100 milioni di euro per ciascuno degli anni dal 2017 al 2020» sono sostituite dalle seguenti: «con una dotazione di 30 milioni di euro per ciascuno degli anni dal 2016 al 2020».

756. Per l'esercizio 2016, le province e le citta' metropolitane:

- a) possono predisporre il bilancio di previsione per la sola annualita' 2016;
- b) al fine di garantire il mantenimento degli equilibri finanziari, possono applicare al bilancio di previsione l'avanzo libero e destinato.

757. Al comma 3 dell'articolo 1-ter del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125, sono aggiunte, in fine, le seguenti parole: «riclassificato secondo lo schema di cui all'allegato 9 del decreto legislativo 23 giugno 2011, n. 118, e successive modificazioni».

758. Al fine di garantire l'equilibrio della situazione corrente per l'anno 2016 dei bilanci delle citta' metropolitane e delle province, le regioni, previa intesa in sede di Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, e successive modificazioni, possono operare lo svincolo dei trasferimenti correnti e in conto capitale gia' attribuiti ai predetti enti e affluiti nell'avanzo di amministrazione vincolato dell'anno 2015. Le quote dell'avanzo di amministrazione dell'anno 2015 cosi' svincolate sono applicate al bilancio di previsione per l'anno 2016 delle citta' metropolitane e delle province dopo l'approvazione del rendiconto dell'esercizio 2015. I trasferimenti oggetto di svincolo possono essere rifinanziati a valere sulle annualita' successive all'anno 2015 del bilancio delle regioni.(18)

759. All'articolo 1, comma 430, della legge 23 dicembre 2014, n. 190, sono apportate le seguenti modificazioni:

- a) le parole: «nell'anno 2015» sono sostituite dalle seguenti: «negli anni 2015 e 2016»;
- b) dopo la parola: «richiedente» sono aggiunte le seguenti: «, che puo' utilizzare gli eventuali risparmi di rata, nonche' quelli provenienti dal riacquisto dei titoli obbligazionari emessi senza vincoli di destinazione. Le operazioni di rinegoziazione di cui al primo periodo possono essere effettuate anche nel corso dell'esercizio provvisorio di cui all'articolo 163 del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267, fermo restando l'obbligo, per gli enti, di effettuare le relative iscrizioni nel bilancio di previsione».

760. All'articolo 4, comma 1, del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125, le parole: «per l'anno 2014» sono sostituite dalle seguenti: «per gli anni 2014 e 2015».

761. Il Fondo nazionale per la montagna di cui all'articolo 2 della legge 31 gennaio 1994, n. 97, e' finanziato per un importo di 5 milioni di euro per ciascuno degli anni 2016, 2017 e 2018.

762. Le norme finalizzate al contenimento della spesa di personale che fanno riferimento al patto di stabilita' interno si intendono riferite agli obiettivi di finanza pubblica recati dai commi da 707 a 734. Restano ferme le disposizioni di cui all'articolo 1, comma 562, della legge 27 dicembre 2006, n. 296, e le altre disposizioni in materia di spesa di personale riferite agli enti che nell'anno 2015 non erano sottoposti alla disciplina del patto di stabilita' interno.

763. In considerazione delle particolari condizioni geo politiche del comune di Campione d'Italia, anche a seguito degli effetti finanziari negativi connessi al tasso di cambio del franco svizzero, e' attribuito al medesimo comune un contributo di 9 milioni di euro per l'anno 2016. Per l'anno 2016 la dotazione del Fondo di solidarieta' comunale di cui al comma 380-ter dell'articolo 1 della legge 24 dicembre 2012, n. 228, da ripartire sulla base dei criteri di cui ai numeri da 1) a 3) della lettera b) del medesimo comma 380-ter, e' ridotta di 9 milioni di euro.

764. Nello stato di previsione del Ministero dell'interno e' istituito, per l'anno 2016, un fondo con la dotazione di 60 milioni di euro. Il fondo e' costituito mediante l'utilizzo delle risorse delle amministrazioni centrali disponibili per le assunzioni di cui all'articolo 1, comma 425, della legge 23 dicembre 2014, n. 190, che sono conseguentemente ridotte. Una quota pari al 66 per cento del predetto fondo e' destinata alle province delle regioni a statuto ordinario che non riescono a garantire il mantenimento della situazione finanziaria corrente per l'anno 2016, ed e' ripartita entro il 28 febbraio 2016, con decreto del Ministro dell'interno, di concerto con il Ministro dell'economia e delle finanze e con il Ministro delegato per gli affari regionali e le autonomie, secondo le modalita' e i criteri definiti in sede di Conferenza Stato-citta' ed autonomie locali. Nelle more del completamento del processo di riordino delle funzioni da parte delle regioni e del trasferimento definitivo del personale soprannumerario nelle amministrazioni pubbliche, la restante quota del 34 per cento del fondo e' finalizzata esclusivamente a concorrere alla corresponsione del trattamento economico al medesimo personale. Con decreto del Ministro dell'interno, su proposta del Ministro per la semplificazione e la pubblica amministrazione, di concerto con il Ministro dell'economia e delle finanze e il Ministro delegato per gli affari regionali e le autonomie, la predetta quota del 34 per cento del fondo di cui al presente comma e' ripartita tra le amministrazioni interessate in proporzione alle unita' di personale dichiarato in soprannumero, e non ancora ricollocato, secondo le risultanze del monitoraggio attivato ai sensi dell'articolo 1, commi 424 e 425, della legge 23 dicembre 2014, n. 190, e del relativo decreto del Ministro per la semplificazione e la pubblica amministrazione 14 settembre 2015, pubblicato nella Gazzetta Ufficiale n. 227 del 30 settembre 2015. (7)

765. Entro trenta giorni dalla data di entrata in vigore della presente legge, ai sensi dell'articolo 1, comma 95, della legge 7 aprile 2014, n. 56, con decreto del Presidente del Consiglio dei ministri, previa deliberazione del Consiglio dei ministri, sentita la Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, e' nominato un commissario al fine di assicurare, nelle regioni che a tale data non hanno provveduto a dare attuazione all'accordo tra Stato e regioni sancito in sede di Conferenza unificata l'11 settembre 2014, il completamento degli adempimenti necessari a rendere effettivo, entro il 30 giugno 2016, il trasferimento delle risorse umane, strumentali e finanziarie relative alle funzioni non fondamentali delle province e delle citta' metropolitane, in attuazione della riforma di cui alla citata legge n. 56 del 2014. Al commissario di cui al presente comma non e' corrisposto alcun compenso, indennita', rimborso spese o emolumento comunque denominato; il commissario puo' avvalersi, ai predetti fini, degli uffici e delle strutture di amministrazioni pubbliche, centrali, regionali e locali. All'attuazione del presente comma si provvede con le risorse umane, strumentali e finanziarie disponibili a legislazione vigente nell'ambito del bilancio autonomo della Presidenza del Consiglio dei ministri e comunque senza nuovi o maggiori oneri a carico della finanza pubblica.

766. Il commissario, sentite le regioni interessate, adotta gli atti necessari per il trasferimento delle risorse di cui al comma 765, come quantificate ai sensi dell'articolo 1, comma 421, della legge 23 dicembre 2014, n. 190, intendendosi che, in assenza di disposizioni legislative regionali e fatta salva la loro successiva adozione, sono attribuite alla regione le funzioni non fondamentali delle province e citta' metropolitane. Per il trasferimento del personale, il commissario opera secondo i criteri individuati ai sensi della legge n. 56 del 2014, nei limiti della capacita' di assunzione e delle relative risorse finanziarie della regione ovvero della capacita' di assunzione e delle relative risorse finanziarie dei comuni che insistono nel territorio della provincia o citta' metropolitana interessata, avvalendosi delle procedure previste dal decreto del Ministro per la semplificazione e la pubblica amministrazione 14 settembre 2015, pubblicato nella Gazzetta Ufficiale n. 227 del 30 settembre 2015.

767. Per le regioni che hanno adottato in via definitiva la legge attuativa dell'accordo tra Stato e regioni sancito in sede di Conferenza unificata l'11 settembre 2014 ma non hanno completato il trasferimento delle risorse, il commissario opera d'intesa con il Presidente della regione, secondo le modalita' previste dalla legge regionale.

768. Il personale delle citta' metropolitane e delle province che si e' collocato in posizione utile nelle graduatorie redatte dal Ministero della giustizia a seguito del bando di mobilita' adottato con ricorso al fondo di cui all'articolo 30, comma 2.3, del decreto legislativo 30 marzo 2001, n. 165, e' inquadrato, entro il 31 gennaio 2016, nei ruoli del Ministero della giustizia con assegnazione negli uffici giudiziari secondo le risultanze delle medesime graduatorie, a prescindere dal nulla osta dell'ente di provenienza.

769. L'acquisizione di personale delle citta' metropolitane e delle province ai sensi dell'articolo 1, comma 425, settimo e ottavo periodo, della legge 23 dicembre 2014, n. 190, e' effettuata prescindendo dall'assenso dell'ente di provenienza.

770. All'articolo 5, comma 3, del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125, e' aggiunto, in fine, il seguente periodo: «Qualora le leggi regionali riallochino le funzioni di polizia amministrativa locale e il relativo personale presso le citta' metropolitane e le province per l'esercizio delle funzioni di vigilanza connesse alle funzioni non fondamentali oggetto di riordino, con copertura dei relativi oneri, la dotazione organica degli enti di area vasta, ridotta ai sensi dell'articolo 1, comma 421, della legge 23 dicembre 2014, n. 190, e' rideterminata in aumento in misura corrispondente al personale riallocato».

771. Al fine di supportare il processo di digitalizzazione in corso presso gli uffici giudiziari e per dare compiuta attuazione al trasferimento al Ministero della giustizia delle spese obbligatorie per il funzionamento degli uffici giudiziari effettuato ai sensi dell'articolo 1, commi da 526 a 530, della legge 23 dicembre 2014, n. 190, il Ministero della giustizia acquisisce un contingente massimo di 1.000 unita' di personale amministrativo proveniente dagli enti di area vasta, nel biennio 2016 e 2017, da inquadrare nel ruolo dell'amministrazione giudiziaria, attingendo prioritariamente alla graduatoria, in corso di validita', ove sia utilmente collocato il personale di cui al comma 769 del presente articolo, ovvero mediante il portale di cui al decreto del Presidente del Consiglio dei ministri 29 settembre 2014. PERIODO SOPPRESSO DAL D.L. 30 GIUGNO 2016, N. 117, CONVERTITO CON MODIFICAZIONI DALLA L. 12 AGOSTO 2016, N. 161.

772. Le unita' di personale che transitano presso il Ministero della giustizia ai sensi dei commi 768, 769 e 771 sono portate a scomputo del personale soprannumerario adibito alle funzioni non fondamentali degli enti di area vasta.

773. All'articolo 21-quater, comma 1, primo periodo, del decreto-legge 27 giugno 2015, n. 83, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 132, le parole: «a indire le procedure di contrattazione collettiva ai fini della definizione di procedure interne» sono sostituite dalle seguenti: «a indire una o piu' procedure interne, nel rispetto del citato CCNL comparto Ministeri 1998/2001 e successivi contratti integrativi dello stesso».

774. E' fatto salvo quanto previsto dall'articolo 7, comma 9-quinquies, del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125.

775. COMMA ABROGATO DALLA L. 11 DICEMBRE 2016, N. 232.

776. All'articolo 1, comma 529, della legge 27 dicembre 2013, n. 147, sono aggiunte, in fine, le seguenti parole: «gia' in servizio alla data di entrata in vigore della presente legge e che comunque abbia maturato il requisito entro il 31 dicembre 2015, ferma restando la necessita' di assicurare la compatibilita' dell'intervento con il raggiungimento dei propri obiettivi di finanza pubblica».

777. Al fine di razionalizzare i costi conseguenti alla violazione del termine di ragionevole durata dei processi, al capo II della legge 24 marzo 2001, n. 89, sono apportate le seguenti modificazioni:

- a) all'articolo 2 sono premessi i seguenti: «Art. 1-bis. - (Rimedi all'irragionevole durata del processo). - 1. La parte di un processo ha diritto a esperire rimedi preventivi alla violazione della Convenzione per la salvaguardia dei diritti dell'uomo e delle liberta' fondamentali, ratificata ai sensi della legge 4 agosto 1955, n. 848, sotto il profilo del mancato rispetto del termine ragionevole di cui all'articolo 6, paragrafo 1, della Convenzione stessa. 2. Chi, pur avendo esperito i rimedi preventivi di cui all'articolo 1-ter, ha subito un danno patrimoniale o non patrimoniale a causa dell'irragionevole durata del processo ha diritto ad una equa riparazione. Art. 1-ter. - (Rimedi preventivi). - 1. Ai fini della presente legge, nei processi civili costituisce rimedio preventivo a norma dell'articolo 1-bis, comma 1, l'introduzione del giudizio nelle forme del procedimento sommario di cognizione di cui agli articoli 702-bis e seguenti del codice di procedura civile. Costituisce altresi' rimedio preventivo formulare richiesta di passaggio dal rito ordinario al rito sommario a norma dell'articolo 183-bis del codice di procedura civile, entro l'udienza di trattazione e comunque almeno sei mesi prima che siano trascorsi i termini di cui all'articolo 2, comma 2-bis. Nelle cause in cui non si applica il rito sommario di cognizione, ivi comprese quelle in grado di appello, costituisce rimedio preventivo proporre istanza di decisione a seguito di trattazione orale a norma dell'articolo 281-sexies del codice di procedura civile, almeno sei mesi prima che siano trascorsi i termini di cui all'articolo 2, comma 2-bis. Nelle cause in cui il tribunale giudica in composizione collegiale, il giudice istruttore quando ritiene che la causa puo' essere decisa a seguito di trattazione orale, a norma dell'articolo 281-sexies del codice di procedura civile, rimette la causa al collegio fissando l'udienza collegiale per la precisazione delle conclusioni e per la discussione orale. 2. L'imputato e le altre parti del processo penale hanno diritto di depositare, personalmente o a mezzo di procuratore speciale, un'istanza di accelerazione almeno sei mesi prima che siano trascorsi i termini di cui all'articolo 2, comma 2-bis. 3. Nei giudizi dinanzi al giudice amministrativo costituisce rimedio preventivo la presentazione dell'istanza di prelievo di cui all'articolo 71, comma 2, del codice del processo amministrativo, di cui al decreto legislativo 2 luglio 2010, n. 104, almeno sei mesi prima che siano trascorsi i termini di cui all'articolo 2, comma 2-bis. 4. Nel procedimento contabile davanti alla Corte dei conti il presunto responsabile ha diritto di depositare, personalmente o a mezzo di procuratore speciale, un'istanza di accelerazione, almeno sei mesi prima che siano trascorsi i termini di cui all'articolo 2, comma 2-bis. 5. La parte dei giudizi di natura pensionistica dinanzi alla Corte dei conti ha diritto di depositare, personalmente o a mezzo di procuratore speciale, un'istanza di accelerazione, almeno sei mesi prima che siano trascorsi i termini di cui all'articolo 2, comma 2-bis. 6. Nei giudizi davanti alla Corte di cassazione la parte ha diritto a depositare un'istanza di accelerazione almeno due mesi prima che siano trascorsi i termini di cui all'articolo 2, comma 2-bis. 7. Restano ferme le disposizioni che determinano l'ordine di priorita' nella trattazione dei procedimenti»;
- b) all'articolo 2, il comma 1 e' sostituito dal seguente: «1. E' inammissibile la domanda di equa riparazione proposta dal soggetto che non ha esperito i rimedi preventivi all'irragionevole durata del processo di cui all'articolo 1-ter»;
- c) all'articolo 2, il comma 2-quinquies e' sostituito dal seguente: «2-quinquies. Non e' riconosciuto alcun indennizzo: a) in favore della parte che ha agito o resistito in giudizio consapevole della infondatezza originaria o sopravvenuta delle proprie domande o difese, anche fuori dai casi di cui all'articolo 96 del codice di procedura civile; b) nel caso di cui all'articolo 91, primo comma, secondo periodo, del codice di procedura civile; c) nel caso di cui all'articolo 13, comma 1, primo periodo, del decreto legislativo 4 marzo 2010, n. 28; d) in ogni altro caso di abuso dei poteri processuali che abbia determinato una ingiustificata dilazione dei tempi del procedimento»;
- d) all'articolo 2, dopo il comma 2-quinquies sono aggiunti i seguenti: «2-sexies. Si presume insussistente il pregiudizio da irragionevole durata del processo, salvo prova contraria, nel caso di: a) dichiarazione di intervenuta prescrizione del reato, limitatamente all'imputato; b) contumacia della parte; c) estinzione del processo per rinuncia o inattivita' delle parti ai sensi degli articoli 306 e 307 del codice di procedura civile e dell'articolo 84 del codice del processo amministrativo, di cui al decreto legislativo 2 luglio 2010, n. 104; d) perenzione del ricorso ai sensi degli articoli 81 e 82 del codice del processo amministrativo, di cui al decreto legislativo 2 luglio 2010, n. 104; e) mancata presentazione della domanda di riunione nel giudizio amministrativo presupposto, in pendenza di giudizi dalla stessa parte introdotti e ricorrendo le condizioni di cui all'articolo 70 del codice del processo amministrativo, di cui al decreto legislativo 2 luglio 2010, n. 104; f) introduzione di domande nuove, connesse con altre gia' proposte, con ricorso separato, pur ricorrendo i presupposti per i motivi aggiunti di cui all'articolo 43 del codice del processo amministrativo, di cui al decreto legislativo 2 luglio 2010, n. 104, salvo che il giudice amministrativo disponga la separazione dei processi; g) irrisorieta' della pretesa o del valore della causa, valutata anche in relazione alle condizioni personali della parte. 2-septies. Si presume parimenti insussistente il danno quando la parte ha conseguito, per effetto della irragionevole durata del processo, vantaggi patrimoniali eguali o maggiori rispetto alla misura dell'indennizzo altrimenti dovuto»; >e) all'articolo 2-bis, il comma 1 e' sostituito dal seguente: «1. Il giudice liquida a titolo di equa riparazione, di regola, una somma di denaro non inferiore a euro 400 e non superiore a euro 800 per ciascun anno, o frazione di anno superiore a sei mesi, che eccede il termine ragionevole di durata del processo. La somma liquidata puo' essere incrementata fino al 20 per cento per gli anni successivi al terzo e fino al 40 per cento per gli anni successivi al settimo»; f) all'articolo 2-bis, dopo il comma 1 sono inseriti i seguenti: «1-bis. La somma puo' essere diminuita fino al 20 per cento quando le parti del processo presupposto sono piu' di dieci e fino al 40 per cento quando le parti del processo sono piu' di cinquanta. 1-ter. La somma puo' essere diminuita fino a un terzo in caso di integrale rigetto delle richieste della parte ricorrente nel procedimento cui la domanda di equa riparazione si riferisce. 1-quater. L'indennizzo e' riconosciuto una sola volta in caso di riunione di piu' giudizi presupposti che coinvolgono la stessa parte. La somma liquidata puo' essere incrementata fino al 20 per cento per ciascun ricorso riunito, quando la riunione e' disposta su istanza di parte»; g) all'articolo 3, il comma 1 e' sostituito dal seguente: «1. La domanda di equa riparazione si propone con ricorso al presidente della corte d'appello del distretto in cui ha sede il giudice innanzi al quale si e' svolto il primo grado del processo presupposto. Si applica l'articolo 125 del codice di procedura civile»; h) all'articolo 3, comma 4, dopo il primo periodo e' inserito il seguente: «Non puo' essere designato il giudice del processo presupposto»; i) al comma 7 dell'articolo 3, dopo le parole: «delle risorse disponibili» sono aggiunte le seguenti: «nel relativo capitolo, fatto salvo il ricorso al conto sospeso»; l) dopo l'articolo 5-quinquies e' inserito il seguente: «Art. 5-sexies. - (Modalita' di pagamento). - 1. Al fine di ricevere il pagamento delle somme liquidate a norma della presente legge, il creditore rilascia all'amministrazione debitrice una dichiarazione, ai sensi degli articoli 46 e 47 del testo unico di cui al decreto del Presidente della Repubblica 28 dicembre 2000, n. 445, attestante la mancata riscossione di somme per il medesimo titolo, l'esercizio di azioni giudiziarie per lo stesso credito, l'ammontare degli importi che l'amministrazione e' ancora tenuta a corrispondere, la modalita' di riscossione prescelta ai sensi del comma 9 del presente articolo, nonche' a trasmettere la documentazione necessaria a norma dei decreti di cui al comma 3. 2. La dichiarazione di cui al comma 1 ha validita' semestrale e deve essere rinnovata a richiesta della pubblica amministrazione. 3. Con decreti del Ministero dell'economia e delle finanze e del Ministero della giustizia, da emanare entro il 30 ottobre 2016, sono approvati i modelli di dichiarazione di cui al comma 1 ed e' individuata la documentazione da trasmettere all'amministrazione debitrice ai sensi del predetto comma 1. Le amministrazioni pubblicano nei propri siti istituzionali la modulistica di cui al periodo precedente. 4. Nel caso di mancata, incompleta o irregolare trasmissione della dichiarazione o della documentazione di cui ai commi precedenti, l'ordine di pagamento non puo' essere emesso. 5. L'amministrazione effettua il pagamento entro sei mesi dalla data in cui sono integralmente assolti gli obblighi previsti ai commi precedenti. Il termine di cui al periodo precedente non inizia a decorrere in caso di mancata, incompleta o irregolare trasmissione della dichiarazione ovvero della documentazione di cui ai commi precedenti. 6. L'amministrazione esegue, ove possibile, i provvedimenti per intero. L'erogazione degli indennizzi agli aventi diritto avviene nei limiti delle risorse disponibili sui pertinenti capitoli di bilancio, fatto salvo il ricorso ad anticipazioni di tesoreria mediante pagamento in conto sospeso, la cui regolarizzazione avviene a carico del fondo di riserva per le spese obbligatorie, di cui all'articolo 26 della legge 31 dicembre 2009, n. 196. 7. Prima che sia decorso il termine di cui al comma 5, i creditori non possono procedere all'esecuzione forzata, alla notifica dell'atto di precetto, ne' proporre ricorso per l'ottemperanza del provvedimento. 8. Qualora i creditori di somme liquidate a norma della presente legge propongano l'azione di ottemperanza di cui al titolo I del libro quarto del codice del processo amministrativo, di cui al decreto legislativo 2 luglio 2010, n. 104, il giudice amministrativo nomina, ove occorra, commissario ad acta un dirigente dell'amministrazione soccombente, con esclusione dei titolari di incarichi di Governo, dei capi dipartimento e di coloro che ricoprono incarichi dirigenziali generali. I compensi riconosciuti al commissario ad acta rientrano nell'onnicomprensivita' della retribuzione dei dirigenti. 9. Le operazioni di pagamento delle somme dovute a norma della presente legge si effettuano mediante accreditamento sui conti correnti o di pagamento dei creditori. I pagamenti per cassa o per vaglia cambiario non trasferibile sono possibili solo se di importo non superiore a 1.000 euro. 10. Nei casi di riscossione per cassa o tramite vaglia cambiario il creditore puo' delegare all'incasso un legale rappresentante con il rilascio di procura speciale. 11. Nel processo di esecuzione forzata, anche in corso, non puo' essere disposto il pagamento di somme o l'assegnazione di crediti in favore dei creditori di somme liquidate a norma della presente legge in caso di mancato, incompleto o irregolare adempimento degli obblighi di comunicazione. La disposizione di cui al presente comma si applica anche al pagamento compiuto dal commissario ad acta. 12. I creditori di provvedimenti notificati anteriormente all'emanazione dei decreti di cui al comma 3 trasmettono la dichiarazione e la documentazione di cui ai commi precedenti avvalendosi della modulistica presente nei siti istituzionali delle amministrazioni. Le dichiarazioni complete e regolari, gia' trasmesse alla data di entrata in vigore del presente articolo, conservano validita' anche in deroga al disposto dei commi 9 e 10»; m) all'articolo 6, dopo il comma 2 sono aggiunti i seguenti: «2-bis. Nei processi la cui durata al 31 ottobre 2016 ecceda i termini ragionevoli di cui all'articolo 2, comma 2-bis, e in quelli assunti in decisione alla stessa data non si applica il comma 1 dell'articolo 2. 2-ter. Il comma 2 dell'articolo 54 del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, come modificato dall'articolo 3, comma 23, dell'allegato 4 al decreto legislativo 2 luglio 2010, n. 104, si applica solo nei processi amministrativi la cui durata al 31 ottobre 2016 ecceda i termini di cui all'articolo 2, comma 2-bis».

778. Per gli anni dal 2016 al 2022, entro il limite di spesa massimo di 10 milioni di euro annui e, a decorrere dall'anno 2023, entro il limite di spesa massimo di 40 milioni di euro annui, i soggetti che vantano crediti per spese, diritti e onorari di avvocato, sorti ai sensi degli articoli 82 e seguenti del testo unico delle disposizioni legislative e regolamentari in materia di spese di giustizia, di cui al decreto del Presidente della Repubblica 30 maggio 2002, n. 115, e successive modificazioni, in qualsiasi data maturati e non ancora saldati, per i quali non e' stata proposta opposizione ai sensi dell'articolo 170 del medesimo testo unico di cui al decreto del Presidente della Repubblica 30 maggio 2002, n. 115, sono ammessi alla compensazione con quanto da essi dovuto per ogni imposta e tassa, compresa l'imposta sul valore aggiunto (IVA), nonche' al pagamento dei contributi previdenziali mediante cessione, anche parziale, dei predetti crediti entro il limite massimo pari all'ammontare dei crediti stessi, aumentato dell'IVA e del contributo previdenziale per gli avvocati (CPA). Tali cessioni sono esenti da ogni imposta di bollo e di registro. PERIODO SOPPRESSO DALLA L. 29 DICEMBRE 2022, N. 197. PERIODO SOPPRESSO DALLA L. 29 DICEMBRE 2022, N. 197.

779. Per le finalita' di cui al comma 778 e' autorizzata la spesa di 10 milioni di euro annui a decorrere dall'anno 2016.

780. Con decreto del Ministro dell'economia e delle finanze, di concerto con il Ministro della giustizia, da emanare entro sessanta giorni dalla data di entrata in vigore della presente legge, sono stabiliti criteri, priorita' e modalita' per l'attuazione delle misure di cui al comma 778 e per garantire il rispetto del limite di spesa di cui al comma 779.

781. Al codice del processo amministrativo, di cui al decreto legislativo 2 luglio 2010, n. 104, sono apportate le seguenti modificazioni:

- a) all'articolo 114, comma 4, lettera e), sono aggiunte, in fine, le seguenti parole: «. Nei giudizi di ottemperanza aventi ad oggetto il pagamento di somme di denaro, la penalita' di mora di cui al primo periodo decorre dal giorno della comunicazione o notificazione dell'ordine di pagamento disposto nella sentenza di ottemperanza; detta penalita' non puo' considerarsi manifestamente iniqua quando e' stabilita in misura pari agli interessi legali»;
- b) dopo l'articolo 71 e' inserito il seguente: «Art. 71-bis. - (Effetti dell'istanza di prelievo). - 1. A seguito dell'istanza di cui al comma 2 dell'articolo 71, il giudice, accertata la completezza del contraddittorio e dell'istruttoria, sentite sul punto le parti costituite, puo' definire, in camera di consiglio, il giudizio con sentenza in forma semplificata».

782. Al decreto-legge 21 giugno 2013, n. 69, convertito, con modificazioni, dalla legge 9 agosto 2013, n. 98, sono apportate le seguenti modificazioni:

- a) all'articolo 62, comma 2, dopo le parole: «in unico grado» sono aggiunte le seguenti: «, fatta eccezione per quelli di cui alla legge 24 marzo 2001, n. 89»;
- b) all'articolo 68, comma 2, e' aggiunto, in fine, il seguente periodo: «Il decreto di cui all'articolo 3, comma 5, della legge 24 marzo 2001, n. 89, e' computato nella misura di un ottavo di provvedimento ai fini del raggiungimento della soglia di cui al periodo precedente»;
- c) all'articolo 72, comma 2, e' aggiunto, in fine, il seguente periodo: «Quando il provvedimento e' costituito dal decreto di cui all'articolo 3, comma 5, della legge 24 marzo 2001, n. 89, l'indennita' e' dovuta nella misura di euro 25 per ciascun decreto».

783. All'articolo 83 del testo unico delle disposizioni legislative e regolamentari in materia di spese di giustizia, di cui al decreto del Presidente della Repubblica 30 maggio 2002, n. 115, e' aggiunto, in fine, il seguente comma: «3-bis. Il decreto di pagamento e' emesso dal giudice contestualmente alla pronuncia del provvedimento che chiude la fase cui si riferisce la relativa richiesta».

784. Al fine di consentire la realizzazione e la piena operativita' di sistemi informatici idonei ad assicurare la completa automatizzazione di tutte le attivita' amministrative relative ai settori del pagamento delle spese di giustizia e dei crediti liquidati a norma della legge 24 marzo 2001, n. 89, i capi degli uffici giudiziari possono stipulare apposite convenzioni, autorizzate dal Ministero della giustizia e senza oneri a carico della finanza pubblica, con i consigli dell'ordine circondariale forense per consentire che alcune unita' di personale dei predetti consigli dell'ordine vengano distaccate presso gli uffici giudiziari a supporto delle attivita' di cancelleria o di segreteria esclusivamente nei settori di cui al presente comma. Le convenzioni sono stipulate in conformita' e nei limiti di una convenzione quadro, previamente stipulata tra il Ministero della giustizia e il Consiglio nazionale forense. La convenzione quadro individua le procedure di controllo necessarie a impedire che i soggetti di cui al presente comma siano adibiti a supporto di attivita' diverse da quelle previste dal presente comma e che agli stessi sia consentito l'accesso a dati sensibili e giudiziari diversi e ulteriori rispetto a quelli strettamente connessi con lo svolgimento delle predette attivita' di supporto. La convenzione quadro prevede l'obbligo dei consigli dell'ordine circondariale forense di stipulare adeguate polizze di assicurazione per la responsabilita' per danno erariale con massimale non inferiore a quello stabilito dalla medesima convenzione, al fine di tutelare il personale di cancelleria o di segreteria dalle eventuali conseguenze derivanti dalle condotte del personale distaccato presso l'ufficio giudiziario.

785. Per tutta la durata del periodo durante il quale i soggetti di cui al comma 784 sono distaccati presso gli uffici giudiziari, i consigli dell'ordine dai quali dipendono sono tenuti a corrispondere loro i trattamenti retributivi, i contributi previdenziali, assicurativi e assistenziali previsti dalle vigenti disposizioni legislative. Per l'intera durata del medesimo periodo, agli stessi soggetti non compete alcuna forma di compenso, di indennita', di rimborso spese o di trattamento previdenziale, assistenziale o assicurativo da parte della pubblica amministrazione, con la quale non si instaura alcun rapporto di lavoro subordinato o autonomo.

786. Le disposizioni di cui ai commi 784 e 785 hanno efficacia per i tre anni successivi alla data della loro entrata in vigore. Le convenzioni stipulate a norma dei predetti commi cessano di avere efficacia decorso il termine di cui al periodo precedente.

787. Le convenzioni, anche diverse da quelle di cui ai commi 784 e 785, stipulate dai capi degli uffici giudiziari con le amministrazioni pubbliche devono essere preventivamente autorizzate, a pena di inefficacia, dal Ministero della giustizia e devono essere realizzate senza nuovi o maggiori oneri per la finanza pubblica.

788. All'articolo 1, comma 250, della legge 27 dicembre 2013, n. 147, il primo periodo e' sostituito dal seguente: «All'esecuzione delle pronunce di condanna al pagamento di somme di denaro emesse nei confronti delle amministrazioni dello Stato per mancato o ritardato recepimento nell'ordinamento di direttive o di altri provvedimenti dell'Unione europea provvede ciascuna delle predette amministrazioni, in relazione alla soccombenza nel giudizio, nell'ambito delle risorse iscritte in bilancio a legislazione vigente».

789. All'articolo 10, comma 12-vicies, del decreto-legge 31 dicembre 2014, n. 192, convertito, con modificazioni, dalla legge 27 febbraio 2015, n. 11, le parole: «dalla conclusione del procedimento penale instaurato per i medesimi fatti e definito con sentenza anteriore alla data di entrata in vigore del decreto legislativo 29 marzo 2010, n. 48, non risulti il coinvolgimento del medesimo soggetto obbligato a titolo di dolo o colpa» sono sostituite dalle seguenti: «dal procedimento penale instaurato per i medesimi fatti accaduti anteriormente alla data di entrata in vigore del decreto legislativo 29 marzo 2010, n. 48, non sia derivata una sentenza di condanna passata in giudicato in cui sia riconosciuto dolo o colpa grave per il medesimo soggetto obbligato».

790. In attuazione dei principi di cui alla direttiva 29/2012/UE del Parlamento europeo e del Consiglio, del 25 ottobre 2012, in materia di diritti, assistenza e protezione delle vittime di reato, in attuazione della Convenzione del Consiglio d'Europa sulla prevenzione e la lotta contro la violenza nei confronti delle donne e la violenza domestica, ratificata ai sensi della legge 27 giugno 2013, n. 77, nonche' in attuazione del decreto-legge 14 agosto 2013, n. 93, convertito, con modificazioni, dalla legge 15 ottobre 2013, n. 119, e' istituito, nelle aziende sanitarie e ospedaliere, un percorso di protezione denominato «Percorso di tutela delle vittime di violenza», con la finalita' di tutelare le persone vulnerabili vittime della altrui violenza, con particolare riferimento alle vittime di violenza sessuale, maltrattamenti o atti persecutori (stalking). All'istituzione del Percorso di tutela delle vittime di violenza si provvede con le risorse finanziarie, umane e strumentali previste a legislazione vigente.

791. Con decreto del Presidente del Consiglio dei ministri, di concerto con i Ministri della giustizia, della salute e dell'interno, d'intesa con la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, tenuto conto delle esperienze gia' operative a livello locale, entro sessanta giorni dalla data di entrata in vigore della presente legge, sono definite a livello nazionale le linee guida volte a rendere operativo il Percorso di tutela delle vittime di violenza, di cui al comma 790, anche in raccordo con le previsioni del Piano d'azione straordinario contro la violenza sessuale e di genere, di cui all'articolo 5, comma 1, del decreto-legge 14 agosto 2013, n. 93, convertito, con modificazioni, dalla legge 15 ottobre 2013, n. 119. L'attuazione delle linee guida avviene attraverso l'istituzione di gruppi multidisciplinari finalizzati a fornire assistenza giudiziaria, sanitaria e sociale, riguardo ad ogni possibile aspetto legato all'emersione e al tempestivo riconoscimento della violenza e a ogni tipo di abuso commesso ai danni dei soggetti di cui al comma 790, garantendo contestualmente la rapida attivazione del citato Percorso di tutela delle vittime di violenza, nel caso in cui la vittima intenda procedere a denuncia, e la presa in carico, da parte dei servizi di assistenza, in collaborazione con i centri antiviolenza. La partecipazione ai gruppi multidisciplinari di cui al secondo periodo non comporta l'erogazione di indennita', gettoni, rimborsi di spese o altri emolumenti.

792. Per favorire la gestione finanziaria degli interventi finanziati dalle risorse europee, dal 1º gennaio 2016 le regioni e le province autonome di Trento e di Bolzano possono istituire un proprio organismo strumentale di cui all'articolo 1, comma 2, lettera b), del decreto legislativo 23 giugno 2011, n. 118, dotato di autonomia gestionale e contabile, denominato «organismo strumentale per gli interventi europei», avente ad oggetto esclusivo la gestione degli interventi europei.

793. La legge regionale e provinciale che provvede all'istituzione dell'organismo strumentale per gli interventi europei disciplina i rapporti tra la regione e le province autonome di Trento e di Bolzano e l'organismo strumentale nel rispetto delle disposizioni del decreto legislativo n. 118 del 2011 e dispone il trasferimento all'organismo di tutti i crediti regionali riguardanti le risorse europee e di cofinanziamento nazionale e di tutti i debiti regionali agli aventi diritto riguardanti gli interventi europei, risultanti da obbligazioni giuridicamente perfezionate. L'eventuale differenza positiva tra i debiti e i crediti trasferiti costituisce debito della regione o della provincia autonoma nei confronti dell'organismo regionale.

794. Il patrimonio degli organismi strumentali di cui al comma 792 e' costituito solo dall'eventuale fondo di cassa, da crediti e da debiti concernenti gli interventi europei. Per lo svolgimento della propria attivita' gli organismi strumentali si avvalgono dei beni e del personale delle regioni o delle province autonome che garantiscono l'equilibrio finanziario, economico e patrimoniale del proprio organismo strumentale per gli interventi europei.

795. La gestione degli organismi strumentali per gli interventi europei si avvale di conti di tesoreria unica appositamente istituiti, intestati agli organismi e funzionanti secondo le modalita' di cui all'articolo 7 del decreto legislativo 7 agosto 1997, n. 279, e successive modificazioni, e di corrispondenti conti correnti istituiti presso i tesorieri delle regioni e delle province autonome di Trento e di Bolzano.

796. Il Fondo di rotazione per l'attuazione delle politiche comunitarie di cui all'articolo 5 della legge 16 aprile 1987, n. 183, versa le risorse europee e quelle di cofinanziamento nazionale destinate alle regioni o alle province autonome di Trento e di Bolzano, nonche' le altre risorse a proprio carico, nei conti di tesoreria unica di cui al comma 795. Fino al perdurare della sospensione della tesoreria unica mista, disposta dall'articolo 35, comma 8, del decreto-legge 24 gennaio 2012, n. 1, convertito, con modificazioni, dalla legge 24 marzo 2012, n. 27, e prorogata dall'articolo 1, comma 395, della legge 23 dicembre 2014, n. 190, nei medesimi conti di tesoreria unica affluiscono le risorse relative al cofinanziamento regionale degli stessi interventi.

797. Gli organismi strumentali per gli interventi europei trasmettono quotidianamente alla banca dati SIOPE di cui all'articolo 14, comma 6, della legge 31 dicembre 2009, n. 196, tramite i propri tesorieri, i dati codificati concernenti tutti gli incassi e i pagamenti effettuati, secondo le modalita' previste per le regioni e le province autonome di Trento e di Bolzano. I tesorieri non possono accettare disposizioni di pagamento prive della codificazione uniforme.

798. In attuazione della legge regionale e provinciale di cui al comma 793, la regione e la provincia autonoma registrano nelle proprie scritture patrimoniali e finanziarie il trasferimento dei debiti e dei crediti trasferiti all'organismo strumentale per gli interventi europei. Il trasferimento dei crediti e dei debiti esigibili al 31 dicembre 2015 e' registrato nel bilancio di previsione 2016-2018, iscrivendo tra gli stanziamenti relativi all'esercizio 2016 le entrate e le spese per trasferimenti da e verso l'organismo strumentale, per lo stesso importo, pari al maggior valore tra i residui attivi e passivi trasferiti, ed effettuando le necessarie regolarizzazioni contabili con i residui attivi e passivi. L'eventuale differenza tra i residui passivi e attivi concorre alla determinazione del debito o del credito della regione o della provincia autonoma nei confronti dell'organismo strumentale, esigibile nell'esercizio 2016. Al fine di garantire il rispetto del principio della competenza finanziaria di cui all'allegato 1 al decreto legislativo 23 giugno 2011, n. 118, il trasferimento dei crediti e dei debiti regionali esigibili nell'esercizio 2016 e nei successivi e' registrato cancellando dalle scritture contabili riguardanti ciascun esercizio i relativi accertamenti e impegni e registrando l'impegno per trasferimenti all'organismo strumentale per gli interventi europei, di importo pari alla differenza tra gli impegni e gli accertamenti cancellati nell'esercizio. I crediti e i debiti cancellati dalla regione o dalla provincia autonoma sono registrati dall'organismo strumentale per gli interventi europei. L'organismo strumentale per gli interventi europei accerta le entrate derivanti dai trasferimenti dalla regione e dalla provincia autonoma a seguito dei correlati impegni della regione e della provincia autonoma.

799. I controlli delle sezioni regionali della Corte dei conti previsti dall'articolo 1 del decreto-legge 10 ottobre 2012, n. 174, convertito, con modificazioni, dalla legge 7 dicembre 2012, n. 213, si estendono anche agli organismi strumentali delle regioni di cui all'articolo 1, comma 2, lettera b), del decreto legislativo 23 giugno 2011, n. 118.

800. I fondi esistenti sulle contabilita' aperte ai sensi del comma 795, nonche' sulle contabilita' presso la tesoreria statale intestate al Ministero dell'economia e delle finanze, destinati in favore degli interventi cofinanziati dall'Unione europea, degli interventi complementari alla programmazione europea, ivi compresi quelli di cui al Piano di azione coesione, degli interventi finanziati con il Fondo per lo sviluppo e la coesione di cui all'articolo 1, comma 703, della legge n. 190 del 2014, nonche' i fondi depositati sulle contabilita' speciali di cui all'articolo 1, comma 671, della predetta legge 23 dicembre 2014, n. 190, a disposizione delle Amministrazioni centrali dello Stato e delle agenzie dalle stesse vigilate, non sono soggetti ad esecuzione forzata. Sui fondi depositati sui conti di tesoreria e sulle contabilita' speciali, come individuati dal comma 795, non sono ammessi atti di sequestro o di pignoramento presso le sezioni di tesoreria dello Stato, a pena di nullita' rilevabile anche d'ufficio. Gli atti di sequestro o di pignoramento eventualmente notificati non determinano obbligo di accantonamento da parte delle sezioni medesime.

801. All'articolo 1 della legge 23 dicembre 2014, n. 190, il comma 671 e' sostituito dal seguente: «671. Al fine di accelerare e semplificare l'iter dei pagamenti riguardanti gli interventi cofinanziati dall'Unione europea e gli interventi di azione e coesione complementari alla programmazione dell'Unione europea, a titolarita' delle Amministrazioni centrali dello Stato ovvero di agenzie dalle stesse vigilate, il Fondo di rotazione di cui all'articolo 5 della legge 16 aprile 1987, n. 183, provvede alle erogazioni a proprio carico, riguardanti i predetti interventi, anche mediante versamenti nelle apposite contabilita' speciali istituite presso ciascuna amministrazione o agenzia titolare degli interventi stessi».

802. All'articolo 1, comma 243, della legge 27 dicembre 2013, n. 147, dopo le parole: «a titolarita' delle Amministrazioni centrali dello Stato» sono inserite le seguenti: «nonche' delle regioni e delle province autonome di Trento e di Bolzano». Alle anticipazioni concesse dalle amministrazioni titolari di interventi cofinanziati dall'Unione europea in favore di soggetti privati, a valere sulle quote di cofinanziamento nazionale, si applica il disposto dell'articolo 131, paragrafo 4, lettera a), del regolamento (UE) n. 1303/2013 del Parlamento europeo e del Consiglio, del 17 dicembre 2013, senza nuovi o maggiori oneri a carico della finanza pubblica. L'articolo 56, comma 2, della legge 6 febbraio 1996, n. 52, e' abrogato.

803. Al recupero delle somme dovute da beneficiari situati sul territorio italiano riguardanti i programmi di cooperazione territoriale europea aventi Autorita' di gestione estera si provvede ai sensi dell'articolo 6, comma 3, della legge 16 aprile 1987, n. 183. Con decreto del Ministro dell'economia e delle finanze, previa intesa con la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, da adottare entro sessanta giorni dalla data di entrata in vigore della presente legge, sono stabilite le modalita' di recupero di cui al precedente periodo.

804. Al fine di assicurare il completamento dei progetti inseriti nella programmazione dei fondi strutturali europei 2007/2013, non conclusi alla data del 31 dicembre 2015, sentita l'Agenzia per la coesione territoriale, la Presidenza del Consiglio dei ministri - Dipartimento per le politiche di coesione, di concerto con il Ministero dell'economia e delle finanze, previa ricognizione delle esigenze di finanziamento presso le amministrazioni titolari dei progetti stessi, presenta al CIPE, entro sessanta giorni dalla data di entrata in vigore della presente legge, una proposta di utilizzo delle risorse previste dalla delibera CIPE n. 10/2015 del 28 gennaio 2015, per l'attuazione dei programmi di azione e coesione, complementari alla programmazione europea. L'assegnazione disposta in favore di amministrazioni che non dispongono di risorse per l'attuazione dei programmi di azione e coesione e' reintegrata alla dotazione dei medesimi programmi, da parte del CIPE, a valere sulle risorse del Fondo per lo sviluppo e la coesione per gli anni successivi al 2016.

805. All'articolo 4 del decreto legislativo 29 dicembre 2011, n. 229, sono apportate le seguenti modificazioni:

- a) il comma 1 e' sostituito dal seguente: «1. Con decreto del Presidente del Consiglio dei ministri, da pubblicare nella Gazzetta Ufficiale, di concerto con il Ministro dell'economia e delle finanze e con il Ministro delle infrastrutture e dei trasporti, adottato previo parere del CIPE, sono stabiliti i criteri per la definizione di un sistema di verifica dell'utilizzo dei finanziamenti per la realizzazione di interventi e programmi pubblici. Fermo restando quanto previsto dall'articolo 32 del decreto-legge 6 luglio 2011, n. 98, convertito, con modificazioni, dalla legge 15 luglio 2011, n. 111, con il medesimo decreto si provvede altresi' alla definizione delle procedure e delle modalita' di definanziamento degli interventi e dei programmi pubblici, considerando anche parametri temporali di riferimento distinti per livello progettuale, tipologia di aggiudicazione, classificazione di opere, costo complessivo, procedura di spesa sin dall'impegno contabile, volti a incentivare una maggiore tempestivita' delle procedure di spesa relative ai finanziamenti. Il definanziamento si applica esclusivamente alle quote di finanziamento a carico del bilancio dello Stato»;
- b) dopo il comma 1 sono inseriti i seguenti: «1-bis. Le quote annuali dei limiti di impegno, dei contributi e delle somme relative ai finanziamenti revocati ai sensi del comma 1 sono versate, previo versamento all'entrata del bilancio dello Stato qualora iscritte in conto residui, a uno specifico fondo per la riprogrammazione degli investimenti per la crescita, da istituire nello stato di previsione del Ministero dell'economia e delle finanze. Le disposizioni di cui al comma 1 non si applicano ai residui perenti. Nell'ambito del fondo di cui al primo periodo e' istituita una apposita sezione in cui sono iscritte le risorse finanziarie provenienti dal Fondo per lo sviluppo e la coesione, a cui continuano ad applicarsi le disposizioni di cui all'articolo 10, comma 10, del decreto-legge 6 luglio 2011, n. 98, convertito, con modificazioni, dalla legge 15 luglio 2011, n. 111. 1-ter. Le risorse del fondo per la riprogrammazione degli investimenti per la crescita, di cui al comma 1-bis, sono assegnate dal CIPE per spese in conto capitale, su proposta del Presidente del Consiglio dei ministri, di concerto con il Ministro dell'economia e delle finanze e con il Ministro delle infrastrutture e dei trasporti, senza vincoli programmatici, settoriali o territoriali ad eccezione delle risorse provenienti dal Fondo per lo sviluppo e la coesione territoriale, che rimangono vincolate alla chiave di riparto territoriale vigente al momento della nuova assegnazione delle risorse. L'assegnazione delle somme revocate puo' svilupparsi su un arco temporale pluriennale, in modo tale da assicurarne la neutralita' rispetto ai saldi di finanza pubblica. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio anche in conto residui»;
- c) al comma 2, le parole: «opere pubbliche nei tempi previsti» sono sostituite dalle seguenti: «interventi e programmi pubblici»;
- d) al comma 3, le parole: «singole opere» sono sostituite dalle seguenti: «singoli interventi e programmi pubblici».

806. Al fine di migliorare il funzionamento del CIPE:

- a) all'articolo 18, comma 1, alinea, del decreto-legge 29 novembre 2008, n. 185, convertito, con modificazioni, dalla legge 28 gennaio 2009, n. 2, le parole: «presieduto in maniera non delegabile dal Presidente del Consiglio dei ministri,» sono soppresse;
- b) all'articolo 4, comma 142, della legge 24 dicembre 2003, n. 350, le parole: «presieduto in maniera non delegabile dal Presidente del Consiglio dei ministri» sono soppresse;
- c) all'articolo 60, comma 1, della legge 27 dicembre 2002, n. 289, e all'articolo 1, comma 355, alinea, della legge 30 dicembre 2004, n. 311, le parole: «presieduto dal Presidente del Consiglio dei ministri in maniera non delegabile» sono soppresse;
- d) l'articolo 2 della legge 17 maggio 1999, n. 144, e' abrogato.

807. Qualora nell'ambito della programmazione del Fondo per lo sviluppo e la coesione 2007-2013 si renda necessaria l'approvazione di una variante urbanistica, ovvero l'espletamento di procedure VAS o VIA, il termine del 31 dicembre 2015 per l'assunzione di obbligazioni giuridicamente vincolanti e' prorogato al 31 dicembre 2016. (15)

808. Il regime di proroga di cui al comma 807 non comporta sanzioni qualora l'obbligazione giuridicamente vincolante sia assunta entro il termine del 30 giugno 2016. L'assunzione di obbligazioni giuridicamente vincolanti nel semestre 1º luglio-31 dicembre 2016 comporta, invece, la sanzione complessiva dell'1,5 per cento del finanziamento totale concesso. (15)

809. La mancata assunzione di obbligazioni giuridicamente vincolanti nel termine prorogato di cui al comma 807 determina la definitiva revoca del finanziamento.

810. La dotazione del fondo di cui all'articolo 41-bis, comma 1, della legge 24 dicembre 2012, n. 234, e' incrementata di 50 milioni di euro per l'anno 2016 e di 100 milioni di euro annui per il periodo 2017-2020.

811. L'autorizzazione di spesa di cui all'articolo 1, comma 13, della legge 27 dicembre 2013, n. 147, come modificata dall'articolo 1, comma 674, della legge 23 dicembre 2014, n. 190, a valere sulle dotazioni del Fondo di rotazione di cui alla legge 16 aprile 1987, n. 183, relativa agli interventi a favore dello sviluppo delle aree interne, e' incrementata di 10 milioni di euro per il triennio 2016-2018.

812. Per effetto di quanto disposto dal comma 811, l'autorizzazione di spesa a favore delle aree interne, a valere sulle dotazioni del Fondo di rotazione della citata legge n. 183 del 1987, e' pari, complessivamente, a 190 milioni di euro, ripartiti come segue: 16 milioni di euro per l'anno 2015, 60 milioni di euro per l'anno 2016, 94 milioni di euro per l'anno 2017 e 20 milioni di euro per l'anno 2018. (31)

813. All'articolo 43 della legge 24 dicembre 2012, n. 234, il comma 9-bis e' sostituito dal seguente: «9-bis. Ai fini della tempestiva esecuzione delle sentenze di condanna rese dalla Corte di giustizia dell'Unione europea ai sensi dell'articolo 260, paragrafi 2 e 3, del Trattato sul funzionamento dell'Unione europea, al pagamento degli oneri finanziari derivanti dalle predette sentenze si provvede a carico del fondo di cui all'articolo 41-bis, comma 1, della presente legge, nel limite massimo di 50 milioni di euro per l'anno 2016 e di 100 milioni di euro annui per il periodo 2017-2020. A fronte dei pagamenti effettuati, il Ministero dell'economia e delle finanze attiva il procedimento di rivalsa a carico delle amministrazioni responsabili delle violazioni che hanno determinato le sentenze di condanna, anche con compensazione con i trasferimenti da effettuare da parte dello Stato in favore delle amministrazioni stesse».

814. All'articolo 41 della legge 24 dicembre 2012, n. 234, dopo il comma 2 sono aggiunti i seguenti: «2-bis. Nel caso di violazione della normativa europea accertata con sentenza della Corte di giustizia dell'Unione europea di condanna al pagamento di sanzioni a carico della Repubblica italiana, ove per provvedere ai dovuti adempimenti si renda necessario procedere all'adozione di una molteplicita' di atti anche collegati tra loro, il Presidente del Consiglio dei ministri, su proposta del Ministro competente per materia, sentiti gli enti inadempienti, assegna a questi ultimi termini congrui per l'adozione di ciascuno dei provvedimenti e atti necessari. Decorso inutilmente anche uno solo di tali termini, il Consiglio dei ministri, sentito il soggetto interessato, su proposta del Presidente del Consiglio dei ministri e del Ministro competente per materia, adotta i provvedimenti necessari, anche normativi, ovvero nomina un apposito commissario. Alla riunione del Consiglio dei ministri e' invitato il Presidente della Giunta regionale della regione interessata al provvedimento. Le disposizioni di cui al presente comma si applicano anche agli inadempimenti conseguenti alle diffide effettuate in data anteriore alla data di entrata in vigore della presente disposizione che si fondino sui presupposti e abbiano le caratteristiche di cui al primo periodo. 2-ter. Il commissario di cui al comma 2-bis esercita le facolta' e i poteri di cui ai commi 4, 5 e 6 dell'articolo 10 del decreto-legge 24 giugno 2014, n. 91, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 116. 2-quater. Le disposizioni di cui ai commi precedenti si applicano anche nei casi in cui sono in corso procedure europee di infrazione».

815. Il Commissario delegato di cui all'ordinanza del Presidente del Consiglio dei ministri 4 ottobre 2007, n. 3614, provvede entro il 30 giugno 2016 ad avviare, sulla base di appositi bandi di gara, gli interventi finalizzati alle attivita' di bonifica e messa in sicurezza del sito di interesse nazionale «Bussi sul Tirino», secondo le priorita' e gli scopi di reindustrializzazione di cui all'articolo 2, comma 3-octies, del decreto-legge 29 dicembre 2010, n. 225, convertito, con modificazioni, dalla legge 26 febbraio 2011, n. 10, utilizzando a tale fine le risorse destinate al medesimo sito di interesse nazionale «Bussi sul Tirino» giacenti sulla contabilita' speciale di cui alla citata ordinanza n. 3614 del 2007. Decorso il predetto termine, il capo del Dipartimento della protezione civile, con propria ordinanza, adottata ai sensi dell'articolo 5, commi 4-ter e 4-quater, della legge 24 febbraio 1992, n. 225, disciplina le modalita' della cessazione delle funzioni del Commissario delegato, fissando altresi' un termine per la chiusura della contabilita' speciale intestata al medesimo Commissario. Eventuali risorse residue sono versate all'entrata del bilancio dello Stato per essere riassegnate ad apposito capitolo di spesa del Ministero dell'ambiente e della tutela del territorio e del mare al fine di essere utilizzate, sulla base di apposito accordo di programma, per interventi di bonifica del sito di interesse nazionale «Bussi sul Tirino», individuati anche ai sensi e con il procedimento di cui all'articolo 252-bis del decreto legislativo 3 aprile 2006, n. 152.

816. In deroga all'articolo 1, commi 424 e 425, della legge 23 dicembre 2014, n. 190, il Ministero dell'ambiente e della tutela del territorio e del mare e' autorizzato ad assumere nell'anno 2016 e nell'anno 2017, a tempo determinato, per un periodo massimo di tre mesi, un contingente di personale di complessive 30 unita', mediante l'utilizzo di graduatorie di concorsi pubblici a tempo indeterminato, con validita' in corso, banditi dall'Istituto superiore per la protezione e la ricerca ambientale (ISPRA). Terminato il periodo di tre mesi, il medesimo Ministero ha la facolta' di assumere il suddetto personale mediante contratti a tempo indeterminato, da inquadrare nell'Area III, posizione economica F, nel rispetto della propria dotazione organica.

817. Al fine di garantire il necessario supporto alle attivita' istituzionali, anche in deroga all'articolo 1, commi 424 e 425, della citata legge 23 dicembre 2014, n. 190, il Ministero dell'ambiente e della tutela del territorio e del mare e' autorizzato nell'anno 2016 e nell'anno 2017 ad assumere a tempo indeterminato un contingente di personale di complessive 11 unita' nel rispetto della propria dotazione organica, mediante l'utilizzo di graduatorie di concorsi pubblici nazionali a tempo indeterminato banditi ed espletati dall'ISPRA, in corso di validita'. Il suddetto personale, corrispondente a 6 unita' di collaboratore amministrativo e 5 unita' di collaboratore tecnico, e' inquadrato nell'Area II, posizione economica F1.

818. Il Ministero dell'ambiente e della tutela del territorio e del mare puo' procedere al reclutamento di cui ai commi 816 e 817 senza il previo espletamento delle procedure di cui all'articolo 34-bis del decreto legislativo 30 marzo 2001, n. 165.

819. Piena e diretta esecuzione e' data alla decisione 2014/335/UE, Euratom del Consiglio, del 26 maggio 2014, relativa al sistema delle risorse proprie dell'Unione europea, a decorrere dalla data della sua entrata in vigore, in conformita' a quanto disposto dall'articolo 11, terzo comma, della decisione stessa.

820. All'articolo 36, comma 1, della legge 24 dicembre 2012, n. 234, le parole: «decreto adottato ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400, dal Ministro competente per materia» sono sostituite dalle seguenti: «decreto del Ministro competente per materia».

821. COMMA ABROGATO DALLA L. 22 MAGGIO 2017, N. 81.

822. Al fine di contribuire alla costituzione delle piattaforme di investimento previste dal regolamento (UE) 2015/1017 del Parlamento europeo e del Consiglio, del 25 giugno 2015, le operazioni finanziarie delle piattaforme di investimento ammissibili al Fondo europeo per gli investimenti strategici (FEIS) promosse dall'istituto nazionale di promozione di cui al comma 826, possono essere assistite dalla garanzia dello Stato. La garanzia dello Stato e' onerosa, a prima richiesta, esplicita, incondizionata e irrevocabile. (47)

823. Le piattaforme di investimento ammissibili alla garanzia dello Stato sono approvate con decreto del Ministro dell'economia e delle finanze, d'intesa con i Ministri interessati.

824. Con decreto del Ministro dell'economia e delle finanze sono stabiliti criteri, modalita' e condizioni per la concessione della garanzia di cui ai commi da 822 a 829.

825. E' istituito nello stato di previsione del Ministero dell'economia e delle finanze un fondo a copertura delle garanzie dello Stato concesse ai sensi dei commi da 822 a 829, con una dotazione iniziale di 200 milioni di euro per l'anno 2016. E' autorizzata allo scopo l'istituzione di un apposito conto corrente di tesoreria. La dotazione del fondo puo' essere incrementata mediante versamento di contributi da parte delle amministrazioni statali e degli enti territoriali secondo modalita' stabilite con il decreto di cui al comma 824, ovvero attraverso la procedura prevista dal comma 876.

826. La Cassa depositi e prestiti S.p.A. ha la qualifica di istituto nazionale di promozione, come definito dall'articolo 2, numero 3), del citato regolamento (UE) 2015/1017, relativo al FEIS, secondo quanto previsto nella comunicazione (COM (2015) 361 final) della Commissione, del 22 luglio 2015.

827. In ragione della qualifica di cui al comma 826, la Cassa depositi e prestiti S. p.A. e' abilitata a svolgere le attivita' degli istituti nazionali di promozione previste dal regolamento (UE) 2015/1017, nonche' i compiti previsti dal regolamento (UE) n. 1303/ 2013 del Parlamento europeo e del Consiglio, del 17 dicembre 2013, recante disposizioni comuni sui fondi strutturali e di investimento europei (Fondi SIE), e dal regolamento (UE, EURATOM) n. 966/2012 del Parlamento europeo e del Consiglio, del 25 ottobre 2012, recante le regole finanziarie applicabili al bilancio generale dell'Unione.

828. La Cassa depositi e prestiti S.p.A. puo' impiegare le risorse della gestione separata di cui all'articolo 5, comma 8, del decreto-legge 30 settembre 2003, n. 269, convertito, con modificazioni, dalla legge 24 novembre 2003, n. 326, per contribuire a realizzare gli obiettivi del FEIS, tra l'altro, mediante il finanziamento di piattaforme d'investimento e di singoli progetti ai sensi del regolamento (UE) 2015/1017, nel rispetto della disciplina dell'Unione europea sugli aiuti di Stato.

829. La Cassa depositi e prestiti S.p.A. o le societa' da essa controllate possono esercitare i compiti di esecuzione degli strumenti finanziari destinatari dei Fondi SIE, di cui al regolamento (UE, EURATOM) n. 966/2012 e al regolamento (UE) n. 1303/2013, in forza di un mandato della Commissione europea ovvero su richiesta delle autorita' di gestione.

830. Le attivita' di cui al comma 829 possono essere condotte anche con apporto finanziario da parte di amministrazioni ed enti pubblici o privati, anche a valere su risorse europee. Le risorse delle amministrazioni statali possono essere individuate con decreto del Presidente del Consiglio dei ministri, sentito il Ministro dell'economia e delle finanze, nell'ambito delle risorse disponibili a legislazione vigente.

831. E' istituito presso Terna Spa un fondo di garanzia nel quale confluiscono le somme, determinate in misura pari a 1 euro/MWh per anno, che i soggetti aggiudicatari ovvero cessionari della potenza assegnata che abbiano assunto l'impegno con Terna Spa di finanziamento delle opere di cui all'articolo 32 della legge 23 luglio 2009, n. 99, e successive modificazioni, sono tenuti a versare fino all'entrata in servizio di ciascun interconnector, in aggiunta ai corrispettivi, determinati dall'Autorita' per l'energia elettrica, il gas e il sistema idrico ai sensi dell'articolo 32, comma 6, della legge 23 luglio 2009, n. 99, che gli stessi riconoscono a Terna Spa per l'esecuzione dei contratti di approvvigionamento. Detto fondo interviene esclusivamente a garanzia degli impegni assunti per il finanziamento di ciascun interconnector. Le somme versate nel fondo di garanzia non possono essere distratte dalla destinazione prevista, ne' essere soggette ad azioni ordinarie, cautelari o conservative da parte dei creditori dei soggetti di cui al presente comma ovvero di Terna Spa. Rispetto a dette somme non opera la compensazione legale e giudiziale e non puo' essere pattuita la compensazione volontaria. In caso di mancato utilizzo, in tutto o in parte, del fondo, al termine del periodo di esenzione, lo stesso e' redistribuito, per la parte residua, ai soggetti di cui al presente comma, in proporzione alle quote di rispettiva competenza. I criteri e le modalita' di gestione del fondo sono disciplinati con decreto del Ministro dello sviluppo economico.

832. Al fine di completare la realizzazione delle nuove infrastrutture di interconnessione con l'estero nella forma di interconnector di cui all'articolo 32 della legge 23 luglio 2009, n. 99, e successive modificazioni, il periodo fissato al comma 6 dello stesso articolo e' esteso al 31 dicembre 2026, secondo le modalita' di cui ai commi da 833 a 836, a favore dei soggetti aggiudicatari ovvero cessionari, di cui al comma 831, a prescindere dalla originaria frontiera di assegnazione, per la capacita' di interconnessione di cui all'articolo 32, comma 1, della legge 23 luglio 2009, n. 99, come incrementata ai sensi dell'articolo 2 del decretolegge 25 gennaio 2010, n. 3, convertito, con modificazioni, dalla legge 22 marzo 2010, n. 41, e limitatamente alla quota di capacita' non ancora in esercizio.

833. I soggetti di cui al comma 831 sono tenuti a sottoscrivere il contratto di mandato per la costruzione e l'esercizio dell'interconnector di cui al medesimo comma entro novanta giorni dal rilascio dell'esenzione, ai sensi del decreto del Ministro delle attivita' produttive 21 ottobre 2005, pubblicato nella Gazzetta Ufficiale n. 256 del 3 novembre 2005, a pena di decadenza dal diritto di cui al comma 832, con obbligo di restituire quanto goduto e ferme restando le eventuali obbligazioni assunte nei confronti di Terna Spa.

834. Al comma 3 dell'articolo 32 della legge 21 luglio 2009, n. 99, le parole: «durata pari a venti anni» sono sostituite dalle seguenti: «durata fino a venti anni». Al comma 6 dello stesso articolo 32, la parola: «ventennale» e' soppressa.

835. Al comma 4 dell'articolo 32 della legge 23 luglio 2009, n. 99, le parole: «trentasei mesi» sono sostituite dalle seguenti: «quarantotto mesi».

836. Per tutto quanto non espressamente previsto dai commi da 831 a 835, trova applicazione l'articolo 32 della legge n. 99 del 2009, e successive modificazioni.

837. PERIODO SOPPRESSO DAL D.L. 4 DICEMBRE 2015, N. 191, CONVERTITO CON MODIFICAZIONI DALLA L. 1 FEBBRAIO 2016, N. 13. PERIODO SOPPRESSO DAL D.L. 4 DICEMBRE 2015, N. 191, CONVERTITO CON MODIFICAZIONI DALLA L. 1 FEBBRAIO 2016, N. 13. PERIODO SOPPRESSO DAL D.L. 4 DICEMBRE 2015, N. 191, CONVERTITO CON MODIFICAZIONI DALLA L. 1 FEBBRAIO 2016, N. 13. La dotazione del Fondo di cui all'articolo 3, comma 1-ter, del citato decreto-legge n. 1 del 2015 e' incrementata di 400 milioni di euro per l'anno 2015 mediante utilizzo delle disponibilita' in conto residui del fondo di cui all'articolo 37, comma 6, del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89. La disposizione di cui al presente comma entra in vigore il giorno stesso della pubblicazione nella Gazzetta Ufficiale della presente legge. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare le occorrenti variazioni di bilancio anche in conto residui.

838. Le risorse assegnate al Ministero dello sviluppo economico e al Ministero dell'ambiente e della tutela del territorio e del mare con il decreto interministeriale n. 231 del 26 settembre 2014, ai sensi dell'articolo 19, commi 2 e 3, del decreto legislativo 13 marzo 2013, n. 30, sono destinate, nei limiti delle somme non impegnate alla data di entrata in vigore del presente comma, ai fini di cui al comma 5 dell'articolo 2 del decreto-legge 20 maggio 2010, n. 72, convertito, con modificazioni, dalla legge 19 luglio 2010, n. 111. Con i decreti di cui al comma 3 dell'articolo 19 del decreto legislativo 13 marzo 2013, n. 30, si provvede negli esercizi successivi ad operare gli opportuni conguagli al fine di assicurare complessivamente il rispetto delle proporzioni indicate nel predetto articolo 19 del citato decreto legislativo n. 30 del 2013 e del vincolo di destinazione a investimenti con finalita' ambientali derivante dalla direttiva 2009/29/CE del Parlamento europeo e del Consiglio, del 23 aprile 2009. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio. Il presente comma entra in vigore il giorno stesso della pubblicazione della presente legge nella Gazzetta Ufficiale.

839. La dotazione del fondo, di cui all'articolo 1, comma 113, della legge 27 dicembre 2013, n. 147, istituito nello stato di previsione del Ministero dell'ambiente e della tutela del territorio e del mare per il finanziamento di un piano straordinario di bonifica delle discariche abusive individuate dalle competenti autorita' statali in relazione alla procedura di infrazione comunitaria n. 2003/2007, e' aumentata di 10 milioni di euro per ciascuno degli anni 2016, 2017 e 2018. Il Ministero provvede ad individuare e rendere pubblico nel sito internet istituzionale un cronoprogramma degli interventi attuativi previsti nel piano e provvede a indicare progressivamente quelli effettivamente realizzati.

840. All'articolo-2-bis, comma 2-bis, del decreto-legge 5 gennaio 2015, n. 1, convertito, con modificazioni, dalla legge 4 marzo 2015, n. 20, sono apportate le seguenti modificazioni:

- a) al primo periodo sono premessi i seguenti: «Con decreto del Ministro dello sviluppo economico, di concerto con il Ministro dell'economia e delle finanze, possono essere definiti, ai fini dell'accesso alla garanzia del Fondo, appositi criteri di valutazione economico-finanziaria delle piccole e medie imprese di cui al comma 1, che tengano conto delle caratteristiche e dei particolari fabbisogni delle predette imprese. Gli specifici criteri di valutazione, che escludono il rilascio della garanzia per le imprese che non presentino adeguate capacita' di rimborso del finanziamento bancario da garantire nonche' per le imprese in difficolta' ai sensi di quanto previsto dalla vigente disciplina dell'Unione europea, sono applicati per un periodo non superiore a dodici mesi dalla data di pubblicazione del citato decreto, fermo restando il limite di euro 35.000.000 di cui al comma 1»;
- b) l'ultimo periodo e' soppresso.

841. All'articolo 27 del decreto legislativo 8 luglio 1999, n. 270, dopo il comma 2 e' aggiunto, in fine, il seguente: «2-bis. Per le imprese di cui all'articolo 2, comma 2, del decreto-legge 23 dicembre 2003, n. 347, convertito, con modificazioni, dalla legge 18 febbraio 2004, n. 39, la durata dei programmi di cui al comma 2 del presente articolo puo' essere autorizzata dal Ministro dello sviluppo economico fino ad un massimo di quattro anni».

842. Sono costituite, con effetto dalle ore 00,00 del 23 novembre 2015, quattro societa' per azioni, denominate Nuova Cassa di risparmio di Ferrara Spa, Nuova Banca delle Marche Spa, Nuova Banca dell'Etruria e del Lazio Spa, Nuova Cassa di risparmio di Chieti Spa, di seguito denominate «le societa'», tutte con sede in Roma, via Nazionale, 91, aventi per oggetto lo svolgimento dell'attivita' di ente-ponte ai sensi dell'articolo 42 del decreto legislativo 16 novembre 2015, n. 180, con riguardo rispettivamente alla Cassa di risparmio di Ferrara Spa, alla Banca delle Marche Spa, alla Banca popolare dell'Etruria e del Lazio - Societa' cooperativa e alla Cassa di risparmio della provincia di Chieti Spa, in risoluzione, con l'obiettivo di mantenere la continuita' delle funzioni essenziali precedentemente svolte dalle medesime banche e, quando le condizioni di mercato sono adeguate, cedere a terzi le partecipazioni al capitale o i diritti, le attivita' o le passivita' acquistate, in conformita' con le disposizioni del medesimo decreto legislativo.

843. Alle societa' di cui al comma 842 possono essere trasferiti azioni, partecipazioni, diritti, nonche' attivita' e passivita' delle banche sottoposte a risoluzione di cui al comma 842, ai sensi dell'articolo 43 del decreto legislativo 16 novembre 2015, n. 180.

844. Il capitale sociale della Nuova Cassa di risparmio di Ferrara Spa e' stabilito in euro 191.000.000 ed e' ripartito in dieci milioni di azioni; il capitale sociale della Nuova Banca delle Marche Spa e' stabilito in euro 1.041.000.000 ed e' ripartito in dieci milioni di azioni; il capitale sociale della Nuova Banca dell'Etruria e del Lazio Spa e' stabilito in euro 442.000.000 ed e' ripartito in dieci milioni di azioni; il capitale sociale della Nuova Cassa di risparmio di Chieti Spa e' stabilito in euro 141.000.000 ed e' ripartito in dieci milioni di azioni. Le azioni sono interamente sottoscritte dal Fondo di risoluzione nazionale; nel rispetto dell'articolo 42, comma 2, del decreto legislativo 16 novembre 2015, n. 180, il capitale di nuova emissione della societa' potra' essere sottoscritto anche da soggetti diversi dal Fondo di risoluzione nazionale.

845. La Banca d'Italia con proprio provvedimento adotta lo statuto delle societa', nomina i primi componenti degli organi di amministrazione e controllo e ne determina i compensi. Resta fermo, per la fase successiva alla costituzione, quanto stabilito dall'articolo 42, comma 3, del decreto legislativo 16 novembre 2015, n. 180. Se gia' adottati alla data di entrata in vigore del decreto-legge 22 novembre 2015, n. 183, tali atti si intendono convalidati.

846. La pubblicazione nella Gazzetta Ufficiale del decreto-legge 22 novembre 2015, n. 183, tiene luogo di tutti gli adempimenti di legge richiesti per la costituzione delle societa'. Dalla medesima data per le obbligazioni sociali rispondono soltanto le societa' con il proprio patrimonio.

847. Fermo restando quanto disposto dal comma 846, gli adempimenti societari sono perfezionati dagli amministratori delle societa' nel piu' breve tempo possibile dall'atto del loro insediamento.

848. Dopo l'avvio del Meccanismo di risoluzione unico ai sensi dell'articolo 99 del regolamento (UE) n. 806/2014 del Parlamento europeo e del Consiglio, del 15 luglio 2014, fermi restando gli obblighi di contribuzione al Fondo di risoluzione unico previsti dagli articoli 70 e 71 del medesimo regolamento (UE) n. 806/2014, le banche aventi sede legale in Italia e le succursali italiane di banche extracomunitarie, qualora i contributi ordinari e straordinari gia' versati al Fondo di risoluzione nazionale, al netto dei recuperi derivanti da operazioni di dismissione poste in essere dal Fondo, non siano sufficienti alla copertura delle obbligazioni, perdite, costi e altre spese a carico del Fondo di risoluzione nazionale in relazione alle misure previste dai Provvedimenti di avvio della risoluzione, versano contribuzioni addizionali al Fondo di risoluzione nazionale nella misura determinata dalla Banca d'Italia, comunque entro il limite complessivo, inclusivo delle contribuzioni versate al Fondo di risoluzione unico, previsto dagli articoli 70 e 71 del regolamento (UE) n. 806/2014. Solo per l'anno 2016, tale limite complessivo e' incrementato di due volte l'importo annuale dei contributi determinati in conformita' all'articolo 70 del regolamento (UE) n. 806/2014 e al relativo regolamento di esecuzione (UE) n. 2015/81 del Consiglio, del 19 dicembre 2014.

849. In caso di inadempimento dell'obbligo di versare al Fondo di risoluzione nazionale le risorse ai sensi del comma 848, si applicano le sanzioni previste dall'articolo 96 del decreto legislativo 16 novembre 2015, n. 180, per la violazione degli articoli 82 e 83 del medesimo decreto legislativo.

850. Nel caso in cui siano adottate azioni di risoluzione, come definite dall'articolo 1, comma 1, lettera f), del decreto legislativo 16 novembre 2015, n. 180, la trasformazione in credito d'imposta delle attivita' per imposte anticipate relative ai componenti negativi di cui al comma 55 dell'articolo 2 del decreto-legge 29 dicembre 2010, n. 225, convertito, con modificazioni, dalla legge 26 febbraio 2011, n. 10, iscritte nella situazione contabile di riferimento dell'ente sottoposto a risoluzione decorre dalla data di avvio della risoluzione e opera sulla base dei dati della medesima situazione contabile. Con decorrenza dal periodo d'imposta in corso alla data di avvio della risoluzione non sono deducibili i componenti negativi corrispondenti alle attivita' per imposte anticipate trasformate in credito d'imposta ai sensi del presente comma.

851. Il comma 850 si applica a decorrere dalla data di entrata in vigore del decreto legislativo 16 novembre 2015, n. 180.

852. Al comma 2 dell'articolo 16 del decreto-legge 27 giugno 2015, n. 83, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 132, le parole: «in corso al 31 dicembre 2015» sono sostituite dalle seguenti: «successivo a quello in corso al 31 dicembre 2014».

853. Ai fini delle imposte sui redditi, i versamenti effettuati dal Fondo di risoluzione nazionale all'ente-ponte non si considerano sopravvenienze attive.

854. Il decreto-legge 22 novembre 2015, n. 183, e' abrogato. Restano validi gli atti e i provvedimenti adottati e sono fatti salvi gli effetti prodottisi e i rapporti giuridici sorti sulla base del medesimo decreto-legge n. 183 del 2015.

855. E' istituito il Fondo di solidarieta' per l'erogazione di prestazioni in favore degli investitori che alla data di entrata in vigore del decreto-legge 22 novembre 2015, n. 183, detenevano strumenti finanziari subordinati emessi dalla Banca delle Marche Spa, dalla Banca popolare dell'Etruria e del Lazio - Societa' cooperativa, dalla Cassa di risparmio di Ferrara Spa e dalla Cassa di risparmio della provincia di Chieti Spa. L'accesso alle prestazioni e' riservato agli investitori che siano persone fisiche, imprenditori individuali, nonche' imprenditori agricoli o coltivatori diretti.

856. Il Fondo di solidarieta' e' alimentato, sulla base delle esigenze finanziarie connesse alla corresponsione delle prestazioni dal Fondo interbancario di tutela dei depositi istituito ai sensi dell'articolo 96 del testo unico delle leggi in materia bancaria e creditizia, di cui al decreto legislativo 1° settembre 1993, n. 385.

857. Con uno o piu' decreti del Ministro dell'economia e delle finanze, di concerto con il Ministro della giustizia, da emanare entro centottanta giorni dalla data di entrata in vigore della presente legge, sono definiti:

- a) le modalita' di gestione del Fondo di solidarieta';
- b) le modalita' e le condizioni di accesso al Fondo di solidarieta', ivi inclusi le modalita' e i termini per la presentazione delle istanze di erogazione delle prestazioni;
- c) i criteri di quantificazione delle prestazioni, determinate in importi corrispondenti alla perdita subita, fino a un ammontare massimo;
- d) le procedure da esperire, che possono essere in tutto o in parte anche di natura arbitrale;
- e) le ulteriori disposizioni per l'attuazione dei commi da 855 a

858. In caso di ricorso a procedura arbitrale, la corresponsione delle prestazioni e' subordinata all'accertamento della responsabilita' per violazione degli obblighi di informazione, diligenza, correttezza e trasparenza previsti dal testo unico delle disposizioni in materia di intermediazione finanziaria, di cui al decreto legislativo 24 febbraio 1998, n. 58, nella prestazione dei servizi e delle attivita' di investimento relativi alla sottoscrizione o al collocamento degli strumenti finanziari subordinati di cui al comma 855.

859. Nei casi di cui al comma 858, con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro dell'economia e delle finanze, previa deliberazione del Consiglio dei ministri, sentite le competenti Commissioni parlamentari, sono nominati gli arbitri, scelti tra persone di comprovata imparzialita', indipendenza, professionalita' e onorabilita', ovvero possono essere disciplinati i criteri e le modalita' di nomina dei medesimi e sono disciplinate le modalita' di funzionamento del collegio arbitrale, nonche' quelle per il supporto organizzativo alle procedure arbitrali, che puo' essere prestato anche avvalendosi di organismi o camere arbitrali gia' esistenti, e per la copertura dei costi delle medesime procedure a carico del Fondo di solidarieta'.

860. Resta salvo il diritto al risarcimento del danno. Il Fondo di solidarieta' e' surrogato nel diritto dell'investitore al risarcimento del danno, nel limite dell'ammontare della prestazione corrisposta.

861. La gestione del Fondo di solidarieta' e' attribuita al Fondo interbancario di tutela dei depositi istituito ai sensi dell'articolo 96 del testo unico di cui al decreto legislativo 1º settembre 1993, n. 385. Ai relativi oneri e spese di gestione si provvede esclusivamente con le risorse finanziarie del Fondo di solidarieta'.

862. Al fine di favorire il miglioramento delle condizioni di salute e sicurezza nei luoghi di lavoro, con effetto dal 1º gennaio 2016, presso l'Istituto nazionale per l'assicurazione contro gli infortuni sul lavoro (INAIL) e' istituito un fondo con la dotazione di 45 milioni di euro per l'anno 2016 e di 35 milioni di euro annui a decorrere dall'anno 2017. Il fondo e' destinato a finanziare gli investimenti per l'acquisto o il noleggio con patto di acquisto di trattori agricoli o forestali o di macchine agricole e forestali, caratterizzati da soluzioni innovative per l'abbattimento delle emissioni inquinanti, la riduzione del rischio rumore, il miglioramento del rendimento e della sostenibilita' globali delle aziende agricole, nel rispetto del regolamento (UE) n. 702/2014 della Commissione, del 25 giugno 2014, e vi possono accedere le micro e le piccole imprese operanti nel settore della produzione agricola primaria dei prodotti agricoli.

863. Nel primo semestre di ciascun anno l'INAIL pubblica nel proprio sito internet istituzionale l'avviso pubblico con l'indicazione delle modalita', dei termini e delle condizioni di ammissibilita' di presentazione delle domande e rende noti i parametri associati sia all'oggetto della domanda sia alle caratteristiche proprie dell'impresa, nel rispetto della normativa europea sugli aiuti di Stato. Nello stesso avviso sono definiti i criteri di premialita' per le imprese che risultano iscritte alla Rete del lavoro agricolo di qualita' di cui all'articolo 6 del decreto-legge 24 giugno 2014, n. 91, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 116, nonche' gli obblighi dei beneficiari e le cause di decadenza e di revoca del contributo.

864. Agli oneri derivanti dall'attuazione delle disposizioni di cui al comma 862 si provvede:

- a) quanto a 20 milioni di euro annui a decorrere dal 2016, a valere sulle risorse gia' previste dall'articolo 1, comma 60, della legge 24 dicembre 2007, n. 247;
- b) quanto a 25 milioni di euro per il 2016 e a 15 milioni di euro annui a decorrere dal 2017, mediante quota parte delle risorse programmate dall'INAIL per il finanziamento dei progetti di cui all'articolo 11, comma 5, del decreto legislativo 9 aprile 2008, n. 81, e successive modificazioni, fermo restando l'equilibrio del bilancio dell'ente.

865. All'articolo 1 della legge 24 dicembre 2007, n. 247, il comma 60 e' abrogato.

866. Per il concorso dello Stato al raggiungimento degli standard europei del parco mezzi destinato al trasporto pubblico locale e regionale, e in particolare per l'accessibilita' per persone a mobilita' ridotta, presso il Ministero delle infrastrutture e dei trasporti e' istituito un Fondo finalizzato all'acquisto diretto, anche per il tramite di societa' specializzate, nonche' alla riqualificazione elettrica e, nei limiti del 15 per cento della dotazione del Fondo, alla riconversione a gas naturale dei mezzi a gasolio euro 4 ed euro 5 e al miglioramento dell'efficienza energetica o al noleggio dei mezzi adibiti al trasporto pubblico locale e regionale. Al Fondo confluiscono, previa intesa con le regioni, le risorse disponibili di cui all'articolo 1, comma 83, della legge 27 dicembre 2013, n. 147, e successivi rifinanziamenti. Al Fondo sono altresi' assegnati, per le medesime finalita', 210 milioni di euro per ciascuno degli anni 2019 e 2020, 130 milioni di euro per l'anno 2021 e 90 milioni di euro per l'anno 2022. Con decreto del Ministro delle infrastrutture e dei trasporti sono individuate modalita', anche innovative e sperimentali, anche per garantire l'accessibilita' alle persone a mobilita' ridotta, per l'attuazione delle disposizioni di cui al presente comma. Il Ministro dell'economia e delle finanze e' autorizzato ad effettuare le occorrenti variazioni di bilancio. (2) (14)

867. In considerazione della grave situazione finanziaria concernente la societa' Ferrovie del Sud Est e servizi automobilistici, con decreto del Ministro delle infrastrutture e dei trasporti, da adottare entro trenta giorni dalla data di entrata in vigore della presente legge, e' disposto il commissariamento della suddetta societa' e sono nominati il commissario ed eventuali sub-commissari. Il commissario provvede, entro novanta giorni dal suo insediamento, a predisporre un piano industriale per il risanamento che preveda, tra l'altro, la riduzione dei costi di funzionamento. Il commissario e' incaricato altresi' di predisporre e presentare al socio unico, nel predetto termine di novanta giorni, una dettagliata e documentata relazione, pubblicata nel sito web del Ministero delle infrastrutture e dei trasporti, nel sito web della medesima societa' nonche' in quello dell'Agenzia per il trasporto e la mobilita' della regione Puglia, in merito allo stato finanziario e patrimoniale della societa', nonche' alle cause che hanno determinato la grave situazione finanziaria della medesima societa', anche al fine di consentire al socio unico di valutare le condizioni per l'esercizio dell'azione di responsabilita' ai sensi dell'articolo 2393 del codice civile. Il commissario, a seguito della ricognizione contabile, provvede, se necessario, dandone preventiva comunicazione al socio e al Ministero dell'economia e delle finanze, ad attivare le procedure di ristrutturazione dei debiti di cui al regio decreto 16 marzo 1942, n. 267. Su proposta del commissario, la societa' puo', altresi', essere trasferita o alienata secondo criteri e modalita' individuati con decreto del Ministro delle infrastrutture e dei trasporti. Fermi restando gli obblighi di cui al presente comma, e' autorizzata la spesa di 70 milioni di euro per l'anno 2016. Le relative risorse sono trasferite al patrimonio della societa' Ferrovie del Sud Est e servizi automobilistici S.r.l. per essere utilizzate, nel rispetto della normativa dell'Unione europea in materia e nell'ambito del piano di risanamento della societa', esclusivamente a copertura delle passivita', anche pregresse, e delle esigenze finanziarie del comparto infrastruttura. Restano fermi gli atti, i provvedimenti e le operazioni gia' realizzati ai sensi del decreto del Ministro delle infrastrutture e dei trasporti del 4 agosto 2016, pubblicato sulla Gazzetta Ufficiale 17 settembre 2016, n.218, ivi compreso il trasferimento della societa' Ferrovie del Sud Est e servizi automobilistici S.r.l. alla societa' Ferrovie dello Stato Italiane S.p.a., realizzato nell'ambito della riorganizzazione delle partecipazioni dello Stato nel settore e in ragione della sussistenza, in capo alla medesima societa', di qualita' industriali e patrimoniali tali da fornire garanzia alla continuita' del lavoro e del servizio, nonche' l'impegno della societa' Ferrovie dello Stato Italiane S.p.a., assunto ai sensi del medesimo decreto, di provvedere nei termini di legge alla rimozione dello squilibrio patrimoniale della societa'. (2)

868. Al fine di migliorare la capacita' di programmazione e di spesa per investimenti dell'ANAS Spa e per garantire un flusso di risorse in linea con le esigenze finanziarie, a decorrere dal 1º gennaio 2016 le risorse iscritte nel bilancio dello Stato, a qualunque titolo destinate all'ANAS Spa, confluiscono in un apposito fondo da iscrivere nello stato di previsione del Ministero delle infrastrutture e dei trasporti. Per l'attuazione di quanto previsto al primo periodo, il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, su proposta del Ministro competente, le opportune variazioni di bilancio in termini di residui, competenza e cassa.

869. Le risorse del fondo di cui al comma 868 confluiscono sul conto di tesoreria intestato all'ANAS Spa, in quanto societa' a totale partecipazione pubblica, entro il decimo giorno di ciascun trimestre sulla base delle previsioni di spesa. Le risorse del conto di tesoreria sono utilizzate per il pagamento diretto delle obbligazioni relative ai quadri economici delle opere previste e finanziate nel contratto di programma - parte investimenti di cui al comma 870, sulla base dell'effettivo avanzamento del cronoprogramma delle stesse. Gli utilizzi delle risorse sono rendicontati trimestralmente dall'ANAS Spa al Ministero delle infrastrutture e dei trasporti, anche con specifica indicazione degli stati di avanzamento delle opere realizzate, riscontrabili dal monitoraggio sullo stato di attuazione delle opere pubbliche ai sensi del decreto legislativo 29 dicembre 2011, n. 229, e dalla relazione di cui al comma 871 del presente articolo. Il bilancio annuale dell'ANAS Spa da' evidenza della gestione del conto di tesoreria. Con decreto del Ministro dell'economia e delle finanze, di concerto con il Ministro delle infrastrutture e dei trasporti, sono definite le modalita' di attuazione del presente comma, anche al fine di prevedere adeguati meccanismi di supervisione e controllo, anche di carattere preventivo, da parte dell'amministrazione.

870. Il contratto di programma tra l'ANAS Spa e il Ministero delle infrastrutture e dei trasporti ha durata quinquennale e riguarda le attivita' di costruzione, manutenzione e gestione della rete stradale e autostradale non a pedaggio nella diretta gestione dell'ANAS Spa nonche' di servizi di interconnessione, decongestione, salvaguardia e sicurezza del traffico che l'ANAS Spa garantisce in tutto il territorio nazionale. Il contratto di programma individua le opere da realizzare e i servizi da rendere sulla base di un piano pluriennale di opere e di un programma di servizi sulla rete stradale. Il contratto di programma stabilisce, altresi', gli standard qualitativi e le priorita', il cronoprogramma di realizzazione delle opere, le sanzioni e le modalita' di verifica da parte del Ministero delle infrastrutture e dei trasporti. Lo schema di contratto di programma e' approvato dal CIPE, su proposta del Ministro delle infrastrutture e dei trasporti, di concerto con il Ministro dell'economia e delle finanze per quanto attiene agli aspetti finanziari. (48)

871. Entro il 30 settembre di ciascun anno l'ANAS Spa trasmette al Ministero delle infrastrutture e dei trasporti una relazione sullo stato di attuazione del contratto di programma di cui al comma 870, ivi compreso lo stato di avanzamento delle opere, sulla relativa situazione finanziaria complessiva, nonche' sulla qualita' dei servizi resi. Il Ministero delle infrastrutture e dei trasporti, validata la suddetta relazione, la trasmette tempestivamente al CIPE, al Ministero dell'economia e delle finanze e alle competenti Commissioni parlamentari.

872. Entro il 31 gennaio di ciascun anno del periodo contrattuale, il CIPE, su proposta del Ministero delle infrastrutture e dei trasporti, approva eventuali aggiornamenti del contratto di programma di cui al comma 870 e, in particolare, del piano pluriennale di opere, in coerenza con l'articolo 2, comma 4, del decreto legislativo 29 dicembre 2011, n. 228, sulla base delle risorse disponibili a legislazione vigente, dell'andamento delle opere e dell'evoluzione della programmazione di settore, nonche' del piano dei servizi in relazione all'andamento della qualita' degli stessi.

873. Qualora dovessero sorgere impedimenti nelle diverse fasi del processo realizzativo delle opere o eventi ed emergenze che incidano sulla programmazione prevista dal contratto di programma, sulla base di motivate esigenze, l'ANAS Spa puo' utilizzare le risorse del fondo di cui al comma 868 in relazione agli effettivi fabbisogni, per realizzare le opere incluse nel piano pluriennale di opere ovvero le ulteriori opere aventi carattere di emergenza. A tal fine l'ANAS Spa da' preventiva comunicazione al Ministero delle infrastrutture e dei trasporti, che rilascia la relativa autorizzazione nei successivi trenta giorni, decorrenti dalla ricezione della comunicazione. Decorso infruttuosamente tale termine, l'ANAS Spa puo' comunque procedere, dandone tempestiva comunicazione al predetto Ministero. Le variazioni confluiscono nell'aggiornamento annuale del piano pluriennale di opere.

874. Nelle more della stipula del contratto di programma 2016-2020 in attuazione dei commi da 868 a 873, le disposizioni dei commi 868 e 869 si applicano alle opere gia' approvate o finanziate nonche' a quelle contenute nel contratto di programma per l'anno 2015 sottoposto al CIPE nella riunione del 6 agosto 2015.

875. Nei territori per i quali e' stato dichiarato lo stato di emergenza ed e' stata completata la procedura di ricognizione ai sensi dell'articolo 5, comma 2, lettera d), della legge 24 febbraio 1992, n. 225, l'ANAS Spa e' autorizzata, mediante apposita delibera del Consiglio dei ministri adottata su proposta del Ministero dell'economia e delle finanze e del Ministero delle infrastrutture e dei trasporti, sentita la Protezione civile, ad effettuare interventi di manutenzione straordinaria sulle strade provinciali e comunali, come classificate dall'articolo 2, commi 5 e 6, del codice della strada, di cui al decreto legislativo 30 aprile 1992, n. 285.

876. Al fine di assicurare il piu' efficiente e tempestivo utilizzo delle risorse pubbliche, il Ministro dell'economia e delle finanze, sentito il Ministro o i Ministri competenti in materia, e' autorizzato, con propri decreti, a disporre variazioni compensative tra capitoli del bilancio dello Stato, anche in conto residui, o ad autorizzare il trasferimento di risorse mediante giro fondo tra conti aperti presso la tesoreria dello Stato, relativi a fondi di garanzia. I predetti decreti sono emanati previa verifica dell'assenza di nuovi o maggiori oneri per la finanza pubblica nonche' delle esigenze attuali e prospettiche dei fondi di origine e di destinazione.

877. L'articolo 11-bis del decreto-legge 6 giugno 2012, n. 74, convertito, con modificazioni, dalla legge 1º agosto 2012, n. 122, e' abrogato.

878. Il fondo di cui all'articolo 37, comma 6, del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, e' rifinanziato per l'importo di 350 milioni di euro per l'anno 2016, di 1,5 miliardi di euro per l'anno 2017, di 1,7 miliardi di euro per l'anno 2018 e di 2 miliardi di euro per l'anno 2019.

879. La dotazione del Fondo di cui all'articolo 6, comma 9-bis, del decreto-legge 30 settembre 2003, n. 269, convertito, con modificazioni, dalla legge 24 novembre 2003, n. 326, e' incrementata di 150 milioni di euro per l'anno 2016.

880. Il Ministero dell'economia e delle finanze e' autorizzato a stipulare con il Comitato di risoluzione unico di cui al regolamento (UE) n. 806/2014 del Parlamento europeo e del Consiglio, del 15 luglio 2014, gli accordi necessari a dare attuazione alla dichiarazione dell'Ecofin del 18 dicembre 2013 che prevede, tra l'altro, che durante il periodo transitorio, come definito dall'articolo 3, paragrafo 1, numero 37), del regolamento (UE) n. 806/2014, gli Stati membri partecipanti all'Unione bancaria assicurino finanziamenti ponte al Fondo di risoluzione unico previsto dal predetto regolamento, nel caso di insufficienza delle risorse dello stesso.

881. Al fine di assicurare la disponibilita' delle risorse eventualmente richieste, in conformita' agli accordi di cui al comma 880, dal Comitato di risoluzione unico, con decreti del Ministro dell'economia e delle finanze e' disposta l'erogazione di finanziamenti ponte al Fondo di risoluzione unico previsto dal regolamento (UE) n. 806/2014 fino all'importo complessivo massimo di 5.753 milioni di euro.

882. Qualora non si renda possibile procedere mediante le ordinarie procedure di gestione dei pagamenti, i decreti del Ministro dell'economia e delle finanze che dispongono l'erogazione dei predetti finanziamenti autorizzano il ricorso ad anticipazioni di tesoreria la cui regolarizzazione e' effettuata mediante emissione di ordini di pagamento sul pertinente capitolo di spesa.

883. Per le finalita' di cui al comma 881, e' istituito nello stato di previsione del Ministero dell'economia e delle finanze un apposito fondo con una dotazione iniziale di 2.500 milioni di euro per l'anno 2016. A tal fine e' autorizzata l'istituzione di apposita contabilita' speciale.

884. Le somme giacenti sulla contabilita' speciale di cui all'articolo 45, comma 2, del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, non utilizzate per le finalita' di cui al medesimo articolo, sono versate all'entrata del bilancio dello Stato, nell'anno 2016, per un importo pari a 1.500 milioni di euro.

885. I rimborsi del capitale derivanti dalle operazioni di finanziamento di cui al comma 881 sono versati all'entrata del bilancio dello Stato, per essere destinati al Fondo per l'ammortamento dei titoli di Stato. I relativi interessi sono versati all'entrata del bilancio dello Stato, per essere riassegnati ai pertinenti capitoli di bilancio ai fini del pagamento degli interessi passivi sui titoli di Stato.

886. Una quota non inferiore al 20 per cento delle risorse disponibili del fondo di garanzia di cui all'articolo 2, comma 100, lettera a), della legge 23 dicembre 1996, n. 662, e' riservata alle imprese localizzate nelle regioni Abruzzo, Basilicata, Calabria, Campania, Molise, Puglia, Sicilia e Sardegna.

887. Al comma 2 dell'articolo 2 del decreto-legge 24 dicembre 2002, n. 282, convertito, con modificazioni, dalla legge 21 febbraio 2003, n. 27, e successive modificazioni, sono apportate le seguenti modificazioni:

- a) al primo periodo, le parole: «1º gennaio 2015» sono sostituite dalle seguenti: «1º gennaio 2016»;
- b) al secondo periodo, le parole: «30 giugno 2015» sono sostituite dalle seguenti: «30 giugno 2016»;
- c) al terzo periodo, le parole: «30 giugno 2015» sono sostituite dalle seguenti: «30 giugno 2016».

888. Sui valori di acquisto delle partecipazioni non negoziate in mercati regolamentati e dei terreni, edificabili o con destinazione agricola, rideterminati con le modalita' e nei termini indicati nel comma 2 dell'articolo 2 del decreto-legge 24 dicembre 2002, n. 282, convertito, con modificazioni, dalla legge 21 febbraio 2003, n. 27, come modificato dal comma 887 del presente articolo, le aliquote delle imposte sostitutive di cui all'articolo 5, comma 2, della legge 28 dicembre 2001, n. 448, sono pari entrambe all'8 per cento, e l'aliquota di cui all'articolo 7, comma 2, della medesima legge e' raddoppiata.

889. I soggetti indicati nell'articolo 73, comma 1, lettere a) e b), del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, che non adottano i principi contabili internazionali nella redazione del bilancio, possono, anche in deroga all'articolo 2426 del codice civile e ad ogni altra disposizione di legge vigente in materia, rivalutare i beni d'impresa e le partecipazioni di cui alla sezione II del capo I della legge 21 novembre 2000, n. 342, ad esclusione degli immobili alla cui produzione o al cui scambio e' diretta l'attivita' di impresa, risultanti dal bilancio dell'esercizio in corso al 31 dicembre 2014.

890. La rivalutazione deve essere eseguita nel bilancio o rendiconto dell'esercizio successivo a quello di cui al comma 889, per il quale il termine di approvazione scade successivamente alla data di entrata in vigore della presente legge, deve riguardare tutti i beni appartenenti alla stessa categoria omogenea e deve essere annotata nel relativo inventario e nella nota integrativa.

891. Il saldo attivo della rivalutazione puo' essere affrancato, in tutto o in parte, con l'applicazione in capo alla societa' di un'imposta sostitutiva delle imposte sui redditi, dell'imposta regionale sulle attivita' produttive e di eventuali addizionali nella misura del 10 per cento, da versare con le modalita' indicate al comma 894.

892. Il maggior valore attribuito ai beni in sede di rivalutazione si considera riconosciuto ai fini delle imposte sui redditi e dell'imposta regionale sulle attivita' produttive a decorrere dal terzo esercizio successivo a quello con riferimento al quale la rivalutazione e' stata eseguita, mediante il versamento di un'imposta sostitutiva delle imposte sui redditi e dell'imposta regionale sulle attivita' produttive e di eventuali addizionali nella misura del 16 per cento per i beni ammortizzabili e del 12 per cento per i beni non ammortizzabili.

893. Nel caso di cessione a titolo oneroso, di assegnazione ai soci, di destinazione a finalita' estranee all'esercizio dell'impresa ovvero al consumo personale o familiare dell'imprenditore dei beni rivalutati in data anteriore a quella di inizio del quarto esercizio successivo a quello nel cui bilancio la rivalutazione e' stata eseguita, ai fini della determinazione delle plusvalenze o minusvalenze si ha riguardo al costo del bene prima della rivalutazione.

894. Le imposte sostitutive di cui ai commi 891 e 892 sono versate in un'unica rata entro il termine di versamento del saldo delle imposte sui redditi dovute per il periodo di imposta con riferimento al quale la rivalutazione e' eseguita. Gli importi da versare possono essere compensati ai sensi del decreto legislativo 9 luglio 1997, n. 241.

895. Si applicano, in quanto compatibili, le disposizioni degli articoli 11, 13, 14 e 15 della legge 21 novembre 2000, n. 342, quelle del regolamento di cui al decreto del Ministro delle finanze 13 aprile 2001, n. 162, nonche' le disposizioni del regolamento di cui al decreto del Ministro dell'economia e delle finanze 19 aprile 2002, n. 86, e dei commi 475, 477 e 478 dell'articolo 1 della legge 30 dicembre 2004, n. 311.

896. Limitatamente ai beni immobili, i maggiori valori iscritti in bilancio ai sensi dell'articolo 14 della legge 21 novembre 2000, n. 342, si considerano riconosciuti con effetto dal periodo d'imposta in corso alla data del 1º dicembre 2017.

897. Le previsioni di cui all'articolo 14, comma 1, della legge 21 novembre 2000, n. 342, si applicano anche ai soggetti che redigono il bilancio in base ai principi contabili internazionali di cui al regolamento (CE) n. 1606/2002 del Parlamento europeo e del Consiglio, del 19 luglio 2002, anche con riferimento alle partecipazioni, in societa' ed enti, costituenti immobilizzazioni finanziarie ai sensi dell'articolo 85, comma 3-bis, del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917. Per tali soggetti, per l'importo corrispondente ai maggiori valori oggetto di riallineamento, al netto dell'imposta sostitutiva di cui al comma 892, e' vincolata una riserva in sospensione di imposta ai fini fiscali che puo' essere affrancata ai sensi del comma 891.

898. All'articolo 49, comma 1, del decreto legislativo 21 novembre 2007, n. 231, le parole: «euro mille» sono sostituite dalle seguenti: «euro tremila» ed e' aggiunto, in fine, il seguente periodo: «Per il servizio di rimessa di denaro di cui all'articolo 1, comma 1, lettera b), numero 6), del decreto legislativo 27 gennaio 2010, n. 11, la soglia e' di euro mille».

899. All'articolo 49, comma 1-bis, del decreto legislativo 21 novembre 2007, n. 231, le parole: «e' di 2.500 euro» sono sostituite dalle seguenti: «e' di euro tremila».

900. All'articolo 15 del decreto-legge 18 ottobre 2012, n. 179, convertito, con modificazioni, dalla legge 17 dicembre 2012, n. 221, sono apportate le seguenti modificazioni:

- a) al comma 4, dopo le parole: «carte di debito» sono inserite le seguenti: «e carte di credito; tale obbligo non trova applicazione nei casi di oggettiva impossibilita' tecnica»;
- b) dopo il comma 4 sono inseriti i seguenti: «4-bis. Al fine di promuovere l'effettuazione di operazioni di pagamento basate su carta di debito o di credito e in particolare per i pagamenti di importo contenuto, ovvero quelli di importo inferiore a 5 euro, entro il 1º febbraio 2016, il Ministero dell'economia e delle finanze provvede con proprio decreto, di concerto col Ministero dello sviluppo economico, sentita la Banca d'Italia, ad assicurare la corretta e integrale applicazione del regolamento (UE) n. 751/2015 del Parlamento europeo e del Consiglio, del 23 aprile 2015, esercitando in particolare le opzioni di cui all'articolo 3 del regolamento stesso. Tale decreto prevede altresi': a) in conformita' alle definizioni, alla disciplina e alle finalita' del regolamento (UE) n. 751/2015, le modifiche, abrogazioni, integrazioni e semplificazioni alla normativa vigente necessarie a realizzare un pieno coordinamento del regolamento stesso con ogni altra disposizione vigente in materia; b) la designazione della Banca d'Italia quale autorita' competente per lo svolgimento delle funzioni previste dal regolamento (UE) n. 751/2015 e dell'Autorita' garante della concorrenza e del mercato quale autorita' competente a verificare il rispetto degli obblighi posti dal medesimo regolamento in materia di pratiche commerciali. 4-ter. I prestatori di servizi di pagamento, i gestori di schemi di carte di pagamento e ogni altro soggetto che interviene nell'effettuazione di un pagamento mediante carta applicano le regole e le misure, anche contrattuali, necessarie ad assicurare l'efficace traslazione degli effetti delle disposizioni del decreto di cui al comma 4-bis, tenuto conto della necessita' di assicurare trasparenza, chiarezza ed efficienza della struttura delle commissioni e la loro stretta correlazione e proporzionalita' ai costi effettivamente sostenuti dai prestatori di servizi di pagamento e dai gestori di circuiti e di schemi di pagamento, nonche' di promuovere l'efficienza dei circuiti e degli schemi di riferimento delle carte nel rispetto delle regole di concorrenza e dell'autonomia contrattuale delle parti»;
- c) al comma 5, le parole: «gli eventuali importi minimi, le modalita' e i termini» sono sostituite dalle seguenti: «le modalita', i termini e l'importo delle sanzioni amministrative pecuniarie» e le parole: «di cui al comma precedente» sono sostituite dalle seguenti: «di cui al comma 4 anche con riferimento alle fattispecie costituenti illecito e alle relative sanzioni pecuniarie amministrative».

901. Dal 1º luglio 2016 le disposizioni di cui al comma 4 dell'articolo 15 del decreto-legge 18 ottobre 2012, n. 179, convertito, con modificazioni, dalla legge 17 dicembre 2012, n. 221, si applicano anche ai dispositivi di cui alla lettera f) del comma 1 dell'articolo 7 del codice della strada, di cui al decreto legislativo 30 aprile 1992, n. 285.

902. All'articolo 12 del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214, il comma 1.1 e' abrogato.

903. All'articolo 32-bis del decreto-legge 12 settembre 2014, n. 133, convertito, con modificazioni, dalla legge 11 novembre 2014, n. 164, il comma 4 e' abrogato.

904. Resta fermo per le pubbliche amministrazioni l'obbligo di procedere alle operazioni di pagamento degli emolumenti a qualsiasi titolo erogati di importo superiore a mille euro, esclusivamente mediante l'utilizzo di strumenti telematici, ai sensi dell'articolo 2, comma 4-ter, del decreto-legge 13 agosto 2011, n. 138, convertito, con modificazioni, dalla legge 14 settembre 2011, n. 148.

905. All'articolo 1, comma 1, terzo periodo, della tariffa, parte prima, allegata al testo unico delle disposizioni concernenti l'imposta di registro, di cui al decreto del Presidente della Repubblica 26 aprile 1986, n. 131, le parole: «12 per cento» sono sostituite dalle seguenti: «15 per cento».

906. Al comma 4-bis dell'articolo 2 del decreto-legge 30 dicembre 2009, n. 194, convertito, con modificazioni, dalla legge 26 febbraio 2010, n. 25, dopo il primo periodo e' inserito il seguente: «Le agevolazioni previste dal periodo precedente si applicano altresi' agli atti di trasferimento a titolo oneroso di terreni agricoli e relative pertinenze, posti in essere a favore di proprietari di masi chiusi di cui alla legge della provincia autonoma di Bolzano 28 novembre 2001, n. 17, da loro abitualmente coltivati».

907. Le disposizioni di cui all'articolo 2, comma 4-bis, del decreto-legge 30 dicembre 2009, n. 194, convertito, con modificazioni, dalla legge 26 febbraio 2010, n. 25, sono applicabili anche a favore del coniuge o dei parenti in linea retta, purche' gia' proprietari di terreni agricoli e conviventi, di soggetti aventi i requisiti di cui al medesimo articolo 2, comma 4-bis.

908. Con decreto del Ministro dell'economia e delle finanze, di concerto con il Ministro delle politiche agricole alimentari e forestali, da adottare entro il 31 gennaio 2016 ai sensi dell'articolo 34, comma 1, del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, sono innalzate le percentuali di compensazione applicabili a taluni prodotti del settore lattiero-caseario in misura non superiore al 10 per cento. Con lo stesso decreto e con le medesime modalita' sono innalzate, per l'anno 2016, le percentuali di compensazione applicabili agli animali vivi della specie bovina e suina rispettivamente in misura non superiore al 7,7 per cento e all'8 per cento. L'attuazione delle disposizioni di cui al precedente periodo non puo' comportare minori entrate superiori a 20 milioni di euro.

909. All'articolo 1, comma 512, della legge 24 dicembre 2012, n. 228, e successive modificazioni, le parole: «7 per cento» sono sostituite dalle seguenti: «30 per cento».

910. All'articolo 1 della legge 23 dicembre 2005, n. 266, il comma 423 e' sostituito dal seguente: «423. Ferme restando le disposizioni tributarie in materia di accisa, la produzione e la cessione di energia elettrica e calorica da fonti rinnovabili agroforestali, sino a 2.400.000 kWh anno, e fotovoltaiche, sino a 260.000 kWh anno, nonche' di carburanti e prodotti chimici di origine agroforestale provenienti prevalentemente dal fondo, effettuate dagli imprenditori agricoli, costituiscono attivita' connesse ai sensi dell'articolo 2135, terzo comma, del codice civile e si considerano produttive di reddito agrario. Per la produzione di energia, oltre i limiti suddetti, il reddito delle persone fisiche, delle societa' semplici e degli altri soggetti di cui all'articolo 1, comma 1093, della legge 27 dicembre 2006, n. 296, e' determinato, ai fini IRPEF ed IRES, applicando all'ammontare dei corrispettivi delle operazioni soggette a registrazione agli effetti dell'imposta sul valore aggiunto, relativamente alla componente riconducibile alla valorizzazione dell'energia ceduta, con esclusione della quota incentivo, il coefficiente di redditivita' del 25 per cento, fatta salva l'opzione per la determinazione del reddito nei modi ordinari, previa comunicazione all'ufficio secondo le modalita' previste dal regolamento di cui al decreto del Presidente della Repubblica 10 novembre 1997, n. 442».

911. L'articolo 52, comma 3, lettera b), del decreto legislativo 26 ottobre 1995, n. 504, si applica anche all'energia elettrica prodotta con impianti azionati da fonti rinnovabili ai sensi della normativa vigente in materia, con potenza disponibile superiore a 20 kw, consumata dai soci delle societa' cooperative di produzione e distribuzione dell'energia elettrica di cui all'articolo 4, numero 8), della legge 6 dicembre 1962, n. 1643, in locali e luoghi diversi dalle abitazioni.

912. Le disposizioni del comma 910 si applicano a decorrere dal periodo di imposta successivo a quello in corso al 31 dicembre 2015.

913. All'articolo 22 del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, il comma 1 e' abrogato.

914. A valere sulle risorse di cui al Fondo di investimento nel capitale di rischio previsto dal regolamento di cui al decreto del Ministro delle politiche agricole e forestali 22 giugno 2004, n. 182, per gli interventi previsti all'articolo 66, comma 3, della legge 27 dicembre 2002, n. 289, l'ISMEA versa all'entrata del bilancio dello Stato la somma di 45 milioni di euro per l'anno 2016.

915. La dotazione del fondo per gli incentivi all'assunzione dei giovani lavoratori agricoli di cui all'articolo 5, comma 2, del decreto-legge 24 giugno 2014, n. 91, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 116, e' ridotta di 8,3 milioni di euro per l'anno 2016, di 7,9 milioni di euro per l'anno 2017 e di 8 milioni di euro per l'anno 2018.

916. A quota parte degli oneri derivanti dall'attuazione delle disposizioni di cui ai commi da 61 a 72 si provvede, quanto a 75 milioni di euro per l'anno 2016, a 18 milioni di euro per l'anno 2017 e a 22,5 milioni di euro per l'anno 2018, mediante utilizzo del fondo di conto capitale iscritto nello stato di previsione del Ministero delle politiche agricole alimentari e forestali ai sensi dell'articolo 49, comma 2, lettera d), del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89.

917. Il comma 3 dell'articolo 35 della legge 24 novembre 2000, n. 340, e' sostituito dai seguenti: «3. Tutti gli atti, i documenti e i provvedimenti relativi ai procedimenti, anche esecutivi, cautelari e tavolari relativi alle controversie in materia di masi chiusi, nonche' quelli relativi all'assunzione del maso chiuso, in seguito all'apertura della successione, sono esenti dall'imposta di bollo, di registro, da ogni altra imposta e tassa e dal contributo unificato. 3-bis. Le disposizioni del comma 3 si applicano per i periodi di imposta per i quali non siano ancora scaduti i termini di accertamento e di riscossione ai sensi della normativa vigente».

918. La misura del prelievo erariale unico sugli apparecchi di cui all'articolo 110, comma 6, lettera a), del testo unico di cui al regio decreto 18 giugno 1931, n. 773, e successive modificazioni, e' fissata in misura pari al 17,5 per cento dell'ammontare delle somme giocate, a decorrere dal 1º gennaio 2016. A decorrere dalla stessa data, la percentuale destinata alle vincite (pay-out) e' fissata in misura non inferiore al 70 per cento.

919. La misura del prelievo erariale unico sugli apparecchi di cui all'articolo 110, comma 6, lettera b), del testo unico di cui al regio decreto 18 giugno 1931, n. 773, e successive modificazioni, e' fissata in misura pari al 5,5 per cento dell'ammontare delle somme giocate, a decorrere dal 1º gennaio 2016.

920. Il comma 649 dell'articolo 1 della legge 23 dicembre 2014, n. 190, e' abrogato.

921. Il comma 649 dell'articolo 1 della legge 23 dicembre 2014, n. 190, si interpreta nel senso che la riduzione su base annua delle risorse statali a disposizione, a titolo di compenso, dei concessionari e dei soggetti che, secondo le rispettive competenze, operano nella gestione e raccolta del gioco praticato mediante apparecchi di cui all'articolo 110, comma 6, del testo unico di cui al regio decreto 18 giugno 1931, n. 773, si applica a ciascun operatore della filiera in misura proporzionale alla sua partecipazione alla distribuzione del compenso, sulla base dei relativi accordi contrattuali, tenuto conto della loro durata nell'anno 2015.

922. A decorrere dal 1º gennaio 2016 e' precluso il rilascio di nulla osta per gli apparecchi di cui all'articolo 110, comma 6, lettera a), del citato testo unico di cui al regio decreto 18 giugno 1931, n. 773, che non siano sostitutivi di nulla osta di apparecchi in esercizio.

923. Ferma restando l'applicazione dell'articolo 1, comma 646, lettera b), della legge 23 dicembre 2014, n. 190, in caso di violazione dell'articolo 7, comma 3-quater, del decreto-legge 13 settembre 2012, n. 158, convertito, con modificazioni, dalla legge 8 novembre 2012, n. 189, il titolare dell'esercizio e' punito con la sanzione amministrativa di euro 20.000; la stessa sanzione si applica al proprietario dell'apparecchio. Il divieto di cui al precedente periodo e la sanzione ivi prevista si applicano, altresi', nell'ipotesi di offerta di giochi promozionali di cui al decreto legislativo 9 aprile 2003, n. 70, per il tramite di qualunque tipologia di apparecchi situati in esercizi pubblici idonei a consentire la connessione telematica al web. Il titolare della piattaforma dei giochi promozionali e' punito con la sanzione amministrativa da euro 50.000 a euro 100.000. Le sanzioni sono irrogate dall'ufficio dell'Agenzia delle dogane e dei monopoli - area monopoli, territorialmente competente; per i soggetti con sede all'estero e' competente l'ufficio dei monopoli del Lazio. ((91))

924. All'articolo 12 del decreto-legge 28 aprile 2009, n. 39, convertito, con modificazioni, dalla legge 24 giugno 2009, n. 77, dopo il comma 1 e' aggiunto il seguente: «1-bis. Le sanzioni previste dal comma 1, lettera o), e dal relativo decreto di attuazione del Ministero dell'economia e delle finanze - Amministrazione autonoma dei monopoli di Stato, si applicano esclusivamente ai concorsi a premio per i quali e' stata accertata la coincidenza con attivita' di gioco riservate allo Stato o l'elusione del monopolio statale dei giochi. Per le altre violazioni resta ferma la disciplina sanzionatoria anteriormente vigente in materia».

925. Le norme di cui al comma 924 si applicano anche in riferimento alle sanzioni gia' irrogate, ma non definitive alla data di entrata in vigore della presente legge, in quanto impugnate o ancora suscettibili di impugnativa. Le relative sanzioni sono rideterminate d'ufficio da parte dell'autorita' competente.

926. Ai soggetti indicati dall'articolo 1, comma 643, della legge 23 dicembre 2014, n. 190, che non hanno aderito entro il 31 gennaio 2015 alla procedura di regolarizzazione di cui al medesimo comma, nonche' a quelli attivi successivamente alla data del 30 ottobre 2014, che comunque offrono scommesse con vincite in denaro in Italia, per conto proprio ovvero di soggetti terzi, anche esteri, senza essere collegati al totalizzatore nazionale dell'Agenzia delle dogane e dei monopoli, fermo in ogni caso il fatto che, in tale caso, il giocatore e' l'offerente e che il contratto di gioco e' pertanto perfezionato in Italia e conseguentemente regolato secondo la legislazione nazionale, e' consentito regolarizzare la propria posizione alle condizioni di cui ai commi 643, 644 e 645 del medesimo articolo 1 della legge n. 190 del 2014, ai quali, a tale fine, sono apportate le seguenti modificazioni:

- a) alle lettere a) e
- b) del comma 643, le parole: «31 gennaio 2015» e «5 gennaio 2015» sono sostituite, rispettivamente, dalle seguenti: «31 gennaio 2016» e «5 gennaio 2016»; b) alla lettera c) del comma 643, le parole: «28 febbraio 2015» sono sostituite dalle seguenti: «29 febbraio 2016»;
- c) alle lettere e) e i) del comma 643, la parola: «2015», ovunque ricorre, e' sostituita dalla seguente: «2016» e le parole: «30 giugno» sono sostituite dalle seguenti: «31 marzo»;
- d) alla lettera g) del comma 644, le parole: «1º gennaio 2015» sono sostituite dalle seguenti: «1º gennaio 2016».

927. Qualora uno o piu' soggetti residenti, operanti nell'ambito di un'unica rete di vendita, svolgano, per conto di soggetti esteri non residenti o comunque sulla base di contratti di ricevitoria o intermediazione con i soggetti terzi, le attivita' tipiche del gestore, anche sotto forma di centro trasmissione dati, quali, ad esempio, raccolta scommesse, raccolta delle somme puntate, pagamento dei premi, e mettano a disposizione dei fruitori finali del servizio strumenti per effettuare la giocata, quali le apparecchiature telematiche e i locali presso cui scommettere, e allorche' i flussi finanziari, relativi alle suddette attivita' ed intercorsi tra i gestori e il soggetto non residente, superino, nell'arco di sei mesi, 500.000 euro, l'Agenzia delle entrate, rilevati i suddetti presupposti dall'informativa dell'intermediario finanziario e degli altri soggetti esercenti attivita' finanziaria indicati nell'articolo 11, commi 1 e 2, del decreto legislativo 21 novembre 2007, n. 231, e successive modificazioni, da effettuare secondo i criteri stabiliti dal Ministero dell'economia e delle finanze, entro sessanta giorni dalla medesima informativa convoca in contraddittorio i gestori e il soggetto estero, i quali possono fornire prova contraria circa la presenza in Italia di una stabile organizzazione, ai sensi dell'articolo 162 del testo unico di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917.

928. Le attivita' svolte dai gestori possono essere desunte dai dati, dalle notizie e dalle informazioni comunicate dal Corpo della guardia di finanza ai fini dell'instaurazione del contraddittorio di cui al comma 927.

929. Laddove, all'esito del procedimento in contraddittorio di cui al comma 927, da concludere entro novanta giorni, sia accertata in Italia la stabile organizzazione del soggetto estero, l'Agenzia delle entrate emette motivato accertamento, liquidando la maggiore imposta e le sanzioni dovute.

930. A seguito di segnalazione dell'Agenzia delle entrate dei contribuenti nei confronti dei quali sia stata accertata la stabile organizzazione, gli intermediari finanziari e gli altri soggetti esercenti attivita' finanziaria indicati nell'articolo 11, commi 1 e 2, del decreto legislativo 21 novembre 2007, n. 231, e successive modificazioni, ai fini della disciplina in materia di antiriciclaggio, sono tenuti ad applicare una ritenuta a titolo d'acconto nella misura del 25 per cento sugli importi delle transazioni verso il beneficiario non residente, con versamento del prelievo entro il sedicesimo giorno del mese successivo a quello di effettuazione del pagamento.

931. Il contribuente puo' comunque presentare, entro sessanta giorni dall'inizio di ciascun periodo di imposta, specifica istanza di interpello disapplicativo, ai sensi dell'articolo 11, comma 2, della legge 27 luglio 2000, n. 212, con la quale dimostri il venir meno dei presupposti di cui ai commi da 918 a 930 del presente articolo.

932. In vista della scadenza delle concessioni vigenti, per garantire la tutela degli interessi pubblici nelle attivita' di raccolta delle scommesse su eventi sportivi, anche ippici, e non sportivi, l'Agenzia delle dogane e dei monopoli, nel rispetto dei principi e delle regole europee e nazionali, attribuisce con gara da indire dal 1º maggio 2016, mediante procedura aperta, competitiva e non discriminatoria, tutte le concessioni per la raccolta delle predette scommesse nel rispetto dei seguenti criteri:

- a) durata della concessione di nove anni, non rinnovabile, per la raccolta, esclusivamente in rete fisica, di scommesse su eventi sportivi, anche ippici, e non sportivi, ivi inclusi le scommesse su eventi simulati ed i concorsi pronostici su base sportiva ed ippica, presso punti di vendita aventi come attivita' prevalente la commercializzazione di prodotti di gioco pubblici, fino a un numero massimo di 10.000 diritti, e presso punti di vendita aventi come attivita' accessoria la commercializzazione dei prodotti di gioco pubblici, fino ad un massimo di 5.000 diritti, di cui fino a un massimo di 1.000 diritti negli esercizi in cui si effettua quale attivita' principale la somministrazione di alimenti e bevande;
- b) base d'asta non inferiore ad euro 32.000 per ogni punto di vendita avente come attivita' principale la commercializzazione dei prodotti di gioco pubblici e ad euro 18.000 per ogni punto di vendita avente come attivita' accessoria la commercializzazione dei prodotti di gioco pubblici;
- c) in caso di aggiudicazione, versamento della somma offerta entro la data di sottoscrizione della concessione;
- d) possibilita' di partecipazione per i soggetti che gia' esercitano attivita' di raccolta di gioco in uno degli Stati dello Spazio economico europeo, avendovi la sede legale ovvero operativa, sulla base di valido ed efficace titolo abilitativo rilasciato secondo le disposizioni vigenti nell'ordinamento di tale Stato.

933. I concessionari per la raccolta delle scommesse di cui al comma 932 e per la raccolta del gioco a distanza di cui al comma 935, in scadenza alla data del 30 giugno 2016, proseguono le loro attivita' di raccolta fino alla data di sottoscrizione delle convenzioni accessive alle concessioni aggiudicate ai sensi dei predetti commi, a condizione che presentino domanda di partecipazione.

934. All'articolo 1 della legge 27 dicembre 2013, n. 147, sono apportate le seguenti modificazioni:

- a) al comma 636: 1) all'alinea, le parole: «anni 2013 e 2014» e «2014» sono sostituite, rispettivamente, dalle seguenti: «anni dal 2013 al 2016» e «2016 a una gara per l'attribuzione di 210 concessioni per il predetto gioco» e le parole: «alla riattribuzione delle medesime concessioni» sono soppresse; 2) alla lettera a), le parole: «euro 200.000» sono sostituite dalle seguenti: «euro 350.000»; 3) alla lettera b), le parole: «sei anni» sono sostituite dalle seguenti: «nove anni, non rinnovabile»; 4) alla lettera c), le parole: «euro 2.800» e «euro 1.400» sono sostituite, rispettivamente, dalle seguenti: «euro 5.000» e «euro 2.500» e dopo le parole: «concessione riattribuita» sono aggiunte le seguenti: «, fermi in ogni caso la sottoscrizione dell'atto integrativo previsto dall'articolo 1, comma 79, della legge 13 dicembre 2010, n. 220, e il divieto di trasferimento dei locali per tutto il periodo della proroga»; 5) la lettera d) e' sostituita dalla seguente: «d) all'atto dell'aggiudicazione, versamento della somma offerta ai sensi della lettera a) entro la data di sottoscrizione della concessione»; 6) dopo la lettera d) e' inserita la seguente: «d-bis) possibilita' di partecipazione per i soggetti che gia' esercitano attivita' di raccolta di gioco in uno degli Stati dello Spazio economico europeo, avendovi la sede legale ovvero operativa, sulla base di valido ed efficace titolo abilitativo rilasciato secondo le disposizioni vigenti nell'ordinamento di tale Stato»;
- b) al comma 637, le parole: «, da adottare entro la fine del mese di maggio 2014,» sono soppresse.

935. In considerazione dell'approssimarsi della scadenza di un gruppo di concessioni relative alla raccolta a distanza dei giochi di cui all'articolo 24, comma 11, lettere da

- a) ad f), della legge 7 luglio 2009, n. 88, al fine di garantire la continuita' delle entrate erariali, nonche' la tutela dei giocatori e della fede pubblica attraverso azioni che consentano il contrasto al gioco illegale, ed un allineamento temporale, al 31 dicembre 2022, di tutte le concessioni aventi ad oggetto la commercializzazione dei giochi a distanza di cui al citato articolo 24, comma 11, l'Agenzia delle dogane e dei monopoli bandisce entro il 31 luglio 2016 una gara per la selezione, mediante procedura aperta, competitiva e non discriminatoria, di 120 concessioni per la commercializzazione dei suddetti giochi a distanza nel rispetto dei criteri previsti dall'articolo 24, comma 15, lettere da a) a e) e g), della citata legge n. 88 del 2009 e previo versamento di un corrispettivo una tantum, per la durata della concessione, pari ad euro 200.000.

936. Entro il 30 aprile 2016, in sede di Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, sono definite le caratteristiche dei punti di vendita ove si raccoglie gioco pubblico, nonche' i criteri per la loro distribuzione e concentrazione territoriale, al fine di garantire i migliori livelli di sicurezza per la tutela della salute, dell'ordine pubblico e della pubblica fede dei giocatori e di prevenire il rischio di accesso dei minori di eta'. Le intese raggiunte in sede di Conferenza unificata sono recepite con decreto del Ministro dell'economia e delle finanze, sentite le Commissioni parlamentari competenti.

937. COMMA ABROGATO DAL D.L. 31 MAGGIO 2021, N. 77, CONVERTITO CON MODIFICAZIONI DALLA L. 29 LUGLIO 2021, N. 108.

938. In ogni caso, e' vietata la pubblicita':

- a) che incoraggi il gioco eccessivo o incontrollato;
- b) che neghi che il gioco possa comportare dei rischi;
- c) che ometta di rendere esplicite le modalita' e le condizioni per la fruizione di incentivi o bonus;
- d) che presenti o suggerisca che il gioco sia un modo per risolvere problemi finanziari o personali, ovvero che costituisca una fonte di guadagno o di sostentamento alternativa al lavoro, piuttosto che una semplice forma di intrattenimento e di divertimento;
- e) che induca a ritenere che l'esperienza, la competenza o l'abilita' del giocatore permetta di ridurre o eliminare l'incertezza della vincita o consenta di vincere sistematicamente;
- f) che si rivolga o faccia riferimento, anche indiretto, ai minori e rappresenti questi ultimi, ovvero soggetti che appaiano evidentemente tali, intenti al gioco;
- g) che utilizzi segni, disegni, personaggi e persone, direttamente e primariamente legati ai minori, che possano generare un diretto interesse su di loro;
- h) che induca a ritenere che il gioco contribuisca ad accrescere la propria autostima, considerazione sociale e successo interpersonale;
- i) che rappresenti l'astensione dal gioco come un valore negativo;
- l) che induca a confondere la facilita' del gioco con la facilita' della vincita;
- m) che contenga dichiarazioni infondate sulla possibilita' di vincita o sul rendimento che i giocatori possono aspettarsi di ottenere dal gioco;
- n) che faccia riferimento a servizi di credito al consumo immediatamente utilizzabili ai fini del gioco.

939. E' altresi' vietata la pubblicita' di giochi con vincita in denaro nelle trasmissioni radiofoniche e televisive generaliste, nel rispetto dei principi sanciti in sede europea, dalle ore 7 alle ore 22 di ogni giorno. Sono esclusi dal divieto di cui al presente comma i media specializzati individuati con decreto del Ministro dell'economia e delle finanze, di concerto con il Ministro dello sviluppo economico, nonche' le lotterie nazionali a estrazione differita di cui all'articolo 21, comma 6, del decreto-legge 1º luglio 2009, n. 78, convertito, con modificazioni, dalla legge 3 agosto 2009, n. 102. Sono altresi' escluse le forme di comunicazione indiretta derivanti dalle sponsorizzazioni nei settori della cultura, della ricerca, dello sport, nonche' nei settori della sanita' e dell'assistenza.

940. La violazione dei divieti di cui ai commi 938 e 939 e delle prescrizioni del decreto di cui al comma 937 e' punita con la sanzione amministrativa pecuniaria di cui all'articolo 7, comma 6, del decreto-legge 13 settembre 2012, n. 158, convertito, con modificazioni, dalla legge 8 novembre 2012, n. 189. Le sanzioni sono irrogate dall'Autorita' per le garanzie nelle comunicazioni, secondo i principi di cui alla legge 24 novembre 1981, n. 689, al soggetto che commissiona la pubblicita', al soggetto che la effettua, nonche' al proprietario del mezzo con il quale essa e' diffusa.

941. Il Ministero della salute, di concerto con il Ministero dell'istruzione, dell'universita' e della ricerca, anche attraverso l'utilizzo dei propri siti web, predispone campagne di informazione e sensibilizzazione, con particolare riferimento alle scuole di ogni ordine e grado, sui fattori di rischio connessi al gioco d'azzardo, al fine di aumentare la consapevolezza sui fenomeni di dipendenza correlati, nonche' sui rischi che ne derivano per la salute, fornendo informazioni sui servizi predisposti dalle strutture pubbliche e del terzo settore per affrontare il problema della dipendenza da gioco d'azzardo.

942. Al fine di semplificare il processo di certificazione dei sistemi del gioco di cui all'articolo 110, comma 6, lettera b), del testo unico delle leggi di pubblica sicurezza, di cui al regio decreto 18 giugno 1931, n. 773, e dei relativi giochi, anche per incrementare il corrispondente gettito erariale, all'articolo 12, comma 1, lettera l), del decreto-legge 28 aprile 2009, n. 39, convertito, con modificazioni, dalla legge 24 giugno 2009, n. 77, le parole: «nonche' le modalita' di verifica della loro conformita'» sono soppresse ed e' aggiunto, in fine, il seguente numero: «5-bis) l'Agenzia delle dogane e dei monopoli stipula convenzioni per l'effettuazione delle verifiche di conformita' dei sistemi di gioco e dei giochi offerti e affida al partner tecnologico la verifica di parte dei sistemi e giochi gia' sottoposti a verifica di conformita' in attuazione delle convenzioni stesse. La presente disposizione si applica a partire dal primo giorno del mese successivo a quello in cui, con decreto del direttore dell'Agenzia delle dogane e dei monopoli, sono emanate le relative disposizioni attuative di carattere tecnico e quelle necessarie per l'effettuazione dei controlli».

943. Con provvedimento dirigenziale generale dell'Agenzia delle dogane e dei monopoli e' disciplinato il processo di evoluzione tecnologica degli apparecchi di cui all'articolo 110, comma 6, lettera a), del testo unico delle leggi di pubblica sicurezza, di cui al regio decreto 18 giugno 1931, n. 773. I nulla osta per gli apparecchi di cui al citato articolo 110, comma 6, lettera a), non possono piu' essere rilasciati decorsi nove mesi dalla data di pubblicazione del decreto del Ministro dell'economia e delle finanze di cui all'articolo 1, comma 569, lettera b), della legge 30 dicembre 2018, n. 145; tali apparecchi devono essere dismessi entro i successivi dodici mesi. A partire dal 1º gennaio 2017 possono essere rilasciati solo nulla osta per apparecchi che consentono il gioco pubblico da ambiente remoto, prevedendo la riduzione proporzionale, in misura non inferiore al 30 per cento, del numero dei nulla osta di esercizio relativi ad apparecchi attivi alla data del 31 luglio 2015, riferibili a ciascun concessionario. Le modalita' di tale riduzione, anche tenuto conto della diffusione territoriale degli apparecchi, il costo dei nuovi nulla osta e le modalita', anche rateali, del relativo pagamento sono definiti con il citato decreto ministeriale.

944. A decorrere dal 1º gennaio 2016 per i giochi di abilita' a distanza con vincita in denaro l'imposta unica di cui al decreto legislativo 23 dicembre 1998, n. 504, e' stabilita nella misura del 20 per cento delle somme che, in base al regolamento di gioco, non risultano restituite al giocatore.

945. A decorrere dal 1º gennaio 2016, alle scommesse a quota fissa, escluse le scommesse ippiche, l'imposta unica di cui al decreto legislativo 23 dicembre 1998, n. 504, si applica sulla differenza tra le somme giocate e le vincite corrisposte, nelle misure del 18 per cento, se la raccolta avviene su rete fisica, e del 22 per cento, se la raccolta avviene a distanza. Al gioco del Bingo a distanza si applica l'imposta unica di cui al citato decreto legislativo n. 504 del 1998; a decorrere dal 1º gennaio 2017 l'imposta unica e' stabilita nella misura del 20 per cento delle somme che, in base al regolamento di gioco, non risultano restituite al giocatore.

946. COMMA ABROGATO DALLA L. 30 DICEMBRE 2024, N. 207.

947. Ai fini del completamento del processo di riordino delle funzioni delle province, di cui all'articolo 1, comma 89, della legge 7 aprile 2014, n. 56, le funzioni relative all'assistenza per l'autonomia e la comunicazione personale degli alunni con disabilita' fisiche o sensoriali, di cui all'articolo 13, comma 3, della legge 5 febbraio 1992, n. 104, e relative alle esigenze di cui all'articolo 139, comma 1, lettera c), del decreto legislativo 31 marzo 1998, n. 112, sono attribuite alle regioni a decorrere dal 1º gennaio 2016, fatte salve le disposizioni legislative regionali che alla predetta data gia' prevedono l'attribuzione delle predette funzioni alle province, alle citta' metropolitane o ai comuni, anche in forma associata. Per l'esercizio delle predette funzioni e' attribuito un contributo di 70 milioni di euro per l'anno 2016. Con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro delegato per gli affari regionali e le autonomie locali, di concerto con il Ministro delegato per la famiglia e le disabilita', con il Ministro dell'istruzione, dell'universita' e della ricerca, con il Ministro dell'economia e delle finanze e con il Ministro dell'interno, previa intesa in sede di Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, da emanare entro trenta giorni dalla data di entrata in vigore della presente legge, si provvede al riparto del contributo di cui al periodo precedente tra gli enti territoriali interessati, anche frazionandolo, per l'anno 2016, sulla base dell'anno scolastico di riferimento, in due erogazioni, tenendo conto dell'effettivo esercizio delle funzioni di cui al primo periodo.

948. Il numero 26) della lettera b) del comma 78 dell'articolo 1 della legge 13 dicembre 2010, n. 220, e' abrogato.

949. Al decreto legislativo 21 novembre 2014, n. 175, sono apportate le seguenti modificazioni:

- a) all'articolo 3, comma 3, al primo periodo, le parole: «prestazioni erogate nel 2015» sono sostituite dalle seguenti: «prestazioni erogate dal 2015» e dopo il secondo periodo e' aggiunto il seguente: «I dati relativi alle prestazioni sanitarie erogate a partire dal 1º gennaio 2016 sono inviati al Sistema tessera sanitaria, con le medesime modalita' di cui al presente comma, anche da parte delle strutture autorizzate per l'erogazione dei servizi sanitari e non accreditate»;
- b) all'articolo 3, dopo il comma 3 e' inserito il seguente: «3-bis. Tutti i cittadini, indipendentemente dalla predisposizione della dichiarazione dei redditi precompilata, possono consultare i dati relativi alle proprie spese sanitarie acquisiti dal Sistema tessera sanitaria ai sensi dei commi 2 e 3 mediante i servizi telematici messi a disposizione dal Sistema tessera sanitaria»;
- c) all'articolo 3, comma 4, dopo il primo periodo e' aggiunto il seguente: «Nel caso di omessa, tardiva o errata trasmissione dei dati di cui al periodo precedente, si applica la sanzione prevista dall'articolo 78, comma 26, della legge 30 dicembre 1991, n. 413, e successive modificazioni»;
- d) all'articolo 3, comma 5, le parole: «commi 2 e 3» sono sostituite dalle seguenti: «commi 2, 3 e 3-bis»;
- e) all'articolo 3, dopo il comma 5-bis e' inserito il seguente: «5-ter. Per le trasmissioni da effettuare nell'anno 2015, relative all'anno 2014, e comunque per quelle effettuate nel primo anno previsto per la trasmissione all'Agenzia delle entrate dei dati e delle certificazioni uniche utili per la predisposizione della dichiarazione precompilata, non si fa luogo all'applicazione delle sanzioni di cui al comma 5-bis del presente articolo, all'articolo 78, comma 26, della legge 30 dicembre 1991, n. 413, e successive modificazioni, all'articolo 4, comma 6-quinquies, del regolamento di cui al decreto del Presidente della Repubblica 22 luglio 1998, n. 322, e successive modificazioni, nei casi di lieve tardivita' o di errata trasmissione dei dati stessi, se l'errore non determina un'indebita fruizione di detrazioni o deduzioni nella dichiarazione precompilata di cui all'articolo 1»;
- f) all'articolo 5, dopo il comma 3 e' aggiunto il seguente: «3-bis. Nel caso di presentazione della dichiarazione direttamente ovvero tramite il sostituto d'imposta che presta l'assistenza fiscale, con modifiche rispetto alla dichiarazione precompilata che incidono sulla determinazione del reddito o dell'imposta e che presentano elementi di incoerenza rispetto ai criteri pubblicati con provvedimento del direttore dell'Agenzia delle entrate ovvero determinano un rimborso di importo superiore a 4.000 euro, l'Agenzia delle entrate puo' effettuare controlli preventivi, in via automatizzata o mediante verifica della documentazione giustificativa, entro quattro mesi dal termine previsto per la trasmissione della dichiarazione, ovvero dalla data della trasmissione, se questa e' successiva a detto termine. Il rimborso che risulta spettante al termine delle operazioni di controllo preventivo e' erogato dall'Agenzia delle entrate non oltre il sesto mese successivo al termine previsto per la trasmissione della dichiarazione, ovvero dalla data della trasmissione, se questa e' successiva a detto termine. Restano fermi i controlli previsti in materia di imposte sui redditi»;
- g) all'articolo 1, comma 4, le parole: «5, comma 3» sono sostituite dalle seguenti: «5, commi 3 e 3-bis»;
- h) all'articolo 5, comma 1, la lettera b) e' abrogata con effetto per le dichiarazioni dei redditi presentate a decorrere dall'anno 2016, relative al periodo di imposta 2015;
- i) all'articolo 35, comma 3, le parole: «e' trasmesso annualmente un numero di dichiarazioni pari all'uno per cento, con uno scostamento massimo del 10 per cento, del rapporto risultante tra le dichiarazioni trasmesse dal centro in ciascuno dei tre anni e la media delle dichiarazioni complessivamente trasmesse dai soggetti che svolgono attivita' di assistenza fiscale nel triennio precedente, compreso quello considerato» sono sostituite dalle seguenti: «la media delle dichiarazioni validamente trasmesse dal centro nel primo triennio sia almeno pari all'uno per cento della media delle dichiarazioni complessivamente trasmesse dai soggetti che svolgono attivita' di assistenza fiscale nel medesimo triennio, con uno scostamento massimo del 10 per cento»;
- l) all'articolo 35, comma 3, le parole: «2016, 2017 e 2018» sono sostituite dalle seguenti: «2015, 2016 e 2017».

950. All'articolo 78 della legge 30 dicembre 1991, n. 413, sono apportate le seguenti modificazioni:

- a) il comma 25-bis e' sostituito dal seguente: «25-bis. Ai fini della elaborazione della dichiarazione dei redditi da parte dell'Agenzia delle entrate, a partire dall'anno d'imposta 2015, nonche' dei controlli sugli oneri deducibili e sugli oneri detraibili, entro il 28 febbraio di ciascun anno, gli enti, le casse e le societa' di mutuo soccorso aventi esclusivamente fine assistenziale e i fondi integrativi del Servizio sanitario nazionale che nell'anno precedente hanno ottenuto l'attestazione di iscrizione nell'Anagrafe dei fondi integrativi del servizio sanitario nazionale di cui all'articolo 9, comma 9, del decreto legislativo 30 dicembre 1992, n. 502, nonche' gli altri fondi comunque denominati, trasmettono all'Agenzia delle entrate, per tutti i soggetti del rapporto, una comunicazione contenente i dati relativi alle spese sanitarie rimborsate per effetto dei contributi versati di cui alla lettera a) del comma 2 dell'articolo 51 e di quelli di cui alla lettera e-ter) del comma 1 dell'articolo 10 del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, nonche' i dati relativi alle spese sanitarie rimborsate che comunque non sono rimaste a carico del contribuente ai sensi dell'articolo 10, comma 1, lettera b), e dell'articolo 15, comma 1, lettera c), dello stesso testo unico»;
- b) il comma 25-ter e' abrogato;
- c) al comma 26: 1) il primo periodo e' soppresso; 2) le parole: «al comma 25», ovunque ricorrono, sono sostituite dalle seguenti: «ai commi 25 e 25-bis».

951. Al regolamento di cui al decreto del Ministro delle finanze 31 maggio 1999, n. 164, sono apportate le seguenti modificazioni:

- a) agli articoli 6 e 22 e' aggiunto, in fine, il seguente comma: «2-bis. In luogo della polizza di cui al comma 1, la garanzia puo' essere prestata sotto forma di cauzione in titoli di Stato o garantiti dallo Stato, al valore di borsa, ovvero di fideiussione rilasciata da una banca o da una impresa di assicurazione per un periodo di quattro anni successivi a quello di svolgimento dell'attivita' di assistenza. Con decreto del Ministro dell'economia e delle finanze possono essere individuate modalita' alternative che offrano adeguate garanzie»;
- b) all'articolo 17, comma 1, dopo la lettera c) e' inserita la seguente: «c-bis) comunicare all'Agenzia delle entrate in via telematica, entro il termine previsto alla lettera c), il risultato finale delle dichiarazioni. Si applicano, ove compatibili, le disposizioni di cui all'articolo 16, comma 4-bis»;
- c) all'articolo 7, comma 2-ter, le parole: «che il numero delle dichiarazioni validamente trasmesse da ciascun centro sia almeno pari all'uno per cento del rapporto risultante tra la media delle dichiarazioni trasmesse dal centro nel triennio precedente e la» sono sostituite dalle seguenti: «annualmente che la media delle dichiarazioni validamente trasmesse da ciascun centro nel triennio precedente sia almeno pari all'uno per cento della».

952. All'articolo 4 del regolamento di cui al decreto del Presidente della Repubblica 22 luglio 1998, n. 322, sono apportate le seguenti modificazioni:

- a) il comma 3-bis e' sostituito dal seguente: «3-bis. Salvo quanto previsto al comma 6-quinquies, i sostituti d'imposta, comprese le Amministrazioni dello Stato, anche con ordinamento autonomo, di cui al comma 1 dell'articolo 29 del decreto del Presidente della Repubblica 29 settembre 1973, n. 600, e successive modificazioni, che effettuano le ritenute sui redditi a norma degli articoli 23, 24, 25, 25-bis, 25-ter e 29 del citato decreto n. 600 del 1973 nonche' dell'articolo 21, comma 15, della legge 27 dicembre 1997, n. 449, e dell'articolo 11 della legge 30 dicembre 1991, n. 413, tenuti al rilascio della certificazione di cui al comma 6-ter del presente articolo, trasmettono in via telematica all'Agenzia delle entrate, direttamente o tramite gli incaricati di cui all'articolo 3, commi 2-bis e 3, la dichiarazione di cui al comma 1 del presente articolo, relativa all'anno solare precedente, entro il 31 luglio di ciascun anno»;
- b) al comma 6-quinquies, il primo periodo e' sostituito dai seguenti: «Le certificazioni di cui al comma 6-ter sono trasmesse in via telematica all'Agenzia delle entrate direttamente o tramite gli incaricati di cui all'articolo 3, commi 2-bis e 3, entro il 7 marzo dell'anno successivo a quello in cui le somme e i valori sono stati corrisposti. Entro la stessa data sono altresi' trasmessi in via telematica gli ulteriori dati fiscali e contributivi e quelli necessari per l'attivita' di controllo dell'Amministrazione finanziaria e degli enti previdenziali e assicurativi, i dati contenuti nelle certificazioni rilasciate ai soli fini contributivi e assicurativi nonche' quelli relativi alle operazioni di conguaglio effettuate a seguito dell'assistenza fiscale prestata ai sensi del decreto legislativo 9 luglio 1997, n. 241, stabiliti con provvedimento del direttore dell'Agenzia delle entrate. Le trasmissioni in via telematica effettuate ai sensi del presente comma sono equiparate a tutti gli effetti alla esposizione dei medesimi dati nella dichiarazione di cui al comma 1».

953. All'articolo 21 del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni dalla legge 30 luglio 2010, n. 122, dopo il comma 1-ter e' aggiunto il seguente: «1-quater. Al fine di semplificare gli adempimenti dei contribuenti, in via sperimentale, per l'anno 2016, l'obbligo di comunicare le operazioni di cui al comma 1 e' escluso per coloro i quali trasmettono i dati al Sistema tessera sanitaria ai sensi dell'articolo 3, comma 3, del decreto legislativo 21 novembre 2014, n. 175».

954. Al testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e successive modificazioni, sono apportate le seguenti modificazioni:

- a) all'articolo 15, comma 1, la lettera d) e' sostituita dalla seguente: «d) le spese funebri sostenute in dipendenza della morte di persone, per importo non superiore a euro 1.550 per ciascuna di esse»;
- b) all'articolo 15, comma 1, la lettera e) e' sostituita dalla seguente: «e) le spese per frequenza di corsi di istruzione universitaria presso universita' statali e non statali, in misura non superiore, per le universita' non statali, a quella stabilita annualmente per ciascuna facolta' universitaria con decreto del Ministero dell'istruzione, dell'universita' e della ricerca da emanare entro il 31 dicembre, tenendo conto degli importi medi delle tasse e contributi dovuti alle universita' statali»;
- c) all'articolo 24, comma 3-bis, le parole: «nei confronti dei soggetti residenti in uno degli Stati membri dell'Unione europea o in uno Stato aderente all'Accordo sullo Spazio economico europeo» sono sostituite dalle seguenti: «nei confronti dei soggetti non residenti nel territorio italiano».

955. Le disposizioni di cui al comma 954, lettere a) e b), si applicano a partire dall'anno d'imposta 2015. Per il primo anno di applicazione, il decreto di cui al comma 954, lettera b), e' adottato entro il 31 gennaio 2016.

956. Con effetto per le dichiarazioni dei redditi presentate a decorrere dall'anno 2016, relative al periodo di imposta 2015, all'articolo 1 della legge 27 dicembre 2013, n. 147, i commi 586 e 587 sono abrogati.

957. All'articolo 39, comma 1-bis, del decreto legislativo 9 luglio 1997, n. 241, le parole: «di una somma pari alla sanzione irrogata » sono sostituite dalle seguenti: «di un importo pari alla sanzione irrogata e alle altre somme indicate al comma 1».

958. Le maggiori entrate per l'anno 2016 derivanti dalla proroga di termini prevista dall'articolo 2 del decreto-legge 30 settembre 2015, n. 153, convertito, con modificazioni, dalla legge 20 novembre 2015, n. 187, sono quantificate nell'importo di 2.320 milioni di euro. (3)(14)

959. Qualora dal monitoraggio delle entrate di cui al comma 958 emerga un andamento che non consenta la realizzazione integrale dell'importo di cui al medesimo comma 958, il Ministro dell'economia e delle finanze, con proprio decreto, da emanare entro il 31 marzo 2016, stabilisce l'aumento, a decorrere dal 1º maggio 2016, delle accise di cui alla direttiva 2008/118/ CE del Consiglio, del 16 dicembre 2008, in misura tale da assicurare il conseguimento del predetto ammontare di maggiori entrate.

960. Al decreto del Presidente della Repubblica 26 ottobre 1972, n. 633, sono apportate le seguenti modifiche:

- a) all'articolo 16, il primo ed il secondo comma sono sostituiti dai seguenti: «L'aliquota dell'imposta e' stabilita nella misura del ventidue per cento della base imponibile dell'operazione. L'aliquota e' ridotta al quattro, al cinque e al dieci per cento per le operazioni che hanno per oggetto i beni e i servizi elencati, rispettivamente, nella parte II, nella parte II-bis e nella parte III dell'allegata tabella A, salvo il disposto dell'articolo 34»;
- b) alla tabella A, parte II, il numero 41-bis) e' abrogato;
- c) alla tabella A, dopo la parte II e' inserita la seguente: «Parte II-bis BENI E SERVIZI SOGGETTI ALL'ALIQUOTA DEL 5 PER CENTO 1) Le prestazioni di cui ai numeri 18), 19), 20), 21) e 27-ter) dell'articolo 10, primo comma, rese in favore dei soggetti indicati nello stesso numero 27-ter) da cooperative sociali e loro consorzi».

961. Le maggiori entrate derivanti dal comma 960 sono pari a 12 milioni di euro.

962. All'articolo 1, comma 331, della legge 27 dicembre 2006, n. 296, il primo e il secondo periodo sono soppressi.

963. Le disposizioni dei commi 960 e 962 si applicano alle operazioni effettuate sulla base di contratti stipulati, rinnovati o prorogati successivamente alla data di entrata in vigore della presente legge.

964. COMMA ABROGATO DALLA L. 30 DICEMBRE 2024, N. 207.

965. Per il potenziamento degli interventi e delle dotazioni strumentali in materia di protezione cibernetica e di sicurezza informatica nazionali nonche' per le spese correnti connesse ai suddetti interventi, e' istituito nello stato di previsione del Ministero dell'economia e delle finanze un fondo con una dotazione finanziaria di 150 milioni di euro per l'anno 2016. Un decimo della dotazione finanziaria del fondo di cui al presente comma e' destinato al rafforzamento della formazione del personale del servizio polizia postale e delle comunicazioni, nonche' all'aggiornamento della tecnologia dei macchinari e delle postazioni informatiche.

966. Con decreto del Presidente del Consiglio dei ministri, previa deliberazione del Comitato interministeriale per la sicurezza della Repubblica (CISR), sentiti il Ministro dell'interno, il Comitato parlamentare per la sicurezza della Repubblica, nonche' i responsabili del Dipartimento delle informazioni per la sicurezza (DIS), dell'Agenzia informazioni e sicurezza esterna (AISE) e dell'Agenzia informazioni e sicurezza interna (AISI), lo stanziamento del fondo di cui al comma 965 e' ripartito in via prioritaria tra tali organismi anche ai fini dell'attuazione, in coerenza con le direttive impartite ai sensi dell'articolo 1, comma 3-bis, della legge 3 agosto 2007, n. 124, di specifiche misure di rafforzamento delle attivita' di prevenzione e di contrasto con mezzi informatici del crimine di matrice terroristica nazionale e internazionale. Di tale ripartizione e' data comunicazione al Comitato parlamentare per la sicurezza della Repubblica. Resta fermo, con riferimento alle risorse finanziarie assegnate ai predetti organismi, quanto disposto dai regolamenti adottati ai sensi dell'articolo 29 della citata legge n. 124 del 2007, e successive modificazioni. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

967. Per l'ammodernamento delle dotazioni strumentali e delle attrezzature anche di protezione personale in uso alle Forze di polizia e al Corpo nazionale dei vigili del fuoco, e' istituito nello stato di previsione del Ministero dell'economia e delle finanze un fondo con una dotazione finanziaria di 50 milioni di euro per l'anno 2016. Per il rinnovo e l'adeguamento della dotazione dei giubbotti antiproiettile della Polizia di Stato e' autorizzata la spesa di 10 milioni di euro per l'anno 2016. Con decreto del Presidente del Consiglio dei ministri, di concerto con il Ministro dell'economia e delle finanze, sentiti il Ministro dell'interno, il Ministro della difesa e il Ministro della giustizia, da adottare entro trenta giorni dalla data di entrata in vigore della presente legge, sono individuati gli interventi e le amministrazioni competenti cui destinare le predette somme. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

968. Alla copertura degli oneri derivanti dal comma 967, secondo periodo, pari a 10 milioni di euro per l'anno 2016, si provvede mediante corrispondente riduzione del fondo di cui all'articolo 1, comma 200, della legge 23 dicembre 2014, n. 190.

969. Al fine di sostenere interventi straordinari per la difesa e la sicurezza nazionale in relazione alla minaccia terroristica, e' istituito nello stato di previsione del Ministero della difesa un fondo con una dotazione finanziaria di 245 milioni di euro per l'anno 2016.

970. Fermo restando quanto disposto dal comma 372, con decreto del Presidente del Consiglio dei ministri, di concerto con il Ministro dell'economia e delle finanze e con il Ministro della difesa, da adottare entro trenta giorni dalla data di entrata in vigore della presente legge, sono individuati gli interventi e gli organismi cui destinare le risorse del fondo di cui al comma 969, con particolare riguardo a quelli diretti a potenziare i sistemi di difesa territoriale e dello spazio aereo e di intervento delle forze speciali e delle forze per operazioni speciali nell'intero dominio di azione terrestre, marittimo, aereo e spaziale, a sviluppare il sistema di sorveglianza satellitare e di comunicazione, ad ammodernare mezzi, sistemi ed equipaggiamenti di difesa, nonche' a rafforzare i supporti logistici e i sistemi per la protezione delle infrastrutture sensibili e di rilevanza strategica. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

971. Il Ministero degli affari esteri e della cooperazione internazionale e' autorizzato, per l'anno 2016, alla spesa di 15 milioni di euro per investimenti destinati ad accrescere il livello di sicurezza delle sedi istituzionali in Italia e all'estero.

972. Nelle more dell'attuazione della delega sulla revisione dei ruoli delle Forze di polizia, del Corpo nazionale dei vigili del fuoco e delle Forze armate e per il riconoscimento dell'impegno profuso al fine di fronteggiare le eccezionali esigenze di sicurezza nazionale, per l'anno 2016 al personale appartenente ai corpi di polizia, al Corpo nazionale dei vigili del fuoco e alle Forze armate non destinatario di un trattamento retributivo dirigenziale e' riconosciuto un contributo straordinario pari a 960 euro su base annua, da corrispondere in quote di pari importo a partire dalla prima retribuzione utile e in relazione al periodo di servizio prestato nel corso dell'anno 2016. Il contributo non ha natura retributiva, non concorre alla formazione del reddito complessivo ai fini dell'imposta sul reddito delle persone fisiche e dell'imposta regionale sulle attivita' produttive e non e' assoggettato a contribuzione previdenziale e assistenziale. Ai soggetti destinatari del contributo straordinario si applicano altresi', ricorrendone le condizioni, le disposizioni contenute nell'articolo 13, comma 1-bis, del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, e successive modificazioni. Per le finalita' di cui al presente comma e' autorizzata la spesa di 510,5 milioni di euro per l'anno 2016. Al fine di garantire il rispetto degli obiettivi programmatici di finanza pubblica, il Ministero dell'economia e delle finanze - Dipartimento dell'amministrazione generale, del personale e dei servizi effettua il monitoraggio mensile dei maggiori oneri derivanti dal presente comma. Nelle more del monitoraggio, e' accantonato e reso indisponibile l'importo di 50 milioni di euro per l'anno 2016 a valere sulle risorse del fondo di cui all'articolo 1, comma 200, della legge 23 dicembre 2014, n. 190, come rifinanziato ai sensi del comma 63 del presente articolo. In relazione agli esiti del monitoraggio, con decreti del Ministro dell'economia e delle finanze si provvede al disaccantonamento ovvero alla riduzione delle risorse necessarie per assicurare la copertura degli eventuali maggiori oneri accertati. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni compensative tra gli stanziamenti iscritti in bilancio ai sensi del presente comma anche tra stati di previsione diversi. L'autorizzazione di spesa di cui all'articolo 2, comma 3, del decreto-legge 28 dicembre 1998, n. 451, convertito, con modificazioni, dalla legge 26 febbraio 1999, n. 40, e successivi rifinanziamenti, e' ridotta di 5,5 milioni di euro per l'anno 2016. (22) (23) (24)

973. All'articolo 3, comma 155, della legge 24 dicembre 2003, n. 350, sono aggiunti, in fine, i seguenti periodi: «E' altresi' autorizzata la spesa di 944.958 euro per l'anno 2016, di 973.892 euro per l'anno 2017 e di 1.576.400 euro annui a decorrere dall'anno 2018, da destinare a provvedimenti normativi diretti all'equiparazione, nell'articolazione delle qualifiche, nella progressione di carriera e nel trattamento giuridico ed economico, del personale direttivo del Corpo di polizia penitenziaria ai corrispondenti ruoli direttivi della Polizia di Stato di cui al decreto legislativo 5 ottobre 2000, n. 334. In ogni caso, restano ferme le disposizioni di cui all'articolo 8 della legge 7 agosto 2015, n. 124».

974. Per l'anno 2016 e' istituito il Programma straordinario di intervento per la riqualificazione urbana e la sicurezza delle periferie delle citta' metropolitane e dei comuni capoluogo di provincia, di seguito denominato «Programma», finalizzato alla realizzazione di interventi urgenti per la rigenerazione delle aree urbane degradate attraverso la promozione di progetti di miglioramento della qualita' del decoro urbano, di manutenzione, riuso e rifunzionalizzazione delle aree pubbliche e delle strutture edilizie esistenti, rivolti all'accrescimento della sicurezza territoriale e della capacita' di resilienza urbana, al potenziamento delle prestazioni urbane anche con riferimento alla mobilita' sostenibile, allo sviluppo di pratiche, come quelle del terzo settore e del servizio civile, per l'inclusione sociale e per la realizzazione di nuovi modelli di welfare metropolitano, anche con riferimento all'adeguamento delle infrastrutture destinate ai servizi sociali e culturali, educativi e didattici, nonche' alle attivita' culturali ed educative promosse da soggetti pubblici e privati.

975. Ai fini della predisposizione del Programma, entro il 1º marzo 2016 gli enti interessati trasmettono i progetti di cui al comma 974 alla Presidenza del Consiglio dei ministri, secondo le modalita' e la procedura stabilite con apposito bando, approvato, entro il 31 gennaio 2016, con decreto del Presidente del Consiglio dei ministri, di concerto con il Ministro dell'economia e delle finanze, con il Ministro delle infrastrutture e dei trasporti e con il Ministro dei beni e delle attivita' culturali e del turismo, sentita la Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281.

976. Con il decreto di cui al comma 975 sono altresi' definiti:

- a) la costituzione, la composizione e le modalita' di funzionamento, presso la Presidenza del Consiglio dei ministri, di un Nucleo per la valutazione dei progetti di riqualificazione, il quale ha facolta' di operare anche avvalendosi del supporto tecnico di enti pubblici o privati ovvero di esperti dotati delle necessarie competenze;
- b) la documentazione che gli enti interessati devono allegare ai progetti e il relativo cronoprogramma di attuazione;
- c) i criteri per la valutazione dei progetti da parte del Nucleo, in coerenza con le finalita' del Programma, tra i quali la tempestiva esecutivita' degli interventi e la capacita' di attivare sinergie tra finanziamenti pubblici e privati.

977. Sulla base dell'istruttoria svolta, il Nucleo seleziona i progetti in coerenza con i criteri definiti dal decreto di cui al comma 975, con le relative indicazioni di priorita'. Con uno o piu' decreti del Presidente del Consiglio dei ministri sono individuati i progetti da inserire nel Programma ai fini della stipulazione di convenzioni o accordi di programma con gli enti promotori dei progetti medesimi. Tali convenzioni o accordi di programma definiscono i soggetti partecipanti alla realizzazione dei progetti, le risorse finanziarie, ivi incluse quelle a valere sul Fondo di cui al comma 978, e i tempi di attuazione dei progetti medesimi, nonche' i criteri per la revoca dei finanziamenti in caso di inerzia realizzativa. Le amministrazioni che sottoscrivono le convenzioni o gli accordi di programma forniscono alla Presidenza del Consiglio dei ministri i dati e le informazioni necessari allo svolgimento dell'attivita' di monitoraggio degli interventi. Il monitoraggio degli interventi avviene ai sensi del decreto legislativo 29 dicembre 2011, n. 229, ove compatibile. L'insieme delle convenzioni e degli accordi stipulati costituisce il Programma.

978. Per l'attuazione delle disposizioni di cui ai commi da 974 a 977, per l'anno 2016 e' istituito nello stato di previsione del Ministero dell'economia e delle finanze un fondo denominato «Fondo per l'attuazione del Programma straordinario di intervento per la riqualificazione urbana e la sicurezza delle periferie», da trasferire al bilancio autonomo della Presidenza del Consiglio dei ministri. A tale fine e' autorizzata la spesa di 500 milioni di euro per l'anno 2016.

979. Al fine di promuovere lo sviluppo della cultura e la conoscenza del patrimonio culturale, a tutti i residenti nel territorio nazionale, in possesso, ove previsto, di permesso di soggiorno in corso di validita' i quali compiono diciotto anni di eta' nell'anno 2016, e' assegnata, nel rispetto del limite di spesa di cui al comma 980, una Carta elettronica. La Carta, dell'importo nominale massimo di euro 500 per l'anno 2016, puo' essere utilizzata per assistere a rappresentazioni teatrali e cinematografiche, per l'acquisto di libri nonche' per l'ingresso a musei, mostre ed eventi culturali, monumenti, gallerie, aree archeologiche, parchi naturali e spettacoli dal vivo. Le somme assegnate con la Carta non costituiscono reddito imponibile del beneficiario e non rilevano ai fini del computo del valore dell'indicatore della situazione economica equivalente. Con decreto del Presidente del Consiglio dei ministri, di concerto con il Ministro dei beni e delle attivita' culturali e del turismo e con il Ministro dell'economia e delle finanze, da adottare entro trenta giorni dalla data di entrata in vigore della presente legge, sono definiti i criteri e le modalita' di attribuzione e di utilizzo della Carta e l'importo da assegnare nell'ambito delle risorse disponibili. (14) (34)

980. Per le finalita' di cui al comma 979 e' autorizzata la spesa di 290 milioni di euro per l'anno 2016, da iscrivere nello stato di previsione del Ministero dei beni e delle attivita' culturali e del turismo.

981. Al fine di assicurare la piena ed efficace realizzazione degli obiettivi istituzionali perseguiti, non si applicano alla Fondazione MAXXI - Museo nazionale delle arti del XXI secolo le norme di contenimento delle spese previste a legislazione vigente a carico dei soggetti inclusi nell'elenco dell'Istituto nazionale di statistica (ISTAT) delle amministrazioni pubbliche di cui all'articolo 1, comma 2, della legge 31 dicembre 2009, n. 196, e successive modificazioni. Agli oneri derivanti dall'attuazione del presente comma, pari a 500.000 euro annui a decorrere dall'anno 2016, si provvede mediante riduzione dell'autorizzazione di spesa di cui all'articolo 25, comma 2, della legge 18 giugno 2009, n. 69.

982. Per le spese sostenute da persone fisiche non nell'esercizio di attivita' di lavoro autonomo o di impresa ai fini dell'installazione di sistemi di videosorveglianza digitale o allarme, nonche' per quelle connesse ai contratti stipulati con istituti di vigilanza, dirette alla prevenzione di attivita' criminali, e' riconosciuto un credito d'imposta ai fini dell'imposta sul reddito, nel limite massimo complessivo di 15 milioni di euro per l'anno 2016. Con decreto del Ministro dell'economia e delle finanze, da adottare entro novanta giorni dalla data di entrata in vigore della presente legge, sono definiti i criteri e le procedure per l'accesso al beneficio di cui al presente comma e per il suo recupero in caso di illegittimo utilizzo, nonche' le ulteriori disposizioni ai fini del contenimento della spesa complessiva entro i limiti di cui al presente comma.

983. COMMA ABROGATO DALLA L. 30 DICEMBRE 2020, N. 178.

984. Per l'anno 2016, agli studenti dei conservatori di musica e degli istituti musicali pareggiati, iscritti ai corsi di strumento secondo il precedente ordinamento e ai corsi di laurea di primo livello secondo il nuovo ordinamento, e' concesso un contributo una tantum di 1.000 euro, non eccedente il costo dello strumento, per l'acquisto di uno strumento musicale nuovo, coerente con il corso di studi, nel limite complessivo di 15 milioni di euro. Lo strumento musicale oggetto di agevolazione deve essere acquistato presso un produttore o un rivenditore, dietro presentazione di un certificato di iscrizione rilasciato dal conservatorio o dagli istituti musicali pareggiati da cui risultino cognome, nome, codice fiscale e corso di strumento cui lo studente e' iscritto. Il contributo e' anticipato all'acquirente dello strumento dal rivenditore sotto forma di sconto sul prezzo di vendita ed e' a questo rimborsato sotto forma di credito d'imposta di pari importo, da utilizzare in compensazione ai sensi dell'articolo 17 del decreto legislativo 9 luglio 1997, n. 241, e successive modificazioni. Con provvedimento del direttore dell'Agenzia delle entrate, da emanare entro trenta giorni dalla data di entrata in vigore della presente legge, sono definiti le modalita' attuative, comprese le modalita' per usufruire del credito d'imposta, il regime dei controlli nonche' ogni altra disposizione necessaria per il monitoraggio dell'agevolazione.

985. Per l'anno finanziario 2016, con riferimento al precedente periodo d'imposta, ciascun contribuente puo' destinare il due per mille della propria imposta sul reddito delle persone fisiche a favore di un'associazione culturale iscritta in un apposito elenco istituito presso la Presidenza del Consiglio dei ministri. Con decreto di natura non regolamentare del Presidente del Consiglio dei ministri, su proposta del Ministro dei beni e delle attivita' culturali e del turismo, di concerto con il Ministro dell'economia e delle finanze, da adottare entro trenta giorni dalla data di entrata in vigore della presente legge, sono stabiliti i requisiti e i criteri per l'iscrizione delle associazioni nell'elenco nonche' le cause e le modalita' di revoca o di decadenza. I contribuenti effettuano la scelta di destinazione di cui al primo periodo in sede di dichiarazione annuale dei redditi ovvero, se esonerati dall'obbligo di presentare la dichiarazione, mediante la compilazione di un'apposita scheda approvata dall'Agenzia delle entrate e allegata ai modelli di dichiarazione. Con il decreto di cui al secondo periodo sono stabiliti i criteri e le modalita' per il riparto e la corresponsione delle somme spettanti alle associazioni culturali sulla base delle scelte operate dai contribuenti, in modo da garantire la tempestivita' e l'economicita' di gestione, nonche' le ulteriori disposizioni applicative del presente comma. Le somme non impegnate nell'esercizio 2016 possono esserlo in quello successivo. Per le finalita' di cui al presente comma e' autorizzata la spesa di 100 milioni di euro per l'anno 2016.

986. In relazione alle contingenti esigenze di prevenzione e di controllo del territorio e di tutela dell'ordine e della sicurezza pubblica, all'articolo 16-ter, comma 1, del decreto-legge 19 giugno 2015, n. 78, convertito, con modificazioni, dalla legge 6 agosto 2015, n. 125, le parole: «con decorrenza non anteriore al 1º ottobre 2015 e al 1º ottobre 2016» sono sostituite dalle seguenti: «con decorrenza non anteriore al 1º ottobre 2015 e al 1º marzo 2016» ed e' aggiunto, in fine, il seguente periodo: «La Polizia di Stato e' altresi' autorizzata, nei limiti degli eventuali ulteriori posti residui, a bandire, per l'anno 2016, un concorso ai sensi dello stesso articolo 2199, comma 4, lettera a), del decreto legislativo n. 66 del 2010».

987. All'articolo 100, comma 2, del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, dopo la lettera o-bis) e' aggiunta la seguente: «o-ter) le somme corrisposte, anche su base volontaria al fondo istituito, con mandato senza rappresentanza, presso uno dei consorzi cui le imprese aderiscono in ottemperanza a obblighi di legge, in conformita' alle disposizioni di legge o contrattuali, indipendentemente dal trattamento contabile ad esse applicato, a condizione che siano utilizzate in conformita' agli scopi di tali consorzi».

988. All'articolo 11, comma 1, lettera a), del decreto legislativo 15 dicembre 1997, n. 446, dopo il numero 1) e' inserito il seguente: «1-bis) le somme corrisposte, anche su base volontaria al fondo istituito, con mandato senza rappresentanza, presso uno dei consorzi cui le imprese aderiscono in ottemperanza a obblighi di legge, in conformita' alle disposizioni di legge o contrattuali, indipendentemente dal trattamento contabile ad esse applicato, a condizione che siano utilizzate in conformita' agli scopi di tali consorzi».

989. Le disposizioni di cui ai commi 987 e 988 si applicano a decorrere dall'esercizio in corso al 31 dicembre 2015.

990. All'articolo 1, comma 269, della legge 23 dicembre 2014, n. 190, le parole: «per l'anno 2015» sono sostituite dalle seguenti: «per gli anni 2015 e 2016».

991. E' assegnato al CONI, con vincolo di destinazione in favore delle attivita' del Comitato promotore per le olimpiadi «Roma 2024», un contributo pari a 2 milioni di euro per l'anno 2016 e a 8 milioni di euro per l'anno 2017.

992. Le disposizioni della presente legge sono applicabili nelle regioni a statuto speciale e nelle province autonome di Trento e di Bolzano compatibilmente con le disposizioni dei rispettivi statuti e le relative norme di attuazione, anche con riferimento alla legge costituzionale 18 ottobre 2001, n. 3.

993. Gli importi da iscrivere nei fondi speciali di cui all'articolo 11, comma 3, lettera c), della legge 31 dicembre 2009, n. 196, per il finanziamento dei provvedimenti legislativi che si prevede possano essere approvati nel triennio 2016-2018 restano determinati, per ciascuno degli anni 2016, 2017 e 2018, nelle misure indicate nelle Tabelle A e B allegate alla presente legge, rispettivamente per il fondo speciale destinato alle spese correnti e per il fondo speciale destinato alle spese in conto capitale.

994. Le dotazioni da iscrivere nei singoli stati di previsione del bilancio 2016 e del triennio 2016-2018 in relazione a leggi di spesa permanente la cui quantificazione e' rinviata alla legge di stabilita', ai sensi dell'articolo 11, comma 3, lettera d), della legge 31 dicembre 2009, n. 196, sono indicate nella Tabella C allegata alla presente legge.

995. Gli importi delle quote destinate a gravare su ciascuno degli anni 2016, 2017 e 2018 per le leggi che dispongono spese a carattere pluriennale in conto capitale, con le relative aggregazioni per programma e per missione e con distinta e analitica evidenziazione dei rifinanziamenti, delle riduzioni e delle rimodulazioni, ai sensi dell'articolo 11, comma 3, lettera e), della legge 31 dicembre 2009, n. 196, sono indicati nella Tabella E allegata alla presente legge.

996. Gli importi delle riduzioni, per ciascuno degli anni del triennio 2016-2018 per le leggi che dispongono spese di parte corrente, con le relative aggregazioni per programma e per missione, ai sensi dell'articolo 11, comma 3, lettera f), della legge 31 dicembre 2009, n. 196, sono indicati nella Tabella D allegata alla presente legge.

997. A valere sulle autorizzazioni di spesa, riportate nella Tabella di cui al comma 995, le amministrazioni pubbliche, ai sensi dell'articolo 30, comma 2, della legge 31 dicembre 2009, n. 196, possono assumere impegni nell'anno 2016, a carico di esercizi futuri, nei limiti massimi di impegnabilita' indicati per ciascuna disposizione legislativa in apposita colonna della stessa Tabella, ivi compresi gli impegni gia' assunti nei precedenti esercizi a valere sulle autorizzazioni medesime.

998. Per gli esercizi finanziari 2016, 2017 e 2018, la copertura della presente legge per le nuove o maggiori spese correnti, per le riduzioni di entrata e per le nuove finalizzazioni nette da iscrivere nel fondo speciale di parte corrente e' assicurata, ai sensi dell'articolo 11, comma 6, della legge 31 dicembre 2009, n. 196, secondo il prospetto allegato alla presente legge.

999. La presente legge, salvo quanto diversamente previsto, entra in vigore il 1º gennaio 2016.

------------- AGGIORNAMENTO (2) Il D.L. 30 dicembre 2015, n. 210, convertito con modificazioni dalla L. 25 febbraio 2016, n. 21, ha disposto (con l'art. 7, comma 9-ter) che "Il termine di novanta giorni entro cui il commissario, nominato ai sensi dell'articolo 1, comma 867, della legge 28 dicembre 2015, n. 208, predispone un piano industriale e' prorogato di ulteriori trenta giorni. Entro lo stesso termine non possono essere intraprese azioni esecutive, anche concorsuali, compresi gli atti di intervento nelle procedure esecutive pendenti, nei confronti della societa' di cui al citato articolo 1, comma 867, della legge n. 208 del 2015. I pignoramenti eventualmente eseguiti non vincolano gli enti debitori e i terzi pignorati, i quali possono disporre delle somme per le finalita' istituzionali della societa' di cui al primo periodo". Ha inoltre disposto (con l'art. 7, comma 11-quater) che "L'applicazione delle disposizioni di cui all'articolo 1, comma 866, della legge 28 dicembre 2015, n. 208, e' differita al 1° gennaio 2017. Conseguentemente nel Fondo di cui al citato articolo 1, comma 866, della legge n. 208 del 2015, confluiscono le risorse di cui all'articolo 1, comma 83, della legge 27 dicembre 2013, n. 147, per le annualita' 2017, 2018 e 2019". ------------- AGGIORNAMENTO (3) Il D.L. 14 febbraio 2016, n. 18, convertito con modificazioni dalla L. 8 aprile 2016, n. 49, ha disposto (con l'art. 16, comma 3) che la modifica al comma 958 del presente articolo ha effetto per gli atti emessi dalla data di entrata in vigore del suddetto decreto fino al 31 dicembre 2016. ------------- AGGIORNAMENTO (7) Il D.L. 24 giugno 2016, n. 113, convertito con modificazioni dalla L. 7 agosto 2016, n. 160, ha disposto: - (con l'art. 7-bis, comma 2) che "Nel rispetto degli equilibri di finanza pubblica, limitatamente all'anno 2016, le risorse di cui all'articolo 1, comma 656, della legge 28 dicembre 2015, n. 208, sono assegnate alle province delle regioni a statuto ordinario per l'attivita' di manutenzione straordinaria della relativa rete viaria"; - (con l'art. 8, comma 1-ter) che "Per l'anno 2016, l'ammontare del contributo di cui al comma 754 dell'articolo 1 della legge 28 dicembre 2015, n. 208, a favore di ciascuna provincia e citta' metropolitana delle regioni a statuto ordinario e' stabilito negli importi indicati nella tabella 2 allegata al presente decreto"; - (con l'art. 8, comma 1-quater) che "Per l'anno 2016, l'ammontare della quota del 66 per cento del fondo di cui al comma 764 dell'articolo 1 della legge 28 dicembre 2015, n. 208, a favore di ciascuna provincia delle regioni a statuto ordinario e' stabilito negli importi indicati nella tabella 3 allegata al presente decreto". ------------- AGGIORNAMENTO (11) Il D.Lgs. 29 ottobre 2016, n. 221 ha disposto (con l'art. 8, comma 1) che le modifiche apportate al comma 621, lettere d) e d-bis), del presente articolo decorrono dal primo giorno del secondo mese successivo all'entrata in vigore del suddetto decreto legislativo. Ha inoltre disposto (con l'art. 9, comma 2) che "L'efficacia del presente decreto, limitatamente alle disposizioni che prevedono agevolazioni alle imprese, e' subordinata alla previa autorizzazione da parte della Commissione europea, ai sensi dell'articolo 108, paragrafo 3, del Trattato sul funzionamento dell'Unione europea, in materia di aiuti di Stato". ------------- AGGIORNAMENTO (14) La L. 11 dicembre 2016, n. 232 ha disposto: - (con l'art. 1, comma 8) che "Le disposizioni dell'articolo 1, comma 91, della legge 28 dicembre 2015, n. 208, si applicano anche agli investimenti in beni materiali strumentali nuovi, esclusi i veicoli e gli altri mezzi di trasporto di cui all'articolo 164, comma 1, lettere b) e b-bis), del testo unico delle imposte sui redditi, di cui al decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, effettuati entro il 31 dicembre 2017, ovvero entro il 30 giugno 2018 a condizione che entro la data del 31 dicembre 2017 il relativo ordine risulti accettato dal venditore e sia avvenuto il pagamento di acconti in misura almeno pari al 20 per cento del costo di acquisizione"; - (con l'art. 1, comma 87) che "Per le finalita' di cui al comma 86 del presente articolo, il Fondo di cui all'articolo 1, comma 312, della legge 28 dicembre 2015, n. 208, e' integrato di euro 3 milioni per l'anno 2017"; - (con l'art. 1, comma 144) che "Per lo sviluppo del sistema nazionale di ciclovie turistiche di cui all'articolo 1, comma 640, primo periodo, della legge 28 dicembre 2015, n. 208, e' autorizzata l'ulteriore spesa di 13 milioni di euro per l'anno 2017, di 30 milioni di euro per l'anno 2018 e di 40 milioni di euro per ciascuno degli anni dal 2019 al 2024"; - (con l'art. 1, comma 233) che "L'autorizzazione di spesa di cui all'articolo 1, comma 284, quinto periodo, della legge 28 dicembre 2015, n. 208, e' ridotta di 100 milioni di euro per l'anno 2017 e di 50 milioni di euro per l'anno 2018 e, conseguentemente, le somme versate in entrata al bilancio dello Stato ai sensi dell'undicesimo periodo del medesimo comma 284, in misura pari a 120 milioni di euro per l'anno 2017 e a 60 milioni di euro per l'anno 2018, sono trasferite all'INPS a copertura dei maggiori oneri derivanti dallo stesso comma 284 nella misura di 20 milioni di euro per l'anno 2017 e di 10 milioni di euro per l'anno 2018 e rimangono acquisite al bilancio dello Stato per l'importo di 100 milioni di euro per l'anno 2017 e di 50 milioni di euro per l'anno 2018"; - (con l'art. 1, comma 238) che "Lo stanziamento del Fondo per la lotta alla poverta' e all'esclusione sociale, di cui all'articolo 1, comma 386, della legge 28 dicembre 2015, n. 208, e' incrementato di 150 milioni di euro annui a decorrere dall'anno 2017"; - (con l'art. 1, comma 354) che "L'applicazione delle disposizioni concernenti il congedo obbligatorio per il padre lavoratore dipendente, da fruire entro i cinque mesi dalla nascita del figlio, introdotte in via sperimentale per gli anni 2013, 2014 e 2015 dall'articolo 4, comma 24, lettera a), della legge 28 giugno 2012, n. 92, nonche', per l'anno 2016, dall'articolo 1, comma 205, della legge 28 dicembre 2015, n. 208, e' prorogata anche per gli anni 2017 e 2018. La durata del congedo obbligatorio per il padre lavoratore dipendente e' aumentata a due giorni per l'anno 2017 e a quattro giorni per l'anno 2018, che possono essere goduti anche in via non continuativa; al medesimo congedo si applica la disciplina di cui al decreto del Ministro del lavoro e delle politiche sociali 22 dicembre 2012, pubblicato nella Gazzetta Ufficiale n. 37 del 13 febbraio 2013. Per l'anno 2018 il padre lavoratore dipendente puo' astenersi per un periodo ulteriore di un giorno previo accordo con la madre e in sua sostituzione in relazione al periodo di astensione obbligatoria spettante a quest'ultima"; - (con l'art. 1, comma 360) che "Le risorse del Fondo per la cura dei soggetti con disturbo dello spettro autistico, di cui all'articolo 1, comma 401, della legge 28 dicembre 2015, n. 208, non utilizzate per l'anno 2016 confluiscono per l'anno 2017 nel Fondo medesimo"; - (con l'art. 1, comma 391) che "Le disposizioni di cui ai commi da 524 a 536 dell'articolo 1 della legge 28 dicembre 2015, n. 208, si applicano alle regioni a statuto speciale e alle province autonome di Trento e di Bolzano, che provvedono al finanziamento del servizio sanitario esclusivamente con risorse dei propri bilanci, compatibilmente con le disposizioni dei rispettivi statuti e delle conseguenti norme di attuazione"; - (con l'art. 1, comma 463) che "A decorrere dall'anno 2017 cessano di avere applicazione i commi da 709 a 712 e da 719 a 734 dell'articolo 1 della legge 28 dicembre 2015, n. 208. Restano fermi gli adempimenti degli enti territoriali relativi al monitoraggio e alla certificazione del saldo di cui all'articolo 1, comma 710, della legge 28 dicembre 2015, n. 208, nonche' l'applicazione delle sanzioni in caso di mancato conseguimento del saldo 2016, di cui al medesimo comma 710, accertato ai sensi dei commi da 720 a 727 dell'articolo 1 della legge 28 dicembre 2015, n. 208. Sono fatti salvi gli effetti connessi all'applicazione nell'anno 2016 dei patti di solidarieta' di cui ai commi da 728 a 732 dell'articolo 1 della legge 28 dicembre 2015, n. 208"; - (con l'art. 1, comma 479, lettera d)) che "Ai sensi dell'articolo 9, comma 4, della legge 24 dicembre 2012, n. 243, a decorrere dall'anno 2018, con riferimento ai risultati dell'anno precedente e a condizione del rispetto dei termini perentori di certificazione di cui ai commi 470 e 473: [...] d) per i comuni che rispettano il saldo di cui al comma 466, lasciando spazi finanziari inutilizzati inferiori all'1 per cento degli accertamenti delle entrate finali dell'esercizio nel quale e' rispettato il medesimo saldo, nell'anno successivo la percentuale stabilita al primo periodo del comma 228 dell'articolo 1 della legge 28 dicembre 2015, n. 208, e' innalzata al 75 per cento qualora il rapporto dipendenti-popolazione dell'anno precedente sia inferiore al rapporto medio dipendenti-popolazione per classe demografica, come definito triennalmente con il decreto del Ministro dell'interno di cui all'articolo 263, comma 2, del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267"; - (con l'art. 1, comma 565) che "Le disposizioni dell'articolo 1, commi da 115 a 120, della legge 28 dicembre 2015, n. 208, si applicano anche alle assegnazioni, trasformazioni e cessioni poste in essere successivamente al 30 settembre 2016 ed entro il 30 settembre 2017. I versamenti rateali dell'imposta sostitutiva di cui al comma 120 del citato articolo 1 della legge n. 208 del 2015 sono effettuati, rispettivamente, entro il 30 novembre 2017 ed entro il 16 giugno 2018"; - (con l'art. 1, comma 566) che "Le disposizioni dell'articolo 1, comma 121, della legge 28 dicembre 2015, n. 208, si applicano anche alle esclusioni dal patrimonio dell'impresa dei beni ivi indicati, posseduti alla data del 31 ottobre 2016, poste in essere dal 1º gennaio 2017 al 31 maggio 2017. I versamenti rateali dell'imposta sostitutiva di cui al comma 121 del citato articolo 1 della legge n. 208 del 2015 sono effettuati, rispettivamente, entro il 30 novembre 2017 e il 16 giugno 2018. Per i soggetti che si avvalgono della presente disposizione gli effetti dell'estromissione decorrono dal 1º gennaio 2017"; - (con l'art. 1, comma 590) che "Al fine di assicurare il sostegno alle famiglie che hanno concluso le procedure di adozione internazionale, il Fondo per le adozioni internazionali, di cui al comma 411 dell'articolo 1 della legge 28 dicembre 2015, n. 208, e' incrementato di 5 milioni di euro per l'anno 2017"; - (con l'art. 1, comma 612) che "Al fine di assicurare il sostegno alle aziende sequestrate e confiscate alla criminalita' organizzata l'autorizzazione di spesa di cui al comma 195 dell'articolo 1 della legge 28 dicembre 2015, n. 208, e' incrementata di ulteriori 10 milioni di euro per l'anno 2019, incremento che confluisce nelle apposite sezioni dei Fondi di cui al comma 196 del citato articolo 1 della legge n. 208 del 2015, con le modalita' dallo stesso riportate e con la medesima ripartizione delle risorse tra le sezioni"; - (con l'art. 1, comma 613) che "Al fine di realizzare un Piano strategico nazionale della mobilita' sostenibile destinato al rinnovo del parco degli autobus dei servizi di trasporto pubblico locale e regionale, alla promozione e al miglioramento della qualita' dell'aria con tecnologie innovative, in attuazione degli accordi internazionali nonche' degli orientamenti e della normativa dell'Unione europea, il Fondo di cui all'articolo 1, comma 866, della legge 28 dicembre 2015, n. 208, e' incrementato di 200 milioni di euro per l'anno 2019 e di 250 milioni di euro per ciascuno degli anni dal 2020 al 2033. Per la promozione dello sviluppo e della diffusione di autobus ad alimentazione alternativa, il Fondo puo' essere destinato anche al finanziamento delle relative infrastrutture tecnologiche di supporto. Nell'ambito del Piano strategico nazionale e' previsto un programma di interventi finalizzati ad aumentare la competitivita' delle imprese produttrici di beni e di servizi nella filiera dei mezzi di trasporto pubblico su gomma e dei sistemi intelligenti per il trasporto, attraverso il sostegno agli investimenti produttivi finalizzati alla transizione verso forme produttive piu' moderne e sostenibili, con particolare riferimento alla ricerca e allo sviluppo di modalita' di alimentazione alternativa, per il quale e' autorizzata la spesa di 2 milioni di euro per l'anno 2017 e di 50 milioni di euro per ciascuno degli anni 2018 e 2019"; - (con l'art. 1, comma 626) che "Le disposizioni di cui all'articolo 1, comma 979, della legge 28 dicembre 2015, n. 208, trovano applicazione nei termini ivi previsti anche con riferimento ai soggetti che compiono diciotto anni di eta' nell'anno 2017, i quali possono utilizzare la Carta elettronica di cui al citato comma 979, anche per l'acquisto di musica registrata, nonche' di corsi di musica, di teatro o di lingua straniera". Il D.L. 14 febbraio 2016, n. 18, convertito con modificazioni dalla L. 8 aprile 2016, n. 49, come modificato dalle L. 11 dicembre 2016, n. 232, ha disposto (con l'art. 16, comma 3) che la modifica apportata al comma 958 del presente articolo ha effetto per gli atti emessi dalla data di entrata in vigore del suddetto decreto fino al 30 giugno 2017. ------------- AGGIORNAMENTO (15) Il D.L. 30 dicembre 2016, n. 244, convertito con modificazioni dalla L. 27 febbraio 2017, n. 19, ha disposto: - (con l'art. 3, comma 3-octies) che "Ai fini della prosecuzione della sperimentazione relativa al riconoscimento della indennita' di disoccupazione mensile denominata DIS-COLL, di cui all'articolo 15 del decreto legislativo 4 marzo 2015, n. 22, le disposizioni di cui all'articolo 1, comma 310, della legge 28 dicembre 2015, n. 208, sono prorogate fino al 30 giugno 2017, in relazione agli eventi di disoccupazione verificatisi a decorrere dal 1º gennaio 2017 e sino al 30 giugno 2017, nel limite di 19,2 milioni di euro per l'anno 2017. Al relativo onere, pari a 19,2 milioni di euro per l'anno 2017, si provvede mediante corrispondente riduzione dell'autorizzazione di spesa di cui all'articolo 43, comma 6, del decreto legislativo 14 settembre 2015, n. 148"; - (con l'art. 4, comma 5) che "Il termine del 31 dicembre 2016 di cui all'articolo 1, comma 215, della legge 28 dicembre 2015, n. 208, relativo alle previsioni di cui all'articolo 6, comma 6-bis, del decreto-legge 31 dicembre 2014, n. 192, convertito, con modificazioni, dalla legge 27 febbraio 2015, n. 11 e' differito al 31 dicembre 2017"; - (con l'art. 9, comma 8) che "E' prorogato al 31 dicembre 2017 il termine di cui all'articolo 1, comma 807, della legge 28 dicembre 2015, n. 208, qualora il procedimento di progettazione e realizzazione delle opere sia stato avviato in vigenza del decreto legislativo 12 aprile 2006, n. 163 e che al 31 dicembre 2016 abbia conseguito l'adozione di variante urbanistica e la conclusione favorevole delle procedure di VAS o VIA. Conseguentemente, in relazione a quanto previsto dal presente comma, i termini di cui al primo e al secondo periodo dall'articolo 1, comma 808, della legge 28 dicembre 2015, n. 208, sono rispettivamente prorogati al 30 giugno 2017 e al semestre 1° luglio-31 dicembre 2017"; - (con l'art. 14, comma 5-bis) che "Per gli enti locali colpiti dal sisma del 20 e 29 maggio 2012, individuati ai sensi dell'articolo 1, comma 1, del decreto-legge 6 giugno 2012, n. 74, convertito, con modificazioni, dalla legge 1° agosto 2012, n. 122, e dell'articolo 67-septies del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134, e' prorogata all'anno 2018 la sospensione, prevista dal comma 456 dell'articolo 1 della legge 28 dicembre 2015, n. 208, degli oneri relativi al pagamento delle rate dei mutui concessi dalla Cassa depositi e prestiti Spa, trasferiti al Ministero dell'economia e delle finanze in attuazione dell'articolo 5, commi 1 e 3, del decreto-legge 30 settembre 2003, n. 269, convertito, con modificazioni, dalla legge 24 novembre 2003, n. 326, da corrispondere nell'anno 2017, incluse quelle il cui pagamento e' stato differito ai sensi dell'articolo 1, comma 426, della legge 24 dicembre 2012, n. 228, dell'articolo 1, comma 356, della legge 27 dicembre 2013, n. 147, e dell'articolo 1, comma 503, della legge 23 dicembre 2014, n. 190". ------------- AGGIORNAMENTO (18) Il D.L. 24 aprile 2017, n. 50, convertito con modificazioni dalla L. 21 giugno 2017, n. 96, ha disposto: -(con l'art. 4, comma 7) che "A decorrere dall'anno 2017 gli enti che hanno facolta' di applicare l'imposta di soggiorno ai sensi dell'articolo 4 del decreto legislativo 14 marzo 2011, n. 23, e il contributo di soggiorno di cui all'articolo 14, comma 16, lettera e), del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, possono, in deroga all'articolo 1, comma 26, della legge 28 dicembre 2015, n. 208, e all'articolo 1, comma 169, della legge 27 dicembre 2006, n. 296, istituire o rimodulare l'imposta di soggiorno e il contributo di soggiorno medesimi"; -(con l'art. 12, comma 1) che "Per conseguire il pieno utilizzo delle risorse stanziate per il credito d'imposta concesso alle imprese che effettuano l'acquisizione dei beni strumentali nuovi destinati a strutture produttive secondo le nuove modalita' e le procedure indicate dall'articolo 1, commi da 98 a 107, della legge 28 dicembre 2015, n. 208, l'autorizzazione di spesa di cui all'articolo 1, comma 108, della medesima legge n. 208 del 2015, e' rimodulata, per gli anni 2017-2019, in 507 milioni di euro per l'anno 2017 e in 672 milioni di euro per ciascuno degli anni 2018 e 2019"; -(con l'art. 46-sexies, comma 1) che "Le agevolazioni di cui ai commi da 445 a 453 dell'articolo 1 della legge 28 dicembre 2015, n. 208, sono prorogate fino al 31 dicembre 2017"; -(con l'art. 55, comma 2) che "La disposizione di cui al comma 1 opera per i premi e le somme erogate in esecuzione dei contratti di cui all'articolo 1, comma 187, della legge 28 dicembre 2015, n. 208, sottoscritti successivamente alla data di entrata in vigore del presente decreto. Per i contratti stipulati anteriormente a tale data continuano ad applicarsi le disposizioni gia' vigenti alla medesima data". La L. 11 dicembre 2016, n. 232 come modificata dal D.L. 24 aprile 2017, n. 50, ha disposto (con l'art. 1, comma 462-bis) che "Le disposizioni di cui all'articolo 1, comma 758, della legge 28 dicembre 2015, n. 208, si applicano anche con riferimento all'esercizio finanziario 2017, tenuto conto degli avanzi di amministrazione vincolati e dei rendiconti relativi all'anno 2016". Ha inoltre disposto (con l'art. 1, comma 479, lettera d)) che "Ai sensi dell'articolo 9, comma 4, della legge 24 dicembre 2012, n. 243, a decorrere dall'anno 2018, con riferimento ai risultati dell'anno precedente e a condizione del rispetto dei termini perentori di certificazione di cui ai commi 470 e 473: [...] d) per i comuni che rispettano il saldo di cui al comma 466, lasciando spazi finanziari inutilizzati inferiori all'1 per cento degli accertamenti delle entrate finali dell'esercizio nel quale e' rispettato il medesimo saldo, nell'anno successivo la percentuale stabilita al primo periodo del comma 228 dell'articolo 1 della legge 28 dicembre 2015, n. 208, e' innalzata al 90 per cento qualora il rapporto dipendenti-popolazione dell'anno precedente sia inferiore al rapporto medio dipendenti-popolazione per classe demografica, come definito triennalmente con il decreto del Ministro dell'interno di cui all'articolo 263, comma 2, del testo unico di cui al decreto legislativo 18 agosto 2000, n. 267". ------------- AGGIORNAMENTO (20) Il D.Lgs. 25 maggio 2017, n. 75 ha disposto (con l'art. 20, comma 10) che "Per il personale medico, tecnico-professionale e infermieristico del Servizio sanitario nazionale, continuano ad applicarsi le disposizioni di cui all'articolo 1, comma 543, della legge 28 dicembre 2015, n. 208, la cui efficacia e' prorogata al 31 dicembre 2018 per l'indizione delle procedure concorsuali straordinarie, al 31 dicembre 2019 per la loro conclusione, e al 31 ottobre 2018 per la stipula di nuovi contratti di lavoro flessibile ai sensi dell'articolo 1, comma 542, della legge 28 dicembre 2015, n. 208". --------------- AGGIORNAMENTO (21) La L. 22 maggio 2017, n. 81 ha disposto (con l'art. 25, comma 1) che "L'autorizzazione di spesa di cui all'articolo 1, comma 204, della legge 28 dicembre 2015, n. 208, e' incrementata di 4,5 milioni di euro per l'anno 2017, di 1,9 milioni di euro per l'anno 2018 e di 4,5 milioni di euro annui a decorrere dall'anno 2019". --------------- AGGIORNAMENTO (22) Il D.Lgs. 29 maggio 2017, n. 94 ha disposto (con l'art. 10, comma 17) che "Il contributo straordinario di cui all'articolo 1, comma 972, della legge 28 dicembre 2015, n. 208, come prorogato dal decreto del Presidente del Consiglio dei Ministri adottato ai sensi dell'articolo 1, comma 365, lettera c), della legge 11 dicembre 2016, n. 232, cessa di essere corrisposto alla data del 30 settembre 2017. Ai volontari in ferma prefissata, ai graduati, ai sergenti, ai marescialli nonche' agli ufficiali con meno di tredici anni di servizio dal conseguimento della nomina ad ufficiale o della qualifica di aspirante, in servizio al 30 settembre 2017, e' corrisposto un assegno lordo una tantum pari ad euro 350,00". --------------- AGGIORNAMENTO (23) Il D.Lgs. 29 maggio 2017, n. 95 ha disposto (con l'art. 45, comma 1) che "Il contributo straordinario di cui all'articolo 1, comma 972, della legge 28 dicembre 2015, n. 208, come prorogato dal decreto del Presidente del consiglio dei ministri del 27 febbraio 2017, adottato ai sensi dell'articolo 1, comma 365, lettera c), della legge 11 dicembre 2016, n. 232, cessa di essere corrisposto alla data del 30 settembre 2017 e, al personale in servizio alla medesima data, e' corrisposto l'assegno lordo una tantum di cui alla tabella E". --------------- AGGIORNAMENTO (24) Il D.Lgs. 29 maggio 2017, n. 97 ha disposto (con l'art. 15, comma 3) che "Il contributo straordinario di cui all'articolo 1, comma 972, della legge 28 dicembre 2015, n. 208, come prorogato dal decreto del Presidente del Consiglio dei ministri, adottato ai sensi dell'articolo 1, comma 365, lettera c), della legge 11 dicembre 2016, n. 232, cessa di essere corrisposto al personale del Corpo nazionale dei vigili del fuoco alla data del 30 settembre 2017. Al medesimo personale in servizio al 1° ottobre 2017 e' corrisposto una tantum un assegno di euro 350". ------------- AGGIORNAMENTO (25) La Corte Costituzionale, con sentenza 3 -14 luglio 2017, n. 191, (in G.U. 1ª s.s. 19/07/2017, n. 29), ha dichiarato "l'illegittimita' costituzionale dell'art. 1, comma 219, della legge 28 dicembre 2015, n. 208, recante «Disposizioni per la formazione del bilancio annuale e pluriennale dello Stato (legge di stabilita' 2016)», nella parte in cui si applica anche alle amministrazioni delle Regioni e delle Province autonome di Trento e di Bolzano". ------------- AGGIORNAMENTO (26) La Corte Costituzionale, con sentenza 20 giugno -14 luglio 2017, n. 192 (in G.U. 1ª s.s. 19/0/2017, n. 29), ha dichiarato "l'illegittimita' costituzionale dell'art. 1, commi 526 e 536, della legge 28 dicembre 2015, n. 208, recante «Disposizioni per la formazione del bilancio annuale e pluriennale dello Stato (legge di stabilita' 2016)», nella parte in cui prevedono che i decreti ministeriali ivi contemplati siano emanati «sentita la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano», anziche' d'intesa con la stessa Conferenza". Ha inoltre dichiarato "l'illegittimita' costituzionale dell'art. 1, commi 524, 525 e 529, della legge n. 208 del 2015, nella parte in cui prevedono che i provvedimenti ivi contemplati siano adottati dalla Giunta regionale". ------------- AGGIORNAMENTO (28) Il D.Lgs. 15 settembre 2017, n. 147 ha disposto: - (con l'art. 17, comma 1) che "A far data dal 1° gennaio 2018, il SIA non e' piu' riconosciuto"; - (con l'art. 17, comma 2) che "Per coloro ai quali il SIA sia stato riconosciuto in data anteriore al 1° gennaio 2018, il beneficio continua ad essere erogato per la durata e secondo le modalita' stabilite dal decreto di cui all'articolo 1, comma 387, lettera a), della legge n. 208 del 2015, come modificato dal decreto di cui all'articolo 1, comma 239, della legge 11 dicembre 2016, n. 232, fatta salva la possibilita' di richiedere il ReI con le modalita' di cui al comma 3. Ai soggetti di cui al presente comma e' consentita la possibilita' di prelievi di contante entro il limite mensile di cui all'articolo 9, comma 7"; - (con l'art. 19, comma 2) che "Per effetto delle previsioni di cui al comma 1, i risparmi a valere sulle risorse attribuite al Fondo carta acquisti dall'articolo 1, comma 156, della legge 23 dicembre 2014, n. 190, confluiscono nel Fondo Poverta' che e' conseguentemente integrato per 55 milioni di euro nel 2018 e per 93 milioni di euro annui a decorrere dal 2019"; - (con l'art. 20, comma 1) che "Per gli effetti degli articoli 18 e 19, la dotazione del Fondo Poverta' e' rideterminata in 1.759 milioni di euro nel 2018, di cui 15 milioni di euro accantonati ai sensi dell'articolo 18, comma 3, in 1.845 milioni di euro annui a decorrere dal 2019. Ai fini dell'erogazione del beneficio economico del ReI di cui all'articolo 4, i limiti di spesa sono determinati in 1.482 milioni di euro nel 2018, fatto salvo l'eventuale disaccantonamento delle somme di cui all'articolo 18, comma 3, e in 1.568 milioni di euro annui a decorrere dal 2019". ------------- AGGIORNAMENTO (30) La Corte Costituzionale, con sentenza 26 settembre - 2 novembre 2017, n. 231 (in G.U. 1ª s.s. 08/11/2017, n. 45), ha dichiarato "l'illegittimita' costituzionale dell'art. 1, comma 541, lettera a), della legge 28 dicembre 2015, n. 208, recante «Disposizioni per la formazione del bilancio annuale e pluriennale dello Stato (Legge di stabilita' 2016)», nella parte in cui si applica alle Province autonome di Trento e di Bolzano" e "l'illegittimita' costituzionale dell'art. 1, comma 574, lettera b), della legge n. 208 del 2015, nella parte in cui impone alle Province autonome di Trento e di Bolzano di adottare misure alternative al fine di garantire, in ogni caso, l'invarianza dell'effetto finanziario". ------------- AGGIORNAMENTO (29) Il D.L. 16 ottobre 2017, n. 148, convertito con modificazioni dalla L. 4 dicembre 2017, n. 172, ha disposto (con l'art. 2, comma 8) che "Il Fondo di cui all'articolo 1, comma 430, della legge 28 dicembre 2015, n. 208, e' ridotto di 100 milioni di euro per l'anno 2018". ------------- AGGIORNAMENTO (31) La L. 27 dicembre 2017, n. 205 ha disposto: - (con l'art. 1, comma 86) che le modifiche di cui ai commi 65 e 67 del presente articolo si applicano a decorrere dal periodo d'imposta successivo a quello in corso al 31 dicembre 2016; - (con l'art. 1, comma 196) che "Per le finalita' di cui ai commi da 190 a 195, lo stanziamento del Fondo per la lotta alla poverta' e all'esclusione sociale, di cui all'articolo 1, comma 386, della legge 28 dicembre 2015, n. 208, e' incrementato di 300 milioni di euro nell'anno 2018, di 700 milioni di euro nell'anno 2019, di 783 milioni di euro nell'anno 2020 e di 755 milioni di euro annui a decorrere dall'anno 2021. Lo stanziamento del medesimo Fondo e' altresi' incrementato di ulteriori 117 milioni di euro nell'anno 2020 e di 145 milioni di euro annui a decorrere dall'anno 2021 per le finalita' da individuare con il Piano nazionale per la lotta alla poverta' e all'esclusione sociale, di cui all'articolo 8 del decreto legislativo 15 settembre 2017, n. 147"; - (con l'art. 1, comma 719) che "Le agevolazioni di cui ai commi da 445 a 453 dell'articolo 1 della legge 28 dicembre 2015, n. 208, sono prorogate fino al 31 dicembre 2019"; - (con l'art. 1, comma 776) che "Il concorso alla finanza pubblica delle regioni a statuto ordinario, per il settore non sanitario, di cui all'articolo 46, comma 6, del decreto-legge 24 aprile 2014, n. 66, convertito, con modificazioni, dalla legge 23 giugno 2014, n. 89, e di cui all'articolo 1, comma 680, della legge 28 dicembre 2015, n. 208, e ripartito secondo i criteri di cui all'articolo 1, comma 534-ter, della legge 11 dicembre 2016, n. 232, e' ridotto di 300 milioni di euro per l'anno 2018 e di 200 milioni di euro per ciascuno degli anni 2019 e 2020"; - (con l'art. 1, comma 892) che "L'autorizzazione di spesa di cui all'articolo 1, comma 108, della legge 28 dicembre 2015, n. 208, relativa al credito d'imposta concesso alle imprese che effettuano l'acquisizione di beni strumentali nuovi destinati a strutture produttive secondo le modalita' e le procedure indicate dall'articolo 1, commi da 98 a 107, della legge 28 dicembre 2015, n. 208, e' incrementata per un importo pari a 200 milioni di euro per l'anno 2018 e a 100 milioni di euro per l'anno 2019"; - (con l'art. 1, comma 896) che "La ripartizione delle risorse, definita all'articolo 1, comma 812, della legge 28 dicembre 2015, n. 208, e' modificata come segue: 16 milioni di euro per l'anno 2015, 60 milioni di euro per l'anno 2016, 94 milioni di euro per l'anno 2017, 20 milioni di euro per l'anno 2018, 30 milioni di euro per l'anno 2019, 30 milioni di euro per l'anno 2020 e 31,18 milioni di euro per l'anno 2021"; - (con l'art. 1, comma 1041) che "L'autorizzazione di spesa di cui all'articolo 1, comma 167, della legge 28 dicembre 2015, n. 208, e' ridotta di 572.000 euro annui per il periodo 2018-2022". La L. 27 dicembre 2017, n. 205, nel modificare l'art. 14, comma 5-bis del D.L. 30 dicembre 2016, n. 244, convertito con modificazioni dalla L. 27 febbraio 2017, n. 19, ha conseguentemente disposto (con l'art. 1, comma 729) che "Per gli enti locali colpiti dal sisma del 20 e 29 maggio 2012, individuati ai sensi dell'articolo 1, comma 1, del decreto-legge 6 giugno 2012, n. 74, convertito, con modificazioni, dalla legge 1º agosto 2012, n. 122, e dell'articolo 67-septies del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134, e' prorogata all'anno 2019 la sospensione, prevista dall'articolo 14, comma 5-bis, del decreto-legge 30 dicembre 2016, n. 244, convertito, con modificazioni, dalla legge 27 febbraio 2017, n. 19, degli oneri relativi al pagamento delle rate dei mutui concessi dalla Cassa depositi e prestiti Spa, trasferiti al Ministero dell'economia e delle finanze in attuazione dell'articolo 5, commi 1 e 3, del decreto-legge 30 settembre 2003, n. 269, convertito, con modificazioni, dalla legge 24 novembre 2003, n. 326, da corrispondere nell'anno 2018, incluse quelle il cui pagamento e' stato differito ai sensi dell'articolo 1, comma 426, della legge 24 dicembre 2012, n. 228, dell'articolo 1, comma 356, della legge 27 dicembre 2013, n. 147, e dell'articolo 1, comma 503, della legge 23 dicembre 2014, n. 190". La L. 11 dicembre 2016, n. 232, come modificata dalla L. 27 dicembre 2017, n. 205, ha disposto (con l'art. 1, comma 87) che "Per le finalita' di cui al comma 86 del presente articolo, il Fondo di cui all'articolo 1, comma 312, della legge 28 dicembre 2015, n. 208, e' integrato di euro 3 milioni per gli anni 2017, 2018 e 2019". -------------- AGGIORNAMENTO (34) La L. 11 dicembre 2016, n. 232, come modificata dal D.L. 25 luglio 2018, n. 91, convertito con modificazioni dalla L. 21 settembre 2018, n. 108, ha disposto (con l'art. 1, comma 626) che "Le disposizioni di cui all'articolo 1, comma 979, della legge 28 dicembre 2015, n. 208, trovano applicazione nei termini ivi previsti anche con riferimento ai soggetti che compiono diciotto anni di eta' nell'anno 2017 e nell'anno 2018, i quali possono utilizzare la Carta elettronica di cui al citato comma 979, anche per l'acquisto di musica registrata, nonche' di corsi di musica, di teatro o di lingua straniera". -------------- AGGIORNAMENTO (35) La Corte Costituzionale, con sentenza 3 - 20 luglio 2018, n. 167 (in G.U. 1ª s.s. 25/07/2018, n. 30), ha dichiarato "l'illegittimita' costituzionale dell'art. 1, comma 478, della legge 28 dicembre 2015, n. 208, recante «Disposizioni per la formazione del bilancio annuale e pluriennale dello Stato (legge di stabilita' 2016)»". -------------- AGGIORNAMENTO (36) Il D.Lgs. 2 ottobre 2018, n. 124 ha disposto (con l'art. 2, comma 2) che "Il Fondo di cui all'articolo 1, comma 312, della legge 28 dicembre 2015, n. 208, e' integrato dell'importo di 3.000.000 di euro annui a decorrere dal 2020, anche per le finalita' connesse alla copertura degli obblighi assicurativi contro le malattie e gli infortuni, in favore dei detenuti e degli internati impegnati in lavori di pubblica utilita' ai sensi dell'articolo 20-ter della legge 26 luglio 1975, n. 354". -------------- AGGIORNAMENTO (38) La L. 30 dicembre 2018, n. 145 ha disposto: - (con l'art. 1, comma 66) che "Le disposizioni dell'articolo 1, comma 121, della legge 28 dicembre 2015, n. 208, si applicano anche alle esclusioni dal patrimonio dell'impresa dei beni ivi indicati, posseduti alla data del 31 ottobre 2018, poste in essere dal 1° gennaio 2019 al 31 maggio 2019. I versamenti rateali dell'imposta sostitutiva di cui al citato comma 121 dell'articolo 1 della legge n. 208 del 2015 sono effettuati, rispettivamente, entro il 30 novembre 2019 e il 16 giugno 2020. Per i soggetti che si avvalgono delle disposizioni del presente comma, gli effetti dell'estromissione decorrono dal 1° gennaio 2019"; - (con l'art. 1, comma 406) che "Il contributo di cui all'articolo 1, comma 385, lettera h), della legge 28 dicembre 2015, n. 208, in favore della Fondazione « I Lincei per la scuola » presso l'Accademia nazionale dei Lincei e' prorogato per l'anno 2019"; - (con l'art. 1, comma 478) che "Il Fondo per il contrasto della poverta' educativa minorile di cui all'articolo 1, comma 392, della legge 28 dicembre 2015, n. 208, e' prorogato per gli anni 2019, 2020 e 2021"; - (con l'art. 1, comma 521) che "Al fine di aumentare il numero dei contratti di formazione specialistica dei medici, di cui all'articolo 37 del decreto legislativo 17 agosto 1999, n. 368, l'autorizzazione di spesa di cui all'articolo 1, comma 424, della legge 27 dicembre 2013, n. 147, e all'articolo 1, comma 252, della legge 28 dicembre 2015, n. 208, e' ulteriormente incrementata di 22,5 milioni di euro per l'anno 2019, di 45 milioni di euro per l'anno 2020, di 68,4 milioni di euro per l'anno 2021, di 91,8 milioni di euro per l'anno 2022 e di 100 milioni di euro annui a decorrere dall'anno 2023". La L. 11 dicembre 2016, n. 232, come modificata dalla L. 30 dicembre 2018, n. 145, ha disposto (con l'art. 1, comma 354) che "L'applicazione delle disposizioni concernenti il congedo obbligatorio per il padre lavoratore dipendente, da fruire entro i cinque mesi dalla nascita del figlio, introdotte in via sperimentale per gli anni 2013, 2014 e 2015 dall'articolo 4, comma 24, lettera a), della legge 28 giugno 2012, n. 92, nonche', per l'anno 2016, dall'articolo 1, comma 205, della legge 28 dicembre 2015, n. 208, e' prorogata anche per gli anni 2017, 2018 e 2019. La durata del congedo obbligatorio per il padre lavoratore dipendente e' aumentata a due giorni per l'anno 2017, a quattro giorni per l'anno 2018 e a cinque giorni per l'anno 2019, che possono essere goduti anche in via non continuativa; al medesimo congedo si applica la disciplina di cui al decreto del Ministro del lavoro e delle politiche sociali 22 dicembre 2012, pubblicato nella Gazzetta Ufficiale n. 37 del 13 febbraio 2013. Per gli anni 2018 e 2019 il padre lavoratore dipendente puo' astenersi per un periodo ulteriore di un giorno previo accordo con la madre e in sua sostituzione in relazione al periodo di astensione obbligatoria spettante a quest'ultima". -------------- AGGIORNAMENTO (37) Il D.Lgs. 29 novembre 2018, n. 142 ha disposto (con l'art. 13, comma 6) che "Le disposizioni del Capo III, Sezione II, si applicano a decorrere dal periodo di imposta successivo a quello in corso al 31 dicembre 2018, nonche' agli utili percepiti e alle plusvalenze realizzate a decorrere dal medesimo periodo di imposta". Ha inoltre (con l'art. 13, comma 9) che "Le disposizioni del Capo V si applicano a decorrere dal periodo d'imposta in corso al 31 dicembre 2018". -------------- AGGIORNAMENTO (39) La Corte Costituzionale, con sentenza 5 dicembre 2018 - 14 febbraio 2019, n. 18, (in G.U. 1ª s.s. 20/02/2019, n. 8), ha dichiarato "l'illegittimita' costituzionale dell'art. 1, comma 714, della legge 28 dicembre 2015, n. 208, recante «Disposizioni per la formazione del bilancio annuale e pluriennale dello Stato (legge di stabilita' 2016)», come sostituito dall'art. 1, comma 434, della legge 11 dicembre 2016, n. 232 (Bilancio di previsione dello Stato per l'anno finanziario 2017 e bilancio pluriennale per il triennio 2017-2019)". -------------- AGGIORNAMENTO (43) Il D.L. 24 ottobre 2019, n. 123, convertito con modificazioni dalla L. 12 dicembre 2019, n. 156, ha disposto (con l'art. 9-vicies quater, comma 1) che "Per gli enti locali colpiti dal sisma del 20 e 29 maggio 2012, individuati dall'articolo 2-bis del decreto-legge 16 ottobre 2017, n. 148, convertito, con modificazioni, dalla legge 4 dicembre 2017, n. 172, e' prorogata all'anno 2021 la sospensione, prevista dal comma 456 dell'articolo 1 della legge 28 dicembre 2015, n. 208, come da ultimo prorogata dal comma 1006 dell'articolo 1 della legge 30 dicembre 2018, n. 145, degli oneri relativi al pagamento delle rate dei mutui concessi dalla Cassa depositi e prestiti Spa, trasferiti al Ministero dell'economia e delle finanze in attuazione dell'articolo 5, commi 1 e 3, del decreto-legge 30 settembre 2003, n. 269, convertito, con modificazioni, dalla legge 24 novembre 2003, n. 326, da corrispondere nell'anno 2020, comprese quelle il cui pagamento e' stato differito ai sensi dell'articolo 1, comma 426, della legge 24 dicembre 2012, n. 228, dell'articolo 1, comma 356, della legge 27 dicembre 2013, n. 147, e dell'articolo 1, comma 503, della legge 23 dicembre 2014, n. 190. Gli oneri di cui al periodo precedente sono pagati, senza applicazione di sanzioni e interessi, a decorrere dall'anno 2021, in rate di pari importo per dieci anni, sulla base della periodicita' di pagamento prevista nei provvedimenti e nei contratti regolanti i mutui stessi". -------------- AGGIORNAMENTO (47) La L. 27 dicembre 2019, n. 160 ha disposto: - (con l'art. 1, comma 89) che "Nell'ambito del nuovo quadro finanziario pluriennale 2021-2027 dell'Unione europea, la garanzia dello Stato di cui all'articolo 1, comma 822, della legge 28 dicembre 2015, n. 208, puo' anche essere concessa in complementarita' con la garanzia di bilancio dell'Unione europea a sostegno di prodotti finanziari forniti da partner esecutivi, secondo la normativa europea e nazionale tempo per tempo vigente. Con decreto di natura non regolamentare del Ministro dell'economia e delle finanze, da adottare entro sessanta giorni dalla data di entrata in vigore del regolamento europeo o di altro atto normativo che disciplina tale garanzia di bilancio dell'Unione europea, sono stabiliti criteri, modalita' e condizioni per la concessione della garanzia dello Stato"; - (con l'art. 1, comma 345) che "Il fondo di cui all'articolo 1, comma 411, della legge 28 dicembre 2015, n. 208, e' incrementato di 500.000 euro annui a decorrere dall'anno 2020"; - (con l'art. 1, comma 690) che "Le disposizioni dell'articolo 1, comma 121, della legge 28 dicembre 2015, n. 208, si applicano anche alle esclusioni dal patrimonio dell'impresa dei beni ivi indicati, posseduti alla data del 31 ottobre 2019, poste in essere dal 1° gennaio 2020 al 31 maggio 2020. I versamenti rateali dell'imposta sostitutiva di cui al citato comma 121 dell'articolo 1 della legge n. 208 del 2015 sono effettuati, rispettivamente, entro il 30 novembre 2020 e il 30 giugno 2021. Per i soggetti che si avvalgono delle disposizioni del presente comma gli effetti dell'estromissione decorrono dal 1° gennaio 2020"; - (con l'art. 1, comma 708) che "Sono fatti salvi gli atti ed i procedimenti gia' in essere alla data di entrata in vigore della presente legge ai sensi delle disposizioni modificate dai commi 706 e 707". La L. 27 dicembre 2019, n. 160 nel modificare l'art. 1, comma 521 della L. 30 dicembre 2018, n. 145 ha conseguentemente disposto (con l'art. 1, comma 271) che "Al fine di aumentare il numero dei contratti di formazione specialistica dei medici, di cui all'articolo 37 del decreto legislativo 17 agosto 1999, n. 368, l'autorizzazione di spesa di cui all'articolo 1, comma 521, della legge 30 dicembre 2018, n. 145, e' ulteriormente incrementata di 5,425 milioni di euro per l'anno 2020, 10,850 milioni di euro per l'anno 2021, 16,492 milioni di euro per l'anno 2022, 22,134 milioni di euro per l'anno 2023 e 24,995 milioni di euro a decorrere dall'anno 2024". Il D.Lgs. 25 maggio 2017, n. 75 come modificato dalla L. 27 dicembre 2019, n. 160, ha disposto (con l'art. 20, comma 10) che "Per il personale dirigenziale e non dirigenziale del Servizio sanitario nazionale, continuano ad applicarsi le disposizioni di cui all'articolo 1, comma 543, della legge 28 dicembre 2015, n. 208, la cui efficacia e' prorogata al 31 dicembre 2019 per l'indizione delle procedure concorsuali straordinarie, al 31 dicembre 2020 per la loro conclusione, e al 31 ottobre 2018 per la stipula di nuovi contratti di lavoro flessibile ai sensi dell'articolo 1, comma 542, della legge 28 dicembre 2015, n. 208". La L. 11 dicembre 2016, n. 232 come modificata dalla L. 27 dicembre 2019, n. 160, ha disposto (con l'art. 1, comma 354) che "L'applicazione delle disposizioni concernenti il congedo obbligatorio per il padre lavoratore dipendente, da fruire entro i cinque mesi dalla nascita del figlio, introdotte in via sperimentale per gli anni 2013, 2014 e 2015 dall'articolo 4, comma 24, lettera a), della legge 28 giugno 2012, n. 92, nonche', per l'anno 2016, dall'articolo 1, comma 205, della legge 28 dicembre 2015, n. 208, e' prorogata anche per gli anni 2017, 2018, 2019 e 2020. La durata del congedo obbligatorio per il padre lavoratore dipendente e' aumentata a due giorni per l'anno 2017, a quattro giorni per l'anno 2018, a cinque giorni per l'anno 2019 e a sette giorni per l'anno 2020, che possono essere goduti anche in via non continuativa; al medesimo congedo si applica la disciplina di cui al decreto del Ministro del lavoro e delle politiche sociali 22 dicembre 2012, pubblicato nella Gazzetta Ufficiale n. 37 del 13 febbraio 2013. Per gli anni 2018, 2019 e 2020 il padre lavoratore dipendente puo' astenersi per un periodo ulteriore di un giorno previo accordo con la madre e in sua sostituzione in relazione al periodo di astensione obbligatoria spettante a quest'ultima". -------------- AGGIORNAMENTO (48) Il D.L. 30 dicembre 2019, n. 162, convertito con modificazioni dalla L. 28 febbraio 2020, n. 8, ha disposto (con l'art. 7, comma 10-duodecies) che "Il contributo di cui all'articolo 1, comma 385, lettera h), della legge 28 dicembre 2015, n. 208, in favore della Fondazione "I Lincei per la scuola" presso l'Accademia nazionale dei Lincei e' prorogato per l'anno 2020". Ha inoltre disposto (con l'art. 13, comma 5) che "Le disposizioni di cui all'articolo 1, comma 870, secondo periodo, della legge 28 dicembre 2015, n. 208, relative alla definizione del corrispettivo annuale del contratto di programma tra l'ANAS S.p.a. e il Ministero delle infrastrutture e dei trasporti, si applicano a decorrere dal contratto di programma per gli anni 2021-2025". -------------- AGGIORNAMENTO (51) L'aggiornamento in calce, precedentemente disposto dall'art. 30, comma 1 del D.L. 2 marzo 2020, n. 9 e' stato eliminato; la modifica ha perso efficacia per effetto dell'abrogazione del D.L. medesimo ad opera della L. 24 aprile 2020, n. 27, la quale ne ha contestualmente fatti salvi gli effetti. -------------- AGGIORNAMENTO (54) Il D.L. 14 agosto 2020, n. 104, convertito con modificazioni dalla L. 13 ottobre 2020, n. 126, ha disposto (con l'art. 31-ter, comma 1) che "La dotazione del Fondo per la cura dei soggetti con disturbo dello spettro autistico, di cui all'articolo 1, comma 401, della legge 28 dicembre 2015, n. 208, e' incrementata di 10 milioni di euro per l'anno 2020". Ha inoltre disposto (con l'art. 80, comma 4) che "L'autorizzazione di spesa di cui all'articolo 1, comma 337, della legge 28 dicembre 2015, n. 208, e' rifinanziata, per l'attuazione degli interventi del piano strategico ivi previsto, nella misura di 25 milioni di euro per l'anno 2020". -------------- AGGIORNAMENTO (56) La L. 30 dicembre 2020, n. 178, ha disposto (con l'art. 1, comma 803) che "La dotazione del Fondo per la lotta alla poverta' e all'esclusione sociale, di cui all'articolo 1, comma 386, della legge 28 dicembre 2015, n. 208, e' incrementata di 2 milioni di euro annui a decorrere dall'anno 2021.". La L. 11 dicembre 2016, n. 232, come modificata dalla L. 30 dicembre 2020, n. 178, ha disposto (con l'art. 1, comma 354) che "L'applicazione delle disposizioni concernenti il congedo obbligatorio per il padre lavoratore dipendente, da fruire entro i cinque mesi dalla nascita del figlio, introdotte in via sperimentale per gli anni 2013, 2014 e 2015 dall'articolo 4, comma 24, lettera a), della legge 28 giugno 2012, n. 92, nonche', per l'anno 2016, dall'articolo 1, comma 205, della legge 28 dicembre 2015, n. 208, e' prorogata anche per gli anni 2017, 2018, 2019, 2020 e 2021. La durata del congedo obbligatorio per il padre lavoratore dipendente e' aumentata a due giorni per l'anno 2017, a quattro giorni per l'anno 2018, a cinque giorni per l'anno 2019, a sette giorni per l'anno 2020 e a dieci giorni per l'anno 2021, che possono essere goduti anche in via non continuativa; al medesimo congedo si applica la disciplina di cui al decreto del Ministro del lavoro e delle politiche sociali 22 dicembre 2012, pubblicato nella Gazzetta Ufficiale n. 37 del 13 febbraio 2013. Per gli anni 2018, 2019, 2020 e 2021 il padre lavoratore dipendente puo' astenersi per un periodo ulteriore di un giorno previo accordo con la madre e in sua sostituzione in relazione al periodo di astensione obbligatoria spettante a quest'ultima". -------------- AGGIORNAMENTO (58) Il D.L. 25 maggio 2021, n. 73 ha disposto (con l'art. 63, comma 5) che "Il Fondo per il contrasto della poverta' educativa minorile di cui all'articolo 1, comma 392, della legge 28 dicembre 2015, n. 208, e' prorogato per l'anno 2022". -------------- AGGIORNAMENTO (59) Il D.L. 31 maggio 2021, n. 77, convertito con modificazioni dalla L. 29 luglio 2021, n. 108, ha disposto (con l'art. 64, comma 6-septies) che "Il contributo di cui all'articolo 1, comma 385, lettera h), della legge 28 dicembre 2015, n. 208, in favore della Fondazione "I Lincei per la scuola" presso l'Accademia nazionale dei Lincei e' prorogato per l'anno 2021". -------------- AGGIORNAMENTO (66) La L. 30 dicembre 2021, n. 234 ha disposto (con l'art. 1, comma 136) che "Il Fondo per il contrasto della poverta' educativa minorile di cui all'articolo 1, comma 392, della legge 28 dicembre 2015, n. 208, e' prorogato per gli anni 2023 e 2024". -------------- AGGIORNAMENTO (71) La L. 29 dicembre 2022, n. 197, ha disposto (con l'art. 1, comma 63) che "Per i premi e le somme erogati nell'anno 2023, l'aliquota dell'imposta sostitutiva sui premi di produttivita', di cui all'articolo 1, comma 182, della legge 28 dicembre 2015, n. 208, e' ridotta al 5 per cento"; Ha inoltre disposto (con l'art. 1, comma 767) che "Per gli enti locali colpiti dagli eventi sismici del 20 e 29 maggio 2012, individuati dall'articolo 2-bis, comma 43, del decreto-legge 16 ottobre 2017, n. 148, convertito, con modificazioni, dalla legge 4 dicembre 2017, n. 172, si applica, anche relativamente all'anno 2023, la sospensione prevista dall'articolo 1, comma 456, della legge 28 dicembre 2015, n. 208, come da ultimo prorogata dall'articolo 57, comma 17, del decreto-legge 14 agosto 2020, n. 104, convertito, con modificazioni, dalla legge 13 ottobre 2020, n. 126, degli oneri relativi al pagamento delle rate dei mutui concessi dalla societa' Cassa depositi e prestiti Spa, trasferiti al Ministero dell'economia e delle finanze in attuazione dell'articolo 5, commi 1 e 3, del decreto-legge 30 settembre 2003, n. 269, convertito, con modificazioni, dalla legge 24 novembre 2003, n. 326, da corrispondere nell'anno 2023, compresi quelli il cui pagamento e' stato differito ai sensi dell'articolo 1, comma 426, della legge 24 dicembre 2012, n. 228, dell'articolo 1, comma 356, della legge 27 dicembre 2013, n. 147, e dell'articolo 1, comma 503, della legge 23 dicembre 2014, n. 190". -------------- AGGIORNAMENTO (72) Il D.L. 29 dicembre 2022, n. 198, convertito con modificazioni dalla L. 24 febbraio 2023, n. 14, ha disposto (con l'art. 5, comma 11-ter) che "Al fine di garantire la prosecuzione delle attivita' della Fondazione "I Lincei per la scuola" presso l'Accademia nazionale dei Lincei, la disposizione di cui all'articolo 1, comma 385, lettera h), della legge 28 dicembre 2015, n. 208, in favore della predetta Fondazione, e' prorogata per l'anno 2023. Agli oneri derivanti dal primo periodo, pari a 250.000 euro per l'anno 2023, si provvede mediante corrispondente riduzione dello stanziamento del fondo speciale di parte corrente iscritto, ai fini del bilancio triennale 2023-2025, nell'ambito del programma "Fondi di riserva e speciali" della missione "Fondi da ripartire" dello stato di previsione del Ministero dell'economia e delle finanze per l'anno 2023, allo scopo parzialmente utilizzando l'accantonamento relativo al Ministero dell'istruzione e del merito". -------------- AGGIORNAMENTO (75) Il D.L. 10 maggio 2023, n. 51, convertito con modificazioni dalla L. 3 luglio 2023, n. 87, ha disposto (con l'art. 4, comma 3-novies) che "Al fine di ristorare i comuni, a decorrere dall'anno 2023, delle minori entrate derivanti dagli atti di aggiornamento presentati dal 1° gennaio 2017 al 31 dicembre 2022 ai sensi dell'articolo 1, comma 22, della legge 28 dicembre 2015, n. 208, che abbiano determinato per ciascun comune una riduzione di gettito complessivamente superiore al 40 per cento rispetto a quello derivante applicando le rendite relative agli immobili appartenenti al gruppo catastale D, come risultanti al 31 dicembre 2022 senza tenere conto degli atti di aggiornamento di cui al presente comma, e utilizzando le aliquote applicabili per l'anno 2022, il contributo previsto dall'articolo 1, comma 24, della legge n. 208 del 2015 e' incrementato di 1,5 milioni di euro annui a decorrere dall'anno 2023". -------------- AGGIORNAMENTO (78) Il D.L. 15 settembre 2023, n. 123, convertito con modificazioni dalla L. 13 novembre 2023, n. 159, ha disposto (con l'art. 1, comma 4-bis) che "Al fine di sostenere, nell'ambito del piano straordinario di cui al comma 1, interventi per la realizzazione o riqualificazione di infrastrutture culturali, l'autorizzazione di spesa di cui all'articolo 1, comma 337, della legge 28 dicembre 2015, n. 208, e' incrementata di 12 milioni di euro per l'anno 2023". -------------- AGGIORNAMENTO (81) Il D.L. 30 dicembre 2023, n. 215, ha disposto (con l'art. 5, comma 1) che "Al fine di garantire la prosecuzione delle attivita' della Fondazione "I Lincei per la scuola" presso l'Accademia nazionale dei Lincei, la disposizione di cui all'articolo 1, comma 385, lettera h), della legge 28 dicembre 2015, n. 208, riguardante interventi finanziari a favore degli italiani nel mondo, relativa alla predetta Fondazione, e' prorogata per l'anno 2024. Agli oneri derivanti dal primo periodo, pari a 250.000 euro per l'anno 2024, si provvede mediante corrispondente riduzione delle proiezioni dello stanziamento del fondo speciale di parte corrente iscritto, ai fini del bilancio triennale 2023-2025, nell'ambito del programma "Fondi di riserva e speciali" della missione "Fondi da ripartire" dello stato di previsione del Ministero dell'economia e delle finanze per l'anno 2023, allo scopo parzialmente utilizzando l'accantonamento relativo al Ministero dell'istruzione e del merito". -------------- AGGIORNAMENTO (87) La L. 30 dicembre 2024,n . 207, ha disposto (con l'art. 1, comma 385) che "Per i premi e le somme erogati negli anni 2025, 2026 e 2027, l'aliquota dell'imposta sostitutiva sui premi di produttivita', di cui all'articolo 1, comma 182, della legge 28 dicembre 2015, n. 208, e' ridotta al 5 per cento". -------------- AGGIORNAMENTO (91) La Corte Costituzionale, con sentenza 7 maggio - 10 luglio 2025, n. 104, (in G.U. 1ª s.s. 16/07/2025, n. 29), ha dichiarato "l'illegittimita' costituzionale dell'art. 1, comma 923, primo periodo, della legge 28 dicembre 2015, n. 208, recante «Disposizioni per la formazione del bilancio annuale e pluriennale dello Stato (legge di stabilita' 2016)», nella parte in cui prevede la sanzione amministrativa di euro ventimila per la violazione dell'art. 7, comma 3-quater, del d.l. n. 158 del 2012, come convertito".

